var YR=Object.defineProperty;var KR=(e,t,n)=>t in e?YR(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n;var Ip=(e,t,n)=>KR(e,typeof t!="symbol"?t+"":t,n);function GR(e,t){for(var n=0;n<t.length;n++){const r=t[n];if(typeof r!="string"&&!Array.isArray(r)){for(const a in r)if(a!=="default"&&!(a in e)){const u=Object.getOwnPropertyDescriptor(r,a);u&&Object.defineProperty(e,a,u.get?u:{enumerable:!0,get:()=>r[a]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const a of document.querySelectorAll('link[rel="modulepreload"]'))r(a);new MutationObserver(a=>{for(const u of a)if(u.type==="childList")for(const o of u.addedNodes)o.tagName==="LINK"&&o.rel==="modulepreload"&&r(o)}).observe(document,{childList:!0,subtree:!0});function n(a){const u={};return a.integrity&&(u.integrity=a.integrity),a.referrerPolicy&&(u.referrerPolicy=a.referrerPolicy),a.crossOrigin==="use-credentials"?u.credentials="include":a.crossOrigin==="anonymous"?u.credentials="omit":u.credentials="same-origin",u}function r(a){if(a.ep)return;a.ep=!0;const u=n(a);fetch(a.href,u)}})();function Tr(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}var Lp={exports:{}},To={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var iO;function XR(){if(iO)return To;iO=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,a,u){var o=null;if(u!==void 0&&(o=""+u),a.key!==void 0&&(o=""+a.key),"key"in a){u={};for(var c in a)c!=="key"&&(u[c]=a[c])}else u=a;return a=u.ref,{$$typeof:e,type:r,key:o,ref:a!==void 0?a:null,props:u}}return To.Fragment=t,To.jsx=n,To.jsxs=n,To}var aO;function ZR(){return aO||(aO=1,Lp.exports=XR()),Lp.exports}var T=ZR(),Bp={exports:{}},Ce={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var lO;function QR(){if(lO)return Ce;lO=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),a=Symbol.for("react.profiler"),u=Symbol.for("react.consumer"),o=Symbol.for("react.context"),c=Symbol.for("react.forward_ref"),f=Symbol.for("react.suspense"),d=Symbol.for("react.memo"),m=Symbol.for("react.lazy"),p=Symbol.for("react.activity"),y=Symbol.iterator;function g(L){return L===null||typeof L!="object"?null:(L=y&&L[y]||L["@@iterator"],typeof L=="function"?L:null)}var x={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},w=Object.assign,S={};function O(L,J,D){this.props=L,this.context=J,this.refs=S,this.updater=D||x}O.prototype.isReactComponent={},O.prototype.setState=function(L,J){if(typeof L!="object"&&typeof L!="function"&&L!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,L,J,"setState")},O.prototype.forceUpdate=function(L){this.updater.enqueueForceUpdate(this,L,"forceUpdate")};function _(){}_.prototype=O.prototype;function k(L,J,D){this.props=L,this.context=J,this.refs=S,this.updater=D||x}var M=k.prototype=new _;M.constructor=k,w(M,O.prototype),M.isPureReactComponent=!0;var N=Array.isArray;function C(){}var z={H:null,A:null,T:null,S:null},$=Object.prototype.hasOwnProperty;function H(L,J,D){var oe=D.ref;return{$$typeof:e,type:L,key:J,ref:oe!==void 0?oe:null,props:D}}function P(L,J){return H(L.type,J,L.props)}function F(L){return typeof L=="object"&&L!==null&&L.$$typeof===e}function I(L){var J={"=":"=0",":":"=2"};return"$"+L.replace(/[=:]/g,function(D){return J[D]})}var ee=/\/+/g;function Z(L,J){return typeof L=="object"&&L!==null&&L.key!=null?I(""+L.key):J.toString(36)}function Y(L){switch(L.status){case"fulfilled":return L.value;case"rejected":throw L.reason;default:switch(typeof L.status=="string"?L.then(C,C):(L.status="pending",L.then(function(J){L.status==="pending"&&(L.status="fulfilled",L.value=J)},function(J){L.status==="pending"&&(L.status="rejected",L.reason=J)})),L.status){case"fulfilled":return L.value;case"rejected":throw L.reason}}throw L}function U(L,J,D,oe,ye){var ve=typeof L;(ve==="undefined"||ve==="boolean")&&(L=null);var Se=!1;if(L===null)Se=!0;else switch(ve){case"bigint":case"string":case"number":Se=!0;break;case"object":switch(L.$$typeof){case e:case t:Se=!0;break;case m:return Se=L._init,U(Se(L._payload),J,D,oe,ye)}}if(Se)return ye=ye(L),Se=oe===""?"."+Z(L,0):oe,N(ye)?(D="",Se!=null&&(D=Se.replace(ee,"$&/")+"/"),U(ye,J,D,"",function(he){return he})):ye!=null&&(F(ye)&&(ye=P(ye,D+(ye.key==null||L&&L.key===ye.key?"":(""+ye.key).replace(ee,"$&/")+"/")+Se)),J.push(ye)),1;Se=0;var ge=oe===""?".":oe+":";if(N(L))for(var K=0;K<L.length;K++)oe=L[K],ve=ge+Z(oe,K),Se+=U(oe,J,D,ve,ye);else if(K=g(L),typeof K=="function")for(L=K.call(L),K=0;!(oe=L.next()).done;)oe=oe.value,ve=ge+Z(oe,K++),Se+=U(oe,J,D,ve,ye);else if(ve==="object"){if(typeof L.then=="function")return U(Y(L),J,D,oe,ye);throw J=String(L),Error("Objects are not valid as a React child (found: "+(J==="[object Object]"?"object with keys {"+Object.keys(L).join(", ")+"}":J)+"). If you meant to render a collection of children, use an array instead.")}return Se}function Q(L,J,D){if(L==null)return L;var oe=[],ye=0;return U(L,oe,"","",function(ve){return J.call(D,ve,ye++)}),oe}function ue(L){if(L._status===-1){var J=L._result;J=J(),J.then(function(D){(L._status===0||L._status===-1)&&(L._status=1,L._result=D)},function(D){(L._status===0||L._status===-1)&&(L._status=2,L._result=D)}),L._status===-1&&(L._status=0,L._result=J)}if(L._status===1)return L._result.default;throw L._result}var de=typeof reportError=="function"?reportError:function(L){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var J=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof L=="object"&&L!==null&&typeof L.message=="string"?String(L.message):String(L),error:L});if(!window.dispatchEvent(J))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",L);return}console.error(L)},R={map:Q,forEach:function(L,J,D){Q(L,function(){J.apply(this,arguments)},D)},count:function(L){var J=0;return Q(L,function(){J++}),J},toArray:function(L){return Q(L,function(J){return J})||[]},only:function(L){if(!F(L))throw Error("React.Children.only expected to receive a single React element child.");return L}};return Ce.Activity=p,Ce.Children=R,Ce.Component=O,Ce.Fragment=n,Ce.Profiler=a,Ce.PureComponent=k,Ce.StrictMode=r,Ce.Suspense=f,Ce.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=z,Ce.__COMPILER_RUNTIME={__proto__:null,c:function(L){return z.H.useMemoCache(L)}},Ce.cache=function(L){return function(){return L.apply(null,arguments)}},Ce.cacheSignal=function(){return null},Ce.cloneElement=function(L,J,D){if(L==null)throw Error("The argument must be a React element, but you passed "+L+".");var oe=w({},L.props),ye=L.key;if(J!=null)for(ve in J.key!==void 0&&(ye=""+J.key),J)!$.call(J,ve)||ve==="key"||ve==="__self"||ve==="__source"||ve==="ref"&&J.ref===void 0||(oe[ve]=J[ve]);var ve=arguments.length-2;if(ve===1)oe.children=D;else if(1<ve){for(var Se=Array(ve),ge=0;ge<ve;ge++)Se[ge]=arguments[ge+2];oe.children=Se}return H(L.type,ye,oe)},Ce.createContext=function(L){return L={$$typeof:o,_currentValue:L,_currentValue2:L,_threadCount:0,Provider:null,Consumer:null},L.Provider=L,L.Consumer={$$typeof:u,_context:L},L},Ce.createElement=function(L,J,D){var oe,ye={},ve=null;if(J!=null)for(oe in J.key!==void 0&&(ve=""+J.key),J)$.call(J,oe)&&oe!=="key"&&oe!=="__self"&&oe!=="__source"&&(ye[oe]=J[oe]);var Se=arguments.length-2;if(Se===1)ye.children=D;else if(1<Se){for(var ge=Array(Se),K=0;K<Se;K++)ge[K]=arguments[K+2];ye.children=ge}if(L&&L.defaultProps)for(oe in Se=L.defaultProps,Se)ye[oe]===void 0&&(ye[oe]=Se[oe]);return H(L,ve,ye)},Ce.createRef=function(){return{current:null}},Ce.forwardRef=function(L){return{$$typeof:c,render:L}},Ce.isValidElement=F,Ce.lazy=function(L){return{$$typeof:m,_payload:{_status:-1,_result:L},_init:ue}},Ce.memo=function(L,J){return{$$typeof:d,type:L,compare:J===void 0?null:J}},Ce.startTransition=function(L){var J=z.T,D={};z.T=D;try{var oe=L(),ye=z.S;ye!==null&&ye(D,oe),typeof oe=="object"&&oe!==null&&typeof oe.then=="function"&&oe.then(C,de)}catch(ve){de(ve)}finally{J!==null&&D.types!==null&&(J.types=D.types),z.T=J}},Ce.unstable_useCacheRefresh=function(){return z.H.useCacheRefresh()},Ce.use=function(L){return z.H.use(L)},Ce.useActionState=function(L,J,D){return z.H.useActionState(L,J,D)},Ce.useCallback=function(L,J){return z.H.useCallback(L,J)},Ce.useContext=function(L){return z.H.useContext(L)},Ce.useDebugValue=function(){},Ce.useDeferredValue=function(L,J){return z.H.useDeferredValue(L,J)},Ce.useEffect=function(L,J){return z.H.useEffect(L,J)},Ce.useEffectEvent=function(L){return z.H.useEffectEvent(L)},Ce.useId=function(){return z.H.useId()},Ce.useImperativeHandle=function(L,J,D){return z.H.useImperativeHandle(L,J,D)},Ce.useInsertionEffect=function(L,J){return z.H.useInsertionEffect(L,J)},Ce.useLayoutEffect=function(L,J){return z.H.useLayoutEffect(L,J)},Ce.useMemo=function(L,J){return z.H.useMemo(L,J)},Ce.useOptimistic=function(L,J){return z.H.useOptimistic(L,J)},Ce.useReducer=function(L,J,D){return z.H.useReducer(L,J,D)},Ce.useRef=function(L){return z.H.useRef(L)},Ce.useState=function(L){return z.H.useState(L)},Ce.useSyncExternalStore=function(L,J,D){return z.H.useSyncExternalStore(L,J,D)},Ce.useTransition=function(){return z.H.useTransition()},Ce.version="19.2.4",Ce}var uO;function Su(){return uO||(uO=1,Bp.exports=QR()),Bp.exports}var E=Su();const Lr=Tr(E),WR=GR({__proto__:null,default:Lr},[E]);var Up={exports:{}},jo={},qp={exports:{}},Hp={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var oO;function JR(){return oO||(oO=1,(function(e){function t(U,Q){var ue=U.length;U.push(Q);e:for(;0<ue;){var de=ue-1>>>1,R=U[de];if(0<a(R,Q))U[de]=Q,U[ue]=R,ue=de;else break e}}function n(U){return U.length===0?null:U[0]}function r(U){if(U.length===0)return null;var Q=U[0],ue=U.pop();if(ue!==Q){U[0]=ue;e:for(var de=0,R=U.length,L=R>>>1;de<L;){var J=2*(de+1)-1,D=U[J],oe=J+1,ye=U[oe];if(0>a(D,ue))oe<R&&0>a(ye,D)?(U[de]=ye,U[oe]=ue,de=oe):(U[de]=D,U[J]=ue,de=J);else if(oe<R&&0>a(ye,ue))U[de]=ye,U[oe]=ue,de=oe;else break e}}return Q}function a(U,Q){var ue=U.sortIndex-Q.sortIndex;return ue!==0?ue:U.id-Q.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var u=performance;e.unstable_now=function(){return u.now()}}else{var o=Date,c=o.now();e.unstable_now=function(){return o.now()-c}}var f=[],d=[],m=1,p=null,y=3,g=!1,x=!1,w=!1,S=!1,O=typeof setTimeout=="function"?setTimeout:null,_=typeof clearTimeout=="function"?clearTimeout:null,k=typeof setImmediate<"u"?setImmediate:null;function M(U){for(var Q=n(d);Q!==null;){if(Q.callback===null)r(d);else if(Q.startTime<=U)r(d),Q.sortIndex=Q.expirationTime,t(f,Q);else break;Q=n(d)}}function N(U){if(w=!1,M(U),!x)if(n(f)!==null)x=!0,C||(C=!0,I());else{var Q=n(d);Q!==null&&Y(N,Q.startTime-U)}}var C=!1,z=-1,$=5,H=-1;function P(){return S?!0:!(e.unstable_now()-H<$)}function F(){if(S=!1,C){var U=e.unstable_now();H=U;var Q=!0;try{e:{x=!1,w&&(w=!1,_(z),z=-1),g=!0;var ue=y;try{t:{for(M(U),p=n(f);p!==null&&!(p.expirationTime>U&&P());){var de=p.callback;if(typeof de=="function"){p.callback=null,y=p.priorityLevel;var R=de(p.expirationTime<=U);if(U=e.unstable_now(),typeof R=="function"){p.callback=R,M(U),Q=!0;break t}p===n(f)&&r(f),M(U)}else r(f);p=n(f)}if(p!==null)Q=!0;else{var L=n(d);L!==null&&Y(N,L.startTime-U),Q=!1}}break e}finally{p=null,y=ue,g=!1}Q=void 0}}finally{Q?I():C=!1}}}var I;if(typeof k=="function")I=function(){k(F)};else if(typeof MessageChannel<"u"){var ee=new MessageChannel,Z=ee.port2;ee.port1.onmessage=F,I=function(){Z.postMessage(null)}}else I=function(){O(F,0)};function Y(U,Q){z=O(function(){U(e.unstable_now())},Q)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(U){U.callback=null},e.unstable_forceFrameRate=function(U){0>U||125<U?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):$=0<U?Math.floor(1e3/U):5},e.unstable_getCurrentPriorityLevel=function(){return y},e.unstable_next=function(U){switch(y){case 1:case 2:case 3:var Q=3;break;default:Q=y}var ue=y;y=Q;try{return U()}finally{y=ue}},e.unstable_requestPaint=function(){S=!0},e.unstable_runWithPriority=function(U,Q){switch(U){case 1:case 2:case 3:case 4:case 5:break;default:U=3}var ue=y;y=U;try{return Q()}finally{y=ue}},e.unstable_scheduleCallback=function(U,Q,ue){var de=e.unstable_now();switch(typeof ue=="object"&&ue!==null?(ue=ue.delay,ue=typeof ue=="number"&&0<ue?de+ue:de):ue=de,U){case 1:var R=-1;break;case 2:R=250;break;case 5:R=1073741823;break;case 4:R=1e4;break;default:R=5e3}return R=ue+R,U={id:m++,callback:Q,priorityLevel:U,startTime:ue,expirationTime:R,sortIndex:-1},ue>de?(U.sortIndex=ue,t(d,U),n(f)===null&&U===n(d)&&(w?(_(z),z=-1):w=!0,Y(N,ue-de))):(U.sortIndex=R,t(f,U),x||g||(x=!0,C||(C=!0,I()))),U},e.unstable_shouldYield=P,e.unstable_wrapCallback=function(U){var Q=y;return function(){var ue=y;y=Q;try{return U.apply(this,arguments)}finally{y=ue}}}})(Hp)),Hp}var sO;function eI(){return sO||(sO=1,qp.exports=JR()),qp.exports}var $p={exports:{}},nn={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var cO;function tI(){if(cO)return nn;cO=1;var e=Su();function t(f){var d="https://react.dev/errors/"+f;if(1<arguments.length){d+="?args[]="+encodeURIComponent(arguments[1]);for(var m=2;m<arguments.length;m++)d+="&args[]="+encodeURIComponent(arguments[m])}return"Minified React error #"+f+"; visit "+d+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var r={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},a=Symbol.for("react.portal");function u(f,d,m){var p=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:a,key:p==null?null:""+p,children:f,containerInfo:d,implementation:m}}var o=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function c(f,d){if(f==="font")return"";if(typeof d=="string")return d==="use-credentials"?d:""}return nn.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,nn.createPortal=function(f,d){var m=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!d||d.nodeType!==1&&d.nodeType!==9&&d.nodeType!==11)throw Error(t(299));return u(f,d,null,m)},nn.flushSync=function(f){var d=o.T,m=r.p;try{if(o.T=null,r.p=2,f)return f()}finally{o.T=d,r.p=m,r.d.f()}},nn.preconnect=function(f,d){typeof f=="string"&&(d?(d=d.crossOrigin,d=typeof d=="string"?d==="use-credentials"?d:"":void 0):d=null,r.d.C(f,d))},nn.prefetchDNS=function(f){typeof f=="string"&&r.d.D(f)},nn.preinit=function(f,d){if(typeof f=="string"&&d&&typeof d.as=="string"){var m=d.as,p=c(m,d.crossOrigin),y=typeof d.integrity=="string"?d.integrity:void 0,g=typeof d.fetchPriority=="string"?d.fetchPriority:void 0;m==="style"?r.d.S(f,typeof d.precedence=="string"?d.precedence:void 0,{crossOrigin:p,integrity:y,fetchPriority:g}):m==="script"&&r.d.X(f,{crossOrigin:p,integrity:y,fetchPriority:g,nonce:typeof d.nonce=="string"?d.nonce:void 0})}},nn.preinitModule=function(f,d){if(typeof f=="string")if(typeof d=="object"&&d!==null){if(d.as==null||d.as==="script"){var m=c(d.as,d.crossOrigin);r.d.M(f,{crossOrigin:m,integrity:typeof d.integrity=="string"?d.integrity:void 0,nonce:typeof d.nonce=="string"?d.nonce:void 0})}}else d==null&&r.d.M(f)},nn.preload=function(f,d){if(typeof f=="string"&&typeof d=="object"&&d!==null&&typeof d.as=="string"){var m=d.as,p=c(m,d.crossOrigin);r.d.L(f,m,{crossOrigin:p,integrity:typeof d.integrity=="string"?d.integrity:void 0,nonce:typeof d.nonce=="string"?d.nonce:void 0,type:typeof d.type=="string"?d.type:void 0,fetchPriority:typeof d.fetchPriority=="string"?d.fetchPriority:void 0,referrerPolicy:typeof d.referrerPolicy=="string"?d.referrerPolicy:void 0,imageSrcSet:typeof d.imageSrcSet=="string"?d.imageSrcSet:void 0,imageSizes:typeof d.imageSizes=="string"?d.imageSizes:void 0,media:typeof d.media=="string"?d.media:void 0})}},nn.preloadModule=function(f,d){if(typeof f=="string")if(d){var m=c(d.as,d.crossOrigin);r.d.m(f,{as:typeof d.as=="string"&&d.as!=="script"?d.as:void 0,crossOrigin:m,integrity:typeof d.integrity=="string"?d.integrity:void 0})}else r.d.m(f)},nn.requestFormReset=function(f){r.d.r(f)},nn.unstable_batchedUpdates=function(f,d){return f(d)},nn.useFormState=function(f,d,m){return o.H.useFormState(f,d,m)},nn.useFormStatus=function(){return o.H.useHostTransitionStatus()},nn.version="19.2.4",nn}var fO;function hC(){if(fO)return $p.exports;fO=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),$p.exports=tI(),$p.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var dO;function nI(){if(dO)return jo;dO=1;var e=eI(),t=Su(),n=hC();function r(i){var l="https://react.dev/errors/"+i;if(1<arguments.length){l+="?args[]="+encodeURIComponent(arguments[1]);for(var s=2;s<arguments.length;s++)l+="&args[]="+encodeURIComponent(arguments[s])}return"Minified React error #"+i+"; visit "+l+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function a(i){return!(!i||i.nodeType!==1&&i.nodeType!==9&&i.nodeType!==11)}function u(i){var l=i,s=i;if(i.alternate)for(;l.return;)l=l.return;else{i=l;do l=i,(l.flags&4098)!==0&&(s=l.return),i=l.return;while(i)}return l.tag===3?s:null}function o(i){if(i.tag===13){var l=i.memoizedState;if(l===null&&(i=i.alternate,i!==null&&(l=i.memoizedState)),l!==null)return l.dehydrated}return null}function c(i){if(i.tag===31){var l=i.memoizedState;if(l===null&&(i=i.alternate,i!==null&&(l=i.memoizedState)),l!==null)return l.dehydrated}return null}function f(i){if(u(i)!==i)throw Error(r(188))}function d(i){var l=i.alternate;if(!l){if(l=u(i),l===null)throw Error(r(188));return l!==i?null:i}for(var s=i,h=l;;){var v=s.return;if(v===null)break;var b=v.alternate;if(b===null){if(h=v.return,h!==null){s=h;continue}break}if(v.child===b.child){for(b=v.child;b;){if(b===s)return f(v),i;if(b===h)return f(v),l;b=b.sibling}throw Error(r(188))}if(s.return!==h.return)s=v,h=b;else{for(var A=!1,j=v.child;j;){if(j===s){A=!0,s=v,h=b;break}if(j===h){A=!0,h=v,s=b;break}j=j.sibling}if(!A){for(j=b.child;j;){if(j===s){A=!0,s=b,h=v;break}if(j===h){A=!0,h=b,s=v;break}j=j.sibling}if(!A)throw Error(r(189))}}if(s.alternate!==h)throw Error(r(190))}if(s.tag!==3)throw Error(r(188));return s.stateNode.current===s?i:l}function m(i){var l=i.tag;if(l===5||l===26||l===27||l===6)return i;for(i=i.child;i!==null;){if(l=m(i),l!==null)return l;i=i.sibling}return null}var p=Object.assign,y=Symbol.for("react.element"),g=Symbol.for("react.transitional.element"),x=Symbol.for("react.portal"),w=Symbol.for("react.fragment"),S=Symbol.for("react.strict_mode"),O=Symbol.for("react.profiler"),_=Symbol.for("react.consumer"),k=Symbol.for("react.context"),M=Symbol.for("react.forward_ref"),N=Symbol.for("react.suspense"),C=Symbol.for("react.suspense_list"),z=Symbol.for("react.memo"),$=Symbol.for("react.lazy"),H=Symbol.for("react.activity"),P=Symbol.for("react.memo_cache_sentinel"),F=Symbol.iterator;function I(i){return i===null||typeof i!="object"?null:(i=F&&i[F]||i["@@iterator"],typeof i=="function"?i:null)}var ee=Symbol.for("react.client.reference");function Z(i){if(i==null)return null;if(typeof i=="function")return i.$$typeof===ee?null:i.displayName||i.name||null;if(typeof i=="string")return i;switch(i){case w:return"Fragment";case O:return"Profiler";case S:return"StrictMode";case N:return"Suspense";case C:return"SuspenseList";case H:return"Activity"}if(typeof i=="object")switch(i.$$typeof){case x:return"Portal";case k:return i.displayName||"Context";case _:return(i._context.displayName||"Context")+".Consumer";case M:var l=i.render;return i=i.displayName,i||(i=l.displayName||l.name||"",i=i!==""?"ForwardRef("+i+")":"ForwardRef"),i;case z:return l=i.displayName||null,l!==null?l:Z(i.type)||"Memo";case $:l=i._payload,i=i._init;try{return Z(i(l))}catch{}}return null}var Y=Array.isArray,U=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Q=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,ue={pending:!1,data:null,method:null,action:null},de=[],R=-1;function L(i){return{current:i}}function J(i){0>R||(i.current=de[R],de[R]=null,R--)}function D(i,l){R++,de[R]=i.current,i.current=l}var oe=L(null),ye=L(null),ve=L(null),Se=L(null);function ge(i,l){switch(D(ve,l),D(ye,i),D(oe,null),l.nodeType){case 9:case 11:i=(i=l.documentElement)&&(i=i.namespaceURI)?kS(i):0;break;default:if(i=l.tagName,l=l.namespaceURI)l=kS(l),i=CS(l,i);else switch(i){case"svg":i=1;break;case"math":i=2;break;default:i=0}}J(oe),D(oe,i)}function K(){J(oe),J(ye),J(ve)}function he(i){i.memoizedState!==null&&D(Se,i);var l=oe.current,s=CS(l,i.type);l!==s&&(D(ye,i),D(oe,s))}function be(i){ye.current===i&&(J(oe),J(ye)),Se.current===i&&(J(Se),Ao._currentValue=ue)}var se,jt;function Ie(i){if(se===void 0)try{throw Error()}catch(s){var l=s.stack.trim().match(/\n( *(at )?)/);se=l&&l[1]||"",jt=-1<s.stack.indexOf(`
    at`)?" (<anonymous>)":-1<s.stack.indexOf("@")?"@unknown:0:0":""}return`
`+se+i+jt}var St=!1;function Ot(i,l){if(!i||St)return"";St=!0;var s=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var h={DetermineComponentFrameRoot:function(){try{if(l){var le=function(){throw Error()};if(Object.defineProperty(le.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(le,[])}catch(ne){var W=ne}Reflect.construct(i,[],le)}else{try{le.call()}catch(ne){W=ne}i.call(le.prototype)}}else{try{throw Error()}catch(ne){W=ne}(le=i())&&typeof le.catch=="function"&&le.catch(function(){})}}catch(ne){if(ne&&W&&typeof ne.stack=="string")return[ne.stack,W.stack]}return[null,null]}};h.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var v=Object.getOwnPropertyDescriptor(h.DetermineComponentFrameRoot,"name");v&&v.configurable&&Object.defineProperty(h.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var b=h.DetermineComponentFrameRoot(),A=b[0],j=b[1];if(A&&j){var B=A.split(`
`),X=j.split(`
`);for(v=h=0;h<B.length&&!B[h].includes("DetermineComponentFrameRoot");)h++;for(;v<X.length&&!X[v].includes("DetermineComponentFrameRoot");)v++;if(h===B.length||v===X.length)for(h=B.length-1,v=X.length-1;1<=h&&0<=v&&B[h]!==X[v];)v--;for(;1<=h&&0<=v;h--,v--)if(B[h]!==X[v]){if(h!==1||v!==1)do if(h--,v--,0>v||B[h]!==X[v]){var re=`
`+B[h].replace(" at new "," at ");return i.displayName&&re.includes("<anonymous>")&&(re=re.replace("<anonymous>",i.displayName)),re}while(1<=h&&0<=v);break}}}finally{St=!1,Error.prepareStackTrace=s}return(s=i?i.displayName||i.name:"")?Ie(s):""}function Gn(i,l){switch(i.tag){case 26:case 27:case 5:return Ie(i.type);case 16:return Ie("Lazy");case 13:return i.child!==l&&l!==null?Ie("Suspense Fallback"):Ie("Suspense");case 19:return Ie("SuspenseList");case 0:case 15:return Ot(i.type,!1);case 11:return Ot(i.type.render,!1);case 1:return Ot(i.type,!0);case 31:return Ie("Activity");default:return""}}function ba(i){try{var l="",s=null;do l+=Gn(i,s),s=i,i=i.return;while(i);return l}catch(h){return`
Error generating stack: `+h.message+`
`+h.stack}}var sl=Object.prototype.hasOwnProperty,cl=e.unstable_scheduleCallback,Ru=e.unstable_cancelCallback,Sh=e.unstable_shouldYield,Oh=e.unstable_requestPaint,on=e.unstable_now,Eh=e.unstable_getCurrentPriorityLevel,ie=e.unstable_ImmediatePriority,fe=e.unstable_UserBlockingPriority,ke=e.unstable_NormalPriority,De=e.unstable_LowPriority,Ke=e.unstable_IdlePriority,zn=e.log,Gr=e.unstable_setDisableYieldValue,sn=null,Mt=null;function yn(i){if(typeof zn=="function"&&Gr(i),Mt&&typeof Mt.setStrictMode=="function")try{Mt.setStrictMode(sn,i)}catch{}}var tt=Math.clz32?Math.clz32:zN,Ii=Math.log,yr=Math.LN2;function zN(i){return i>>>=0,i===0?32:31-(Ii(i)/yr|0)|0}var Is=256,Ls=262144,Bs=4194304;function xa(i){var l=i&42;if(l!==0)return l;switch(i&-i){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return i&261888;case 262144:case 524288:case 1048576:case 2097152:return i&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return i&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return i}}function Us(i,l,s){var h=i.pendingLanes;if(h===0)return 0;var v=0,b=i.suspendedLanes,A=i.pingedLanes;i=i.warmLanes;var j=h&134217727;return j!==0?(h=j&~b,h!==0?v=xa(h):(A&=j,A!==0?v=xa(A):s||(s=j&~i,s!==0&&(v=xa(s))))):(j=h&~b,j!==0?v=xa(j):A!==0?v=xa(A):s||(s=h&~i,s!==0&&(v=xa(s)))),v===0?0:l!==0&&l!==v&&(l&b)===0&&(b=v&-v,s=l&-l,b>=s||b===32&&(s&4194048)!==0)?l:v}function Iu(i,l){return(i.pendingLanes&~(i.suspendedLanes&~i.pingedLanes)&l)===0}function DN(i,l){switch(i){case 1:case 2:case 4:case 8:case 64:return l+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function ox(){var i=Bs;return Bs<<=1,(Bs&62914560)===0&&(Bs=4194304),i}function Ah(i){for(var l=[],s=0;31>s;s++)l.push(i);return l}function Lu(i,l){i.pendingLanes|=l,l!==268435456&&(i.suspendedLanes=0,i.pingedLanes=0,i.warmLanes=0)}function NN(i,l,s,h,v,b){var A=i.pendingLanes;i.pendingLanes=s,i.suspendedLanes=0,i.pingedLanes=0,i.warmLanes=0,i.expiredLanes&=s,i.entangledLanes&=s,i.errorRecoveryDisabledLanes&=s,i.shellSuspendCounter=0;var j=i.entanglements,B=i.expirationTimes,X=i.hiddenUpdates;for(s=A&~s;0<s;){var re=31-tt(s),le=1<<re;j[re]=0,B[re]=-1;var W=X[re];if(W!==null)for(X[re]=null,re=0;re<W.length;re++){var ne=W[re];ne!==null&&(ne.lane&=-536870913)}s&=~le}h!==0&&sx(i,h,0),b!==0&&v===0&&i.tag!==0&&(i.suspendedLanes|=b&~(A&~l))}function sx(i,l,s){i.pendingLanes|=l,i.suspendedLanes&=~l;var h=31-tt(l);i.entangledLanes|=l,i.entanglements[h]=i.entanglements[h]|1073741824|s&261930}function cx(i,l){var s=i.entangledLanes|=l;for(i=i.entanglements;s;){var h=31-tt(s),v=1<<h;v&l|i[h]&l&&(i[h]|=l),s&=~v}}function fx(i,l){var s=l&-l;return s=(s&42)!==0?1:_h(s),(s&(i.suspendedLanes|l))!==0?0:s}function _h(i){switch(i){case 2:i=1;break;case 8:i=4;break;case 32:i=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:i=128;break;case 268435456:i=134217728;break;default:i=0}return i}function kh(i){return i&=-i,2<i?8<i?(i&134217727)!==0?32:268435456:8:2}function dx(){var i=Q.p;return i!==0?i:(i=window.event,i===void 0?32:QS(i.type))}function hx(i,l){var s=Q.p;try{return Q.p=i,l()}finally{Q.p=s}}var Li=Math.random().toString(36).slice(2),Yt="__reactFiber$"+Li,gn="__reactProps$"+Li,fl="__reactContainer$"+Li,Ch="__reactEvents$"+Li,PN="__reactListeners$"+Li,RN="__reactHandles$"+Li,mx="__reactResources$"+Li,Bu="__reactMarker$"+Li;function Th(i){delete i[Yt],delete i[gn],delete i[Ch],delete i[PN],delete i[RN]}function dl(i){var l=i[Yt];if(l)return l;for(var s=i.parentNode;s;){if(l=s[fl]||s[Yt]){if(s=l.alternate,l.child!==null||s!==null&&s.child!==null)for(i=PS(i);i!==null;){if(s=i[Yt])return s;i=PS(i)}return l}i=s,s=i.parentNode}return null}function hl(i){if(i=i[Yt]||i[fl]){var l=i.tag;if(l===5||l===6||l===13||l===31||l===26||l===27||l===3)return i}return null}function Uu(i){var l=i.tag;if(l===5||l===26||l===27||l===6)return i.stateNode;throw Error(r(33))}function ml(i){var l=i[mx];return l||(l=i[mx]={hoistableStyles:new Map,hoistableScripts:new Map}),l}function Rt(i){i[Bu]=!0}var px=new Set,vx={};function wa(i,l){pl(i,l),pl(i+"Capture",l)}function pl(i,l){for(vx[i]=l,i=0;i<l.length;i++)px.add(l[i])}var IN=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),yx={},gx={};function LN(i){return sl.call(gx,i)?!0:sl.call(yx,i)?!1:IN.test(i)?gx[i]=!0:(yx[i]=!0,!1)}function qs(i,l,s){if(LN(l))if(s===null)i.removeAttribute(l);else{switch(typeof s){case"undefined":case"function":case"symbol":i.removeAttribute(l);return;case"boolean":var h=l.toLowerCase().slice(0,5);if(h!=="data-"&&h!=="aria-"){i.removeAttribute(l);return}}i.setAttribute(l,""+s)}}function Hs(i,l,s){if(s===null)i.removeAttribute(l);else{switch(typeof s){case"undefined":case"function":case"symbol":case"boolean":i.removeAttribute(l);return}i.setAttribute(l,""+s)}}function Xr(i,l,s,h){if(h===null)i.removeAttribute(s);else{switch(typeof h){case"undefined":case"function":case"symbol":case"boolean":i.removeAttribute(s);return}i.setAttributeNS(l,s,""+h)}}function Xn(i){switch(typeof i){case"bigint":case"boolean":case"number":case"string":case"undefined":return i;case"object":return i;default:return""}}function bx(i){var l=i.type;return(i=i.nodeName)&&i.toLowerCase()==="input"&&(l==="checkbox"||l==="radio")}function BN(i,l,s){var h=Object.getOwnPropertyDescriptor(i.constructor.prototype,l);if(!i.hasOwnProperty(l)&&typeof h<"u"&&typeof h.get=="function"&&typeof h.set=="function"){var v=h.get,b=h.set;return Object.defineProperty(i,l,{configurable:!0,get:function(){return v.call(this)},set:function(A){s=""+A,b.call(this,A)}}),Object.defineProperty(i,l,{enumerable:h.enumerable}),{getValue:function(){return s},setValue:function(A){s=""+A},stopTracking:function(){i._valueTracker=null,delete i[l]}}}}function jh(i){if(!i._valueTracker){var l=bx(i)?"checked":"value";i._valueTracker=BN(i,l,""+i[l])}}function xx(i){if(!i)return!1;var l=i._valueTracker;if(!l)return!0;var s=l.getValue(),h="";return i&&(h=bx(i)?i.checked?"true":"false":i.value),i=h,i!==s?(l.setValue(i),!0):!1}function $s(i){if(i=i||(typeof document<"u"?document:void 0),typeof i>"u")return null;try{return i.activeElement||i.body}catch{return i.body}}var UN=/[\n"\\]/g;function Zn(i){return i.replace(UN,function(l){return"\\"+l.charCodeAt(0).toString(16)+" "})}function Mh(i,l,s,h,v,b,A,j){i.name="",A!=null&&typeof A!="function"&&typeof A!="symbol"&&typeof A!="boolean"?i.type=A:i.removeAttribute("type"),l!=null?A==="number"?(l===0&&i.value===""||i.value!=l)&&(i.value=""+Xn(l)):i.value!==""+Xn(l)&&(i.value=""+Xn(l)):A!=="submit"&&A!=="reset"||i.removeAttribute("value"),l!=null?zh(i,A,Xn(l)):s!=null?zh(i,A,Xn(s)):h!=null&&i.removeAttribute("value"),v==null&&b!=null&&(i.defaultChecked=!!b),v!=null&&(i.checked=v&&typeof v!="function"&&typeof v!="symbol"),j!=null&&typeof j!="function"&&typeof j!="symbol"&&typeof j!="boolean"?i.name=""+Xn(j):i.removeAttribute("name")}function wx(i,l,s,h,v,b,A,j){if(b!=null&&typeof b!="function"&&typeof b!="symbol"&&typeof b!="boolean"&&(i.type=b),l!=null||s!=null){if(!(b!=="submit"&&b!=="reset"||l!=null)){jh(i);return}s=s!=null?""+Xn(s):"",l=l!=null?""+Xn(l):s,j||l===i.value||(i.value=l),i.defaultValue=l}h=h??v,h=typeof h!="function"&&typeof h!="symbol"&&!!h,i.checked=j?i.checked:!!h,i.defaultChecked=!!h,A!=null&&typeof A!="function"&&typeof A!="symbol"&&typeof A!="boolean"&&(i.name=A),jh(i)}function zh(i,l,s){l==="number"&&$s(i.ownerDocument)===i||i.defaultValue===""+s||(i.defaultValue=""+s)}function vl(i,l,s,h){if(i=i.options,l){l={};for(var v=0;v<s.length;v++)l["$"+s[v]]=!0;for(s=0;s<i.length;s++)v=l.hasOwnProperty("$"+i[s].value),i[s].selected!==v&&(i[s].selected=v),v&&h&&(i[s].defaultSelected=!0)}else{for(s=""+Xn(s),l=null,v=0;v<i.length;v++){if(i[v].value===s){i[v].selected=!0,h&&(i[v].defaultSelected=!0);return}l!==null||i[v].disabled||(l=i[v])}l!==null&&(l.selected=!0)}}function Sx(i,l,s){if(l!=null&&(l=""+Xn(l),l!==i.value&&(i.value=l),s==null)){i.defaultValue!==l&&(i.defaultValue=l);return}i.defaultValue=s!=null?""+Xn(s):""}function Ox(i,l,s,h){if(l==null){if(h!=null){if(s!=null)throw Error(r(92));if(Y(h)){if(1<h.length)throw Error(r(93));h=h[0]}s=h}s==null&&(s=""),l=s}s=Xn(l),i.defaultValue=s,h=i.textContent,h===s&&h!==""&&h!==null&&(i.value=h),jh(i)}function yl(i,l){if(l){var s=i.firstChild;if(s&&s===i.lastChild&&s.nodeType===3){s.nodeValue=l;return}}i.textContent=l}var qN=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Ex(i,l,s){var h=l.indexOf("--")===0;s==null||typeof s=="boolean"||s===""?h?i.setProperty(l,""):l==="float"?i.cssFloat="":i[l]="":h?i.setProperty(l,s):typeof s!="number"||s===0||qN.has(l)?l==="float"?i.cssFloat=s:i[l]=(""+s).trim():i[l]=s+"px"}function Ax(i,l,s){if(l!=null&&typeof l!="object")throw Error(r(62));if(i=i.style,s!=null){for(var h in s)!s.hasOwnProperty(h)||l!=null&&l.hasOwnProperty(h)||(h.indexOf("--")===0?i.setProperty(h,""):h==="float"?i.cssFloat="":i[h]="");for(var v in l)h=l[v],l.hasOwnProperty(v)&&s[v]!==h&&Ex(i,v,h)}else for(var b in l)l.hasOwnProperty(b)&&Ex(i,b,l[b])}function Dh(i){if(i.indexOf("-")===-1)return!1;switch(i){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var HN=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),$N=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Fs(i){return $N.test(""+i)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":i}function Zr(){}var Nh=null;function Ph(i){return i=i.target||i.srcElement||window,i.correspondingUseElement&&(i=i.correspondingUseElement),i.nodeType===3?i.parentNode:i}var gl=null,bl=null;function _x(i){var l=hl(i);if(l&&(i=l.stateNode)){var s=i[gn]||null;e:switch(i=l.stateNode,l.type){case"input":if(Mh(i,s.value,s.defaultValue,s.defaultValue,s.checked,s.defaultChecked,s.type,s.name),l=s.name,s.type==="radio"&&l!=null){for(s=i;s.parentNode;)s=s.parentNode;for(s=s.querySelectorAll('input[name="'+Zn(""+l)+'"][type="radio"]'),l=0;l<s.length;l++){var h=s[l];if(h!==i&&h.form===i.form){var v=h[gn]||null;if(!v)throw Error(r(90));Mh(h,v.value,v.defaultValue,v.defaultValue,v.checked,v.defaultChecked,v.type,v.name)}}for(l=0;l<s.length;l++)h=s[l],h.form===i.form&&xx(h)}break e;case"textarea":Sx(i,s.value,s.defaultValue);break e;case"select":l=s.value,l!=null&&vl(i,!!s.multiple,l,!1)}}}var Rh=!1;function kx(i,l,s){if(Rh)return i(l,s);Rh=!0;try{var h=i(l);return h}finally{if(Rh=!1,(gl!==null||bl!==null)&&(Mc(),gl&&(l=gl,i=bl,bl=gl=null,_x(l),i)))for(l=0;l<i.length;l++)_x(i[l])}}function qu(i,l){var s=i.stateNode;if(s===null)return null;var h=s[gn]||null;if(h===null)return null;s=h[l];e:switch(l){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(h=!h.disabled)||(i=i.type,h=!(i==="button"||i==="input"||i==="select"||i==="textarea")),i=!h;break e;default:i=!1}if(i)return null;if(s&&typeof s!="function")throw Error(r(231,l,typeof s));return s}var Qr=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Ih=!1;if(Qr)try{var Hu={};Object.defineProperty(Hu,"passive",{get:function(){Ih=!0}}),window.addEventListener("test",Hu,Hu),window.removeEventListener("test",Hu,Hu)}catch{Ih=!1}var Bi=null,Lh=null,Vs=null;function Cx(){if(Vs)return Vs;var i,l=Lh,s=l.length,h,v="value"in Bi?Bi.value:Bi.textContent,b=v.length;for(i=0;i<s&&l[i]===v[i];i++);var A=s-i;for(h=1;h<=A&&l[s-h]===v[b-h];h++);return Vs=v.slice(i,1<h?1-h:void 0)}function Ys(i){var l=i.keyCode;return"charCode"in i?(i=i.charCode,i===0&&l===13&&(i=13)):i=l,i===10&&(i=13),32<=i||i===13?i:0}function Ks(){return!0}function Tx(){return!1}function bn(i){function l(s,h,v,b,A){this._reactName=s,this._targetInst=v,this.type=h,this.nativeEvent=b,this.target=A,this.currentTarget=null;for(var j in i)i.hasOwnProperty(j)&&(s=i[j],this[j]=s?s(b):b[j]);return this.isDefaultPrevented=(b.defaultPrevented!=null?b.defaultPrevented:b.returnValue===!1)?Ks:Tx,this.isPropagationStopped=Tx,this}return p(l.prototype,{preventDefault:function(){this.defaultPrevented=!0;var s=this.nativeEvent;s&&(s.preventDefault?s.preventDefault():typeof s.returnValue!="unknown"&&(s.returnValue=!1),this.isDefaultPrevented=Ks)},stopPropagation:function(){var s=this.nativeEvent;s&&(s.stopPropagation?s.stopPropagation():typeof s.cancelBubble!="unknown"&&(s.cancelBubble=!0),this.isPropagationStopped=Ks)},persist:function(){},isPersistent:Ks}),l}var Sa={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(i){return i.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Gs=bn(Sa),$u=p({},Sa,{view:0,detail:0}),FN=bn($u),Bh,Uh,Fu,Xs=p({},$u,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Hh,button:0,buttons:0,relatedTarget:function(i){return i.relatedTarget===void 0?i.fromElement===i.srcElement?i.toElement:i.fromElement:i.relatedTarget},movementX:function(i){return"movementX"in i?i.movementX:(i!==Fu&&(Fu&&i.type==="mousemove"?(Bh=i.screenX-Fu.screenX,Uh=i.screenY-Fu.screenY):Uh=Bh=0,Fu=i),Bh)},movementY:function(i){return"movementY"in i?i.movementY:Uh}}),jx=bn(Xs),VN=p({},Xs,{dataTransfer:0}),YN=bn(VN),KN=p({},$u,{relatedTarget:0}),qh=bn(KN),GN=p({},Sa,{animationName:0,elapsedTime:0,pseudoElement:0}),XN=bn(GN),ZN=p({},Sa,{clipboardData:function(i){return"clipboardData"in i?i.clipboardData:window.clipboardData}}),QN=bn(ZN),WN=p({},Sa,{data:0}),Mx=bn(WN),JN={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},eP={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},tP={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function nP(i){var l=this.nativeEvent;return l.getModifierState?l.getModifierState(i):(i=tP[i])?!!l[i]:!1}function Hh(){return nP}var rP=p({},$u,{key:function(i){if(i.key){var l=JN[i.key]||i.key;if(l!=="Unidentified")return l}return i.type==="keypress"?(i=Ys(i),i===13?"Enter":String.fromCharCode(i)):i.type==="keydown"||i.type==="keyup"?eP[i.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Hh,charCode:function(i){return i.type==="keypress"?Ys(i):0},keyCode:function(i){return i.type==="keydown"||i.type==="keyup"?i.keyCode:0},which:function(i){return i.type==="keypress"?Ys(i):i.type==="keydown"||i.type==="keyup"?i.keyCode:0}}),iP=bn(rP),aP=p({},Xs,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),zx=bn(aP),lP=p({},$u,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Hh}),uP=bn(lP),oP=p({},Sa,{propertyName:0,elapsedTime:0,pseudoElement:0}),sP=bn(oP),cP=p({},Xs,{deltaX:function(i){return"deltaX"in i?i.deltaX:"wheelDeltaX"in i?-i.wheelDeltaX:0},deltaY:function(i){return"deltaY"in i?i.deltaY:"wheelDeltaY"in i?-i.wheelDeltaY:"wheelDelta"in i?-i.wheelDelta:0},deltaZ:0,deltaMode:0}),fP=bn(cP),dP=p({},Sa,{newState:0,oldState:0}),hP=bn(dP),mP=[9,13,27,32],$h=Qr&&"CompositionEvent"in window,Vu=null;Qr&&"documentMode"in document&&(Vu=document.documentMode);var pP=Qr&&"TextEvent"in window&&!Vu,Dx=Qr&&(!$h||Vu&&8<Vu&&11>=Vu),Nx=" ",Px=!1;function Rx(i,l){switch(i){case"keyup":return mP.indexOf(l.keyCode)!==-1;case"keydown":return l.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Ix(i){return i=i.detail,typeof i=="object"&&"data"in i?i.data:null}var xl=!1;function vP(i,l){switch(i){case"compositionend":return Ix(l);case"keypress":return l.which!==32?null:(Px=!0,Nx);case"textInput":return i=l.data,i===Nx&&Px?null:i;default:return null}}function yP(i,l){if(xl)return i==="compositionend"||!$h&&Rx(i,l)?(i=Cx(),Vs=Lh=Bi=null,xl=!1,i):null;switch(i){case"paste":return null;case"keypress":if(!(l.ctrlKey||l.altKey||l.metaKey)||l.ctrlKey&&l.altKey){if(l.char&&1<l.char.length)return l.char;if(l.which)return String.fromCharCode(l.which)}return null;case"compositionend":return Dx&&l.locale!=="ko"?null:l.data;default:return null}}var gP={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Lx(i){var l=i&&i.nodeName&&i.nodeName.toLowerCase();return l==="input"?!!gP[i.type]:l==="textarea"}function Bx(i,l,s,h){gl?bl?bl.push(h):bl=[h]:gl=h,l=Lc(l,"onChange"),0<l.length&&(s=new Gs("onChange","change",null,s,h),i.push({event:s,listeners:l}))}var Yu=null,Ku=null;function bP(i){wS(i,0)}function Zs(i){var l=Uu(i);if(xx(l))return i}function Ux(i,l){if(i==="change")return l}var qx=!1;if(Qr){var Fh;if(Qr){var Vh="oninput"in document;if(!Vh){var Hx=document.createElement("div");Hx.setAttribute("oninput","return;"),Vh=typeof Hx.oninput=="function"}Fh=Vh}else Fh=!1;qx=Fh&&(!document.documentMode||9<document.documentMode)}function $x(){Yu&&(Yu.detachEvent("onpropertychange",Fx),Ku=Yu=null)}function Fx(i){if(i.propertyName==="value"&&Zs(Ku)){var l=[];Bx(l,Ku,i,Ph(i)),kx(bP,l)}}function xP(i,l,s){i==="focusin"?($x(),Yu=l,Ku=s,Yu.attachEvent("onpropertychange",Fx)):i==="focusout"&&$x()}function wP(i){if(i==="selectionchange"||i==="keyup"||i==="keydown")return Zs(Ku)}function SP(i,l){if(i==="click")return Zs(l)}function OP(i,l){if(i==="input"||i==="change")return Zs(l)}function EP(i,l){return i===l&&(i!==0||1/i===1/l)||i!==i&&l!==l}var Dn=typeof Object.is=="function"?Object.is:EP;function Gu(i,l){if(Dn(i,l))return!0;if(typeof i!="object"||i===null||typeof l!="object"||l===null)return!1;var s=Object.keys(i),h=Object.keys(l);if(s.length!==h.length)return!1;for(h=0;h<s.length;h++){var v=s[h];if(!sl.call(l,v)||!Dn(i[v],l[v]))return!1}return!0}function Vx(i){for(;i&&i.firstChild;)i=i.firstChild;return i}function Yx(i,l){var s=Vx(i);i=0;for(var h;s;){if(s.nodeType===3){if(h=i+s.textContent.length,i<=l&&h>=l)return{node:s,offset:l-i};i=h}e:{for(;s;){if(s.nextSibling){s=s.nextSibling;break e}s=s.parentNode}s=void 0}s=Vx(s)}}function Kx(i,l){return i&&l?i===l?!0:i&&i.nodeType===3?!1:l&&l.nodeType===3?Kx(i,l.parentNode):"contains"in i?i.contains(l):i.compareDocumentPosition?!!(i.compareDocumentPosition(l)&16):!1:!1}function Gx(i){i=i!=null&&i.ownerDocument!=null&&i.ownerDocument.defaultView!=null?i.ownerDocument.defaultView:window;for(var l=$s(i.document);l instanceof i.HTMLIFrameElement;){try{var s=typeof l.contentWindow.location.href=="string"}catch{s=!1}if(s)i=l.contentWindow;else break;l=$s(i.document)}return l}function Yh(i){var l=i&&i.nodeName&&i.nodeName.toLowerCase();return l&&(l==="input"&&(i.type==="text"||i.type==="search"||i.type==="tel"||i.type==="url"||i.type==="password")||l==="textarea"||i.contentEditable==="true")}var AP=Qr&&"documentMode"in document&&11>=document.documentMode,wl=null,Kh=null,Xu=null,Gh=!1;function Xx(i,l,s){var h=s.window===s?s.document:s.nodeType===9?s:s.ownerDocument;Gh||wl==null||wl!==$s(h)||(h=wl,"selectionStart"in h&&Yh(h)?h={start:h.selectionStart,end:h.selectionEnd}:(h=(h.ownerDocument&&h.ownerDocument.defaultView||window).getSelection(),h={anchorNode:h.anchorNode,anchorOffset:h.anchorOffset,focusNode:h.focusNode,focusOffset:h.focusOffset}),Xu&&Gu(Xu,h)||(Xu=h,h=Lc(Kh,"onSelect"),0<h.length&&(l=new Gs("onSelect","select",null,l,s),i.push({event:l,listeners:h}),l.target=wl)))}function Oa(i,l){var s={};return s[i.toLowerCase()]=l.toLowerCase(),s["Webkit"+i]="webkit"+l,s["Moz"+i]="moz"+l,s}var Sl={animationend:Oa("Animation","AnimationEnd"),animationiteration:Oa("Animation","AnimationIteration"),animationstart:Oa("Animation","AnimationStart"),transitionrun:Oa("Transition","TransitionRun"),transitionstart:Oa("Transition","TransitionStart"),transitioncancel:Oa("Transition","TransitionCancel"),transitionend:Oa("Transition","TransitionEnd")},Xh={},Zx={};Qr&&(Zx=document.createElement("div").style,"AnimationEvent"in window||(delete Sl.animationend.animation,delete Sl.animationiteration.animation,delete Sl.animationstart.animation),"TransitionEvent"in window||delete Sl.transitionend.transition);function Ea(i){if(Xh[i])return Xh[i];if(!Sl[i])return i;var l=Sl[i],s;for(s in l)if(l.hasOwnProperty(s)&&s in Zx)return Xh[i]=l[s];return i}var Qx=Ea("animationend"),Wx=Ea("animationiteration"),Jx=Ea("animationstart"),_P=Ea("transitionrun"),kP=Ea("transitionstart"),CP=Ea("transitioncancel"),e1=Ea("transitionend"),t1=new Map,Zh="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Zh.push("scrollEnd");function gr(i,l){t1.set(i,l),wa(l,[i])}var Qs=typeof reportError=="function"?reportError:function(i){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var l=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof i=="object"&&i!==null&&typeof i.message=="string"?String(i.message):String(i),error:i});if(!window.dispatchEvent(l))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",i);return}console.error(i)},Qn=[],Ol=0,Qh=0;function Ws(){for(var i=Ol,l=Qh=Ol=0;l<i;){var s=Qn[l];Qn[l++]=null;var h=Qn[l];Qn[l++]=null;var v=Qn[l];Qn[l++]=null;var b=Qn[l];if(Qn[l++]=null,h!==null&&v!==null){var A=h.pending;A===null?v.next=v:(v.next=A.next,A.next=v),h.pending=v}b!==0&&n1(s,v,b)}}function Js(i,l,s,h){Qn[Ol++]=i,Qn[Ol++]=l,Qn[Ol++]=s,Qn[Ol++]=h,Qh|=h,i.lanes|=h,i=i.alternate,i!==null&&(i.lanes|=h)}function Wh(i,l,s,h){return Js(i,l,s,h),ec(i)}function Aa(i,l){return Js(i,null,null,l),ec(i)}function n1(i,l,s){i.lanes|=s;var h=i.alternate;h!==null&&(h.lanes|=s);for(var v=!1,b=i.return;b!==null;)b.childLanes|=s,h=b.alternate,h!==null&&(h.childLanes|=s),b.tag===22&&(i=b.stateNode,i===null||i._visibility&1||(v=!0)),i=b,b=b.return;return i.tag===3?(b=i.stateNode,v&&l!==null&&(v=31-tt(s),i=b.hiddenUpdates,h=i[v],h===null?i[v]=[l]:h.push(l),l.lane=s|536870912),b):null}function ec(i){if(50<go)throw go=0,up=null,Error(r(185));for(var l=i.return;l!==null;)i=l,l=i.return;return i.tag===3?i.stateNode:null}var El={};function TP(i,l,s,h){this.tag=i,this.key=s,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=l,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=h,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Nn(i,l,s,h){return new TP(i,l,s,h)}function Jh(i){return i=i.prototype,!(!i||!i.isReactComponent)}function Wr(i,l){var s=i.alternate;return s===null?(s=Nn(i.tag,l,i.key,i.mode),s.elementType=i.elementType,s.type=i.type,s.stateNode=i.stateNode,s.alternate=i,i.alternate=s):(s.pendingProps=l,s.type=i.type,s.flags=0,s.subtreeFlags=0,s.deletions=null),s.flags=i.flags&65011712,s.childLanes=i.childLanes,s.lanes=i.lanes,s.child=i.child,s.memoizedProps=i.memoizedProps,s.memoizedState=i.memoizedState,s.updateQueue=i.updateQueue,l=i.dependencies,s.dependencies=l===null?null:{lanes:l.lanes,firstContext:l.firstContext},s.sibling=i.sibling,s.index=i.index,s.ref=i.ref,s.refCleanup=i.refCleanup,s}function r1(i,l){i.flags&=65011714;var s=i.alternate;return s===null?(i.childLanes=0,i.lanes=l,i.child=null,i.subtreeFlags=0,i.memoizedProps=null,i.memoizedState=null,i.updateQueue=null,i.dependencies=null,i.stateNode=null):(i.childLanes=s.childLanes,i.lanes=s.lanes,i.child=s.child,i.subtreeFlags=0,i.deletions=null,i.memoizedProps=s.memoizedProps,i.memoizedState=s.memoizedState,i.updateQueue=s.updateQueue,i.type=s.type,l=s.dependencies,i.dependencies=l===null?null:{lanes:l.lanes,firstContext:l.firstContext}),i}function tc(i,l,s,h,v,b){var A=0;if(h=i,typeof i=="function")Jh(i)&&(A=1);else if(typeof i=="string")A=NR(i,s,oe.current)?26:i==="html"||i==="head"||i==="body"?27:5;else e:switch(i){case H:return i=Nn(31,s,l,v),i.elementType=H,i.lanes=b,i;case w:return _a(s.children,v,b,l);case S:A=8,v|=24;break;case O:return i=Nn(12,s,l,v|2),i.elementType=O,i.lanes=b,i;case N:return i=Nn(13,s,l,v),i.elementType=N,i.lanes=b,i;case C:return i=Nn(19,s,l,v),i.elementType=C,i.lanes=b,i;default:if(typeof i=="object"&&i!==null)switch(i.$$typeof){case k:A=10;break e;case _:A=9;break e;case M:A=11;break e;case z:A=14;break e;case $:A=16,h=null;break e}A=29,s=Error(r(130,i===null?"null":typeof i,"")),h=null}return l=Nn(A,s,l,v),l.elementType=i,l.type=h,l.lanes=b,l}function _a(i,l,s,h){return i=Nn(7,i,h,l),i.lanes=s,i}function em(i,l,s){return i=Nn(6,i,null,l),i.lanes=s,i}function i1(i){var l=Nn(18,null,null,0);return l.stateNode=i,l}function tm(i,l,s){return l=Nn(4,i.children!==null?i.children:[],i.key,l),l.lanes=s,l.stateNode={containerInfo:i.containerInfo,pendingChildren:null,implementation:i.implementation},l}var a1=new WeakMap;function Wn(i,l){if(typeof i=="object"&&i!==null){var s=a1.get(i);return s!==void 0?s:(l={value:i,source:l,stack:ba(l)},a1.set(i,l),l)}return{value:i,source:l,stack:ba(l)}}var Al=[],_l=0,nc=null,Zu=0,Jn=[],er=0,Ui=null,Mr=1,zr="";function Jr(i,l){Al[_l++]=Zu,Al[_l++]=nc,nc=i,Zu=l}function l1(i,l,s){Jn[er++]=Mr,Jn[er++]=zr,Jn[er++]=Ui,Ui=i;var h=Mr;i=zr;var v=32-tt(h)-1;h&=~(1<<v),s+=1;var b=32-tt(l)+v;if(30<b){var A=v-v%5;b=(h&(1<<A)-1).toString(32),h>>=A,v-=A,Mr=1<<32-tt(l)+v|s<<v|h,zr=b+i}else Mr=1<<b|s<<v|h,zr=i}function nm(i){i.return!==null&&(Jr(i,1),l1(i,1,0))}function rm(i){for(;i===nc;)nc=Al[--_l],Al[_l]=null,Zu=Al[--_l],Al[_l]=null;for(;i===Ui;)Ui=Jn[--er],Jn[er]=null,zr=Jn[--er],Jn[er]=null,Mr=Jn[--er],Jn[er]=null}function u1(i,l){Jn[er++]=Mr,Jn[er++]=zr,Jn[er++]=Ui,Mr=l.id,zr=l.overflow,Ui=i}var Kt=null,ot=null,Ue=!1,qi=null,tr=!1,im=Error(r(519));function Hi(i){var l=Error(r(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Qu(Wn(l,i)),im}function o1(i){var l=i.stateNode,s=i.type,h=i.memoizedProps;switch(l[Yt]=i,l[gn]=h,s){case"dialog":Pe("cancel",l),Pe("close",l);break;case"iframe":case"object":case"embed":Pe("load",l);break;case"video":case"audio":for(s=0;s<xo.length;s++)Pe(xo[s],l);break;case"source":Pe("error",l);break;case"img":case"image":case"link":Pe("error",l),Pe("load",l);break;case"details":Pe("toggle",l);break;case"input":Pe("invalid",l),wx(l,h.value,h.defaultValue,h.checked,h.defaultChecked,h.type,h.name,!0);break;case"select":Pe("invalid",l);break;case"textarea":Pe("invalid",l),Ox(l,h.value,h.defaultValue,h.children)}s=h.children,typeof s!="string"&&typeof s!="number"&&typeof s!="bigint"||l.textContent===""+s||h.suppressHydrationWarning===!0||AS(l.textContent,s)?(h.popover!=null&&(Pe("beforetoggle",l),Pe("toggle",l)),h.onScroll!=null&&Pe("scroll",l),h.onScrollEnd!=null&&Pe("scrollend",l),h.onClick!=null&&(l.onclick=Zr),l=!0):l=!1,l||Hi(i,!0)}function s1(i){for(Kt=i.return;Kt;)switch(Kt.tag){case 5:case 31:case 13:tr=!1;return;case 27:case 3:tr=!0;return;default:Kt=Kt.return}}function kl(i){if(i!==Kt)return!1;if(!Ue)return s1(i),Ue=!0,!1;var l=i.tag,s;if((s=l!==3&&l!==27)&&((s=l===5)&&(s=i.type,s=!(s!=="form"&&s!=="button")||Sp(i.type,i.memoizedProps)),s=!s),s&&ot&&Hi(i),s1(i),l===13){if(i=i.memoizedState,i=i!==null?i.dehydrated:null,!i)throw Error(r(317));ot=NS(i)}else if(l===31){if(i=i.memoizedState,i=i!==null?i.dehydrated:null,!i)throw Error(r(317));ot=NS(i)}else l===27?(l=ot,na(i.type)?(i=kp,kp=null,ot=i):ot=l):ot=Kt?rr(i.stateNode.nextSibling):null;return!0}function ka(){ot=Kt=null,Ue=!1}function am(){var i=qi;return i!==null&&(On===null?On=i:On.push.apply(On,i),qi=null),i}function Qu(i){qi===null?qi=[i]:qi.push(i)}var lm=L(null),Ca=null,ei=null;function $i(i,l,s){D(lm,l._currentValue),l._currentValue=s}function ti(i){i._currentValue=lm.current,J(lm)}function um(i,l,s){for(;i!==null;){var h=i.alternate;if((i.childLanes&l)!==l?(i.childLanes|=l,h!==null&&(h.childLanes|=l)):h!==null&&(h.childLanes&l)!==l&&(h.childLanes|=l),i===s)break;i=i.return}}function om(i,l,s,h){var v=i.child;for(v!==null&&(v.return=i);v!==null;){var b=v.dependencies;if(b!==null){var A=v.child;b=b.firstContext;e:for(;b!==null;){var j=b;b=v;for(var B=0;B<l.length;B++)if(j.context===l[B]){b.lanes|=s,j=b.alternate,j!==null&&(j.lanes|=s),um(b.return,s,i),h||(A=null);break e}b=j.next}}else if(v.tag===18){if(A=v.return,A===null)throw Error(r(341));A.lanes|=s,b=A.alternate,b!==null&&(b.lanes|=s),um(A,s,i),A=null}else A=v.child;if(A!==null)A.return=v;else for(A=v;A!==null;){if(A===i){A=null;break}if(v=A.sibling,v!==null){v.return=A.return,A=v;break}A=A.return}v=A}}function Cl(i,l,s,h){i=null;for(var v=l,b=!1;v!==null;){if(!b){if((v.flags&524288)!==0)b=!0;else if((v.flags&262144)!==0)break}if(v.tag===10){var A=v.alternate;if(A===null)throw Error(r(387));if(A=A.memoizedProps,A!==null){var j=v.type;Dn(v.pendingProps.value,A.value)||(i!==null?i.push(j):i=[j])}}else if(v===Se.current){if(A=v.alternate,A===null)throw Error(r(387));A.memoizedState.memoizedState!==v.memoizedState.memoizedState&&(i!==null?i.push(Ao):i=[Ao])}v=v.return}i!==null&&om(l,i,s,h),l.flags|=262144}function rc(i){for(i=i.firstContext;i!==null;){if(!Dn(i.context._currentValue,i.memoizedValue))return!0;i=i.next}return!1}function Ta(i){Ca=i,ei=null,i=i.dependencies,i!==null&&(i.firstContext=null)}function Gt(i){return c1(Ca,i)}function ic(i,l){return Ca===null&&Ta(i),c1(i,l)}function c1(i,l){var s=l._currentValue;if(l={context:l,memoizedValue:s,next:null},ei===null){if(i===null)throw Error(r(308));ei=l,i.dependencies={lanes:0,firstContext:l},i.flags|=524288}else ei=ei.next=l;return s}var jP=typeof AbortController<"u"?AbortController:function(){var i=[],l=this.signal={aborted:!1,addEventListener:function(s,h){i.push(h)}};this.abort=function(){l.aborted=!0,i.forEach(function(s){return s()})}},MP=e.unstable_scheduleCallback,zP=e.unstable_NormalPriority,Et={$$typeof:k,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function sm(){return{controller:new jP,data:new Map,refCount:0}}function Wu(i){i.refCount--,i.refCount===0&&MP(zP,function(){i.controller.abort()})}var Ju=null,cm=0,Tl=0,jl=null;function DP(i,l){if(Ju===null){var s=Ju=[];cm=0,Tl=hp(),jl={status:"pending",value:void 0,then:function(h){s.push(h)}}}return cm++,l.then(f1,f1),l}function f1(){if(--cm===0&&Ju!==null){jl!==null&&(jl.status="fulfilled");var i=Ju;Ju=null,Tl=0,jl=null;for(var l=0;l<i.length;l++)(0,i[l])()}}function NP(i,l){var s=[],h={status:"pending",value:null,reason:null,then:function(v){s.push(v)}};return i.then(function(){h.status="fulfilled",h.value=l;for(var v=0;v<s.length;v++)(0,s[v])(l)},function(v){for(h.status="rejected",h.reason=v,v=0;v<s.length;v++)(0,s[v])(void 0)}),h}var d1=U.S;U.S=function(i,l){Xw=on(),typeof l=="object"&&l!==null&&typeof l.then=="function"&&DP(i,l),d1!==null&&d1(i,l)};var ja=L(null);function fm(){var i=ja.current;return i!==null?i:nt.pooledCache}function ac(i,l){l===null?D(ja,ja.current):D(ja,l.pool)}function h1(){var i=fm();return i===null?null:{parent:Et._currentValue,pool:i}}var Ml=Error(r(460)),dm=Error(r(474)),lc=Error(r(542)),uc={then:function(){}};function m1(i){return i=i.status,i==="fulfilled"||i==="rejected"}function p1(i,l,s){switch(s=i[s],s===void 0?i.push(l):s!==l&&(l.then(Zr,Zr),l=s),l.status){case"fulfilled":return l.value;case"rejected":throw i=l.reason,y1(i),i;default:if(typeof l.status=="string")l.then(Zr,Zr);else{if(i=nt,i!==null&&100<i.shellSuspendCounter)throw Error(r(482));i=l,i.status="pending",i.then(function(h){if(l.status==="pending"){var v=l;v.status="fulfilled",v.value=h}},function(h){if(l.status==="pending"){var v=l;v.status="rejected",v.reason=h}})}switch(l.status){case"fulfilled":return l.value;case"rejected":throw i=l.reason,y1(i),i}throw za=l,Ml}}function Ma(i){try{var l=i._init;return l(i._payload)}catch(s){throw s!==null&&typeof s=="object"&&typeof s.then=="function"?(za=s,Ml):s}}var za=null;function v1(){if(za===null)throw Error(r(459));var i=za;return za=null,i}function y1(i){if(i===Ml||i===lc)throw Error(r(483))}var zl=null,eo=0;function oc(i){var l=eo;return eo+=1,zl===null&&(zl=[]),p1(zl,i,l)}function to(i,l){l=l.props.ref,i.ref=l!==void 0?l:null}function sc(i,l){throw l.$$typeof===y?Error(r(525)):(i=Object.prototype.toString.call(l),Error(r(31,i==="[object Object]"?"object with keys {"+Object.keys(l).join(", ")+"}":i)))}function g1(i){function l(V,q){if(i){var G=V.deletions;G===null?(V.deletions=[q],V.flags|=16):G.push(q)}}function s(V,q){if(!i)return null;for(;q!==null;)l(V,q),q=q.sibling;return null}function h(V){for(var q=new Map;V!==null;)V.key!==null?q.set(V.key,V):q.set(V.index,V),V=V.sibling;return q}function v(V,q){return V=Wr(V,q),V.index=0,V.sibling=null,V}function b(V,q,G){return V.index=G,i?(G=V.alternate,G!==null?(G=G.index,G<q?(V.flags|=67108866,q):G):(V.flags|=67108866,q)):(V.flags|=1048576,q)}function A(V){return i&&V.alternate===null&&(V.flags|=67108866),V}function j(V,q,G,ae){return q===null||q.tag!==6?(q=em(G,V.mode,ae),q.return=V,q):(q=v(q,G),q.return=V,q)}function B(V,q,G,ae){var Oe=G.type;return Oe===w?re(V,q,G.props.children,ae,G.key):q!==null&&(q.elementType===Oe||typeof Oe=="object"&&Oe!==null&&Oe.$$typeof===$&&Ma(Oe)===q.type)?(q=v(q,G.props),to(q,G),q.return=V,q):(q=tc(G.type,G.key,G.props,null,V.mode,ae),to(q,G),q.return=V,q)}function X(V,q,G,ae){return q===null||q.tag!==4||q.stateNode.containerInfo!==G.containerInfo||q.stateNode.implementation!==G.implementation?(q=tm(G,V.mode,ae),q.return=V,q):(q=v(q,G.children||[]),q.return=V,q)}function re(V,q,G,ae,Oe){return q===null||q.tag!==7?(q=_a(G,V.mode,ae,Oe),q.return=V,q):(q=v(q,G),q.return=V,q)}function le(V,q,G){if(typeof q=="string"&&q!==""||typeof q=="number"||typeof q=="bigint")return q=em(""+q,V.mode,G),q.return=V,q;if(typeof q=="object"&&q!==null){switch(q.$$typeof){case g:return G=tc(q.type,q.key,q.props,null,V.mode,G),to(G,q),G.return=V,G;case x:return q=tm(q,V.mode,G),q.return=V,q;case $:return q=Ma(q),le(V,q,G)}if(Y(q)||I(q))return q=_a(q,V.mode,G,null),q.return=V,q;if(typeof q.then=="function")return le(V,oc(q),G);if(q.$$typeof===k)return le(V,ic(V,q),G);sc(V,q)}return null}function W(V,q,G,ae){var Oe=q!==null?q.key:null;if(typeof G=="string"&&G!==""||typeof G=="number"||typeof G=="bigint")return Oe!==null?null:j(V,q,""+G,ae);if(typeof G=="object"&&G!==null){switch(G.$$typeof){case g:return G.key===Oe?B(V,q,G,ae):null;case x:return G.key===Oe?X(V,q,G,ae):null;case $:return G=Ma(G),W(V,q,G,ae)}if(Y(G)||I(G))return Oe!==null?null:re(V,q,G,ae,null);if(typeof G.then=="function")return W(V,q,oc(G),ae);if(G.$$typeof===k)return W(V,q,ic(V,G),ae);sc(V,G)}return null}function ne(V,q,G,ae,Oe){if(typeof ae=="string"&&ae!==""||typeof ae=="number"||typeof ae=="bigint")return V=V.get(G)||null,j(q,V,""+ae,Oe);if(typeof ae=="object"&&ae!==null){switch(ae.$$typeof){case g:return V=V.get(ae.key===null?G:ae.key)||null,B(q,V,ae,Oe);case x:return V=V.get(ae.key===null?G:ae.key)||null,X(q,V,ae,Oe);case $:return ae=Ma(ae),ne(V,q,G,ae,Oe)}if(Y(ae)||I(ae))return V=V.get(G)||null,re(q,V,ae,Oe,null);if(typeof ae.then=="function")return ne(V,q,G,oc(ae),Oe);if(ae.$$typeof===k)return ne(V,q,G,ic(q,ae),Oe);sc(q,ae)}return null}function pe(V,q,G,ae){for(var Oe=null,$e=null,xe=q,Me=q=0,Be=null;xe!==null&&Me<G.length;Me++){xe.index>Me?(Be=xe,xe=null):Be=xe.sibling;var Fe=W(V,xe,G[Me],ae);if(Fe===null){xe===null&&(xe=Be);break}i&&xe&&Fe.alternate===null&&l(V,xe),q=b(Fe,q,Me),$e===null?Oe=Fe:$e.sibling=Fe,$e=Fe,xe=Be}if(Me===G.length)return s(V,xe),Ue&&Jr(V,Me),Oe;if(xe===null){for(;Me<G.length;Me++)xe=le(V,G[Me],ae),xe!==null&&(q=b(xe,q,Me),$e===null?Oe=xe:$e.sibling=xe,$e=xe);return Ue&&Jr(V,Me),Oe}for(xe=h(xe);Me<G.length;Me++)Be=ne(xe,V,Me,G[Me],ae),Be!==null&&(i&&Be.alternate!==null&&xe.delete(Be.key===null?Me:Be.key),q=b(Be,q,Me),$e===null?Oe=Be:$e.sibling=Be,$e=Be);return i&&xe.forEach(function(ua){return l(V,ua)}),Ue&&Jr(V,Me),Oe}function _e(V,q,G,ae){if(G==null)throw Error(r(151));for(var Oe=null,$e=null,xe=q,Me=q=0,Be=null,Fe=G.next();xe!==null&&!Fe.done;Me++,Fe=G.next()){xe.index>Me?(Be=xe,xe=null):Be=xe.sibling;var ua=W(V,xe,Fe.value,ae);if(ua===null){xe===null&&(xe=Be);break}i&&xe&&ua.alternate===null&&l(V,xe),q=b(ua,q,Me),$e===null?Oe=ua:$e.sibling=ua,$e=ua,xe=Be}if(Fe.done)return s(V,xe),Ue&&Jr(V,Me),Oe;if(xe===null){for(;!Fe.done;Me++,Fe=G.next())Fe=le(V,Fe.value,ae),Fe!==null&&(q=b(Fe,q,Me),$e===null?Oe=Fe:$e.sibling=Fe,$e=Fe);return Ue&&Jr(V,Me),Oe}for(xe=h(xe);!Fe.done;Me++,Fe=G.next())Fe=ne(xe,V,Me,Fe.value,ae),Fe!==null&&(i&&Fe.alternate!==null&&xe.delete(Fe.key===null?Me:Fe.key),q=b(Fe,q,Me),$e===null?Oe=Fe:$e.sibling=Fe,$e=Fe);return i&&xe.forEach(function(VR){return l(V,VR)}),Ue&&Jr(V,Me),Oe}function Je(V,q,G,ae){if(typeof G=="object"&&G!==null&&G.type===w&&G.key===null&&(G=G.props.children),typeof G=="object"&&G!==null){switch(G.$$typeof){case g:e:{for(var Oe=G.key;q!==null;){if(q.key===Oe){if(Oe=G.type,Oe===w){if(q.tag===7){s(V,q.sibling),ae=v(q,G.props.children),ae.return=V,V=ae;break e}}else if(q.elementType===Oe||typeof Oe=="object"&&Oe!==null&&Oe.$$typeof===$&&Ma(Oe)===q.type){s(V,q.sibling),ae=v(q,G.props),to(ae,G),ae.return=V,V=ae;break e}s(V,q);break}else l(V,q);q=q.sibling}G.type===w?(ae=_a(G.props.children,V.mode,ae,G.key),ae.return=V,V=ae):(ae=tc(G.type,G.key,G.props,null,V.mode,ae),to(ae,G),ae.return=V,V=ae)}return A(V);case x:e:{for(Oe=G.key;q!==null;){if(q.key===Oe)if(q.tag===4&&q.stateNode.containerInfo===G.containerInfo&&q.stateNode.implementation===G.implementation){s(V,q.sibling),ae=v(q,G.children||[]),ae.return=V,V=ae;break e}else{s(V,q);break}else l(V,q);q=q.sibling}ae=tm(G,V.mode,ae),ae.return=V,V=ae}return A(V);case $:return G=Ma(G),Je(V,q,G,ae)}if(Y(G))return pe(V,q,G,ae);if(I(G)){if(Oe=I(G),typeof Oe!="function")throw Error(r(150));return G=Oe.call(G),_e(V,q,G,ae)}if(typeof G.then=="function")return Je(V,q,oc(G),ae);if(G.$$typeof===k)return Je(V,q,ic(V,G),ae);sc(V,G)}return typeof G=="string"&&G!==""||typeof G=="number"||typeof G=="bigint"?(G=""+G,q!==null&&q.tag===6?(s(V,q.sibling),ae=v(q,G),ae.return=V,V=ae):(s(V,q),ae=em(G,V.mode,ae),ae.return=V,V=ae),A(V)):s(V,q)}return function(V,q,G,ae){try{eo=0;var Oe=Je(V,q,G,ae);return zl=null,Oe}catch(xe){if(xe===Ml||xe===lc)throw xe;var $e=Nn(29,xe,null,V.mode);return $e.lanes=ae,$e.return=V,$e}finally{}}}var Da=g1(!0),b1=g1(!1),Fi=!1;function hm(i){i.updateQueue={baseState:i.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function mm(i,l){i=i.updateQueue,l.updateQueue===i&&(l.updateQueue={baseState:i.baseState,firstBaseUpdate:i.firstBaseUpdate,lastBaseUpdate:i.lastBaseUpdate,shared:i.shared,callbacks:null})}function Vi(i){return{lane:i,tag:0,payload:null,callback:null,next:null}}function Yi(i,l,s){var h=i.updateQueue;if(h===null)return null;if(h=h.shared,(Ye&2)!==0){var v=h.pending;return v===null?l.next=l:(l.next=v.next,v.next=l),h.pending=l,l=ec(i),n1(i,null,s),l}return Js(i,h,l,s),ec(i)}function no(i,l,s){if(l=l.updateQueue,l!==null&&(l=l.shared,(s&4194048)!==0)){var h=l.lanes;h&=i.pendingLanes,s|=h,l.lanes=s,cx(i,s)}}function pm(i,l){var s=i.updateQueue,h=i.alternate;if(h!==null&&(h=h.updateQueue,s===h)){var v=null,b=null;if(s=s.firstBaseUpdate,s!==null){do{var A={lane:s.lane,tag:s.tag,payload:s.payload,callback:null,next:null};b===null?v=b=A:b=b.next=A,s=s.next}while(s!==null);b===null?v=b=l:b=b.next=l}else v=b=l;s={baseState:h.baseState,firstBaseUpdate:v,lastBaseUpdate:b,shared:h.shared,callbacks:h.callbacks},i.updateQueue=s;return}i=s.lastBaseUpdate,i===null?s.firstBaseUpdate=l:i.next=l,s.lastBaseUpdate=l}var vm=!1;function ro(){if(vm){var i=jl;if(i!==null)throw i}}function io(i,l,s,h){vm=!1;var v=i.updateQueue;Fi=!1;var b=v.firstBaseUpdate,A=v.lastBaseUpdate,j=v.shared.pending;if(j!==null){v.shared.pending=null;var B=j,X=B.next;B.next=null,A===null?b=X:A.next=X,A=B;var re=i.alternate;re!==null&&(re=re.updateQueue,j=re.lastBaseUpdate,j!==A&&(j===null?re.firstBaseUpdate=X:j.next=X,re.lastBaseUpdate=B))}if(b!==null){var le=v.baseState;A=0,re=X=B=null,j=b;do{var W=j.lane&-536870913,ne=W!==j.lane;if(ne?(Le&W)===W:(h&W)===W){W!==0&&W===Tl&&(vm=!0),re!==null&&(re=re.next={lane:0,tag:j.tag,payload:j.payload,callback:null,next:null});e:{var pe=i,_e=j;W=l;var Je=s;switch(_e.tag){case 1:if(pe=_e.payload,typeof pe=="function"){le=pe.call(Je,le,W);break e}le=pe;break e;case 3:pe.flags=pe.flags&-65537|128;case 0:if(pe=_e.payload,W=typeof pe=="function"?pe.call(Je,le,W):pe,W==null)break e;le=p({},le,W);break e;case 2:Fi=!0}}W=j.callback,W!==null&&(i.flags|=64,ne&&(i.flags|=8192),ne=v.callbacks,ne===null?v.callbacks=[W]:ne.push(W))}else ne={lane:W,tag:j.tag,payload:j.payload,callback:j.callback,next:null},re===null?(X=re=ne,B=le):re=re.next=ne,A|=W;if(j=j.next,j===null){if(j=v.shared.pending,j===null)break;ne=j,j=ne.next,ne.next=null,v.lastBaseUpdate=ne,v.shared.pending=null}}while(!0);re===null&&(B=le),v.baseState=B,v.firstBaseUpdate=X,v.lastBaseUpdate=re,b===null&&(v.shared.lanes=0),Qi|=A,i.lanes=A,i.memoizedState=le}}function x1(i,l){if(typeof i!="function")throw Error(r(191,i));i.call(l)}function w1(i,l){var s=i.callbacks;if(s!==null)for(i.callbacks=null,i=0;i<s.length;i++)x1(s[i],l)}var Dl=L(null),cc=L(0);function S1(i,l){i=ci,D(cc,i),D(Dl,l),ci=i|l.baseLanes}function ym(){D(cc,ci),D(Dl,Dl.current)}function gm(){ci=cc.current,J(Dl),J(cc)}var Pn=L(null),nr=null;function Ki(i){var l=i.alternate;D(bt,bt.current&1),D(Pn,i),nr===null&&(l===null||Dl.current!==null||l.memoizedState!==null)&&(nr=i)}function bm(i){D(bt,bt.current),D(Pn,i),nr===null&&(nr=i)}function O1(i){i.tag===22?(D(bt,bt.current),D(Pn,i),nr===null&&(nr=i)):Gi()}function Gi(){D(bt,bt.current),D(Pn,Pn.current)}function Rn(i){J(Pn),nr===i&&(nr=null),J(bt)}var bt=L(0);function fc(i){for(var l=i;l!==null;){if(l.tag===13){var s=l.memoizedState;if(s!==null&&(s=s.dehydrated,s===null||Ap(s)||_p(s)))return l}else if(l.tag===19&&(l.memoizedProps.revealOrder==="forwards"||l.memoizedProps.revealOrder==="backwards"||l.memoizedProps.revealOrder==="unstable_legacy-backwards"||l.memoizedProps.revealOrder==="together")){if((l.flags&128)!==0)return l}else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===i)break;for(;l.sibling===null;){if(l.return===null||l.return===i)return null;l=l.return}l.sibling.return=l.return,l=l.sibling}return null}var ni=0,Te=null,Qe=null,At=null,dc=!1,Nl=!1,Na=!1,hc=0,ao=0,Pl=null,PP=0;function pt(){throw Error(r(321))}function xm(i,l){if(l===null)return!1;for(var s=0;s<l.length&&s<i.length;s++)if(!Dn(i[s],l[s]))return!1;return!0}function wm(i,l,s,h,v,b){return ni=b,Te=l,l.memoizedState=null,l.updateQueue=null,l.lanes=0,U.H=i===null||i.memoizedState===null?lw:Rm,Na=!1,b=s(h,v),Na=!1,Nl&&(b=A1(l,s,h,v)),E1(i),b}function E1(i){U.H=oo;var l=Qe!==null&&Qe.next!==null;if(ni=0,At=Qe=Te=null,dc=!1,ao=0,Pl=null,l)throw Error(r(300));i===null||_t||(i=i.dependencies,i!==null&&rc(i)&&(_t=!0))}function A1(i,l,s,h){Te=i;var v=0;do{if(Nl&&(Pl=null),ao=0,Nl=!1,25<=v)throw Error(r(301));if(v+=1,At=Qe=null,i.updateQueue!=null){var b=i.updateQueue;b.lastEffect=null,b.events=null,b.stores=null,b.memoCache!=null&&(b.memoCache.index=0)}U.H=uw,b=l(s,h)}while(Nl);return b}function RP(){var i=U.H,l=i.useState()[0];return l=typeof l.then=="function"?lo(l):l,i=i.useState()[0],(Qe!==null?Qe.memoizedState:null)!==i&&(Te.flags|=1024),l}function Sm(){var i=hc!==0;return hc=0,i}function Om(i,l,s){l.updateQueue=i.updateQueue,l.flags&=-2053,i.lanes&=~s}function Em(i){if(dc){for(i=i.memoizedState;i!==null;){var l=i.queue;l!==null&&(l.pending=null),i=i.next}dc=!1}ni=0,At=Qe=Te=null,Nl=!1,ao=hc=0,Pl=null}function cn(){var i={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return At===null?Te.memoizedState=At=i:At=At.next=i,At}function xt(){if(Qe===null){var i=Te.alternate;i=i!==null?i.memoizedState:null}else i=Qe.next;var l=At===null?Te.memoizedState:At.next;if(l!==null)At=l,Qe=i;else{if(i===null)throw Te.alternate===null?Error(r(467)):Error(r(310));Qe=i,i={memoizedState:Qe.memoizedState,baseState:Qe.baseState,baseQueue:Qe.baseQueue,queue:Qe.queue,next:null},At===null?Te.memoizedState=At=i:At=At.next=i}return At}function mc(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function lo(i){var l=ao;return ao+=1,Pl===null&&(Pl=[]),i=p1(Pl,i,l),l=Te,(At===null?l.memoizedState:At.next)===null&&(l=l.alternate,U.H=l===null||l.memoizedState===null?lw:Rm),i}function pc(i){if(i!==null&&typeof i=="object"){if(typeof i.then=="function")return lo(i);if(i.$$typeof===k)return Gt(i)}throw Error(r(438,String(i)))}function Am(i){var l=null,s=Te.updateQueue;if(s!==null&&(l=s.memoCache),l==null){var h=Te.alternate;h!==null&&(h=h.updateQueue,h!==null&&(h=h.memoCache,h!=null&&(l={data:h.data.map(function(v){return v.slice()}),index:0})))}if(l==null&&(l={data:[],index:0}),s===null&&(s=mc(),Te.updateQueue=s),s.memoCache=l,s=l.data[l.index],s===void 0)for(s=l.data[l.index]=Array(i),h=0;h<i;h++)s[h]=P;return l.index++,s}function ri(i,l){return typeof l=="function"?l(i):l}function vc(i){var l=xt();return _m(l,Qe,i)}function _m(i,l,s){var h=i.queue;if(h===null)throw Error(r(311));h.lastRenderedReducer=s;var v=i.baseQueue,b=h.pending;if(b!==null){if(v!==null){var A=v.next;v.next=b.next,b.next=A}l.baseQueue=v=b,h.pending=null}if(b=i.baseState,v===null)i.memoizedState=b;else{l=v.next;var j=A=null,B=null,X=l,re=!1;do{var le=X.lane&-536870913;if(le!==X.lane?(Le&le)===le:(ni&le)===le){var W=X.revertLane;if(W===0)B!==null&&(B=B.next={lane:0,revertLane:0,gesture:null,action:X.action,hasEagerState:X.hasEagerState,eagerState:X.eagerState,next:null}),le===Tl&&(re=!0);else if((ni&W)===W){X=X.next,W===Tl&&(re=!0);continue}else le={lane:0,revertLane:X.revertLane,gesture:null,action:X.action,hasEagerState:X.hasEagerState,eagerState:X.eagerState,next:null},B===null?(j=B=le,A=b):B=B.next=le,Te.lanes|=W,Qi|=W;le=X.action,Na&&s(b,le),b=X.hasEagerState?X.eagerState:s(b,le)}else W={lane:le,revertLane:X.revertLane,gesture:X.gesture,action:X.action,hasEagerState:X.hasEagerState,eagerState:X.eagerState,next:null},B===null?(j=B=W,A=b):B=B.next=W,Te.lanes|=le,Qi|=le;X=X.next}while(X!==null&&X!==l);if(B===null?A=b:B.next=j,!Dn(b,i.memoizedState)&&(_t=!0,re&&(s=jl,s!==null)))throw s;i.memoizedState=b,i.baseState=A,i.baseQueue=B,h.lastRenderedState=b}return v===null&&(h.lanes=0),[i.memoizedState,h.dispatch]}function km(i){var l=xt(),s=l.queue;if(s===null)throw Error(r(311));s.lastRenderedReducer=i;var h=s.dispatch,v=s.pending,b=l.memoizedState;if(v!==null){s.pending=null;var A=v=v.next;do b=i(b,A.action),A=A.next;while(A!==v);Dn(b,l.memoizedState)||(_t=!0),l.memoizedState=b,l.baseQueue===null&&(l.baseState=b),s.lastRenderedState=b}return[b,h]}function _1(i,l,s){var h=Te,v=xt(),b=Ue;if(b){if(s===void 0)throw Error(r(407));s=s()}else s=l();var A=!Dn((Qe||v).memoizedState,s);if(A&&(v.memoizedState=s,_t=!0),v=v.queue,jm(T1.bind(null,h,v,i),[i]),v.getSnapshot!==l||A||At!==null&&At.memoizedState.tag&1){if(h.flags|=2048,Rl(9,{destroy:void 0},C1.bind(null,h,v,s,l),null),nt===null)throw Error(r(349));b||(ni&127)!==0||k1(h,l,s)}return s}function k1(i,l,s){i.flags|=16384,i={getSnapshot:l,value:s},l=Te.updateQueue,l===null?(l=mc(),Te.updateQueue=l,l.stores=[i]):(s=l.stores,s===null?l.stores=[i]:s.push(i))}function C1(i,l,s,h){l.value=s,l.getSnapshot=h,j1(l)&&M1(i)}function T1(i,l,s){return s(function(){j1(l)&&M1(i)})}function j1(i){var l=i.getSnapshot;i=i.value;try{var s=l();return!Dn(i,s)}catch{return!0}}function M1(i){var l=Aa(i,2);l!==null&&En(l,i,2)}function Cm(i){var l=cn();if(typeof i=="function"){var s=i;if(i=s(),Na){yn(!0);try{s()}finally{yn(!1)}}}return l.memoizedState=l.baseState=i,l.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:ri,lastRenderedState:i},l}function z1(i,l,s,h){return i.baseState=s,_m(i,Qe,typeof h=="function"?h:ri)}function IP(i,l,s,h,v){if(bc(i))throw Error(r(485));if(i=l.action,i!==null){var b={payload:v,action:i,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(A){b.listeners.push(A)}};U.T!==null?s(!0):b.isTransition=!1,h(b),s=l.pending,s===null?(b.next=l.pending=b,D1(l,b)):(b.next=s.next,l.pending=s.next=b)}}function D1(i,l){var s=l.action,h=l.payload,v=i.state;if(l.isTransition){var b=U.T,A={};U.T=A;try{var j=s(v,h),B=U.S;B!==null&&B(A,j),N1(i,l,j)}catch(X){Tm(i,l,X)}finally{b!==null&&A.types!==null&&(b.types=A.types),U.T=b}}else try{b=s(v,h),N1(i,l,b)}catch(X){Tm(i,l,X)}}function N1(i,l,s){s!==null&&typeof s=="object"&&typeof s.then=="function"?s.then(function(h){P1(i,l,h)},function(h){return Tm(i,l,h)}):P1(i,l,s)}function P1(i,l,s){l.status="fulfilled",l.value=s,R1(l),i.state=s,l=i.pending,l!==null&&(s=l.next,s===l?i.pending=null:(s=s.next,l.next=s,D1(i,s)))}function Tm(i,l,s){var h=i.pending;if(i.pending=null,h!==null){h=h.next;do l.status="rejected",l.reason=s,R1(l),l=l.next;while(l!==h)}i.action=null}function R1(i){i=i.listeners;for(var l=0;l<i.length;l++)(0,i[l])()}function I1(i,l){return l}function L1(i,l){if(Ue){var s=nt.formState;if(s!==null){e:{var h=Te;if(Ue){if(ot){t:{for(var v=ot,b=tr;v.nodeType!==8;){if(!b){v=null;break t}if(v=rr(v.nextSibling),v===null){v=null;break t}}b=v.data,v=b==="F!"||b==="F"?v:null}if(v){ot=rr(v.nextSibling),h=v.data==="F!";break e}}Hi(h)}h=!1}h&&(l=s[0])}}return s=cn(),s.memoizedState=s.baseState=l,h={pending:null,lanes:0,dispatch:null,lastRenderedReducer:I1,lastRenderedState:l},s.queue=h,s=rw.bind(null,Te,h),h.dispatch=s,h=Cm(!1),b=Pm.bind(null,Te,!1,h.queue),h=cn(),v={state:l,dispatch:null,action:i,pending:null},h.queue=v,s=IP.bind(null,Te,v,b,s),v.dispatch=s,h.memoizedState=i,[l,s,!1]}function B1(i){var l=xt();return U1(l,Qe,i)}function U1(i,l,s){if(l=_m(i,l,I1)[0],i=vc(ri)[0],typeof l=="object"&&l!==null&&typeof l.then=="function")try{var h=lo(l)}catch(A){throw A===Ml?lc:A}else h=l;l=xt();var v=l.queue,b=v.dispatch;return s!==l.memoizedState&&(Te.flags|=2048,Rl(9,{destroy:void 0},LP.bind(null,v,s),null)),[h,b,i]}function LP(i,l){i.action=l}function q1(i){var l=xt(),s=Qe;if(s!==null)return U1(l,s,i);xt(),l=l.memoizedState,s=xt();var h=s.queue.dispatch;return s.memoizedState=i,[l,h,!1]}function Rl(i,l,s,h){return i={tag:i,create:s,deps:h,inst:l,next:null},l=Te.updateQueue,l===null&&(l=mc(),Te.updateQueue=l),s=l.lastEffect,s===null?l.lastEffect=i.next=i:(h=s.next,s.next=i,i.next=h,l.lastEffect=i),i}function H1(){return xt().memoizedState}function yc(i,l,s,h){var v=cn();Te.flags|=i,v.memoizedState=Rl(1|l,{destroy:void 0},s,h===void 0?null:h)}function gc(i,l,s,h){var v=xt();h=h===void 0?null:h;var b=v.memoizedState.inst;Qe!==null&&h!==null&&xm(h,Qe.memoizedState.deps)?v.memoizedState=Rl(l,b,s,h):(Te.flags|=i,v.memoizedState=Rl(1|l,b,s,h))}function $1(i,l){yc(8390656,8,i,l)}function jm(i,l){gc(2048,8,i,l)}function BP(i){Te.flags|=4;var l=Te.updateQueue;if(l===null)l=mc(),Te.updateQueue=l,l.events=[i];else{var s=l.events;s===null?l.events=[i]:s.push(i)}}function F1(i){var l=xt().memoizedState;return BP({ref:l,nextImpl:i}),function(){if((Ye&2)!==0)throw Error(r(440));return l.impl.apply(void 0,arguments)}}function V1(i,l){return gc(4,2,i,l)}function Y1(i,l){return gc(4,4,i,l)}function K1(i,l){if(typeof l=="function"){i=i();var s=l(i);return function(){typeof s=="function"?s():l(null)}}if(l!=null)return i=i(),l.current=i,function(){l.current=null}}function G1(i,l,s){s=s!=null?s.concat([i]):null,gc(4,4,K1.bind(null,l,i),s)}function Mm(){}function X1(i,l){var s=xt();l=l===void 0?null:l;var h=s.memoizedState;return l!==null&&xm(l,h[1])?h[0]:(s.memoizedState=[i,l],i)}function Z1(i,l){var s=xt();l=l===void 0?null:l;var h=s.memoizedState;if(l!==null&&xm(l,h[1]))return h[0];if(h=i(),Na){yn(!0);try{i()}finally{yn(!1)}}return s.memoizedState=[h,l],h}function zm(i,l,s){return s===void 0||(ni&1073741824)!==0&&(Le&261930)===0?i.memoizedState=l:(i.memoizedState=s,i=Qw(),Te.lanes|=i,Qi|=i,s)}function Q1(i,l,s,h){return Dn(s,l)?s:Dl.current!==null?(i=zm(i,s,h),Dn(i,l)||(_t=!0),i):(ni&42)===0||(ni&1073741824)!==0&&(Le&261930)===0?(_t=!0,i.memoizedState=s):(i=Qw(),Te.lanes|=i,Qi|=i,l)}function W1(i,l,s,h,v){var b=Q.p;Q.p=b!==0&&8>b?b:8;var A=U.T,j={};U.T=j,Pm(i,!1,l,s);try{var B=v(),X=U.S;if(X!==null&&X(j,B),B!==null&&typeof B=="object"&&typeof B.then=="function"){var re=NP(B,h);uo(i,l,re,Bn(i))}else uo(i,l,h,Bn(i))}catch(le){uo(i,l,{then:function(){},status:"rejected",reason:le},Bn())}finally{Q.p=b,A!==null&&j.types!==null&&(A.types=j.types),U.T=A}}function UP(){}function Dm(i,l,s,h){if(i.tag!==5)throw Error(r(476));var v=J1(i).queue;W1(i,v,l,ue,s===null?UP:function(){return ew(i),s(h)})}function J1(i){var l=i.memoizedState;if(l!==null)return l;l={memoizedState:ue,baseState:ue,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:ri,lastRenderedState:ue},next:null};var s={};return l.next={memoizedState:s,baseState:s,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:ri,lastRenderedState:s},next:null},i.memoizedState=l,i=i.alternate,i!==null&&(i.memoizedState=l),l}function ew(i){var l=J1(i);l.next===null&&(l=i.alternate.memoizedState),uo(i,l.next.queue,{},Bn())}function Nm(){return Gt(Ao)}function tw(){return xt().memoizedState}function nw(){return xt().memoizedState}function qP(i){for(var l=i.return;l!==null;){switch(l.tag){case 24:case 3:var s=Bn();i=Vi(s);var h=Yi(l,i,s);h!==null&&(En(h,l,s),no(h,l,s)),l={cache:sm()},i.payload=l;return}l=l.return}}function HP(i,l,s){var h=Bn();s={lane:h,revertLane:0,gesture:null,action:s,hasEagerState:!1,eagerState:null,next:null},bc(i)?iw(l,s):(s=Wh(i,l,s,h),s!==null&&(En(s,i,h),aw(s,l,h)))}function rw(i,l,s){var h=Bn();uo(i,l,s,h)}function uo(i,l,s,h){var v={lane:h,revertLane:0,gesture:null,action:s,hasEagerState:!1,eagerState:null,next:null};if(bc(i))iw(l,v);else{var b=i.alternate;if(i.lanes===0&&(b===null||b.lanes===0)&&(b=l.lastRenderedReducer,b!==null))try{var A=l.lastRenderedState,j=b(A,s);if(v.hasEagerState=!0,v.eagerState=j,Dn(j,A))return Js(i,l,v,0),nt===null&&Ws(),!1}catch{}finally{}if(s=Wh(i,l,v,h),s!==null)return En(s,i,h),aw(s,l,h),!0}return!1}function Pm(i,l,s,h){if(h={lane:2,revertLane:hp(),gesture:null,action:h,hasEagerState:!1,eagerState:null,next:null},bc(i)){if(l)throw Error(r(479))}else l=Wh(i,s,h,2),l!==null&&En(l,i,2)}function bc(i){var l=i.alternate;return i===Te||l!==null&&l===Te}function iw(i,l){Nl=dc=!0;var s=i.pending;s===null?l.next=l:(l.next=s.next,s.next=l),i.pending=l}function aw(i,l,s){if((s&4194048)!==0){var h=l.lanes;h&=i.pendingLanes,s|=h,l.lanes=s,cx(i,s)}}var oo={readContext:Gt,use:pc,useCallback:pt,useContext:pt,useEffect:pt,useImperativeHandle:pt,useLayoutEffect:pt,useInsertionEffect:pt,useMemo:pt,useReducer:pt,useRef:pt,useState:pt,useDebugValue:pt,useDeferredValue:pt,useTransition:pt,useSyncExternalStore:pt,useId:pt,useHostTransitionStatus:pt,useFormState:pt,useActionState:pt,useOptimistic:pt,useMemoCache:pt,useCacheRefresh:pt};oo.useEffectEvent=pt;var lw={readContext:Gt,use:pc,useCallback:function(i,l){return cn().memoizedState=[i,l===void 0?null:l],i},useContext:Gt,useEffect:$1,useImperativeHandle:function(i,l,s){s=s!=null?s.concat([i]):null,yc(4194308,4,K1.bind(null,l,i),s)},useLayoutEffect:function(i,l){return yc(4194308,4,i,l)},useInsertionEffect:function(i,l){yc(4,2,i,l)},useMemo:function(i,l){var s=cn();l=l===void 0?null:l;var h=i();if(Na){yn(!0);try{i()}finally{yn(!1)}}return s.memoizedState=[h,l],h},useReducer:function(i,l,s){var h=cn();if(s!==void 0){var v=s(l);if(Na){yn(!0);try{s(l)}finally{yn(!1)}}}else v=l;return h.memoizedState=h.baseState=v,i={pending:null,lanes:0,dispatch:null,lastRenderedReducer:i,lastRenderedState:v},h.queue=i,i=i.dispatch=HP.bind(null,Te,i),[h.memoizedState,i]},useRef:function(i){var l=cn();return i={current:i},l.memoizedState=i},useState:function(i){i=Cm(i);var l=i.queue,s=rw.bind(null,Te,l);return l.dispatch=s,[i.memoizedState,s]},useDebugValue:Mm,useDeferredValue:function(i,l){var s=cn();return zm(s,i,l)},useTransition:function(){var i=Cm(!1);return i=W1.bind(null,Te,i.queue,!0,!1),cn().memoizedState=i,[!1,i]},useSyncExternalStore:function(i,l,s){var h=Te,v=cn();if(Ue){if(s===void 0)throw Error(r(407));s=s()}else{if(s=l(),nt===null)throw Error(r(349));(Le&127)!==0||k1(h,l,s)}v.memoizedState=s;var b={value:s,getSnapshot:l};return v.queue=b,$1(T1.bind(null,h,b,i),[i]),h.flags|=2048,Rl(9,{destroy:void 0},C1.bind(null,h,b,s,l),null),s},useId:function(){var i=cn(),l=nt.identifierPrefix;if(Ue){var s=zr,h=Mr;s=(h&~(1<<32-tt(h)-1)).toString(32)+s,l="_"+l+"R_"+s,s=hc++,0<s&&(l+="H"+s.toString(32)),l+="_"}else s=PP++,l="_"+l+"r_"+s.toString(32)+"_";return i.memoizedState=l},useHostTransitionStatus:Nm,useFormState:L1,useActionState:L1,useOptimistic:function(i){var l=cn();l.memoizedState=l.baseState=i;var s={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return l.queue=s,l=Pm.bind(null,Te,!0,s),s.dispatch=l,[i,l]},useMemoCache:Am,useCacheRefresh:function(){return cn().memoizedState=qP.bind(null,Te)},useEffectEvent:function(i){var l=cn(),s={impl:i};return l.memoizedState=s,function(){if((Ye&2)!==0)throw Error(r(440));return s.impl.apply(void 0,arguments)}}},Rm={readContext:Gt,use:pc,useCallback:X1,useContext:Gt,useEffect:jm,useImperativeHandle:G1,useInsertionEffect:V1,useLayoutEffect:Y1,useMemo:Z1,useReducer:vc,useRef:H1,useState:function(){return vc(ri)},useDebugValue:Mm,useDeferredValue:function(i,l){var s=xt();return Q1(s,Qe.memoizedState,i,l)},useTransition:function(){var i=vc(ri)[0],l=xt().memoizedState;return[typeof i=="boolean"?i:lo(i),l]},useSyncExternalStore:_1,useId:tw,useHostTransitionStatus:Nm,useFormState:B1,useActionState:B1,useOptimistic:function(i,l){var s=xt();return z1(s,Qe,i,l)},useMemoCache:Am,useCacheRefresh:nw};Rm.useEffectEvent=F1;var uw={readContext:Gt,use:pc,useCallback:X1,useContext:Gt,useEffect:jm,useImperativeHandle:G1,useInsertionEffect:V1,useLayoutEffect:Y1,useMemo:Z1,useReducer:km,useRef:H1,useState:function(){return km(ri)},useDebugValue:Mm,useDeferredValue:function(i,l){var s=xt();return Qe===null?zm(s,i,l):Q1(s,Qe.memoizedState,i,l)},useTransition:function(){var i=km(ri)[0],l=xt().memoizedState;return[typeof i=="boolean"?i:lo(i),l]},useSyncExternalStore:_1,useId:tw,useHostTransitionStatus:Nm,useFormState:q1,useActionState:q1,useOptimistic:function(i,l){var s=xt();return Qe!==null?z1(s,Qe,i,l):(s.baseState=i,[i,s.queue.dispatch])},useMemoCache:Am,useCacheRefresh:nw};uw.useEffectEvent=F1;function Im(i,l,s,h){l=i.memoizedState,s=s(h,l),s=s==null?l:p({},l,s),i.memoizedState=s,i.lanes===0&&(i.updateQueue.baseState=s)}var Lm={enqueueSetState:function(i,l,s){i=i._reactInternals;var h=Bn(),v=Vi(h);v.payload=l,s!=null&&(v.callback=s),l=Yi(i,v,h),l!==null&&(En(l,i,h),no(l,i,h))},enqueueReplaceState:function(i,l,s){i=i._reactInternals;var h=Bn(),v=Vi(h);v.tag=1,v.payload=l,s!=null&&(v.callback=s),l=Yi(i,v,h),l!==null&&(En(l,i,h),no(l,i,h))},enqueueForceUpdate:function(i,l){i=i._reactInternals;var s=Bn(),h=Vi(s);h.tag=2,l!=null&&(h.callback=l),l=Yi(i,h,s),l!==null&&(En(l,i,s),no(l,i,s))}};function ow(i,l,s,h,v,b,A){return i=i.stateNode,typeof i.shouldComponentUpdate=="function"?i.shouldComponentUpdate(h,b,A):l.prototype&&l.prototype.isPureReactComponent?!Gu(s,h)||!Gu(v,b):!0}function sw(i,l,s,h){i=l.state,typeof l.componentWillReceiveProps=="function"&&l.componentWillReceiveProps(s,h),typeof l.UNSAFE_componentWillReceiveProps=="function"&&l.UNSAFE_componentWillReceiveProps(s,h),l.state!==i&&Lm.enqueueReplaceState(l,l.state,null)}function Pa(i,l){var s=l;if("ref"in l){s={};for(var h in l)h!=="ref"&&(s[h]=l[h])}if(i=i.defaultProps){s===l&&(s=p({},s));for(var v in i)s[v]===void 0&&(s[v]=i[v])}return s}function cw(i){Qs(i)}function fw(i){console.error(i)}function dw(i){Qs(i)}function xc(i,l){try{var s=i.onUncaughtError;s(l.value,{componentStack:l.stack})}catch(h){setTimeout(function(){throw h})}}function hw(i,l,s){try{var h=i.onCaughtError;h(s.value,{componentStack:s.stack,errorBoundary:l.tag===1?l.stateNode:null})}catch(v){setTimeout(function(){throw v})}}function Bm(i,l,s){return s=Vi(s),s.tag=3,s.payload={element:null},s.callback=function(){xc(i,l)},s}function mw(i){return i=Vi(i),i.tag=3,i}function pw(i,l,s,h){var v=s.type.getDerivedStateFromError;if(typeof v=="function"){var b=h.value;i.payload=function(){return v(b)},i.callback=function(){hw(l,s,h)}}var A=s.stateNode;A!==null&&typeof A.componentDidCatch=="function"&&(i.callback=function(){hw(l,s,h),typeof v!="function"&&(Wi===null?Wi=new Set([this]):Wi.add(this));var j=h.stack;this.componentDidCatch(h.value,{componentStack:j!==null?j:""})})}function $P(i,l,s,h,v){if(s.flags|=32768,h!==null&&typeof h=="object"&&typeof h.then=="function"){if(l=s.alternate,l!==null&&Cl(l,s,v,!0),s=Pn.current,s!==null){switch(s.tag){case 31:case 13:return nr===null?zc():s.alternate===null&&vt===0&&(vt=3),s.flags&=-257,s.flags|=65536,s.lanes=v,h===uc?s.flags|=16384:(l=s.updateQueue,l===null?s.updateQueue=new Set([h]):l.add(h),cp(i,h,v)),!1;case 22:return s.flags|=65536,h===uc?s.flags|=16384:(l=s.updateQueue,l===null?(l={transitions:null,markerInstances:null,retryQueue:new Set([h])},s.updateQueue=l):(s=l.retryQueue,s===null?l.retryQueue=new Set([h]):s.add(h)),cp(i,h,v)),!1}throw Error(r(435,s.tag))}return cp(i,h,v),zc(),!1}if(Ue)return l=Pn.current,l!==null?((l.flags&65536)===0&&(l.flags|=256),l.flags|=65536,l.lanes=v,h!==im&&(i=Error(r(422),{cause:h}),Qu(Wn(i,s)))):(h!==im&&(l=Error(r(423),{cause:h}),Qu(Wn(l,s))),i=i.current.alternate,i.flags|=65536,v&=-v,i.lanes|=v,h=Wn(h,s),v=Bm(i.stateNode,h,v),pm(i,v),vt!==4&&(vt=2)),!1;var b=Error(r(520),{cause:h});if(b=Wn(b,s),yo===null?yo=[b]:yo.push(b),vt!==4&&(vt=2),l===null)return!0;h=Wn(h,s),s=l;do{switch(s.tag){case 3:return s.flags|=65536,i=v&-v,s.lanes|=i,i=Bm(s.stateNode,h,i),pm(s,i),!1;case 1:if(l=s.type,b=s.stateNode,(s.flags&128)===0&&(typeof l.getDerivedStateFromError=="function"||b!==null&&typeof b.componentDidCatch=="function"&&(Wi===null||!Wi.has(b))))return s.flags|=65536,v&=-v,s.lanes|=v,v=mw(v),pw(v,i,s,h),pm(s,v),!1}s=s.return}while(s!==null);return!1}var Um=Error(r(461)),_t=!1;function Xt(i,l,s,h){l.child=i===null?b1(l,null,s,h):Da(l,i.child,s,h)}function vw(i,l,s,h,v){s=s.render;var b=l.ref;if("ref"in h){var A={};for(var j in h)j!=="ref"&&(A[j]=h[j])}else A=h;return Ta(l),h=wm(i,l,s,A,b,v),j=Sm(),i!==null&&!_t?(Om(i,l,v),ii(i,l,v)):(Ue&&j&&nm(l),l.flags|=1,Xt(i,l,h,v),l.child)}function yw(i,l,s,h,v){if(i===null){var b=s.type;return typeof b=="function"&&!Jh(b)&&b.defaultProps===void 0&&s.compare===null?(l.tag=15,l.type=b,gw(i,l,b,h,v)):(i=tc(s.type,null,h,l,l.mode,v),i.ref=l.ref,i.return=l,l.child=i)}if(b=i.child,!Gm(i,v)){var A=b.memoizedProps;if(s=s.compare,s=s!==null?s:Gu,s(A,h)&&i.ref===l.ref)return ii(i,l,v)}return l.flags|=1,i=Wr(b,h),i.ref=l.ref,i.return=l,l.child=i}function gw(i,l,s,h,v){if(i!==null){var b=i.memoizedProps;if(Gu(b,h)&&i.ref===l.ref)if(_t=!1,l.pendingProps=h=b,Gm(i,v))(i.flags&131072)!==0&&(_t=!0);else return l.lanes=i.lanes,ii(i,l,v)}return qm(i,l,s,h,v)}function bw(i,l,s,h){var v=h.children,b=i!==null?i.memoizedState:null;if(i===null&&l.stateNode===null&&(l.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),h.mode==="hidden"){if((l.flags&128)!==0){if(b=b!==null?b.baseLanes|s:s,i!==null){for(h=l.child=i.child,v=0;h!==null;)v=v|h.lanes|h.childLanes,h=h.sibling;h=v&~b}else h=0,l.child=null;return xw(i,l,b,s,h)}if((s&536870912)!==0)l.memoizedState={baseLanes:0,cachePool:null},i!==null&&ac(l,b!==null?b.cachePool:null),b!==null?S1(l,b):ym(),O1(l);else return h=l.lanes=536870912,xw(i,l,b!==null?b.baseLanes|s:s,s,h)}else b!==null?(ac(l,b.cachePool),S1(l,b),Gi(),l.memoizedState=null):(i!==null&&ac(l,null),ym(),Gi());return Xt(i,l,v,s),l.child}function so(i,l){return i!==null&&i.tag===22||l.stateNode!==null||(l.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),l.sibling}function xw(i,l,s,h,v){var b=fm();return b=b===null?null:{parent:Et._currentValue,pool:b},l.memoizedState={baseLanes:s,cachePool:b},i!==null&&ac(l,null),ym(),O1(l),i!==null&&Cl(i,l,h,!0),l.childLanes=v,null}function wc(i,l){return l=Oc({mode:l.mode,children:l.children},i.mode),l.ref=i.ref,i.child=l,l.return=i,l}function ww(i,l,s){return Da(l,i.child,null,s),i=wc(l,l.pendingProps),i.flags|=2,Rn(l),l.memoizedState=null,i}function FP(i,l,s){var h=l.pendingProps,v=(l.flags&128)!==0;if(l.flags&=-129,i===null){if(Ue){if(h.mode==="hidden")return i=wc(l,h),l.lanes=536870912,so(null,i);if(bm(l),(i=ot)?(i=DS(i,tr),i=i!==null&&i.data==="&"?i:null,i!==null&&(l.memoizedState={dehydrated:i,treeContext:Ui!==null?{id:Mr,overflow:zr}:null,retryLane:536870912,hydrationErrors:null},s=i1(i),s.return=l,l.child=s,Kt=l,ot=null)):i=null,i===null)throw Hi(l);return l.lanes=536870912,null}return wc(l,h)}var b=i.memoizedState;if(b!==null){var A=b.dehydrated;if(bm(l),v)if(l.flags&256)l.flags&=-257,l=ww(i,l,s);else if(l.memoizedState!==null)l.child=i.child,l.flags|=128,l=null;else throw Error(r(558));else if(_t||Cl(i,l,s,!1),v=(s&i.childLanes)!==0,_t||v){if(h=nt,h!==null&&(A=fx(h,s),A!==0&&A!==b.retryLane))throw b.retryLane=A,Aa(i,A),En(h,i,A),Um;zc(),l=ww(i,l,s)}else i=b.treeContext,ot=rr(A.nextSibling),Kt=l,Ue=!0,qi=null,tr=!1,i!==null&&u1(l,i),l=wc(l,h),l.flags|=4096;return l}return i=Wr(i.child,{mode:h.mode,children:h.children}),i.ref=l.ref,l.child=i,i.return=l,i}function Sc(i,l){var s=l.ref;if(s===null)i!==null&&i.ref!==null&&(l.flags|=4194816);else{if(typeof s!="function"&&typeof s!="object")throw Error(r(284));(i===null||i.ref!==s)&&(l.flags|=4194816)}}function qm(i,l,s,h,v){return Ta(l),s=wm(i,l,s,h,void 0,v),h=Sm(),i!==null&&!_t?(Om(i,l,v),ii(i,l,v)):(Ue&&h&&nm(l),l.flags|=1,Xt(i,l,s,v),l.child)}function Sw(i,l,s,h,v,b){return Ta(l),l.updateQueue=null,s=A1(l,h,s,v),E1(i),h=Sm(),i!==null&&!_t?(Om(i,l,b),ii(i,l,b)):(Ue&&h&&nm(l),l.flags|=1,Xt(i,l,s,b),l.child)}function Ow(i,l,s,h,v){if(Ta(l),l.stateNode===null){var b=El,A=s.contextType;typeof A=="object"&&A!==null&&(b=Gt(A)),b=new s(h,b),l.memoizedState=b.state!==null&&b.state!==void 0?b.state:null,b.updater=Lm,l.stateNode=b,b._reactInternals=l,b=l.stateNode,b.props=h,b.state=l.memoizedState,b.refs={},hm(l),A=s.contextType,b.context=typeof A=="object"&&A!==null?Gt(A):El,b.state=l.memoizedState,A=s.getDerivedStateFromProps,typeof A=="function"&&(Im(l,s,A,h),b.state=l.memoizedState),typeof s.getDerivedStateFromProps=="function"||typeof b.getSnapshotBeforeUpdate=="function"||typeof b.UNSAFE_componentWillMount!="function"&&typeof b.componentWillMount!="function"||(A=b.state,typeof b.componentWillMount=="function"&&b.componentWillMount(),typeof b.UNSAFE_componentWillMount=="function"&&b.UNSAFE_componentWillMount(),A!==b.state&&Lm.enqueueReplaceState(b,b.state,null),io(l,h,b,v),ro(),b.state=l.memoizedState),typeof b.componentDidMount=="function"&&(l.flags|=4194308),h=!0}else if(i===null){b=l.stateNode;var j=l.memoizedProps,B=Pa(s,j);b.props=B;var X=b.context,re=s.contextType;A=El,typeof re=="object"&&re!==null&&(A=Gt(re));var le=s.getDerivedStateFromProps;re=typeof le=="function"||typeof b.getSnapshotBeforeUpdate=="function",j=l.pendingProps!==j,re||typeof b.UNSAFE_componentWillReceiveProps!="function"&&typeof b.componentWillReceiveProps!="function"||(j||X!==A)&&sw(l,b,h,A),Fi=!1;var W=l.memoizedState;b.state=W,io(l,h,b,v),ro(),X=l.memoizedState,j||W!==X||Fi?(typeof le=="function"&&(Im(l,s,le,h),X=l.memoizedState),(B=Fi||ow(l,s,B,h,W,X,A))?(re||typeof b.UNSAFE_componentWillMount!="function"&&typeof b.componentWillMount!="function"||(typeof b.componentWillMount=="function"&&b.componentWillMount(),typeof b.UNSAFE_componentWillMount=="function"&&b.UNSAFE_componentWillMount()),typeof b.componentDidMount=="function"&&(l.flags|=4194308)):(typeof b.componentDidMount=="function"&&(l.flags|=4194308),l.memoizedProps=h,l.memoizedState=X),b.props=h,b.state=X,b.context=A,h=B):(typeof b.componentDidMount=="function"&&(l.flags|=4194308),h=!1)}else{b=l.stateNode,mm(i,l),A=l.memoizedProps,re=Pa(s,A),b.props=re,le=l.pendingProps,W=b.context,X=s.contextType,B=El,typeof X=="object"&&X!==null&&(B=Gt(X)),j=s.getDerivedStateFromProps,(X=typeof j=="function"||typeof b.getSnapshotBeforeUpdate=="function")||typeof b.UNSAFE_componentWillReceiveProps!="function"&&typeof b.componentWillReceiveProps!="function"||(A!==le||W!==B)&&sw(l,b,h,B),Fi=!1,W=l.memoizedState,b.state=W,io(l,h,b,v),ro();var ne=l.memoizedState;A!==le||W!==ne||Fi||i!==null&&i.dependencies!==null&&rc(i.dependencies)?(typeof j=="function"&&(Im(l,s,j,h),ne=l.memoizedState),(re=Fi||ow(l,s,re,h,W,ne,B)||i!==null&&i.dependencies!==null&&rc(i.dependencies))?(X||typeof b.UNSAFE_componentWillUpdate!="function"&&typeof b.componentWillUpdate!="function"||(typeof b.componentWillUpdate=="function"&&b.componentWillUpdate(h,ne,B),typeof b.UNSAFE_componentWillUpdate=="function"&&b.UNSAFE_componentWillUpdate(h,ne,B)),typeof b.componentDidUpdate=="function"&&(l.flags|=4),typeof b.getSnapshotBeforeUpdate=="function"&&(l.flags|=1024)):(typeof b.componentDidUpdate!="function"||A===i.memoizedProps&&W===i.memoizedState||(l.flags|=4),typeof b.getSnapshotBeforeUpdate!="function"||A===i.memoizedProps&&W===i.memoizedState||(l.flags|=1024),l.memoizedProps=h,l.memoizedState=ne),b.props=h,b.state=ne,b.context=B,h=re):(typeof b.componentDidUpdate!="function"||A===i.memoizedProps&&W===i.memoizedState||(l.flags|=4),typeof b.getSnapshotBeforeUpdate!="function"||A===i.memoizedProps&&W===i.memoizedState||(l.flags|=1024),h=!1)}return b=h,Sc(i,l),h=(l.flags&128)!==0,b||h?(b=l.stateNode,s=h&&typeof s.getDerivedStateFromError!="function"?null:b.render(),l.flags|=1,i!==null&&h?(l.child=Da(l,i.child,null,v),l.child=Da(l,null,s,v)):Xt(i,l,s,v),l.memoizedState=b.state,i=l.child):i=ii(i,l,v),i}function Ew(i,l,s,h){return ka(),l.flags|=256,Xt(i,l,s,h),l.child}var Hm={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function $m(i){return{baseLanes:i,cachePool:h1()}}function Fm(i,l,s){return i=i!==null?i.childLanes&~s:0,l&&(i|=Ln),i}function Aw(i,l,s){var h=l.pendingProps,v=!1,b=(l.flags&128)!==0,A;if((A=b)||(A=i!==null&&i.memoizedState===null?!1:(bt.current&2)!==0),A&&(v=!0,l.flags&=-129),A=(l.flags&32)!==0,l.flags&=-33,i===null){if(Ue){if(v?Ki(l):Gi(),(i=ot)?(i=DS(i,tr),i=i!==null&&i.data!=="&"?i:null,i!==null&&(l.memoizedState={dehydrated:i,treeContext:Ui!==null?{id:Mr,overflow:zr}:null,retryLane:536870912,hydrationErrors:null},s=i1(i),s.return=l,l.child=s,Kt=l,ot=null)):i=null,i===null)throw Hi(l);return _p(i)?l.lanes=32:l.lanes=536870912,null}var j=h.children;return h=h.fallback,v?(Gi(),v=l.mode,j=Oc({mode:"hidden",children:j},v),h=_a(h,v,s,null),j.return=l,h.return=l,j.sibling=h,l.child=j,h=l.child,h.memoizedState=$m(s),h.childLanes=Fm(i,A,s),l.memoizedState=Hm,so(null,h)):(Ki(l),Vm(l,j))}var B=i.memoizedState;if(B!==null&&(j=B.dehydrated,j!==null)){if(b)l.flags&256?(Ki(l),l.flags&=-257,l=Ym(i,l,s)):l.memoizedState!==null?(Gi(),l.child=i.child,l.flags|=128,l=null):(Gi(),j=h.fallback,v=l.mode,h=Oc({mode:"visible",children:h.children},v),j=_a(j,v,s,null),j.flags|=2,h.return=l,j.return=l,h.sibling=j,l.child=h,Da(l,i.child,null,s),h=l.child,h.memoizedState=$m(s),h.childLanes=Fm(i,A,s),l.memoizedState=Hm,l=so(null,h));else if(Ki(l),_p(j)){if(A=j.nextSibling&&j.nextSibling.dataset,A)var X=A.dgst;A=X,h=Error(r(419)),h.stack="",h.digest=A,Qu({value:h,source:null,stack:null}),l=Ym(i,l,s)}else if(_t||Cl(i,l,s,!1),A=(s&i.childLanes)!==0,_t||A){if(A=nt,A!==null&&(h=fx(A,s),h!==0&&h!==B.retryLane))throw B.retryLane=h,Aa(i,h),En(A,i,h),Um;Ap(j)||zc(),l=Ym(i,l,s)}else Ap(j)?(l.flags|=192,l.child=i.child,l=null):(i=B.treeContext,ot=rr(j.nextSibling),Kt=l,Ue=!0,qi=null,tr=!1,i!==null&&u1(l,i),l=Vm(l,h.children),l.flags|=4096);return l}return v?(Gi(),j=h.fallback,v=l.mode,B=i.child,X=B.sibling,h=Wr(B,{mode:"hidden",children:h.children}),h.subtreeFlags=B.subtreeFlags&65011712,X!==null?j=Wr(X,j):(j=_a(j,v,s,null),j.flags|=2),j.return=l,h.return=l,h.sibling=j,l.child=h,so(null,h),h=l.child,j=i.child.memoizedState,j===null?j=$m(s):(v=j.cachePool,v!==null?(B=Et._currentValue,v=v.parent!==B?{parent:B,pool:B}:v):v=h1(),j={baseLanes:j.baseLanes|s,cachePool:v}),h.memoizedState=j,h.childLanes=Fm(i,A,s),l.memoizedState=Hm,so(i.child,h)):(Ki(l),s=i.child,i=s.sibling,s=Wr(s,{mode:"visible",children:h.children}),s.return=l,s.sibling=null,i!==null&&(A=l.deletions,A===null?(l.deletions=[i],l.flags|=16):A.push(i)),l.child=s,l.memoizedState=null,s)}function Vm(i,l){return l=Oc({mode:"visible",children:l},i.mode),l.return=i,i.child=l}function Oc(i,l){return i=Nn(22,i,null,l),i.lanes=0,i}function Ym(i,l,s){return Da(l,i.child,null,s),i=Vm(l,l.pendingProps.children),i.flags|=2,l.memoizedState=null,i}function _w(i,l,s){i.lanes|=l;var h=i.alternate;h!==null&&(h.lanes|=l),um(i.return,l,s)}function Km(i,l,s,h,v,b){var A=i.memoizedState;A===null?i.memoizedState={isBackwards:l,rendering:null,renderingStartTime:0,last:h,tail:s,tailMode:v,treeForkCount:b}:(A.isBackwards=l,A.rendering=null,A.renderingStartTime=0,A.last=h,A.tail=s,A.tailMode=v,A.treeForkCount=b)}function kw(i,l,s){var h=l.pendingProps,v=h.revealOrder,b=h.tail;h=h.children;var A=bt.current,j=(A&2)!==0;if(j?(A=A&1|2,l.flags|=128):A&=1,D(bt,A),Xt(i,l,h,s),h=Ue?Zu:0,!j&&i!==null&&(i.flags&128)!==0)e:for(i=l.child;i!==null;){if(i.tag===13)i.memoizedState!==null&&_w(i,s,l);else if(i.tag===19)_w(i,s,l);else if(i.child!==null){i.child.return=i,i=i.child;continue}if(i===l)break e;for(;i.sibling===null;){if(i.return===null||i.return===l)break e;i=i.return}i.sibling.return=i.return,i=i.sibling}switch(v){case"forwards":for(s=l.child,v=null;s!==null;)i=s.alternate,i!==null&&fc(i)===null&&(v=s),s=s.sibling;s=v,s===null?(v=l.child,l.child=null):(v=s.sibling,s.sibling=null),Km(l,!1,v,s,b,h);break;case"backwards":case"unstable_legacy-backwards":for(s=null,v=l.child,l.child=null;v!==null;){if(i=v.alternate,i!==null&&fc(i)===null){l.child=v;break}i=v.sibling,v.sibling=s,s=v,v=i}Km(l,!0,s,null,b,h);break;case"together":Km(l,!1,null,null,void 0,h);break;default:l.memoizedState=null}return l.child}function ii(i,l,s){if(i!==null&&(l.dependencies=i.dependencies),Qi|=l.lanes,(s&l.childLanes)===0)if(i!==null){if(Cl(i,l,s,!1),(s&l.childLanes)===0)return null}else return null;if(i!==null&&l.child!==i.child)throw Error(r(153));if(l.child!==null){for(i=l.child,s=Wr(i,i.pendingProps),l.child=s,s.return=l;i.sibling!==null;)i=i.sibling,s=s.sibling=Wr(i,i.pendingProps),s.return=l;s.sibling=null}return l.child}function Gm(i,l){return(i.lanes&l)!==0?!0:(i=i.dependencies,!!(i!==null&&rc(i)))}function VP(i,l,s){switch(l.tag){case 3:ge(l,l.stateNode.containerInfo),$i(l,Et,i.memoizedState.cache),ka();break;case 27:case 5:he(l);break;case 4:ge(l,l.stateNode.containerInfo);break;case 10:$i(l,l.type,l.memoizedProps.value);break;case 31:if(l.memoizedState!==null)return l.flags|=128,bm(l),null;break;case 13:var h=l.memoizedState;if(h!==null)return h.dehydrated!==null?(Ki(l),l.flags|=128,null):(s&l.child.childLanes)!==0?Aw(i,l,s):(Ki(l),i=ii(i,l,s),i!==null?i.sibling:null);Ki(l);break;case 19:var v=(i.flags&128)!==0;if(h=(s&l.childLanes)!==0,h||(Cl(i,l,s,!1),h=(s&l.childLanes)!==0),v){if(h)return kw(i,l,s);l.flags|=128}if(v=l.memoizedState,v!==null&&(v.rendering=null,v.tail=null,v.lastEffect=null),D(bt,bt.current),h)break;return null;case 22:return l.lanes=0,bw(i,l,s,l.pendingProps);case 24:$i(l,Et,i.memoizedState.cache)}return ii(i,l,s)}function Cw(i,l,s){if(i!==null)if(i.memoizedProps!==l.pendingProps)_t=!0;else{if(!Gm(i,s)&&(l.flags&128)===0)return _t=!1,VP(i,l,s);_t=(i.flags&131072)!==0}else _t=!1,Ue&&(l.flags&1048576)!==0&&l1(l,Zu,l.index);switch(l.lanes=0,l.tag){case 16:e:{var h=l.pendingProps;if(i=Ma(l.elementType),l.type=i,typeof i=="function")Jh(i)?(h=Pa(i,h),l.tag=1,l=Ow(null,l,i,h,s)):(l.tag=0,l=qm(null,l,i,h,s));else{if(i!=null){var v=i.$$typeof;if(v===M){l.tag=11,l=vw(null,l,i,h,s);break e}else if(v===z){l.tag=14,l=yw(null,l,i,h,s);break e}}throw l=Z(i)||i,Error(r(306,l,""))}}return l;case 0:return qm(i,l,l.type,l.pendingProps,s);case 1:return h=l.type,v=Pa(h,l.pendingProps),Ow(i,l,h,v,s);case 3:e:{if(ge(l,l.stateNode.containerInfo),i===null)throw Error(r(387));h=l.pendingProps;var b=l.memoizedState;v=b.element,mm(i,l),io(l,h,null,s);var A=l.memoizedState;if(h=A.cache,$i(l,Et,h),h!==b.cache&&om(l,[Et],s,!0),ro(),h=A.element,b.isDehydrated)if(b={element:h,isDehydrated:!1,cache:A.cache},l.updateQueue.baseState=b,l.memoizedState=b,l.flags&256){l=Ew(i,l,h,s);break e}else if(h!==v){v=Wn(Error(r(424)),l),Qu(v),l=Ew(i,l,h,s);break e}else{switch(i=l.stateNode.containerInfo,i.nodeType){case 9:i=i.body;break;default:i=i.nodeName==="HTML"?i.ownerDocument.body:i}for(ot=rr(i.firstChild),Kt=l,Ue=!0,qi=null,tr=!0,s=b1(l,null,h,s),l.child=s;s;)s.flags=s.flags&-3|4096,s=s.sibling}else{if(ka(),h===v){l=ii(i,l,s);break e}Xt(i,l,h,s)}l=l.child}return l;case 26:return Sc(i,l),i===null?(s=BS(l.type,null,l.pendingProps,null))?l.memoizedState=s:Ue||(s=l.type,i=l.pendingProps,h=Bc(ve.current).createElement(s),h[Yt]=l,h[gn]=i,Zt(h,s,i),Rt(h),l.stateNode=h):l.memoizedState=BS(l.type,i.memoizedProps,l.pendingProps,i.memoizedState),null;case 27:return he(l),i===null&&Ue&&(h=l.stateNode=RS(l.type,l.pendingProps,ve.current),Kt=l,tr=!0,v=ot,na(l.type)?(kp=v,ot=rr(h.firstChild)):ot=v),Xt(i,l,l.pendingProps.children,s),Sc(i,l),i===null&&(l.flags|=4194304),l.child;case 5:return i===null&&Ue&&((v=h=ot)&&(h=wR(h,l.type,l.pendingProps,tr),h!==null?(l.stateNode=h,Kt=l,ot=rr(h.firstChild),tr=!1,v=!0):v=!1),v||Hi(l)),he(l),v=l.type,b=l.pendingProps,A=i!==null?i.memoizedProps:null,h=b.children,Sp(v,b)?h=null:A!==null&&Sp(v,A)&&(l.flags|=32),l.memoizedState!==null&&(v=wm(i,l,RP,null,null,s),Ao._currentValue=v),Sc(i,l),Xt(i,l,h,s),l.child;case 6:return i===null&&Ue&&((i=s=ot)&&(s=SR(s,l.pendingProps,tr),s!==null?(l.stateNode=s,Kt=l,ot=null,i=!0):i=!1),i||Hi(l)),null;case 13:return Aw(i,l,s);case 4:return ge(l,l.stateNode.containerInfo),h=l.pendingProps,i===null?l.child=Da(l,null,h,s):Xt(i,l,h,s),l.child;case 11:return vw(i,l,l.type,l.pendingProps,s);case 7:return Xt(i,l,l.pendingProps,s),l.child;case 8:return Xt(i,l,l.pendingProps.children,s),l.child;case 12:return Xt(i,l,l.pendingProps.children,s),l.child;case 10:return h=l.pendingProps,$i(l,l.type,h.value),Xt(i,l,h.children,s),l.child;case 9:return v=l.type._context,h=l.pendingProps.children,Ta(l),v=Gt(v),h=h(v),l.flags|=1,Xt(i,l,h,s),l.child;case 14:return yw(i,l,l.type,l.pendingProps,s);case 15:return gw(i,l,l.type,l.pendingProps,s);case 19:return kw(i,l,s);case 31:return FP(i,l,s);case 22:return bw(i,l,s,l.pendingProps);case 24:return Ta(l),h=Gt(Et),i===null?(v=fm(),v===null&&(v=nt,b=sm(),v.pooledCache=b,b.refCount++,b!==null&&(v.pooledCacheLanes|=s),v=b),l.memoizedState={parent:h,cache:v},hm(l),$i(l,Et,v)):((i.lanes&s)!==0&&(mm(i,l),io(l,null,null,s),ro()),v=i.memoizedState,b=l.memoizedState,v.parent!==h?(v={parent:h,cache:h},l.memoizedState=v,l.lanes===0&&(l.memoizedState=l.updateQueue.baseState=v),$i(l,Et,h)):(h=b.cache,$i(l,Et,h),h!==v.cache&&om(l,[Et],s,!0))),Xt(i,l,l.pendingProps.children,s),l.child;case 29:throw l.pendingProps}throw Error(r(156,l.tag))}function ai(i){i.flags|=4}function Xm(i,l,s,h,v){if((l=(i.mode&32)!==0)&&(l=!1),l){if(i.flags|=16777216,(v&335544128)===v)if(i.stateNode.complete)i.flags|=8192;else if(tS())i.flags|=8192;else throw za=uc,dm}else i.flags&=-16777217}function Tw(i,l){if(l.type!=="stylesheet"||(l.state.loading&4)!==0)i.flags&=-16777217;else if(i.flags|=16777216,!FS(l))if(tS())i.flags|=8192;else throw za=uc,dm}function Ec(i,l){l!==null&&(i.flags|=4),i.flags&16384&&(l=i.tag!==22?ox():536870912,i.lanes|=l,Ul|=l)}function co(i,l){if(!Ue)switch(i.tailMode){case"hidden":l=i.tail;for(var s=null;l!==null;)l.alternate!==null&&(s=l),l=l.sibling;s===null?i.tail=null:s.sibling=null;break;case"collapsed":s=i.tail;for(var h=null;s!==null;)s.alternate!==null&&(h=s),s=s.sibling;h===null?l||i.tail===null?i.tail=null:i.tail.sibling=null:h.sibling=null}}function st(i){var l=i.alternate!==null&&i.alternate.child===i.child,s=0,h=0;if(l)for(var v=i.child;v!==null;)s|=v.lanes|v.childLanes,h|=v.subtreeFlags&65011712,h|=v.flags&65011712,v.return=i,v=v.sibling;else for(v=i.child;v!==null;)s|=v.lanes|v.childLanes,h|=v.subtreeFlags,h|=v.flags,v.return=i,v=v.sibling;return i.subtreeFlags|=h,i.childLanes=s,l}function YP(i,l,s){var h=l.pendingProps;switch(rm(l),l.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return st(l),null;case 1:return st(l),null;case 3:return s=l.stateNode,h=null,i!==null&&(h=i.memoizedState.cache),l.memoizedState.cache!==h&&(l.flags|=2048),ti(Et),K(),s.pendingContext&&(s.context=s.pendingContext,s.pendingContext=null),(i===null||i.child===null)&&(kl(l)?ai(l):i===null||i.memoizedState.isDehydrated&&(l.flags&256)===0||(l.flags|=1024,am())),st(l),null;case 26:var v=l.type,b=l.memoizedState;return i===null?(ai(l),b!==null?(st(l),Tw(l,b)):(st(l),Xm(l,v,null,h,s))):b?b!==i.memoizedState?(ai(l),st(l),Tw(l,b)):(st(l),l.flags&=-16777217):(i=i.memoizedProps,i!==h&&ai(l),st(l),Xm(l,v,i,h,s)),null;case 27:if(be(l),s=ve.current,v=l.type,i!==null&&l.stateNode!=null)i.memoizedProps!==h&&ai(l);else{if(!h){if(l.stateNode===null)throw Error(r(166));return st(l),null}i=oe.current,kl(l)?o1(l):(i=RS(v,h,s),l.stateNode=i,ai(l))}return st(l),null;case 5:if(be(l),v=l.type,i!==null&&l.stateNode!=null)i.memoizedProps!==h&&ai(l);else{if(!h){if(l.stateNode===null)throw Error(r(166));return st(l),null}if(b=oe.current,kl(l))o1(l);else{var A=Bc(ve.current);switch(b){case 1:b=A.createElementNS("http://www.w3.org/2000/svg",v);break;case 2:b=A.createElementNS("http://www.w3.org/1998/Math/MathML",v);break;default:switch(v){case"svg":b=A.createElementNS("http://www.w3.org/2000/svg",v);break;case"math":b=A.createElementNS("http://www.w3.org/1998/Math/MathML",v);break;case"script":b=A.createElement("div"),b.innerHTML="<script><\/script>",b=b.removeChild(b.firstChild);break;case"select":b=typeof h.is=="string"?A.createElement("select",{is:h.is}):A.createElement("select"),h.multiple?b.multiple=!0:h.size&&(b.size=h.size);break;default:b=typeof h.is=="string"?A.createElement(v,{is:h.is}):A.createElement(v)}}b[Yt]=l,b[gn]=h;e:for(A=l.child;A!==null;){if(A.tag===5||A.tag===6)b.appendChild(A.stateNode);else if(A.tag!==4&&A.tag!==27&&A.child!==null){A.child.return=A,A=A.child;continue}if(A===l)break e;for(;A.sibling===null;){if(A.return===null||A.return===l)break e;A=A.return}A.sibling.return=A.return,A=A.sibling}l.stateNode=b;e:switch(Zt(b,v,h),v){case"button":case"input":case"select":case"textarea":h=!!h.autoFocus;break e;case"img":h=!0;break e;default:h=!1}h&&ai(l)}}return st(l),Xm(l,l.type,i===null?null:i.memoizedProps,l.pendingProps,s),null;case 6:if(i&&l.stateNode!=null)i.memoizedProps!==h&&ai(l);else{if(typeof h!="string"&&l.stateNode===null)throw Error(r(166));if(i=ve.current,kl(l)){if(i=l.stateNode,s=l.memoizedProps,h=null,v=Kt,v!==null)switch(v.tag){case 27:case 5:h=v.memoizedProps}i[Yt]=l,i=!!(i.nodeValue===s||h!==null&&h.suppressHydrationWarning===!0||AS(i.nodeValue,s)),i||Hi(l,!0)}else i=Bc(i).createTextNode(h),i[Yt]=l,l.stateNode=i}return st(l),null;case 31:if(s=l.memoizedState,i===null||i.memoizedState!==null){if(h=kl(l),s!==null){if(i===null){if(!h)throw Error(r(318));if(i=l.memoizedState,i=i!==null?i.dehydrated:null,!i)throw Error(r(557));i[Yt]=l}else ka(),(l.flags&128)===0&&(l.memoizedState=null),l.flags|=4;st(l),i=!1}else s=am(),i!==null&&i.memoizedState!==null&&(i.memoizedState.hydrationErrors=s),i=!0;if(!i)return l.flags&256?(Rn(l),l):(Rn(l),null);if((l.flags&128)!==0)throw Error(r(558))}return st(l),null;case 13:if(h=l.memoizedState,i===null||i.memoizedState!==null&&i.memoizedState.dehydrated!==null){if(v=kl(l),h!==null&&h.dehydrated!==null){if(i===null){if(!v)throw Error(r(318));if(v=l.memoizedState,v=v!==null?v.dehydrated:null,!v)throw Error(r(317));v[Yt]=l}else ka(),(l.flags&128)===0&&(l.memoizedState=null),l.flags|=4;st(l),v=!1}else v=am(),i!==null&&i.memoizedState!==null&&(i.memoizedState.hydrationErrors=v),v=!0;if(!v)return l.flags&256?(Rn(l),l):(Rn(l),null)}return Rn(l),(l.flags&128)!==0?(l.lanes=s,l):(s=h!==null,i=i!==null&&i.memoizedState!==null,s&&(h=l.child,v=null,h.alternate!==null&&h.alternate.memoizedState!==null&&h.alternate.memoizedState.cachePool!==null&&(v=h.alternate.memoizedState.cachePool.pool),b=null,h.memoizedState!==null&&h.memoizedState.cachePool!==null&&(b=h.memoizedState.cachePool.pool),b!==v&&(h.flags|=2048)),s!==i&&s&&(l.child.flags|=8192),Ec(l,l.updateQueue),st(l),null);case 4:return K(),i===null&&yp(l.stateNode.containerInfo),st(l),null;case 10:return ti(l.type),st(l),null;case 19:if(J(bt),h=l.memoizedState,h===null)return st(l),null;if(v=(l.flags&128)!==0,b=h.rendering,b===null)if(v)co(h,!1);else{if(vt!==0||i!==null&&(i.flags&128)!==0)for(i=l.child;i!==null;){if(b=fc(i),b!==null){for(l.flags|=128,co(h,!1),i=b.updateQueue,l.updateQueue=i,Ec(l,i),l.subtreeFlags=0,i=s,s=l.child;s!==null;)r1(s,i),s=s.sibling;return D(bt,bt.current&1|2),Ue&&Jr(l,h.treeForkCount),l.child}i=i.sibling}h.tail!==null&&on()>Tc&&(l.flags|=128,v=!0,co(h,!1),l.lanes=4194304)}else{if(!v)if(i=fc(b),i!==null){if(l.flags|=128,v=!0,i=i.updateQueue,l.updateQueue=i,Ec(l,i),co(h,!0),h.tail===null&&h.tailMode==="hidden"&&!b.alternate&&!Ue)return st(l),null}else 2*on()-h.renderingStartTime>Tc&&s!==536870912&&(l.flags|=128,v=!0,co(h,!1),l.lanes=4194304);h.isBackwards?(b.sibling=l.child,l.child=b):(i=h.last,i!==null?i.sibling=b:l.child=b,h.last=b)}return h.tail!==null?(i=h.tail,h.rendering=i,h.tail=i.sibling,h.renderingStartTime=on(),i.sibling=null,s=bt.current,D(bt,v?s&1|2:s&1),Ue&&Jr(l,h.treeForkCount),i):(st(l),null);case 22:case 23:return Rn(l),gm(),h=l.memoizedState!==null,i!==null?i.memoizedState!==null!==h&&(l.flags|=8192):h&&(l.flags|=8192),h?(s&536870912)!==0&&(l.flags&128)===0&&(st(l),l.subtreeFlags&6&&(l.flags|=8192)):st(l),s=l.updateQueue,s!==null&&Ec(l,s.retryQueue),s=null,i!==null&&i.memoizedState!==null&&i.memoizedState.cachePool!==null&&(s=i.memoizedState.cachePool.pool),h=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(h=l.memoizedState.cachePool.pool),h!==s&&(l.flags|=2048),i!==null&&J(ja),null;case 24:return s=null,i!==null&&(s=i.memoizedState.cache),l.memoizedState.cache!==s&&(l.flags|=2048),ti(Et),st(l),null;case 25:return null;case 30:return null}throw Error(r(156,l.tag))}function KP(i,l){switch(rm(l),l.tag){case 1:return i=l.flags,i&65536?(l.flags=i&-65537|128,l):null;case 3:return ti(Et),K(),i=l.flags,(i&65536)!==0&&(i&128)===0?(l.flags=i&-65537|128,l):null;case 26:case 27:case 5:return be(l),null;case 31:if(l.memoizedState!==null){if(Rn(l),l.alternate===null)throw Error(r(340));ka()}return i=l.flags,i&65536?(l.flags=i&-65537|128,l):null;case 13:if(Rn(l),i=l.memoizedState,i!==null&&i.dehydrated!==null){if(l.alternate===null)throw Error(r(340));ka()}return i=l.flags,i&65536?(l.flags=i&-65537|128,l):null;case 19:return J(bt),null;case 4:return K(),null;case 10:return ti(l.type),null;case 22:case 23:return Rn(l),gm(),i!==null&&J(ja),i=l.flags,i&65536?(l.flags=i&-65537|128,l):null;case 24:return ti(Et),null;case 25:return null;default:return null}}function jw(i,l){switch(rm(l),l.tag){case 3:ti(Et),K();break;case 26:case 27:case 5:be(l);break;case 4:K();break;case 31:l.memoizedState!==null&&Rn(l);break;case 13:Rn(l);break;case 19:J(bt);break;case 10:ti(l.type);break;case 22:case 23:Rn(l),gm(),i!==null&&J(ja);break;case 24:ti(Et)}}function fo(i,l){try{var s=l.updateQueue,h=s!==null?s.lastEffect:null;if(h!==null){var v=h.next;s=v;do{if((s.tag&i)===i){h=void 0;var b=s.create,A=s.inst;h=b(),A.destroy=h}s=s.next}while(s!==v)}}catch(j){Xe(l,l.return,j)}}function Xi(i,l,s){try{var h=l.updateQueue,v=h!==null?h.lastEffect:null;if(v!==null){var b=v.next;h=b;do{if((h.tag&i)===i){var A=h.inst,j=A.destroy;if(j!==void 0){A.destroy=void 0,v=l;var B=s,X=j;try{X()}catch(re){Xe(v,B,re)}}}h=h.next}while(h!==b)}}catch(re){Xe(l,l.return,re)}}function Mw(i){var l=i.updateQueue;if(l!==null){var s=i.stateNode;try{w1(l,s)}catch(h){Xe(i,i.return,h)}}}function zw(i,l,s){s.props=Pa(i.type,i.memoizedProps),s.state=i.memoizedState;try{s.componentWillUnmount()}catch(h){Xe(i,l,h)}}function ho(i,l){try{var s=i.ref;if(s!==null){switch(i.tag){case 26:case 27:case 5:var h=i.stateNode;break;case 30:h=i.stateNode;break;default:h=i.stateNode}typeof s=="function"?i.refCleanup=s(h):s.current=h}}catch(v){Xe(i,l,v)}}function Dr(i,l){var s=i.ref,h=i.refCleanup;if(s!==null)if(typeof h=="function")try{h()}catch(v){Xe(i,l,v)}finally{i.refCleanup=null,i=i.alternate,i!=null&&(i.refCleanup=null)}else if(typeof s=="function")try{s(null)}catch(v){Xe(i,l,v)}else s.current=null}function Dw(i){var l=i.type,s=i.memoizedProps,h=i.stateNode;try{e:switch(l){case"button":case"input":case"select":case"textarea":s.autoFocus&&h.focus();break e;case"img":s.src?h.src=s.src:s.srcSet&&(h.srcset=s.srcSet)}}catch(v){Xe(i,i.return,v)}}function Zm(i,l,s){try{var h=i.stateNode;pR(h,i.type,s,l),h[gn]=l}catch(v){Xe(i,i.return,v)}}function Nw(i){return i.tag===5||i.tag===3||i.tag===26||i.tag===27&&na(i.type)||i.tag===4}function Qm(i){e:for(;;){for(;i.sibling===null;){if(i.return===null||Nw(i.return))return null;i=i.return}for(i.sibling.return=i.return,i=i.sibling;i.tag!==5&&i.tag!==6&&i.tag!==18;){if(i.tag===27&&na(i.type)||i.flags&2||i.child===null||i.tag===4)continue e;i.child.return=i,i=i.child}if(!(i.flags&2))return i.stateNode}}function Wm(i,l,s){var h=i.tag;if(h===5||h===6)i=i.stateNode,l?(s.nodeType===9?s.body:s.nodeName==="HTML"?s.ownerDocument.body:s).insertBefore(i,l):(l=s.nodeType===9?s.body:s.nodeName==="HTML"?s.ownerDocument.body:s,l.appendChild(i),s=s._reactRootContainer,s!=null||l.onclick!==null||(l.onclick=Zr));else if(h!==4&&(h===27&&na(i.type)&&(s=i.stateNode,l=null),i=i.child,i!==null))for(Wm(i,l,s),i=i.sibling;i!==null;)Wm(i,l,s),i=i.sibling}function Ac(i,l,s){var h=i.tag;if(h===5||h===6)i=i.stateNode,l?s.insertBefore(i,l):s.appendChild(i);else if(h!==4&&(h===27&&na(i.type)&&(s=i.stateNode),i=i.child,i!==null))for(Ac(i,l,s),i=i.sibling;i!==null;)Ac(i,l,s),i=i.sibling}function Pw(i){var l=i.stateNode,s=i.memoizedProps;try{for(var h=i.type,v=l.attributes;v.length;)l.removeAttributeNode(v[0]);Zt(l,h,s),l[Yt]=i,l[gn]=s}catch(b){Xe(i,i.return,b)}}var li=!1,kt=!1,Jm=!1,Rw=typeof WeakSet=="function"?WeakSet:Set,It=null;function GP(i,l){if(i=i.containerInfo,xp=Yc,i=Gx(i),Yh(i)){if("selectionStart"in i)var s={start:i.selectionStart,end:i.selectionEnd};else e:{s=(s=i.ownerDocument)&&s.defaultView||window;var h=s.getSelection&&s.getSelection();if(h&&h.rangeCount!==0){s=h.anchorNode;var v=h.anchorOffset,b=h.focusNode;h=h.focusOffset;try{s.nodeType,b.nodeType}catch{s=null;break e}var A=0,j=-1,B=-1,X=0,re=0,le=i,W=null;t:for(;;){for(var ne;le!==s||v!==0&&le.nodeType!==3||(j=A+v),le!==b||h!==0&&le.nodeType!==3||(B=A+h),le.nodeType===3&&(A+=le.nodeValue.length),(ne=le.firstChild)!==null;)W=le,le=ne;for(;;){if(le===i)break t;if(W===s&&++X===v&&(j=A),W===b&&++re===h&&(B=A),(ne=le.nextSibling)!==null)break;le=W,W=le.parentNode}le=ne}s=j===-1||B===-1?null:{start:j,end:B}}else s=null}s=s||{start:0,end:0}}else s=null;for(wp={focusedElem:i,selectionRange:s},Yc=!1,It=l;It!==null;)if(l=It,i=l.child,(l.subtreeFlags&1028)!==0&&i!==null)i.return=l,It=i;else for(;It!==null;){switch(l=It,b=l.alternate,i=l.flags,l.tag){case 0:if((i&4)!==0&&(i=l.updateQueue,i=i!==null?i.events:null,i!==null))for(s=0;s<i.length;s++)v=i[s],v.ref.impl=v.nextImpl;break;case 11:case 15:break;case 1:if((i&1024)!==0&&b!==null){i=void 0,s=l,v=b.memoizedProps,b=b.memoizedState,h=s.stateNode;try{var pe=Pa(s.type,v);i=h.getSnapshotBeforeUpdate(pe,b),h.__reactInternalSnapshotBeforeUpdate=i}catch(_e){Xe(s,s.return,_e)}}break;case 3:if((i&1024)!==0){if(i=l.stateNode.containerInfo,s=i.nodeType,s===9)Ep(i);else if(s===1)switch(i.nodeName){case"HEAD":case"HTML":case"BODY":Ep(i);break;default:i.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((i&1024)!==0)throw Error(r(163))}if(i=l.sibling,i!==null){i.return=l.return,It=i;break}It=l.return}}function Iw(i,l,s){var h=s.flags;switch(s.tag){case 0:case 11:case 15:oi(i,s),h&4&&fo(5,s);break;case 1:if(oi(i,s),h&4)if(i=s.stateNode,l===null)try{i.componentDidMount()}catch(A){Xe(s,s.return,A)}else{var v=Pa(s.type,l.memoizedProps);l=l.memoizedState;try{i.componentDidUpdate(v,l,i.__reactInternalSnapshotBeforeUpdate)}catch(A){Xe(s,s.return,A)}}h&64&&Mw(s),h&512&&ho(s,s.return);break;case 3:if(oi(i,s),h&64&&(i=s.updateQueue,i!==null)){if(l=null,s.child!==null)switch(s.child.tag){case 27:case 5:l=s.child.stateNode;break;case 1:l=s.child.stateNode}try{w1(i,l)}catch(A){Xe(s,s.return,A)}}break;case 27:l===null&&h&4&&Pw(s);case 26:case 5:oi(i,s),l===null&&h&4&&Dw(s),h&512&&ho(s,s.return);break;case 12:oi(i,s);break;case 31:oi(i,s),h&4&&Uw(i,s);break;case 13:oi(i,s),h&4&&qw(i,s),h&64&&(i=s.memoizedState,i!==null&&(i=i.dehydrated,i!==null&&(s=rR.bind(null,s),OR(i,s))));break;case 22:if(h=s.memoizedState!==null||li,!h){l=l!==null&&l.memoizedState!==null||kt,v=li;var b=kt;li=h,(kt=l)&&!b?si(i,s,(s.subtreeFlags&8772)!==0):oi(i,s),li=v,kt=b}break;case 30:break;default:oi(i,s)}}function Lw(i){var l=i.alternate;l!==null&&(i.alternate=null,Lw(l)),i.child=null,i.deletions=null,i.sibling=null,i.tag===5&&(l=i.stateNode,l!==null&&Th(l)),i.stateNode=null,i.return=null,i.dependencies=null,i.memoizedProps=null,i.memoizedState=null,i.pendingProps=null,i.stateNode=null,i.updateQueue=null}var dt=null,xn=!1;function ui(i,l,s){for(s=s.child;s!==null;)Bw(i,l,s),s=s.sibling}function Bw(i,l,s){if(Mt&&typeof Mt.onCommitFiberUnmount=="function")try{Mt.onCommitFiberUnmount(sn,s)}catch{}switch(s.tag){case 26:kt||Dr(s,l),ui(i,l,s),s.memoizedState?s.memoizedState.count--:s.stateNode&&(s=s.stateNode,s.parentNode.removeChild(s));break;case 27:kt||Dr(s,l);var h=dt,v=xn;na(s.type)&&(dt=s.stateNode,xn=!1),ui(i,l,s),So(s.stateNode),dt=h,xn=v;break;case 5:kt||Dr(s,l);case 6:if(h=dt,v=xn,dt=null,ui(i,l,s),dt=h,xn=v,dt!==null)if(xn)try{(dt.nodeType===9?dt.body:dt.nodeName==="HTML"?dt.ownerDocument.body:dt).removeChild(s.stateNode)}catch(b){Xe(s,l,b)}else try{dt.removeChild(s.stateNode)}catch(b){Xe(s,l,b)}break;case 18:dt!==null&&(xn?(i=dt,MS(i.nodeType===9?i.body:i.nodeName==="HTML"?i.ownerDocument.body:i,s.stateNode),Gl(i)):MS(dt,s.stateNode));break;case 4:h=dt,v=xn,dt=s.stateNode.containerInfo,xn=!0,ui(i,l,s),dt=h,xn=v;break;case 0:case 11:case 14:case 15:Xi(2,s,l),kt||Xi(4,s,l),ui(i,l,s);break;case 1:kt||(Dr(s,l),h=s.stateNode,typeof h.componentWillUnmount=="function"&&zw(s,l,h)),ui(i,l,s);break;case 21:ui(i,l,s);break;case 22:kt=(h=kt)||s.memoizedState!==null,ui(i,l,s),kt=h;break;default:ui(i,l,s)}}function Uw(i,l){if(l.memoizedState===null&&(i=l.alternate,i!==null&&(i=i.memoizedState,i!==null))){i=i.dehydrated;try{Gl(i)}catch(s){Xe(l,l.return,s)}}}function qw(i,l){if(l.memoizedState===null&&(i=l.alternate,i!==null&&(i=i.memoizedState,i!==null&&(i=i.dehydrated,i!==null))))try{Gl(i)}catch(s){Xe(l,l.return,s)}}function XP(i){switch(i.tag){case 31:case 13:case 19:var l=i.stateNode;return l===null&&(l=i.stateNode=new Rw),l;case 22:return i=i.stateNode,l=i._retryCache,l===null&&(l=i._retryCache=new Rw),l;default:throw Error(r(435,i.tag))}}function _c(i,l){var s=XP(i);l.forEach(function(h){if(!s.has(h)){s.add(h);var v=iR.bind(null,i,h);h.then(v,v)}})}function wn(i,l){var s=l.deletions;if(s!==null)for(var h=0;h<s.length;h++){var v=s[h],b=i,A=l,j=A;e:for(;j!==null;){switch(j.tag){case 27:if(na(j.type)){dt=j.stateNode,xn=!1;break e}break;case 5:dt=j.stateNode,xn=!1;break e;case 3:case 4:dt=j.stateNode.containerInfo,xn=!0;break e}j=j.return}if(dt===null)throw Error(r(160));Bw(b,A,v),dt=null,xn=!1,b=v.alternate,b!==null&&(b.return=null),v.return=null}if(l.subtreeFlags&13886)for(l=l.child;l!==null;)Hw(l,i),l=l.sibling}var br=null;function Hw(i,l){var s=i.alternate,h=i.flags;switch(i.tag){case 0:case 11:case 14:case 15:wn(l,i),Sn(i),h&4&&(Xi(3,i,i.return),fo(3,i),Xi(5,i,i.return));break;case 1:wn(l,i),Sn(i),h&512&&(kt||s===null||Dr(s,s.return)),h&64&&li&&(i=i.updateQueue,i!==null&&(h=i.callbacks,h!==null&&(s=i.shared.hiddenCallbacks,i.shared.hiddenCallbacks=s===null?h:s.concat(h))));break;case 26:var v=br;if(wn(l,i),Sn(i),h&512&&(kt||s===null||Dr(s,s.return)),h&4){var b=s!==null?s.memoizedState:null;if(h=i.memoizedState,s===null)if(h===null)if(i.stateNode===null){e:{h=i.type,s=i.memoizedProps,v=v.ownerDocument||v;t:switch(h){case"title":b=v.getElementsByTagName("title")[0],(!b||b[Bu]||b[Yt]||b.namespaceURI==="http://www.w3.org/2000/svg"||b.hasAttribute("itemprop"))&&(b=v.createElement(h),v.head.insertBefore(b,v.querySelector("head > title"))),Zt(b,h,s),b[Yt]=i,Rt(b),h=b;break e;case"link":var A=HS("link","href",v).get(h+(s.href||""));if(A){for(var j=0;j<A.length;j++)if(b=A[j],b.getAttribute("href")===(s.href==null||s.href===""?null:s.href)&&b.getAttribute("rel")===(s.rel==null?null:s.rel)&&b.getAttribute("title")===(s.title==null?null:s.title)&&b.getAttribute("crossorigin")===(s.crossOrigin==null?null:s.crossOrigin)){A.splice(j,1);break t}}b=v.createElement(h),Zt(b,h,s),v.head.appendChild(b);break;case"meta":if(A=HS("meta","content",v).get(h+(s.content||""))){for(j=0;j<A.length;j++)if(b=A[j],b.getAttribute("content")===(s.content==null?null:""+s.content)&&b.getAttribute("name")===(s.name==null?null:s.name)&&b.getAttribute("property")===(s.property==null?null:s.property)&&b.getAttribute("http-equiv")===(s.httpEquiv==null?null:s.httpEquiv)&&b.getAttribute("charset")===(s.charSet==null?null:s.charSet)){A.splice(j,1);break t}}b=v.createElement(h),Zt(b,h,s),v.head.appendChild(b);break;default:throw Error(r(468,h))}b[Yt]=i,Rt(b),h=b}i.stateNode=h}else $S(v,i.type,i.stateNode);else i.stateNode=qS(v,h,i.memoizedProps);else b!==h?(b===null?s.stateNode!==null&&(s=s.stateNode,s.parentNode.removeChild(s)):b.count--,h===null?$S(v,i.type,i.stateNode):qS(v,h,i.memoizedProps)):h===null&&i.stateNode!==null&&Zm(i,i.memoizedProps,s.memoizedProps)}break;case 27:wn(l,i),Sn(i),h&512&&(kt||s===null||Dr(s,s.return)),s!==null&&h&4&&Zm(i,i.memoizedProps,s.memoizedProps);break;case 5:if(wn(l,i),Sn(i),h&512&&(kt||s===null||Dr(s,s.return)),i.flags&32){v=i.stateNode;try{yl(v,"")}catch(pe){Xe(i,i.return,pe)}}h&4&&i.stateNode!=null&&(v=i.memoizedProps,Zm(i,v,s!==null?s.memoizedProps:v)),h&1024&&(Jm=!0);break;case 6:if(wn(l,i),Sn(i),h&4){if(i.stateNode===null)throw Error(r(162));h=i.memoizedProps,s=i.stateNode;try{s.nodeValue=h}catch(pe){Xe(i,i.return,pe)}}break;case 3:if(Hc=null,v=br,br=Uc(l.containerInfo),wn(l,i),br=v,Sn(i),h&4&&s!==null&&s.memoizedState.isDehydrated)try{Gl(l.containerInfo)}catch(pe){Xe(i,i.return,pe)}Jm&&(Jm=!1,$w(i));break;case 4:h=br,br=Uc(i.stateNode.containerInfo),wn(l,i),Sn(i),br=h;break;case 12:wn(l,i),Sn(i);break;case 31:wn(l,i),Sn(i),h&4&&(h=i.updateQueue,h!==null&&(i.updateQueue=null,_c(i,h)));break;case 13:wn(l,i),Sn(i),i.child.flags&8192&&i.memoizedState!==null!=(s!==null&&s.memoizedState!==null)&&(Cc=on()),h&4&&(h=i.updateQueue,h!==null&&(i.updateQueue=null,_c(i,h)));break;case 22:v=i.memoizedState!==null;var B=s!==null&&s.memoizedState!==null,X=li,re=kt;if(li=X||v,kt=re||B,wn(l,i),kt=re,li=X,Sn(i),h&8192)e:for(l=i.stateNode,l._visibility=v?l._visibility&-2:l._visibility|1,v&&(s===null||B||li||kt||Ra(i)),s=null,l=i;;){if(l.tag===5||l.tag===26){if(s===null){B=s=l;try{if(b=B.stateNode,v)A=b.style,typeof A.setProperty=="function"?A.setProperty("display","none","important"):A.display="none";else{j=B.stateNode;var le=B.memoizedProps.style,W=le!=null&&le.hasOwnProperty("display")?le.display:null;j.style.display=W==null||typeof W=="boolean"?"":(""+W).trim()}}catch(pe){Xe(B,B.return,pe)}}}else if(l.tag===6){if(s===null){B=l;try{B.stateNode.nodeValue=v?"":B.memoizedProps}catch(pe){Xe(B,B.return,pe)}}}else if(l.tag===18){if(s===null){B=l;try{var ne=B.stateNode;v?zS(ne,!0):zS(B.stateNode,!1)}catch(pe){Xe(B,B.return,pe)}}}else if((l.tag!==22&&l.tag!==23||l.memoizedState===null||l===i)&&l.child!==null){l.child.return=l,l=l.child;continue}if(l===i)break e;for(;l.sibling===null;){if(l.return===null||l.return===i)break e;s===l&&(s=null),l=l.return}s===l&&(s=null),l.sibling.return=l.return,l=l.sibling}h&4&&(h=i.updateQueue,h!==null&&(s=h.retryQueue,s!==null&&(h.retryQueue=null,_c(i,s))));break;case 19:wn(l,i),Sn(i),h&4&&(h=i.updateQueue,h!==null&&(i.updateQueue=null,_c(i,h)));break;case 30:break;case 21:break;default:wn(l,i),Sn(i)}}function Sn(i){var l=i.flags;if(l&2){try{for(var s,h=i.return;h!==null;){if(Nw(h)){s=h;break}h=h.return}if(s==null)throw Error(r(160));switch(s.tag){case 27:var v=s.stateNode,b=Qm(i);Ac(i,b,v);break;case 5:var A=s.stateNode;s.flags&32&&(yl(A,""),s.flags&=-33);var j=Qm(i);Ac(i,j,A);break;case 3:case 4:var B=s.stateNode.containerInfo,X=Qm(i);Wm(i,X,B);break;default:throw Error(r(161))}}catch(re){Xe(i,i.return,re)}i.flags&=-3}l&4096&&(i.flags&=-4097)}function $w(i){if(i.subtreeFlags&1024)for(i=i.child;i!==null;){var l=i;$w(l),l.tag===5&&l.flags&1024&&l.stateNode.reset(),i=i.sibling}}function oi(i,l){if(l.subtreeFlags&8772)for(l=l.child;l!==null;)Iw(i,l.alternate,l),l=l.sibling}function Ra(i){for(i=i.child;i!==null;){var l=i;switch(l.tag){case 0:case 11:case 14:case 15:Xi(4,l,l.return),Ra(l);break;case 1:Dr(l,l.return);var s=l.stateNode;typeof s.componentWillUnmount=="function"&&zw(l,l.return,s),Ra(l);break;case 27:So(l.stateNode);case 26:case 5:Dr(l,l.return),Ra(l);break;case 22:l.memoizedState===null&&Ra(l);break;case 30:Ra(l);break;default:Ra(l)}i=i.sibling}}function si(i,l,s){for(s=s&&(l.subtreeFlags&8772)!==0,l=l.child;l!==null;){var h=l.alternate,v=i,b=l,A=b.flags;switch(b.tag){case 0:case 11:case 15:si(v,b,s),fo(4,b);break;case 1:if(si(v,b,s),h=b,v=h.stateNode,typeof v.componentDidMount=="function")try{v.componentDidMount()}catch(X){Xe(h,h.return,X)}if(h=b,v=h.updateQueue,v!==null){var j=h.stateNode;try{var B=v.shared.hiddenCallbacks;if(B!==null)for(v.shared.hiddenCallbacks=null,v=0;v<B.length;v++)x1(B[v],j)}catch(X){Xe(h,h.return,X)}}s&&A&64&&Mw(b),ho(b,b.return);break;case 27:Pw(b);case 26:case 5:si(v,b,s),s&&h===null&&A&4&&Dw(b),ho(b,b.return);break;case 12:si(v,b,s);break;case 31:si(v,b,s),s&&A&4&&Uw(v,b);break;case 13:si(v,b,s),s&&A&4&&qw(v,b);break;case 22:b.memoizedState===null&&si(v,b,s),ho(b,b.return);break;case 30:break;default:si(v,b,s)}l=l.sibling}}function ep(i,l){var s=null;i!==null&&i.memoizedState!==null&&i.memoizedState.cachePool!==null&&(s=i.memoizedState.cachePool.pool),i=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(i=l.memoizedState.cachePool.pool),i!==s&&(i!=null&&i.refCount++,s!=null&&Wu(s))}function tp(i,l){i=null,l.alternate!==null&&(i=l.alternate.memoizedState.cache),l=l.memoizedState.cache,l!==i&&(l.refCount++,i!=null&&Wu(i))}function xr(i,l,s,h){if(l.subtreeFlags&10256)for(l=l.child;l!==null;)Fw(i,l,s,h),l=l.sibling}function Fw(i,l,s,h){var v=l.flags;switch(l.tag){case 0:case 11:case 15:xr(i,l,s,h),v&2048&&fo(9,l);break;case 1:xr(i,l,s,h);break;case 3:xr(i,l,s,h),v&2048&&(i=null,l.alternate!==null&&(i=l.alternate.memoizedState.cache),l=l.memoizedState.cache,l!==i&&(l.refCount++,i!=null&&Wu(i)));break;case 12:if(v&2048){xr(i,l,s,h),i=l.stateNode;try{var b=l.memoizedProps,A=b.id,j=b.onPostCommit;typeof j=="function"&&j(A,l.alternate===null?"mount":"update",i.passiveEffectDuration,-0)}catch(B){Xe(l,l.return,B)}}else xr(i,l,s,h);break;case 31:xr(i,l,s,h);break;case 13:xr(i,l,s,h);break;case 23:break;case 22:b=l.stateNode,A=l.alternate,l.memoizedState!==null?b._visibility&2?xr(i,l,s,h):mo(i,l):b._visibility&2?xr(i,l,s,h):(b._visibility|=2,Il(i,l,s,h,(l.subtreeFlags&10256)!==0||!1)),v&2048&&ep(A,l);break;case 24:xr(i,l,s,h),v&2048&&tp(l.alternate,l);break;default:xr(i,l,s,h)}}function Il(i,l,s,h,v){for(v=v&&((l.subtreeFlags&10256)!==0||!1),l=l.child;l!==null;){var b=i,A=l,j=s,B=h,X=A.flags;switch(A.tag){case 0:case 11:case 15:Il(b,A,j,B,v),fo(8,A);break;case 23:break;case 22:var re=A.stateNode;A.memoizedState!==null?re._visibility&2?Il(b,A,j,B,v):mo(b,A):(re._visibility|=2,Il(b,A,j,B,v)),v&&X&2048&&ep(A.alternate,A);break;case 24:Il(b,A,j,B,v),v&&X&2048&&tp(A.alternate,A);break;default:Il(b,A,j,B,v)}l=l.sibling}}function mo(i,l){if(l.subtreeFlags&10256)for(l=l.child;l!==null;){var s=i,h=l,v=h.flags;switch(h.tag){case 22:mo(s,h),v&2048&&ep(h.alternate,h);break;case 24:mo(s,h),v&2048&&tp(h.alternate,h);break;default:mo(s,h)}l=l.sibling}}var po=8192;function Ll(i,l,s){if(i.subtreeFlags&po)for(i=i.child;i!==null;)Vw(i,l,s),i=i.sibling}function Vw(i,l,s){switch(i.tag){case 26:Ll(i,l,s),i.flags&po&&i.memoizedState!==null&&PR(s,br,i.memoizedState,i.memoizedProps);break;case 5:Ll(i,l,s);break;case 3:case 4:var h=br;br=Uc(i.stateNode.containerInfo),Ll(i,l,s),br=h;break;case 22:i.memoizedState===null&&(h=i.alternate,h!==null&&h.memoizedState!==null?(h=po,po=16777216,Ll(i,l,s),po=h):Ll(i,l,s));break;default:Ll(i,l,s)}}function Yw(i){var l=i.alternate;if(l!==null&&(i=l.child,i!==null)){l.child=null;do l=i.sibling,i.sibling=null,i=l;while(i!==null)}}function vo(i){var l=i.deletions;if((i.flags&16)!==0){if(l!==null)for(var s=0;s<l.length;s++){var h=l[s];It=h,Gw(h,i)}Yw(i)}if(i.subtreeFlags&10256)for(i=i.child;i!==null;)Kw(i),i=i.sibling}function Kw(i){switch(i.tag){case 0:case 11:case 15:vo(i),i.flags&2048&&Xi(9,i,i.return);break;case 3:vo(i);break;case 12:vo(i);break;case 22:var l=i.stateNode;i.memoizedState!==null&&l._visibility&2&&(i.return===null||i.return.tag!==13)?(l._visibility&=-3,kc(i)):vo(i);break;default:vo(i)}}function kc(i){var l=i.deletions;if((i.flags&16)!==0){if(l!==null)for(var s=0;s<l.length;s++){var h=l[s];It=h,Gw(h,i)}Yw(i)}for(i=i.child;i!==null;){switch(l=i,l.tag){case 0:case 11:case 15:Xi(8,l,l.return),kc(l);break;case 22:s=l.stateNode,s._visibility&2&&(s._visibility&=-3,kc(l));break;default:kc(l)}i=i.sibling}}function Gw(i,l){for(;It!==null;){var s=It;switch(s.tag){case 0:case 11:case 15:Xi(8,s,l);break;case 23:case 22:if(s.memoizedState!==null&&s.memoizedState.cachePool!==null){var h=s.memoizedState.cachePool.pool;h!=null&&h.refCount++}break;case 24:Wu(s.memoizedState.cache)}if(h=s.child,h!==null)h.return=s,It=h;else e:for(s=i;It!==null;){h=It;var v=h.sibling,b=h.return;if(Lw(h),h===s){It=null;break e}if(v!==null){v.return=b,It=v;break e}It=b}}}var ZP={getCacheForType:function(i){var l=Gt(Et),s=l.data.get(i);return s===void 0&&(s=i(),l.data.set(i,s)),s},cacheSignal:function(){return Gt(Et).controller.signal}},QP=typeof WeakMap=="function"?WeakMap:Map,Ye=0,nt=null,Ne=null,Le=0,Ge=0,In=null,Zi=!1,Bl=!1,np=!1,ci=0,vt=0,Qi=0,Ia=0,rp=0,Ln=0,Ul=0,yo=null,On=null,ip=!1,Cc=0,Xw=0,Tc=1/0,jc=null,Wi=null,zt=0,Ji=null,ql=null,fi=0,ap=0,lp=null,Zw=null,go=0,up=null;function Bn(){return(Ye&2)!==0&&Le!==0?Le&-Le:U.T!==null?hp():dx()}function Qw(){if(Ln===0)if((Le&536870912)===0||Ue){var i=Ls;Ls<<=1,(Ls&3932160)===0&&(Ls=262144),Ln=i}else Ln=536870912;return i=Pn.current,i!==null&&(i.flags|=32),Ln}function En(i,l,s){(i===nt&&(Ge===2||Ge===9)||i.cancelPendingCommit!==null)&&(Hl(i,0),ea(i,Le,Ln,!1)),Lu(i,s),((Ye&2)===0||i!==nt)&&(i===nt&&((Ye&2)===0&&(Ia|=s),vt===4&&ea(i,Le,Ln,!1)),Nr(i))}function Ww(i,l,s){if((Ye&6)!==0)throw Error(r(327));var h=!s&&(l&127)===0&&(l&i.expiredLanes)===0||Iu(i,l),v=h?eR(i,l):sp(i,l,!0),b=h;do{if(v===0){Bl&&!h&&ea(i,l,0,!1);break}else{if(s=i.current.alternate,b&&!WP(s)){v=sp(i,l,!1),b=!1;continue}if(v===2){if(b=l,i.errorRecoveryDisabledLanes&b)var A=0;else A=i.pendingLanes&-536870913,A=A!==0?A:A&536870912?536870912:0;if(A!==0){l=A;e:{var j=i;v=yo;var B=j.current.memoizedState.isDehydrated;if(B&&(Hl(j,A).flags|=256),A=sp(j,A,!1),A!==2){if(np&&!B){j.errorRecoveryDisabledLanes|=b,Ia|=b,v=4;break e}b=On,On=v,b!==null&&(On===null?On=b:On.push.apply(On,b))}v=A}if(b=!1,v!==2)continue}}if(v===1){Hl(i,0),ea(i,l,0,!0);break}e:{switch(h=i,b=v,b){case 0:case 1:throw Error(r(345));case 4:if((l&4194048)!==l)break;case 6:ea(h,l,Ln,!Zi);break e;case 2:On=null;break;case 3:case 5:break;default:throw Error(r(329))}if((l&62914560)===l&&(v=Cc+300-on(),10<v)){if(ea(h,l,Ln,!Zi),Us(h,0,!0)!==0)break e;fi=l,h.timeoutHandle=TS(Jw.bind(null,h,s,On,jc,ip,l,Ln,Ia,Ul,Zi,b,"Throttled",-0,0),v);break e}Jw(h,s,On,jc,ip,l,Ln,Ia,Ul,Zi,b,null,-0,0)}}break}while(!0);Nr(i)}function Jw(i,l,s,h,v,b,A,j,B,X,re,le,W,ne){if(i.timeoutHandle=-1,le=l.subtreeFlags,le&8192||(le&16785408)===16785408){le={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Zr},Vw(l,b,le);var pe=(b&62914560)===b?Cc-on():(b&4194048)===b?Xw-on():0;if(pe=RR(le,pe),pe!==null){fi=b,i.cancelPendingCommit=pe(uS.bind(null,i,l,b,s,h,v,A,j,B,re,le,null,W,ne)),ea(i,b,A,!X);return}}uS(i,l,b,s,h,v,A,j,B)}function WP(i){for(var l=i;;){var s=l.tag;if((s===0||s===11||s===15)&&l.flags&16384&&(s=l.updateQueue,s!==null&&(s=s.stores,s!==null)))for(var h=0;h<s.length;h++){var v=s[h],b=v.getSnapshot;v=v.value;try{if(!Dn(b(),v))return!1}catch{return!1}}if(s=l.child,l.subtreeFlags&16384&&s!==null)s.return=l,l=s;else{if(l===i)break;for(;l.sibling===null;){if(l.return===null||l.return===i)return!0;l=l.return}l.sibling.return=l.return,l=l.sibling}}return!0}function ea(i,l,s,h){l&=~rp,l&=~Ia,i.suspendedLanes|=l,i.pingedLanes&=~l,h&&(i.warmLanes|=l),h=i.expirationTimes;for(var v=l;0<v;){var b=31-tt(v),A=1<<b;h[b]=-1,v&=~A}s!==0&&sx(i,s,l)}function Mc(){return(Ye&6)===0?(bo(0),!1):!0}function op(){if(Ne!==null){if(Ge===0)var i=Ne.return;else i=Ne,ei=Ca=null,Em(i),zl=null,eo=0,i=Ne;for(;i!==null;)jw(i.alternate,i),i=i.return;Ne=null}}function Hl(i,l){var s=i.timeoutHandle;s!==-1&&(i.timeoutHandle=-1,gR(s)),s=i.cancelPendingCommit,s!==null&&(i.cancelPendingCommit=null,s()),fi=0,op(),nt=i,Ne=s=Wr(i.current,null),Le=l,Ge=0,In=null,Zi=!1,Bl=Iu(i,l),np=!1,Ul=Ln=rp=Ia=Qi=vt=0,On=yo=null,ip=!1,(l&8)!==0&&(l|=l&32);var h=i.entangledLanes;if(h!==0)for(i=i.entanglements,h&=l;0<h;){var v=31-tt(h),b=1<<v;l|=i[v],h&=~b}return ci=l,Ws(),s}function eS(i,l){Te=null,U.H=oo,l===Ml||l===lc?(l=v1(),Ge=3):l===dm?(l=v1(),Ge=4):Ge=l===Um?8:l!==null&&typeof l=="object"&&typeof l.then=="function"?6:1,In=l,Ne===null&&(vt=1,xc(i,Wn(l,i.current)))}function tS(){var i=Pn.current;return i===null?!0:(Le&4194048)===Le?nr===null:(Le&62914560)===Le||(Le&536870912)!==0?i===nr:!1}function nS(){var i=U.H;return U.H=oo,i===null?oo:i}function rS(){var i=U.A;return U.A=ZP,i}function zc(){vt=4,Zi||(Le&4194048)!==Le&&Pn.current!==null||(Bl=!0),(Qi&134217727)===0&&(Ia&134217727)===0||nt===null||ea(nt,Le,Ln,!1)}function sp(i,l,s){var h=Ye;Ye|=2;var v=nS(),b=rS();(nt!==i||Le!==l)&&(jc=null,Hl(i,l)),l=!1;var A=vt;e:do try{if(Ge!==0&&Ne!==null){var j=Ne,B=In;switch(Ge){case 8:op(),A=6;break e;case 3:case 2:case 9:case 6:Pn.current===null&&(l=!0);var X=Ge;if(Ge=0,In=null,$l(i,j,B,X),s&&Bl){A=0;break e}break;default:X=Ge,Ge=0,In=null,$l(i,j,B,X)}}JP(),A=vt;break}catch(re){eS(i,re)}while(!0);return l&&i.shellSuspendCounter++,ei=Ca=null,Ye=h,U.H=v,U.A=b,Ne===null&&(nt=null,Le=0,Ws()),A}function JP(){for(;Ne!==null;)iS(Ne)}function eR(i,l){var s=Ye;Ye|=2;var h=nS(),v=rS();nt!==i||Le!==l?(jc=null,Tc=on()+500,Hl(i,l)):Bl=Iu(i,l);e:do try{if(Ge!==0&&Ne!==null){l=Ne;var b=In;t:switch(Ge){case 1:Ge=0,In=null,$l(i,l,b,1);break;case 2:case 9:if(m1(b)){Ge=0,In=null,aS(l);break}l=function(){Ge!==2&&Ge!==9||nt!==i||(Ge=7),Nr(i)},b.then(l,l);break e;case 3:Ge=7;break e;case 4:Ge=5;break e;case 7:m1(b)?(Ge=0,In=null,aS(l)):(Ge=0,In=null,$l(i,l,b,7));break;case 5:var A=null;switch(Ne.tag){case 26:A=Ne.memoizedState;case 5:case 27:var j=Ne;if(A?FS(A):j.stateNode.complete){Ge=0,In=null;var B=j.sibling;if(B!==null)Ne=B;else{var X=j.return;X!==null?(Ne=X,Dc(X)):Ne=null}break t}}Ge=0,In=null,$l(i,l,b,5);break;case 6:Ge=0,In=null,$l(i,l,b,6);break;case 8:op(),vt=6;break e;default:throw Error(r(462))}}tR();break}catch(re){eS(i,re)}while(!0);return ei=Ca=null,U.H=h,U.A=v,Ye=s,Ne!==null?0:(nt=null,Le=0,Ws(),vt)}function tR(){for(;Ne!==null&&!Sh();)iS(Ne)}function iS(i){var l=Cw(i.alternate,i,ci);i.memoizedProps=i.pendingProps,l===null?Dc(i):Ne=l}function aS(i){var l=i,s=l.alternate;switch(l.tag){case 15:case 0:l=Sw(s,l,l.pendingProps,l.type,void 0,Le);break;case 11:l=Sw(s,l,l.pendingProps,l.type.render,l.ref,Le);break;case 5:Em(l);default:jw(s,l),l=Ne=r1(l,ci),l=Cw(s,l,ci)}i.memoizedProps=i.pendingProps,l===null?Dc(i):Ne=l}function $l(i,l,s,h){ei=Ca=null,Em(l),zl=null,eo=0;var v=l.return;try{if($P(i,v,l,s,Le)){vt=1,xc(i,Wn(s,i.current)),Ne=null;return}}catch(b){if(v!==null)throw Ne=v,b;vt=1,xc(i,Wn(s,i.current)),Ne=null;return}l.flags&32768?(Ue||h===1?i=!0:Bl||(Le&536870912)!==0?i=!1:(Zi=i=!0,(h===2||h===9||h===3||h===6)&&(h=Pn.current,h!==null&&h.tag===13&&(h.flags|=16384))),lS(l,i)):Dc(l)}function Dc(i){var l=i;do{if((l.flags&32768)!==0){lS(l,Zi);return}i=l.return;var s=YP(l.alternate,l,ci);if(s!==null){Ne=s;return}if(l=l.sibling,l!==null){Ne=l;return}Ne=l=i}while(l!==null);vt===0&&(vt=5)}function lS(i,l){do{var s=KP(i.alternate,i);if(s!==null){s.flags&=32767,Ne=s;return}if(s=i.return,s!==null&&(s.flags|=32768,s.subtreeFlags=0,s.deletions=null),!l&&(i=i.sibling,i!==null)){Ne=i;return}Ne=i=s}while(i!==null);vt=6,Ne=null}function uS(i,l,s,h,v,b,A,j,B){i.cancelPendingCommit=null;do Nc();while(zt!==0);if((Ye&6)!==0)throw Error(r(327));if(l!==null){if(l===i.current)throw Error(r(177));if(b=l.lanes|l.childLanes,b|=Qh,NN(i,s,b,A,j,B),i===nt&&(Ne=nt=null,Le=0),ql=l,Ji=i,fi=s,ap=b,lp=v,Zw=h,(l.subtreeFlags&10256)!==0||(l.flags&10256)!==0?(i.callbackNode=null,i.callbackPriority=0,aR(ke,function(){return dS(),null})):(i.callbackNode=null,i.callbackPriority=0),h=(l.flags&13878)!==0,(l.subtreeFlags&13878)!==0||h){h=U.T,U.T=null,v=Q.p,Q.p=2,A=Ye,Ye|=4;try{GP(i,l,s)}finally{Ye=A,Q.p=v,U.T=h}}zt=1,oS(),sS(),cS()}}function oS(){if(zt===1){zt=0;var i=Ji,l=ql,s=(l.flags&13878)!==0;if((l.subtreeFlags&13878)!==0||s){s=U.T,U.T=null;var h=Q.p;Q.p=2;var v=Ye;Ye|=4;try{Hw(l,i);var b=wp,A=Gx(i.containerInfo),j=b.focusedElem,B=b.selectionRange;if(A!==j&&j&&j.ownerDocument&&Kx(j.ownerDocument.documentElement,j)){if(B!==null&&Yh(j)){var X=B.start,re=B.end;if(re===void 0&&(re=X),"selectionStart"in j)j.selectionStart=X,j.selectionEnd=Math.min(re,j.value.length);else{var le=j.ownerDocument||document,W=le&&le.defaultView||window;if(W.getSelection){var ne=W.getSelection(),pe=j.textContent.length,_e=Math.min(B.start,pe),Je=B.end===void 0?_e:Math.min(B.end,pe);!ne.extend&&_e>Je&&(A=Je,Je=_e,_e=A);var V=Yx(j,_e),q=Yx(j,Je);if(V&&q&&(ne.rangeCount!==1||ne.anchorNode!==V.node||ne.anchorOffset!==V.offset||ne.focusNode!==q.node||ne.focusOffset!==q.offset)){var G=le.createRange();G.setStart(V.node,V.offset),ne.removeAllRanges(),_e>Je?(ne.addRange(G),ne.extend(q.node,q.offset)):(G.setEnd(q.node,q.offset),ne.addRange(G))}}}}for(le=[],ne=j;ne=ne.parentNode;)ne.nodeType===1&&le.push({element:ne,left:ne.scrollLeft,top:ne.scrollTop});for(typeof j.focus=="function"&&j.focus(),j=0;j<le.length;j++){var ae=le[j];ae.element.scrollLeft=ae.left,ae.element.scrollTop=ae.top}}Yc=!!xp,wp=xp=null}finally{Ye=v,Q.p=h,U.T=s}}i.current=l,zt=2}}function sS(){if(zt===2){zt=0;var i=Ji,l=ql,s=(l.flags&8772)!==0;if((l.subtreeFlags&8772)!==0||s){s=U.T,U.T=null;var h=Q.p;Q.p=2;var v=Ye;Ye|=4;try{Iw(i,l.alternate,l)}finally{Ye=v,Q.p=h,U.T=s}}zt=3}}function cS(){if(zt===4||zt===3){zt=0,Oh();var i=Ji,l=ql,s=fi,h=Zw;(l.subtreeFlags&10256)!==0||(l.flags&10256)!==0?zt=5:(zt=0,ql=Ji=null,fS(i,i.pendingLanes));var v=i.pendingLanes;if(v===0&&(Wi=null),kh(s),l=l.stateNode,Mt&&typeof Mt.onCommitFiberRoot=="function")try{Mt.onCommitFiberRoot(sn,l,void 0,(l.current.flags&128)===128)}catch{}if(h!==null){l=U.T,v=Q.p,Q.p=2,U.T=null;try{for(var b=i.onRecoverableError,A=0;A<h.length;A++){var j=h[A];b(j.value,{componentStack:j.stack})}}finally{U.T=l,Q.p=v}}(fi&3)!==0&&Nc(),Nr(i),v=i.pendingLanes,(s&261930)!==0&&(v&42)!==0?i===up?go++:(go=0,up=i):go=0,bo(0)}}function fS(i,l){(i.pooledCacheLanes&=l)===0&&(l=i.pooledCache,l!=null&&(i.pooledCache=null,Wu(l)))}function Nc(){return oS(),sS(),cS(),dS()}function dS(){if(zt!==5)return!1;var i=Ji,l=ap;ap=0;var s=kh(fi),h=U.T,v=Q.p;try{Q.p=32>s?32:s,U.T=null,s=lp,lp=null;var b=Ji,A=fi;if(zt=0,ql=Ji=null,fi=0,(Ye&6)!==0)throw Error(r(331));var j=Ye;if(Ye|=4,Kw(b.current),Fw(b,b.current,A,s),Ye=j,bo(0,!1),Mt&&typeof Mt.onPostCommitFiberRoot=="function")try{Mt.onPostCommitFiberRoot(sn,b)}catch{}return!0}finally{Q.p=v,U.T=h,fS(i,l)}}function hS(i,l,s){l=Wn(s,l),l=Bm(i.stateNode,l,2),i=Yi(i,l,2),i!==null&&(Lu(i,2),Nr(i))}function Xe(i,l,s){if(i.tag===3)hS(i,i,s);else for(;l!==null;){if(l.tag===3){hS(l,i,s);break}else if(l.tag===1){var h=l.stateNode;if(typeof l.type.getDerivedStateFromError=="function"||typeof h.componentDidCatch=="function"&&(Wi===null||!Wi.has(h))){i=Wn(s,i),s=mw(2),h=Yi(l,s,2),h!==null&&(pw(s,h,l,i),Lu(h,2),Nr(h));break}}l=l.return}}function cp(i,l,s){var h=i.pingCache;if(h===null){h=i.pingCache=new QP;var v=new Set;h.set(l,v)}else v=h.get(l),v===void 0&&(v=new Set,h.set(l,v));v.has(s)||(np=!0,v.add(s),i=nR.bind(null,i,l,s),l.then(i,i))}function nR(i,l,s){var h=i.pingCache;h!==null&&h.delete(l),i.pingedLanes|=i.suspendedLanes&s,i.warmLanes&=~s,nt===i&&(Le&s)===s&&(vt===4||vt===3&&(Le&62914560)===Le&&300>on()-Cc?(Ye&2)===0&&Hl(i,0):rp|=s,Ul===Le&&(Ul=0)),Nr(i)}function mS(i,l){l===0&&(l=ox()),i=Aa(i,l),i!==null&&(Lu(i,l),Nr(i))}function rR(i){var l=i.memoizedState,s=0;l!==null&&(s=l.retryLane),mS(i,s)}function iR(i,l){var s=0;switch(i.tag){case 31:case 13:var h=i.stateNode,v=i.memoizedState;v!==null&&(s=v.retryLane);break;case 19:h=i.stateNode;break;case 22:h=i.stateNode._retryCache;break;default:throw Error(r(314))}h!==null&&h.delete(l),mS(i,s)}function aR(i,l){return cl(i,l)}var Pc=null,Fl=null,fp=!1,Rc=!1,dp=!1,ta=0;function Nr(i){i!==Fl&&i.next===null&&(Fl===null?Pc=Fl=i:Fl=Fl.next=i),Rc=!0,fp||(fp=!0,uR())}function bo(i,l){if(!dp&&Rc){dp=!0;do for(var s=!1,h=Pc;h!==null;){if(i!==0){var v=h.pendingLanes;if(v===0)var b=0;else{var A=h.suspendedLanes,j=h.pingedLanes;b=(1<<31-tt(42|i)+1)-1,b&=v&~(A&~j),b=b&201326741?b&201326741|1:b?b|2:0}b!==0&&(s=!0,gS(h,b))}else b=Le,b=Us(h,h===nt?b:0,h.cancelPendingCommit!==null||h.timeoutHandle!==-1),(b&3)===0||Iu(h,b)||(s=!0,gS(h,b));h=h.next}while(s);dp=!1}}function lR(){pS()}function pS(){Rc=fp=!1;var i=0;ta!==0&&yR()&&(i=ta);for(var l=on(),s=null,h=Pc;h!==null;){var v=h.next,b=vS(h,l);b===0?(h.next=null,s===null?Pc=v:s.next=v,v===null&&(Fl=s)):(s=h,(i!==0||(b&3)!==0)&&(Rc=!0)),h=v}zt!==0&&zt!==5||bo(i),ta!==0&&(ta=0)}function vS(i,l){for(var s=i.suspendedLanes,h=i.pingedLanes,v=i.expirationTimes,b=i.pendingLanes&-62914561;0<b;){var A=31-tt(b),j=1<<A,B=v[A];B===-1?((j&s)===0||(j&h)!==0)&&(v[A]=DN(j,l)):B<=l&&(i.expiredLanes|=j),b&=~j}if(l=nt,s=Le,s=Us(i,i===l?s:0,i.cancelPendingCommit!==null||i.timeoutHandle!==-1),h=i.callbackNode,s===0||i===l&&(Ge===2||Ge===9)||i.cancelPendingCommit!==null)return h!==null&&h!==null&&Ru(h),i.callbackNode=null,i.callbackPriority=0;if((s&3)===0||Iu(i,s)){if(l=s&-s,l===i.callbackPriority)return l;switch(h!==null&&Ru(h),kh(s)){case 2:case 8:s=fe;break;case 32:s=ke;break;case 268435456:s=Ke;break;default:s=ke}return h=yS.bind(null,i),s=cl(s,h),i.callbackPriority=l,i.callbackNode=s,l}return h!==null&&h!==null&&Ru(h),i.callbackPriority=2,i.callbackNode=null,2}function yS(i,l){if(zt!==0&&zt!==5)return i.callbackNode=null,i.callbackPriority=0,null;var s=i.callbackNode;if(Nc()&&i.callbackNode!==s)return null;var h=Le;return h=Us(i,i===nt?h:0,i.cancelPendingCommit!==null||i.timeoutHandle!==-1),h===0?null:(Ww(i,h,l),vS(i,on()),i.callbackNode!=null&&i.callbackNode===s?yS.bind(null,i):null)}function gS(i,l){if(Nc())return null;Ww(i,l,!0)}function uR(){bR(function(){(Ye&6)!==0?cl(ie,lR):pS()})}function hp(){if(ta===0){var i=Tl;i===0&&(i=Is,Is<<=1,(Is&261888)===0&&(Is=256)),ta=i}return ta}function bS(i){return i==null||typeof i=="symbol"||typeof i=="boolean"?null:typeof i=="function"?i:Fs(""+i)}function xS(i,l){var s=l.ownerDocument.createElement("input");return s.name=l.name,s.value=l.value,i.id&&s.setAttribute("form",i.id),l.parentNode.insertBefore(s,l),i=new FormData(i),s.parentNode.removeChild(s),i}function oR(i,l,s,h,v){if(l==="submit"&&s&&s.stateNode===v){var b=bS((v[gn]||null).action),A=h.submitter;A&&(l=(l=A[gn]||null)?bS(l.formAction):A.getAttribute("formAction"),l!==null&&(b=l,A=null));var j=new Gs("action","action",null,h,v);i.push({event:j,listeners:[{instance:null,listener:function(){if(h.defaultPrevented){if(ta!==0){var B=A?xS(v,A):new FormData(v);Dm(s,{pending:!0,data:B,method:v.method,action:b},null,B)}}else typeof b=="function"&&(j.preventDefault(),B=A?xS(v,A):new FormData(v),Dm(s,{pending:!0,data:B,method:v.method,action:b},b,B))},currentTarget:v}]})}}for(var mp=0;mp<Zh.length;mp++){var pp=Zh[mp],sR=pp.toLowerCase(),cR=pp[0].toUpperCase()+pp.slice(1);gr(sR,"on"+cR)}gr(Qx,"onAnimationEnd"),gr(Wx,"onAnimationIteration"),gr(Jx,"onAnimationStart"),gr("dblclick","onDoubleClick"),gr("focusin","onFocus"),gr("focusout","onBlur"),gr(_P,"onTransitionRun"),gr(kP,"onTransitionStart"),gr(CP,"onTransitionCancel"),gr(e1,"onTransitionEnd"),pl("onMouseEnter",["mouseout","mouseover"]),pl("onMouseLeave",["mouseout","mouseover"]),pl("onPointerEnter",["pointerout","pointerover"]),pl("onPointerLeave",["pointerout","pointerover"]),wa("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),wa("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),wa("onBeforeInput",["compositionend","keypress","textInput","paste"]),wa("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),wa("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),wa("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var xo="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),fR=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(xo));function wS(i,l){l=(l&4)!==0;for(var s=0;s<i.length;s++){var h=i[s],v=h.event;h=h.listeners;e:{var b=void 0;if(l)for(var A=h.length-1;0<=A;A--){var j=h[A],B=j.instance,X=j.currentTarget;if(j=j.listener,B!==b&&v.isPropagationStopped())break e;b=j,v.currentTarget=X;try{b(v)}catch(re){Qs(re)}v.currentTarget=null,b=B}else for(A=0;A<h.length;A++){if(j=h[A],B=j.instance,X=j.currentTarget,j=j.listener,B!==b&&v.isPropagationStopped())break e;b=j,v.currentTarget=X;try{b(v)}catch(re){Qs(re)}v.currentTarget=null,b=B}}}}function Pe(i,l){var s=l[Ch];s===void 0&&(s=l[Ch]=new Set);var h=i+"__bubble";s.has(h)||(SS(l,i,2,!1),s.add(h))}function vp(i,l,s){var h=0;l&&(h|=4),SS(s,i,h,l)}var Ic="_reactListening"+Math.random().toString(36).slice(2);function yp(i){if(!i[Ic]){i[Ic]=!0,px.forEach(function(s){s!=="selectionchange"&&(fR.has(s)||vp(s,!1,i),vp(s,!0,i))});var l=i.nodeType===9?i:i.ownerDocument;l===null||l[Ic]||(l[Ic]=!0,vp("selectionchange",!1,l))}}function SS(i,l,s,h){switch(QS(l)){case 2:var v=BR;break;case 8:v=UR;break;default:v=zp}s=v.bind(null,l,s,i),v=void 0,!Ih||l!=="touchstart"&&l!=="touchmove"&&l!=="wheel"||(v=!0),h?v!==void 0?i.addEventListener(l,s,{capture:!0,passive:v}):i.addEventListener(l,s,!0):v!==void 0?i.addEventListener(l,s,{passive:v}):i.addEventListener(l,s,!1)}function gp(i,l,s,h,v){var b=h;if((l&1)===0&&(l&2)===0&&h!==null)e:for(;;){if(h===null)return;var A=h.tag;if(A===3||A===4){var j=h.stateNode.containerInfo;if(j===v)break;if(A===4)for(A=h.return;A!==null;){var B=A.tag;if((B===3||B===4)&&A.stateNode.containerInfo===v)return;A=A.return}for(;j!==null;){if(A=dl(j),A===null)return;if(B=A.tag,B===5||B===6||B===26||B===27){h=b=A;continue e}j=j.parentNode}}h=h.return}kx(function(){var X=b,re=Ph(s),le=[];e:{var W=t1.get(i);if(W!==void 0){var ne=Gs,pe=i;switch(i){case"keypress":if(Ys(s)===0)break e;case"keydown":case"keyup":ne=iP;break;case"focusin":pe="focus",ne=qh;break;case"focusout":pe="blur",ne=qh;break;case"beforeblur":case"afterblur":ne=qh;break;case"click":if(s.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":ne=jx;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":ne=YN;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":ne=uP;break;case Qx:case Wx:case Jx:ne=XN;break;case e1:ne=sP;break;case"scroll":case"scrollend":ne=FN;break;case"wheel":ne=fP;break;case"copy":case"cut":case"paste":ne=QN;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":ne=zx;break;case"toggle":case"beforetoggle":ne=hP}var _e=(l&4)!==0,Je=!_e&&(i==="scroll"||i==="scrollend"),V=_e?W!==null?W+"Capture":null:W;_e=[];for(var q=X,G;q!==null;){var ae=q;if(G=ae.stateNode,ae=ae.tag,ae!==5&&ae!==26&&ae!==27||G===null||V===null||(ae=qu(q,V),ae!=null&&_e.push(wo(q,ae,G))),Je)break;q=q.return}0<_e.length&&(W=new ne(W,pe,null,s,re),le.push({event:W,listeners:_e}))}}if((l&7)===0){e:{if(W=i==="mouseover"||i==="pointerover",ne=i==="mouseout"||i==="pointerout",W&&s!==Nh&&(pe=s.relatedTarget||s.fromElement)&&(dl(pe)||pe[fl]))break e;if((ne||W)&&(W=re.window===re?re:(W=re.ownerDocument)?W.defaultView||W.parentWindow:window,ne?(pe=s.relatedTarget||s.toElement,ne=X,pe=pe?dl(pe):null,pe!==null&&(Je=u(pe),_e=pe.tag,pe!==Je||_e!==5&&_e!==27&&_e!==6)&&(pe=null)):(ne=null,pe=X),ne!==pe)){if(_e=jx,ae="onMouseLeave",V="onMouseEnter",q="mouse",(i==="pointerout"||i==="pointerover")&&(_e=zx,ae="onPointerLeave",V="onPointerEnter",q="pointer"),Je=ne==null?W:Uu(ne),G=pe==null?W:Uu(pe),W=new _e(ae,q+"leave",ne,s,re),W.target=Je,W.relatedTarget=G,ae=null,dl(re)===X&&(_e=new _e(V,q+"enter",pe,s,re),_e.target=G,_e.relatedTarget=Je,ae=_e),Je=ae,ne&&pe)t:{for(_e=dR,V=ne,q=pe,G=0,ae=V;ae;ae=_e(ae))G++;ae=0;for(var Oe=q;Oe;Oe=_e(Oe))ae++;for(;0<G-ae;)V=_e(V),G--;for(;0<ae-G;)q=_e(q),ae--;for(;G--;){if(V===q||q!==null&&V===q.alternate){_e=V;break t}V=_e(V),q=_e(q)}_e=null}else _e=null;ne!==null&&OS(le,W,ne,_e,!1),pe!==null&&Je!==null&&OS(le,Je,pe,_e,!0)}}e:{if(W=X?Uu(X):window,ne=W.nodeName&&W.nodeName.toLowerCase(),ne==="select"||ne==="input"&&W.type==="file")var $e=Ux;else if(Lx(W))if(qx)$e=OP;else{$e=wP;var xe=xP}else ne=W.nodeName,!ne||ne.toLowerCase()!=="input"||W.type!=="checkbox"&&W.type!=="radio"?X&&Dh(X.elementType)&&($e=Ux):$e=SP;if($e&&($e=$e(i,X))){Bx(le,$e,s,re);break e}xe&&xe(i,W,X),i==="focusout"&&X&&W.type==="number"&&X.memoizedProps.value!=null&&zh(W,"number",W.value)}switch(xe=X?Uu(X):window,i){case"focusin":(Lx(xe)||xe.contentEditable==="true")&&(wl=xe,Kh=X,Xu=null);break;case"focusout":Xu=Kh=wl=null;break;case"mousedown":Gh=!0;break;case"contextmenu":case"mouseup":case"dragend":Gh=!1,Xx(le,s,re);break;case"selectionchange":if(AP)break;case"keydown":case"keyup":Xx(le,s,re)}var Me;if($h)e:{switch(i){case"compositionstart":var Be="onCompositionStart";break e;case"compositionend":Be="onCompositionEnd";break e;case"compositionupdate":Be="onCompositionUpdate";break e}Be=void 0}else xl?Rx(i,s)&&(Be="onCompositionEnd"):i==="keydown"&&s.keyCode===229&&(Be="onCompositionStart");Be&&(Dx&&s.locale!=="ko"&&(xl||Be!=="onCompositionStart"?Be==="onCompositionEnd"&&xl&&(Me=Cx()):(Bi=re,Lh="value"in Bi?Bi.value:Bi.textContent,xl=!0)),xe=Lc(X,Be),0<xe.length&&(Be=new Mx(Be,i,null,s,re),le.push({event:Be,listeners:xe}),Me?Be.data=Me:(Me=Ix(s),Me!==null&&(Be.data=Me)))),(Me=pP?vP(i,s):yP(i,s))&&(Be=Lc(X,"onBeforeInput"),0<Be.length&&(xe=new Mx("onBeforeInput","beforeinput",null,s,re),le.push({event:xe,listeners:Be}),xe.data=Me)),oR(le,i,X,s,re)}wS(le,l)})}function wo(i,l,s){return{instance:i,listener:l,currentTarget:s}}function Lc(i,l){for(var s=l+"Capture",h=[];i!==null;){var v=i,b=v.stateNode;if(v=v.tag,v!==5&&v!==26&&v!==27||b===null||(v=qu(i,s),v!=null&&h.unshift(wo(i,v,b)),v=qu(i,l),v!=null&&h.push(wo(i,v,b))),i.tag===3)return h;i=i.return}return[]}function dR(i){if(i===null)return null;do i=i.return;while(i&&i.tag!==5&&i.tag!==27);return i||null}function OS(i,l,s,h,v){for(var b=l._reactName,A=[];s!==null&&s!==h;){var j=s,B=j.alternate,X=j.stateNode;if(j=j.tag,B!==null&&B===h)break;j!==5&&j!==26&&j!==27||X===null||(B=X,v?(X=qu(s,b),X!=null&&A.unshift(wo(s,X,B))):v||(X=qu(s,b),X!=null&&A.push(wo(s,X,B)))),s=s.return}A.length!==0&&i.push({event:l,listeners:A})}var hR=/\r\n?/g,mR=/\u0000|\uFFFD/g;function ES(i){return(typeof i=="string"?i:""+i).replace(hR,`
`).replace(mR,"")}function AS(i,l){return l=ES(l),ES(i)===l}function We(i,l,s,h,v,b){switch(s){case"children":typeof h=="string"?l==="body"||l==="textarea"&&h===""||yl(i,h):(typeof h=="number"||typeof h=="bigint")&&l!=="body"&&yl(i,""+h);break;case"className":Hs(i,"class",h);break;case"tabIndex":Hs(i,"tabindex",h);break;case"dir":case"role":case"viewBox":case"width":case"height":Hs(i,s,h);break;case"style":Ax(i,h,b);break;case"data":if(l!=="object"){Hs(i,"data",h);break}case"src":case"href":if(h===""&&(l!=="a"||s!=="href")){i.removeAttribute(s);break}if(h==null||typeof h=="function"||typeof h=="symbol"||typeof h=="boolean"){i.removeAttribute(s);break}h=Fs(""+h),i.setAttribute(s,h);break;case"action":case"formAction":if(typeof h=="function"){i.setAttribute(s,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof b=="function"&&(s==="formAction"?(l!=="input"&&We(i,l,"name",v.name,v,null),We(i,l,"formEncType",v.formEncType,v,null),We(i,l,"formMethod",v.formMethod,v,null),We(i,l,"formTarget",v.formTarget,v,null)):(We(i,l,"encType",v.encType,v,null),We(i,l,"method",v.method,v,null),We(i,l,"target",v.target,v,null)));if(h==null||typeof h=="symbol"||typeof h=="boolean"){i.removeAttribute(s);break}h=Fs(""+h),i.setAttribute(s,h);break;case"onClick":h!=null&&(i.onclick=Zr);break;case"onScroll":h!=null&&Pe("scroll",i);break;case"onScrollEnd":h!=null&&Pe("scrollend",i);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(s=h.__html,s!=null){if(v.children!=null)throw Error(r(60));i.innerHTML=s}}break;case"multiple":i.multiple=h&&typeof h!="function"&&typeof h!="symbol";break;case"muted":i.muted=h&&typeof h!="function"&&typeof h!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(h==null||typeof h=="function"||typeof h=="boolean"||typeof h=="symbol"){i.removeAttribute("xlink:href");break}s=Fs(""+h),i.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",s);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":h!=null&&typeof h!="function"&&typeof h!="symbol"?i.setAttribute(s,""+h):i.removeAttribute(s);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":h&&typeof h!="function"&&typeof h!="symbol"?i.setAttribute(s,""):i.removeAttribute(s);break;case"capture":case"download":h===!0?i.setAttribute(s,""):h!==!1&&h!=null&&typeof h!="function"&&typeof h!="symbol"?i.setAttribute(s,h):i.removeAttribute(s);break;case"cols":case"rows":case"size":case"span":h!=null&&typeof h!="function"&&typeof h!="symbol"&&!isNaN(h)&&1<=h?i.setAttribute(s,h):i.removeAttribute(s);break;case"rowSpan":case"start":h==null||typeof h=="function"||typeof h=="symbol"||isNaN(h)?i.removeAttribute(s):i.setAttribute(s,h);break;case"popover":Pe("beforetoggle",i),Pe("toggle",i),qs(i,"popover",h);break;case"xlinkActuate":Xr(i,"http://www.w3.org/1999/xlink","xlink:actuate",h);break;case"xlinkArcrole":Xr(i,"http://www.w3.org/1999/xlink","xlink:arcrole",h);break;case"xlinkRole":Xr(i,"http://www.w3.org/1999/xlink","xlink:role",h);break;case"xlinkShow":Xr(i,"http://www.w3.org/1999/xlink","xlink:show",h);break;case"xlinkTitle":Xr(i,"http://www.w3.org/1999/xlink","xlink:title",h);break;case"xlinkType":Xr(i,"http://www.w3.org/1999/xlink","xlink:type",h);break;case"xmlBase":Xr(i,"http://www.w3.org/XML/1998/namespace","xml:base",h);break;case"xmlLang":Xr(i,"http://www.w3.org/XML/1998/namespace","xml:lang",h);break;case"xmlSpace":Xr(i,"http://www.w3.org/XML/1998/namespace","xml:space",h);break;case"is":qs(i,"is",h);break;case"innerText":case"textContent":break;default:(!(2<s.length)||s[0]!=="o"&&s[0]!=="O"||s[1]!=="n"&&s[1]!=="N")&&(s=HN.get(s)||s,qs(i,s,h))}}function bp(i,l,s,h,v,b){switch(s){case"style":Ax(i,h,b);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(s=h.__html,s!=null){if(v.children!=null)throw Error(r(60));i.innerHTML=s}}break;case"children":typeof h=="string"?yl(i,h):(typeof h=="number"||typeof h=="bigint")&&yl(i,""+h);break;case"onScroll":h!=null&&Pe("scroll",i);break;case"onScrollEnd":h!=null&&Pe("scrollend",i);break;case"onClick":h!=null&&(i.onclick=Zr);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!vx.hasOwnProperty(s))e:{if(s[0]==="o"&&s[1]==="n"&&(v=s.endsWith("Capture"),l=s.slice(2,v?s.length-7:void 0),b=i[gn]||null,b=b!=null?b[s]:null,typeof b=="function"&&i.removeEventListener(l,b,v),typeof h=="function")){typeof b!="function"&&b!==null&&(s in i?i[s]=null:i.hasAttribute(s)&&i.removeAttribute(s)),i.addEventListener(l,h,v);break e}s in i?i[s]=h:h===!0?i.setAttribute(s,""):qs(i,s,h)}}}function Zt(i,l,s){switch(l){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Pe("error",i),Pe("load",i);var h=!1,v=!1,b;for(b in s)if(s.hasOwnProperty(b)){var A=s[b];if(A!=null)switch(b){case"src":h=!0;break;case"srcSet":v=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,l));default:We(i,l,b,A,s,null)}}v&&We(i,l,"srcSet",s.srcSet,s,null),h&&We(i,l,"src",s.src,s,null);return;case"input":Pe("invalid",i);var j=b=A=v=null,B=null,X=null;for(h in s)if(s.hasOwnProperty(h)){var re=s[h];if(re!=null)switch(h){case"name":v=re;break;case"type":A=re;break;case"checked":B=re;break;case"defaultChecked":X=re;break;case"value":b=re;break;case"defaultValue":j=re;break;case"children":case"dangerouslySetInnerHTML":if(re!=null)throw Error(r(137,l));break;default:We(i,l,h,re,s,null)}}wx(i,b,j,B,X,A,v,!1);return;case"select":Pe("invalid",i),h=A=b=null;for(v in s)if(s.hasOwnProperty(v)&&(j=s[v],j!=null))switch(v){case"value":b=j;break;case"defaultValue":A=j;break;case"multiple":h=j;default:We(i,l,v,j,s,null)}l=b,s=A,i.multiple=!!h,l!=null?vl(i,!!h,l,!1):s!=null&&vl(i,!!h,s,!0);return;case"textarea":Pe("invalid",i),b=v=h=null;for(A in s)if(s.hasOwnProperty(A)&&(j=s[A],j!=null))switch(A){case"value":h=j;break;case"defaultValue":v=j;break;case"children":b=j;break;case"dangerouslySetInnerHTML":if(j!=null)throw Error(r(91));break;default:We(i,l,A,j,s,null)}Ox(i,h,v,b);return;case"option":for(B in s)if(s.hasOwnProperty(B)&&(h=s[B],h!=null))switch(B){case"selected":i.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:We(i,l,B,h,s,null)}return;case"dialog":Pe("beforetoggle",i),Pe("toggle",i),Pe("cancel",i),Pe("close",i);break;case"iframe":case"object":Pe("load",i);break;case"video":case"audio":for(h=0;h<xo.length;h++)Pe(xo[h],i);break;case"image":Pe("error",i),Pe("load",i);break;case"details":Pe("toggle",i);break;case"embed":case"source":case"link":Pe("error",i),Pe("load",i);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(X in s)if(s.hasOwnProperty(X)&&(h=s[X],h!=null))switch(X){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,l));default:We(i,l,X,h,s,null)}return;default:if(Dh(l)){for(re in s)s.hasOwnProperty(re)&&(h=s[re],h!==void 0&&bp(i,l,re,h,s,void 0));return}}for(j in s)s.hasOwnProperty(j)&&(h=s[j],h!=null&&We(i,l,j,h,s,null))}function pR(i,l,s,h){switch(l){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var v=null,b=null,A=null,j=null,B=null,X=null,re=null;for(ne in s){var le=s[ne];if(s.hasOwnProperty(ne)&&le!=null)switch(ne){case"checked":break;case"value":break;case"defaultValue":B=le;default:h.hasOwnProperty(ne)||We(i,l,ne,null,h,le)}}for(var W in h){var ne=h[W];if(le=s[W],h.hasOwnProperty(W)&&(ne!=null||le!=null))switch(W){case"type":b=ne;break;case"name":v=ne;break;case"checked":X=ne;break;case"defaultChecked":re=ne;break;case"value":A=ne;break;case"defaultValue":j=ne;break;case"children":case"dangerouslySetInnerHTML":if(ne!=null)throw Error(r(137,l));break;default:ne!==le&&We(i,l,W,ne,h,le)}}Mh(i,A,j,B,X,re,b,v);return;case"select":ne=A=j=W=null;for(b in s)if(B=s[b],s.hasOwnProperty(b)&&B!=null)switch(b){case"value":break;case"multiple":ne=B;default:h.hasOwnProperty(b)||We(i,l,b,null,h,B)}for(v in h)if(b=h[v],B=s[v],h.hasOwnProperty(v)&&(b!=null||B!=null))switch(v){case"value":W=b;break;case"defaultValue":j=b;break;case"multiple":A=b;default:b!==B&&We(i,l,v,b,h,B)}l=j,s=A,h=ne,W!=null?vl(i,!!s,W,!1):!!h!=!!s&&(l!=null?vl(i,!!s,l,!0):vl(i,!!s,s?[]:"",!1));return;case"textarea":ne=W=null;for(j in s)if(v=s[j],s.hasOwnProperty(j)&&v!=null&&!h.hasOwnProperty(j))switch(j){case"value":break;case"children":break;default:We(i,l,j,null,h,v)}for(A in h)if(v=h[A],b=s[A],h.hasOwnProperty(A)&&(v!=null||b!=null))switch(A){case"value":W=v;break;case"defaultValue":ne=v;break;case"children":break;case"dangerouslySetInnerHTML":if(v!=null)throw Error(r(91));break;default:v!==b&&We(i,l,A,v,h,b)}Sx(i,W,ne);return;case"option":for(var pe in s)if(W=s[pe],s.hasOwnProperty(pe)&&W!=null&&!h.hasOwnProperty(pe))switch(pe){case"selected":i.selected=!1;break;default:We(i,l,pe,null,h,W)}for(B in h)if(W=h[B],ne=s[B],h.hasOwnProperty(B)&&W!==ne&&(W!=null||ne!=null))switch(B){case"selected":i.selected=W&&typeof W!="function"&&typeof W!="symbol";break;default:We(i,l,B,W,h,ne)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var _e in s)W=s[_e],s.hasOwnProperty(_e)&&W!=null&&!h.hasOwnProperty(_e)&&We(i,l,_e,null,h,W);for(X in h)if(W=h[X],ne=s[X],h.hasOwnProperty(X)&&W!==ne&&(W!=null||ne!=null))switch(X){case"children":case"dangerouslySetInnerHTML":if(W!=null)throw Error(r(137,l));break;default:We(i,l,X,W,h,ne)}return;default:if(Dh(l)){for(var Je in s)W=s[Je],s.hasOwnProperty(Je)&&W!==void 0&&!h.hasOwnProperty(Je)&&bp(i,l,Je,void 0,h,W);for(re in h)W=h[re],ne=s[re],!h.hasOwnProperty(re)||W===ne||W===void 0&&ne===void 0||bp(i,l,re,W,h,ne);return}}for(var V in s)W=s[V],s.hasOwnProperty(V)&&W!=null&&!h.hasOwnProperty(V)&&We(i,l,V,null,h,W);for(le in h)W=h[le],ne=s[le],!h.hasOwnProperty(le)||W===ne||W==null&&ne==null||We(i,l,le,W,h,ne)}function _S(i){switch(i){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function vR(){if(typeof performance.getEntriesByType=="function"){for(var i=0,l=0,s=performance.getEntriesByType("resource"),h=0;h<s.length;h++){var v=s[h],b=v.transferSize,A=v.initiatorType,j=v.duration;if(b&&j&&_S(A)){for(A=0,j=v.responseEnd,h+=1;h<s.length;h++){var B=s[h],X=B.startTime;if(X>j)break;var re=B.transferSize,le=B.initiatorType;re&&_S(le)&&(B=B.responseEnd,A+=re*(B<j?1:(j-X)/(B-X)))}if(--h,l+=8*(b+A)/(v.duration/1e3),i++,10<i)break}}if(0<i)return l/i/1e6}return navigator.connection&&(i=navigator.connection.downlink,typeof i=="number")?i:5}var xp=null,wp=null;function Bc(i){return i.nodeType===9?i:i.ownerDocument}function kS(i){switch(i){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function CS(i,l){if(i===0)switch(l){case"svg":return 1;case"math":return 2;default:return 0}return i===1&&l==="foreignObject"?0:i}function Sp(i,l){return i==="textarea"||i==="noscript"||typeof l.children=="string"||typeof l.children=="number"||typeof l.children=="bigint"||typeof l.dangerouslySetInnerHTML=="object"&&l.dangerouslySetInnerHTML!==null&&l.dangerouslySetInnerHTML.__html!=null}var Op=null;function yR(){var i=window.event;return i&&i.type==="popstate"?i===Op?!1:(Op=i,!0):(Op=null,!1)}var TS=typeof setTimeout=="function"?setTimeout:void 0,gR=typeof clearTimeout=="function"?clearTimeout:void 0,jS=typeof Promise=="function"?Promise:void 0,bR=typeof queueMicrotask=="function"?queueMicrotask:typeof jS<"u"?function(i){return jS.resolve(null).then(i).catch(xR)}:TS;function xR(i){setTimeout(function(){throw i})}function na(i){return i==="head"}function MS(i,l){var s=l,h=0;do{var v=s.nextSibling;if(i.removeChild(s),v&&v.nodeType===8)if(s=v.data,s==="/$"||s==="/&"){if(h===0){i.removeChild(v),Gl(l);return}h--}else if(s==="$"||s==="$?"||s==="$~"||s==="$!"||s==="&")h++;else if(s==="html")So(i.ownerDocument.documentElement);else if(s==="head"){s=i.ownerDocument.head,So(s);for(var b=s.firstChild;b;){var A=b.nextSibling,j=b.nodeName;b[Bu]||j==="SCRIPT"||j==="STYLE"||j==="LINK"&&b.rel.toLowerCase()==="stylesheet"||s.removeChild(b),b=A}}else s==="body"&&So(i.ownerDocument.body);s=v}while(s);Gl(l)}function zS(i,l){var s=i;i=0;do{var h=s.nextSibling;if(s.nodeType===1?l?(s._stashedDisplay=s.style.display,s.style.display="none"):(s.style.display=s._stashedDisplay||"",s.getAttribute("style")===""&&s.removeAttribute("style")):s.nodeType===3&&(l?(s._stashedText=s.nodeValue,s.nodeValue=""):s.nodeValue=s._stashedText||""),h&&h.nodeType===8)if(s=h.data,s==="/$"){if(i===0)break;i--}else s!=="$"&&s!=="$?"&&s!=="$~"&&s!=="$!"||i++;s=h}while(s)}function Ep(i){var l=i.firstChild;for(l&&l.nodeType===10&&(l=l.nextSibling);l;){var s=l;switch(l=l.nextSibling,s.nodeName){case"HTML":case"HEAD":case"BODY":Ep(s),Th(s);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(s.rel.toLowerCase()==="stylesheet")continue}i.removeChild(s)}}function wR(i,l,s,h){for(;i.nodeType===1;){var v=s;if(i.nodeName.toLowerCase()!==l.toLowerCase()){if(!h&&(i.nodeName!=="INPUT"||i.type!=="hidden"))break}else if(h){if(!i[Bu])switch(l){case"meta":if(!i.hasAttribute("itemprop"))break;return i;case"link":if(b=i.getAttribute("rel"),b==="stylesheet"&&i.hasAttribute("data-precedence"))break;if(b!==v.rel||i.getAttribute("href")!==(v.href==null||v.href===""?null:v.href)||i.getAttribute("crossorigin")!==(v.crossOrigin==null?null:v.crossOrigin)||i.getAttribute("title")!==(v.title==null?null:v.title))break;return i;case"style":if(i.hasAttribute("data-precedence"))break;return i;case"script":if(b=i.getAttribute("src"),(b!==(v.src==null?null:v.src)||i.getAttribute("type")!==(v.type==null?null:v.type)||i.getAttribute("crossorigin")!==(v.crossOrigin==null?null:v.crossOrigin))&&b&&i.hasAttribute("async")&&!i.hasAttribute("itemprop"))break;return i;default:return i}}else if(l==="input"&&i.type==="hidden"){var b=v.name==null?null:""+v.name;if(v.type==="hidden"&&i.getAttribute("name")===b)return i}else return i;if(i=rr(i.nextSibling),i===null)break}return null}function SR(i,l,s){if(l==="")return null;for(;i.nodeType!==3;)if((i.nodeType!==1||i.nodeName!=="INPUT"||i.type!=="hidden")&&!s||(i=rr(i.nextSibling),i===null))return null;return i}function DS(i,l){for(;i.nodeType!==8;)if((i.nodeType!==1||i.nodeName!=="INPUT"||i.type!=="hidden")&&!l||(i=rr(i.nextSibling),i===null))return null;return i}function Ap(i){return i.data==="$?"||i.data==="$~"}function _p(i){return i.data==="$!"||i.data==="$?"&&i.ownerDocument.readyState!=="loading"}function OR(i,l){var s=i.ownerDocument;if(i.data==="$~")i._reactRetry=l;else if(i.data!=="$?"||s.readyState!=="loading")l();else{var h=function(){l(),s.removeEventListener("DOMContentLoaded",h)};s.addEventListener("DOMContentLoaded",h),i._reactRetry=h}}function rr(i){for(;i!=null;i=i.nextSibling){var l=i.nodeType;if(l===1||l===3)break;if(l===8){if(l=i.data,l==="$"||l==="$!"||l==="$?"||l==="$~"||l==="&"||l==="F!"||l==="F")break;if(l==="/$"||l==="/&")return null}}return i}var kp=null;function NS(i){i=i.nextSibling;for(var l=0;i;){if(i.nodeType===8){var s=i.data;if(s==="/$"||s==="/&"){if(l===0)return rr(i.nextSibling);l--}else s!=="$"&&s!=="$!"&&s!=="$?"&&s!=="$~"&&s!=="&"||l++}i=i.nextSibling}return null}function PS(i){i=i.previousSibling;for(var l=0;i;){if(i.nodeType===8){var s=i.data;if(s==="$"||s==="$!"||s==="$?"||s==="$~"||s==="&"){if(l===0)return i;l--}else s!=="/$"&&s!=="/&"||l++}i=i.previousSibling}return null}function RS(i,l,s){switch(l=Bc(s),i){case"html":if(i=l.documentElement,!i)throw Error(r(452));return i;case"head":if(i=l.head,!i)throw Error(r(453));return i;case"body":if(i=l.body,!i)throw Error(r(454));return i;default:throw Error(r(451))}}function So(i){for(var l=i.attributes;l.length;)i.removeAttributeNode(l[0]);Th(i)}var ir=new Map,IS=new Set;function Uc(i){return typeof i.getRootNode=="function"?i.getRootNode():i.nodeType===9?i:i.ownerDocument}var di=Q.d;Q.d={f:ER,r:AR,D:_R,C:kR,L:CR,m:TR,X:MR,S:jR,M:zR};function ER(){var i=di.f(),l=Mc();return i||l}function AR(i){var l=hl(i);l!==null&&l.tag===5&&l.type==="form"?ew(l):di.r(i)}var Vl=typeof document>"u"?null:document;function LS(i,l,s){var h=Vl;if(h&&typeof l=="string"&&l){var v=Zn(l);v='link[rel="'+i+'"][href="'+v+'"]',typeof s=="string"&&(v+='[crossorigin="'+s+'"]'),IS.has(v)||(IS.add(v),i={rel:i,crossOrigin:s,href:l},h.querySelector(v)===null&&(l=h.createElement("link"),Zt(l,"link",i),Rt(l),h.head.appendChild(l)))}}function _R(i){di.D(i),LS("dns-prefetch",i,null)}function kR(i,l){di.C(i,l),LS("preconnect",i,l)}function CR(i,l,s){di.L(i,l,s);var h=Vl;if(h&&i&&l){var v='link[rel="preload"][as="'+Zn(l)+'"]';l==="image"&&s&&s.imageSrcSet?(v+='[imagesrcset="'+Zn(s.imageSrcSet)+'"]',typeof s.imageSizes=="string"&&(v+='[imagesizes="'+Zn(s.imageSizes)+'"]')):v+='[href="'+Zn(i)+'"]';var b=v;switch(l){case"style":b=Yl(i);break;case"script":b=Kl(i)}ir.has(b)||(i=p({rel:"preload",href:l==="image"&&s&&s.imageSrcSet?void 0:i,as:l},s),ir.set(b,i),h.querySelector(v)!==null||l==="style"&&h.querySelector(Oo(b))||l==="script"&&h.querySelector(Eo(b))||(l=h.createElement("link"),Zt(l,"link",i),Rt(l),h.head.appendChild(l)))}}function TR(i,l){di.m(i,l);var s=Vl;if(s&&i){var h=l&&typeof l.as=="string"?l.as:"script",v='link[rel="modulepreload"][as="'+Zn(h)+'"][href="'+Zn(i)+'"]',b=v;switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":b=Kl(i)}if(!ir.has(b)&&(i=p({rel:"modulepreload",href:i},l),ir.set(b,i),s.querySelector(v)===null)){switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(s.querySelector(Eo(b)))return}h=s.createElement("link"),Zt(h,"link",i),Rt(h),s.head.appendChild(h)}}}function jR(i,l,s){di.S(i,l,s);var h=Vl;if(h&&i){var v=ml(h).hoistableStyles,b=Yl(i);l=l||"default";var A=v.get(b);if(!A){var j={loading:0,preload:null};if(A=h.querySelector(Oo(b)))j.loading=5;else{i=p({rel:"stylesheet",href:i,"data-precedence":l},s),(s=ir.get(b))&&Cp(i,s);var B=A=h.createElement("link");Rt(B),Zt(B,"link",i),B._p=new Promise(function(X,re){B.onload=X,B.onerror=re}),B.addEventListener("load",function(){j.loading|=1}),B.addEventListener("error",function(){j.loading|=2}),j.loading|=4,qc(A,l,h)}A={type:"stylesheet",instance:A,count:1,state:j},v.set(b,A)}}}function MR(i,l){di.X(i,l);var s=Vl;if(s&&i){var h=ml(s).hoistableScripts,v=Kl(i),b=h.get(v);b||(b=s.querySelector(Eo(v)),b||(i=p({src:i,async:!0},l),(l=ir.get(v))&&Tp(i,l),b=s.createElement("script"),Rt(b),Zt(b,"link",i),s.head.appendChild(b)),b={type:"script",instance:b,count:1,state:null},h.set(v,b))}}function zR(i,l){di.M(i,l);var s=Vl;if(s&&i){var h=ml(s).hoistableScripts,v=Kl(i),b=h.get(v);b||(b=s.querySelector(Eo(v)),b||(i=p({src:i,async:!0,type:"module"},l),(l=ir.get(v))&&Tp(i,l),b=s.createElement("script"),Rt(b),Zt(b,"link",i),s.head.appendChild(b)),b={type:"script",instance:b,count:1,state:null},h.set(v,b))}}function BS(i,l,s,h){var v=(v=ve.current)?Uc(v):null;if(!v)throw Error(r(446));switch(i){case"meta":case"title":return null;case"style":return typeof s.precedence=="string"&&typeof s.href=="string"?(l=Yl(s.href),s=ml(v).hoistableStyles,h=s.get(l),h||(h={type:"style",instance:null,count:0,state:null},s.set(l,h)),h):{type:"void",instance:null,count:0,state:null};case"link":if(s.rel==="stylesheet"&&typeof s.href=="string"&&typeof s.precedence=="string"){i=Yl(s.href);var b=ml(v).hoistableStyles,A=b.get(i);if(A||(v=v.ownerDocument||v,A={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},b.set(i,A),(b=v.querySelector(Oo(i)))&&!b._p&&(A.instance=b,A.state.loading=5),ir.has(i)||(s={rel:"preload",as:"style",href:s.href,crossOrigin:s.crossOrigin,integrity:s.integrity,media:s.media,hrefLang:s.hrefLang,referrerPolicy:s.referrerPolicy},ir.set(i,s),b||DR(v,i,s,A.state))),l&&h===null)throw Error(r(528,""));return A}if(l&&h!==null)throw Error(r(529,""));return null;case"script":return l=s.async,s=s.src,typeof s=="string"&&l&&typeof l!="function"&&typeof l!="symbol"?(l=Kl(s),s=ml(v).hoistableScripts,h=s.get(l),h||(h={type:"script",instance:null,count:0,state:null},s.set(l,h)),h):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,i))}}function Yl(i){return'href="'+Zn(i)+'"'}function Oo(i){return'link[rel="stylesheet"]['+i+"]"}function US(i){return p({},i,{"data-precedence":i.precedence,precedence:null})}function DR(i,l,s,h){i.querySelector('link[rel="preload"][as="style"]['+l+"]")?h.loading=1:(l=i.createElement("link"),h.preload=l,l.addEventListener("load",function(){return h.loading|=1}),l.addEventListener("error",function(){return h.loading|=2}),Zt(l,"link",s),Rt(l),i.head.appendChild(l))}function Kl(i){return'[src="'+Zn(i)+'"]'}function Eo(i){return"script[async]"+i}function qS(i,l,s){if(l.count++,l.instance===null)switch(l.type){case"style":var h=i.querySelector('style[data-href~="'+Zn(s.href)+'"]');if(h)return l.instance=h,Rt(h),h;var v=p({},s,{"data-href":s.href,"data-precedence":s.precedence,href:null,precedence:null});return h=(i.ownerDocument||i).createElement("style"),Rt(h),Zt(h,"style",v),qc(h,s.precedence,i),l.instance=h;case"stylesheet":v=Yl(s.href);var b=i.querySelector(Oo(v));if(b)return l.state.loading|=4,l.instance=b,Rt(b),b;h=US(s),(v=ir.get(v))&&Cp(h,v),b=(i.ownerDocument||i).createElement("link"),Rt(b);var A=b;return A._p=new Promise(function(j,B){A.onload=j,A.onerror=B}),Zt(b,"link",h),l.state.loading|=4,qc(b,s.precedence,i),l.instance=b;case"script":return b=Kl(s.src),(v=i.querySelector(Eo(b)))?(l.instance=v,Rt(v),v):(h=s,(v=ir.get(b))&&(h=p({},s),Tp(h,v)),i=i.ownerDocument||i,v=i.createElement("script"),Rt(v),Zt(v,"link",h),i.head.appendChild(v),l.instance=v);case"void":return null;default:throw Error(r(443,l.type))}else l.type==="stylesheet"&&(l.state.loading&4)===0&&(h=l.instance,l.state.loading|=4,qc(h,s.precedence,i));return l.instance}function qc(i,l,s){for(var h=s.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),v=h.length?h[h.length-1]:null,b=v,A=0;A<h.length;A++){var j=h[A];if(j.dataset.precedence===l)b=j;else if(b!==v)break}b?b.parentNode.insertBefore(i,b.nextSibling):(l=s.nodeType===9?s.head:s,l.insertBefore(i,l.firstChild))}function Cp(i,l){i.crossOrigin==null&&(i.crossOrigin=l.crossOrigin),i.referrerPolicy==null&&(i.referrerPolicy=l.referrerPolicy),i.title==null&&(i.title=l.title)}function Tp(i,l){i.crossOrigin==null&&(i.crossOrigin=l.crossOrigin),i.referrerPolicy==null&&(i.referrerPolicy=l.referrerPolicy),i.integrity==null&&(i.integrity=l.integrity)}var Hc=null;function HS(i,l,s){if(Hc===null){var h=new Map,v=Hc=new Map;v.set(s,h)}else v=Hc,h=v.get(s),h||(h=new Map,v.set(s,h));if(h.has(i))return h;for(h.set(i,null),s=s.getElementsByTagName(i),v=0;v<s.length;v++){var b=s[v];if(!(b[Bu]||b[Yt]||i==="link"&&b.getAttribute("rel")==="stylesheet")&&b.namespaceURI!=="http://www.w3.org/2000/svg"){var A=b.getAttribute(l)||"";A=i+A;var j=h.get(A);j?j.push(b):h.set(A,[b])}}return h}function $S(i,l,s){i=i.ownerDocument||i,i.head.insertBefore(s,l==="title"?i.querySelector("head > title"):null)}function NR(i,l,s){if(s===1||l.itemProp!=null)return!1;switch(i){case"meta":case"title":return!0;case"style":if(typeof l.precedence!="string"||typeof l.href!="string"||l.href==="")break;return!0;case"link":if(typeof l.rel!="string"||typeof l.href!="string"||l.href===""||l.onLoad||l.onError)break;switch(l.rel){case"stylesheet":return i=l.disabled,typeof l.precedence=="string"&&i==null;default:return!0}case"script":if(l.async&&typeof l.async!="function"&&typeof l.async!="symbol"&&!l.onLoad&&!l.onError&&l.src&&typeof l.src=="string")return!0}return!1}function FS(i){return!(i.type==="stylesheet"&&(i.state.loading&3)===0)}function PR(i,l,s,h){if(s.type==="stylesheet"&&(typeof h.media!="string"||matchMedia(h.media).matches!==!1)&&(s.state.loading&4)===0){if(s.instance===null){var v=Yl(h.href),b=l.querySelector(Oo(v));if(b){l=b._p,l!==null&&typeof l=="object"&&typeof l.then=="function"&&(i.count++,i=$c.bind(i),l.then(i,i)),s.state.loading|=4,s.instance=b,Rt(b);return}b=l.ownerDocument||l,h=US(h),(v=ir.get(v))&&Cp(h,v),b=b.createElement("link"),Rt(b);var A=b;A._p=new Promise(function(j,B){A.onload=j,A.onerror=B}),Zt(b,"link",h),s.instance=b}i.stylesheets===null&&(i.stylesheets=new Map),i.stylesheets.set(s,l),(l=s.state.preload)&&(s.state.loading&3)===0&&(i.count++,s=$c.bind(i),l.addEventListener("load",s),l.addEventListener("error",s))}}var jp=0;function RR(i,l){return i.stylesheets&&i.count===0&&Vc(i,i.stylesheets),0<i.count||0<i.imgCount?function(s){var h=setTimeout(function(){if(i.stylesheets&&Vc(i,i.stylesheets),i.unsuspend){var b=i.unsuspend;i.unsuspend=null,b()}},6e4+l);0<i.imgBytes&&jp===0&&(jp=62500*vR());var v=setTimeout(function(){if(i.waitingForImages=!1,i.count===0&&(i.stylesheets&&Vc(i,i.stylesheets),i.unsuspend)){var b=i.unsuspend;i.unsuspend=null,b()}},(i.imgBytes>jp?50:800)+l);return i.unsuspend=s,function(){i.unsuspend=null,clearTimeout(h),clearTimeout(v)}}:null}function $c(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Vc(this,this.stylesheets);else if(this.unsuspend){var i=this.unsuspend;this.unsuspend=null,i()}}}var Fc=null;function Vc(i,l){i.stylesheets=null,i.unsuspend!==null&&(i.count++,Fc=new Map,l.forEach(IR,i),Fc=null,$c.call(i))}function IR(i,l){if(!(l.state.loading&4)){var s=Fc.get(i);if(s)var h=s.get(null);else{s=new Map,Fc.set(i,s);for(var v=i.querySelectorAll("link[data-precedence],style[data-precedence]"),b=0;b<v.length;b++){var A=v[b];(A.nodeName==="LINK"||A.getAttribute("media")!=="not all")&&(s.set(A.dataset.precedence,A),h=A)}h&&s.set(null,h)}v=l.instance,A=v.getAttribute("data-precedence"),b=s.get(A)||h,b===h&&s.set(null,v),s.set(A,v),this.count++,h=$c.bind(this),v.addEventListener("load",h),v.addEventListener("error",h),b?b.parentNode.insertBefore(v,b.nextSibling):(i=i.nodeType===9?i.head:i,i.insertBefore(v,i.firstChild)),l.state.loading|=4}}var Ao={$$typeof:k,Provider:null,Consumer:null,_currentValue:ue,_currentValue2:ue,_threadCount:0};function LR(i,l,s,h,v,b,A,j,B){this.tag=1,this.containerInfo=i,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ah(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ah(0),this.hiddenUpdates=Ah(null),this.identifierPrefix=h,this.onUncaughtError=v,this.onCaughtError=b,this.onRecoverableError=A,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=B,this.incompleteTransitions=new Map}function VS(i,l,s,h,v,b,A,j,B,X,re,le){return i=new LR(i,l,s,A,B,X,re,le,j),l=1,b===!0&&(l|=24),b=Nn(3,null,null,l),i.current=b,b.stateNode=i,l=sm(),l.refCount++,i.pooledCache=l,l.refCount++,b.memoizedState={element:h,isDehydrated:s,cache:l},hm(b),i}function YS(i){return i?(i=El,i):El}function KS(i,l,s,h,v,b){v=YS(v),h.context===null?h.context=v:h.pendingContext=v,h=Vi(l),h.payload={element:s},b=b===void 0?null:b,b!==null&&(h.callback=b),s=Yi(i,h,l),s!==null&&(En(s,i,l),no(s,i,l))}function GS(i,l){if(i=i.memoizedState,i!==null&&i.dehydrated!==null){var s=i.retryLane;i.retryLane=s!==0&&s<l?s:l}}function Mp(i,l){GS(i,l),(i=i.alternate)&&GS(i,l)}function XS(i){if(i.tag===13||i.tag===31){var l=Aa(i,67108864);l!==null&&En(l,i,67108864),Mp(i,67108864)}}function ZS(i){if(i.tag===13||i.tag===31){var l=Bn();l=_h(l);var s=Aa(i,l);s!==null&&En(s,i,l),Mp(i,l)}}var Yc=!0;function BR(i,l,s,h){var v=U.T;U.T=null;var b=Q.p;try{Q.p=2,zp(i,l,s,h)}finally{Q.p=b,U.T=v}}function UR(i,l,s,h){var v=U.T;U.T=null;var b=Q.p;try{Q.p=8,zp(i,l,s,h)}finally{Q.p=b,U.T=v}}function zp(i,l,s,h){if(Yc){var v=Dp(h);if(v===null)gp(i,l,h,Kc,s),WS(i,h);else if(HR(v,i,l,s,h))h.stopPropagation();else if(WS(i,h),l&4&&-1<qR.indexOf(i)){for(;v!==null;){var b=hl(v);if(b!==null)switch(b.tag){case 3:if(b=b.stateNode,b.current.memoizedState.isDehydrated){var A=xa(b.pendingLanes);if(A!==0){var j=b;for(j.pendingLanes|=2,j.entangledLanes|=2;A;){var B=1<<31-tt(A);j.entanglements[1]|=B,A&=~B}Nr(b),(Ye&6)===0&&(Tc=on()+500,bo(0))}}break;case 31:case 13:j=Aa(b,2),j!==null&&En(j,b,2),Mc(),Mp(b,2)}if(b=Dp(h),b===null&&gp(i,l,h,Kc,s),b===v)break;v=b}v!==null&&h.stopPropagation()}else gp(i,l,h,null,s)}}function Dp(i){return i=Ph(i),Np(i)}var Kc=null;function Np(i){if(Kc=null,i=dl(i),i!==null){var l=u(i);if(l===null)i=null;else{var s=l.tag;if(s===13){if(i=o(l),i!==null)return i;i=null}else if(s===31){if(i=c(l),i!==null)return i;i=null}else if(s===3){if(l.stateNode.current.memoizedState.isDehydrated)return l.tag===3?l.stateNode.containerInfo:null;i=null}else l!==i&&(i=null)}}return Kc=i,null}function QS(i){switch(i){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Eh()){case ie:return 2;case fe:return 8;case ke:case De:return 32;case Ke:return 268435456;default:return 32}default:return 32}}var Pp=!1,ra=null,ia=null,aa=null,_o=new Map,ko=new Map,la=[],qR="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function WS(i,l){switch(i){case"focusin":case"focusout":ra=null;break;case"dragenter":case"dragleave":ia=null;break;case"mouseover":case"mouseout":aa=null;break;case"pointerover":case"pointerout":_o.delete(l.pointerId);break;case"gotpointercapture":case"lostpointercapture":ko.delete(l.pointerId)}}function Co(i,l,s,h,v,b){return i===null||i.nativeEvent!==b?(i={blockedOn:l,domEventName:s,eventSystemFlags:h,nativeEvent:b,targetContainers:[v]},l!==null&&(l=hl(l),l!==null&&XS(l)),i):(i.eventSystemFlags|=h,l=i.targetContainers,v!==null&&l.indexOf(v)===-1&&l.push(v),i)}function HR(i,l,s,h,v){switch(l){case"focusin":return ra=Co(ra,i,l,s,h,v),!0;case"dragenter":return ia=Co(ia,i,l,s,h,v),!0;case"mouseover":return aa=Co(aa,i,l,s,h,v),!0;case"pointerover":var b=v.pointerId;return _o.set(b,Co(_o.get(b)||null,i,l,s,h,v)),!0;case"gotpointercapture":return b=v.pointerId,ko.set(b,Co(ko.get(b)||null,i,l,s,h,v)),!0}return!1}function JS(i){var l=dl(i.target);if(l!==null){var s=u(l);if(s!==null){if(l=s.tag,l===13){if(l=o(s),l!==null){i.blockedOn=l,hx(i.priority,function(){ZS(s)});return}}else if(l===31){if(l=c(s),l!==null){i.blockedOn=l,hx(i.priority,function(){ZS(s)});return}}else if(l===3&&s.stateNode.current.memoizedState.isDehydrated){i.blockedOn=s.tag===3?s.stateNode.containerInfo:null;return}}}i.blockedOn=null}function Gc(i){if(i.blockedOn!==null)return!1;for(var l=i.targetContainers;0<l.length;){var s=Dp(i.nativeEvent);if(s===null){s=i.nativeEvent;var h=new s.constructor(s.type,s);Nh=h,s.target.dispatchEvent(h),Nh=null}else return l=hl(s),l!==null&&XS(l),i.blockedOn=s,!1;l.shift()}return!0}function eO(i,l,s){Gc(i)&&s.delete(l)}function $R(){Pp=!1,ra!==null&&Gc(ra)&&(ra=null),ia!==null&&Gc(ia)&&(ia=null),aa!==null&&Gc(aa)&&(aa=null),_o.forEach(eO),ko.forEach(eO)}function Xc(i,l){i.blockedOn===l&&(i.blockedOn=null,Pp||(Pp=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,$R)))}var Zc=null;function tO(i){Zc!==i&&(Zc=i,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){Zc===i&&(Zc=null);for(var l=0;l<i.length;l+=3){var s=i[l],h=i[l+1],v=i[l+2];if(typeof h!="function"){if(Np(h||s)===null)continue;break}var b=hl(s);b!==null&&(i.splice(l,3),l-=3,Dm(b,{pending:!0,data:v,method:s.method,action:h},h,v))}}))}function Gl(i){function l(B){return Xc(B,i)}ra!==null&&Xc(ra,i),ia!==null&&Xc(ia,i),aa!==null&&Xc(aa,i),_o.forEach(l),ko.forEach(l);for(var s=0;s<la.length;s++){var h=la[s];h.blockedOn===i&&(h.blockedOn=null)}for(;0<la.length&&(s=la[0],s.blockedOn===null);)JS(s),s.blockedOn===null&&la.shift();if(s=(i.ownerDocument||i).$$reactFormReplay,s!=null)for(h=0;h<s.length;h+=3){var v=s[h],b=s[h+1],A=v[gn]||null;if(typeof b=="function")A||tO(s);else if(A){var j=null;if(b&&b.hasAttribute("formAction")){if(v=b,A=b[gn]||null)j=A.formAction;else if(Np(v)!==null)continue}else j=A.action;typeof j=="function"?s[h+1]=j:(s.splice(h,3),h-=3),tO(s)}}}function nO(){function i(b){b.canIntercept&&b.info==="react-transition"&&b.intercept({handler:function(){return new Promise(function(A){return v=A})},focusReset:"manual",scroll:"manual"})}function l(){v!==null&&(v(),v=null),h||setTimeout(s,20)}function s(){if(!h&&!navigation.transition){var b=navigation.currentEntry;b&&b.url!=null&&navigation.navigate(b.url,{state:b.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var h=!1,v=null;return navigation.addEventListener("navigate",i),navigation.addEventListener("navigatesuccess",l),navigation.addEventListener("navigateerror",l),setTimeout(s,100),function(){h=!0,navigation.removeEventListener("navigate",i),navigation.removeEventListener("navigatesuccess",l),navigation.removeEventListener("navigateerror",l),v!==null&&(v(),v=null)}}}function Rp(i){this._internalRoot=i}Qc.prototype.render=Rp.prototype.render=function(i){var l=this._internalRoot;if(l===null)throw Error(r(409));var s=l.current,h=Bn();KS(s,h,i,l,null,null)},Qc.prototype.unmount=Rp.prototype.unmount=function(){var i=this._internalRoot;if(i!==null){this._internalRoot=null;var l=i.containerInfo;KS(i.current,2,null,i,null,null),Mc(),l[fl]=null}};function Qc(i){this._internalRoot=i}Qc.prototype.unstable_scheduleHydration=function(i){if(i){var l=dx();i={blockedOn:null,target:i,priority:l};for(var s=0;s<la.length&&l!==0&&l<la[s].priority;s++);la.splice(s,0,i),s===0&&JS(i)}};var rO=t.version;if(rO!=="19.2.4")throw Error(r(527,rO,"19.2.4"));Q.findDOMNode=function(i){var l=i._reactInternals;if(l===void 0)throw typeof i.render=="function"?Error(r(188)):(i=Object.keys(i).join(","),Error(r(268,i)));return i=d(l),i=i!==null?m(i):null,i=i===null?null:i.stateNode,i};var FR={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:U,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Wc=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Wc.isDisabled&&Wc.supportsFiber)try{sn=Wc.inject(FR),Mt=Wc}catch{}}return jo.createRoot=function(i,l){if(!a(i))throw Error(r(299));var s=!1,h="",v=cw,b=fw,A=dw;return l!=null&&(l.unstable_strictMode===!0&&(s=!0),l.identifierPrefix!==void 0&&(h=l.identifierPrefix),l.onUncaughtError!==void 0&&(v=l.onUncaughtError),l.onCaughtError!==void 0&&(b=l.onCaughtError),l.onRecoverableError!==void 0&&(A=l.onRecoverableError)),l=VS(i,1,!1,null,null,s,h,null,v,b,A,nO),i[fl]=l.current,yp(i),new Rp(l)},jo.hydrateRoot=function(i,l,s){if(!a(i))throw Error(r(299));var h=!1,v="",b=cw,A=fw,j=dw,B=null;return s!=null&&(s.unstable_strictMode===!0&&(h=!0),s.identifierPrefix!==void 0&&(v=s.identifierPrefix),s.onUncaughtError!==void 0&&(b=s.onUncaughtError),s.onCaughtError!==void 0&&(A=s.onCaughtError),s.onRecoverableError!==void 0&&(j=s.onRecoverableError),s.formState!==void 0&&(B=s.formState)),l=VS(i,1,!0,l,s??null,h,v,B,b,A,j,nO),l.context=YS(null),s=l.current,h=Bn(),h=_h(h),v=Vi(h),v.callback=null,Yi(s,v,h),s=h,l.current.lanes=s,Lu(l,s),Nr(l),i[fl]=l.current,yp(i),new Qc(l)},jo.version="19.2.4",jo}var hO;function rI(){if(hO)return Up.exports;hO=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),Up.exports=nI(),Up.exports}var iI=rI();let aI=0;function Mo(){return`msg-${++aI}`}function lI(){const[e,t]=E.useState([]),[n,r]=E.useState(!1),[a,u]=E.useState(null),[o,c]=E.useState([]),[f,d]=E.useState("connecting"),[m,p]=E.useState({input:0,output:0,total:0}),[y,g]=E.useState([]),x=E.useRef(0),[w,S]=E.useState([]),O=E.useRef(null),_=E.useRef(""),k=E.useRef(null),M=E.useCallback(()=>{const H=_.current;H&&(_.current="",t(P=>{const F=P[P.length-1];if(F&&F.role==="assistant"&&F.isStreaming&&F.toolCalls.length===0){const ee=[...P];return ee[ee.length-1]={...F,content:F.content+H},ee}const I=Date.now();return[...P,{id:Mo(),role:"assistant",content:H,toolCalls:[],isStreaming:!0,timestamp:I,startedAt:I}]}))},[]),N=E.useCallback(H=>{switch(H.type){case"tool_start":_.current&&M(),t(P=>{const F=P[P.length-1],I={id:H.id,name:H.name,args:H.args,status:"running"};if(F&&F.role==="assistant"){const Z=[...P];return Z[Z.length-1]={...F,toolCalls:[...F.toolCalls,I]},Z}const ee=Date.now();return[...P,{id:Mo(),role:"assistant",content:"",toolCalls:[I],isStreaming:!0,timestamp:ee,startedAt:ee}]});break;case"tool_end":t(P=>{const F=[...P];for(let I=F.length-1;I>=0;I--){const ee=F[I],Z=ee.toolCalls.findIndex(Y=>Y.id===H.id);if(Z>=0){const Y=[...ee.toolCalls];Y[Z]={...Y[Z],status:H.status,result:H.result,errorMessage:H.error_message,durationMs:H.duration_ms},F[I]={...ee,toolCalls:Y};break}}return F});break;case"extraction":{if(t(P=>{const F=[...P];for(let I=F.length-1;I>=0;I--){const ee=F[I],Z=ee.toolCalls.findIndex(Y=>Y.name===H.tool_name&&Y.status==="running");if(Z>=0){const Y=[...ee.toolCalls];return Y[Z]={...Y[Z],extraction:{extracted_type:H.extracted_type,data:H.data}},F[I]={...ee,toolCalls:Y},F}}return P}),H.extracted_type==="todos"){const P=H.data,I=(Array.isArray(P)?P:P&&typeof P=="object"&&"todos"in P?P.todos??[]:[]).map(ee=>{if(ee&&typeof ee=="object"){const Z=ee;return{content:Z.content??Z.task??"",status:Z.status??(Z.done===!0?"completed":(Z.done===!1,"pending"))}}return{content:String(ee),status:"pending"}});c(I)}break}case"interrupt":r(!1),u(H);break;case"complete":{r(!1);const P=Date.now();t(F=>{if(F.length===0)return F;let I=!1;const ee=F.map(Z=>Z.isStreaming?(I=!0,{...Z,isStreaming:!1,durationMs:Z.startedAt?P-Z.startedAt:void 0}):Z);return I?ee:F});break}case"error":r(!1),t(P=>[...P,{id:Mo(),role:"assistant",content:`Error: ${H.error}`,toolCalls:[],timestamp:Date.now()}]);break;case"usage":p(P=>({input:P.input+H.input_tokens,output:P.output+H.output_tokens,total:P.total+H.total_tokens})),g(P=>{if(P.length===0)return P;const F=[...P],I=F[F.length-1];return F[F.length-1]={...I,input:I.input+H.input_tokens,output:I.output+H.output_tokens,total:I.total+H.total_tokens},F});break;case"cancelled":{r(!1);const P=Date.now();t(F=>[...F.map(ee=>ee.isStreaming?{...ee,isStreaming:!1,durationMs:ee.startedAt?P-ee.startedAt:void 0}:ee),{id:Mo(),role:"system",content:"Task terminated",toolCalls:[],timestamp:Date.now()}]);break}case"file_changed":S(P=>[...P,{event:H.event,path:H.path}]);break}},[M]);E.useEffect(()=>{const H=window.location.protocol==="https:"?"wss:":"ws:",P=new WebSocket(`${H}//${window.location.host}/ws/chat`);return P.onopen=()=>d("connected"),P.onclose=()=>d("disconnected"),P.onerror=()=>d("error"),P.onmessage=F=>{const I=JSON.parse(F.data);I.type==="content"?(_.current+=I.content,k.current||(k.current=requestAnimationFrame(()=>{M(),k.current=null}))):(_.current&&M(),N(I))},O.current=P,()=>{k.current&&cancelAnimationFrame(k.current),P.close()}},[N,M]);const C=E.useCallback((H,P)=>{if(!O.current||O.current.readyState!==WebSocket.OPEN)return;t(I=>[...I,{id:Mo(),role:"user",content:H,toolCalls:[],timestamp:Date.now()}]),x.current+=1;const F=x.current;g(I=>[...I,{turn:F,input:0,output:0,total:0}]),O.current.send(JSON.stringify({type:"message",content:H,cwd:P==null?void 0:P.cwd})),r(!0)},[]),z=E.useCallback(H=>{!O.current||O.current.readyState!==WebSocket.OPEN||(O.current.send(JSON.stringify({type:"interrupt_response",decisions:H})),u(null),r(!0))},[]),$=E.useCallback(()=>{!O.current||O.current.readyState!==WebSocket.OPEN||(_.current&&M(),O.current.send(JSON.stringify({type:"cancel"})))},[M]);return{messages:e,isStreaming:n,interrupt:a,todos:o,tokenUsage:m,usageHistory:y,connectionStatus:f,fileChanges:w,sendMessage:C,respondToInterrupt:z,cancelStream:$}}function uI(e){const[t,n]=E.useState({entries:[],loading:!0,error:null}),[r,a]=E.useState(null),[u,o]=E.useState(new Set(["/"])),[c,f]=E.useState("/"),d=E.useCallback(async(O="/",_=1)=>{try{const k=await fetch(`/api/files/tree?path=${encodeURIComponent(O)}&depth=${_}`);if(!k.ok)throw new Error(`HTTP ${k.status}`);return(await k.json()).entries}catch(k){return console.error("Failed to fetch file tree:",k),[]}},[]),m=E.useCallback(async()=>{n(_=>({..._,loading:!0}));const O=await d(c,1);n({entries:O,loading:!1,error:null})},[d,c]);E.useEffect(()=>{m()},[m]),E.useEffect(()=>{e.length>0&&m()},[e,m]);const p=E.useCallback(async O=>{o(k=>{const M=new Set(k);return M.has(O)?M.delete(O):M.add(O),M}),n(k=>{const M=N=>N.map(C=>C.path===O&&C.is_dir&&!C.children?{...C,children:[]}:C.children?{...C,children:M(C.children)}:C);return{...k,entries:M(k.entries)}});const _=await d(O,1);n(k=>{const M=N=>N.map(C=>C.path===O?{...C,children:_}:C.children?{...C,children:M(C.children)}:C);return{...k,entries:M(k.entries)}})},[d]),y=E.useCallback(async O=>{try{const _=await fetch(`/api/files/preview?path=${encodeURIComponent(O)}`);if(!_.ok)throw new Error(`HTTP ${_.status}`);const k=await _.json();a(k)}catch(_){console.error("Failed to preview file:",_)}},[]),g=E.useCallback(O=>{f(O),o(new Set([O])),a(null)},[]),x=E.useCallback(async O=>{const _=new FormData;_.append("file",O);try{const k=await fetch(`/api/files/upload?path=${encodeURIComponent(c)}`,{method:"POST",body:_});if(!k.ok)throw new Error(`HTTP ${k.status}`);m()}catch(k){console.error("Failed to upload file:",k)}},[c,m]),w=E.useCallback(async O=>{const _=c==="/"?`/${O}`:`${c}/${O}`;try{const k=await fetch("/api/files/mkdir",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({path:_})});if(!k.ok)throw new Error(`HTTP ${k.status}`);m()}catch(k){console.error("Failed to create folder:",k)}},[c,m]),S=E.useCallback(async O=>{try{const _=await fetch("/api/files/delete",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({path:O})});if(!_.ok)throw new Error(`HTTP ${_.status}`);m()}catch(_){console.error("Failed to delete:",_)}},[m]);return{tree:t,selectedFile:r,expandedDirs:u,workspacePath:c,toggleDir:p,openFile:y,enterDir:g,uploadFile:x,createFolder:w,deletePath:S,setSelectedFile:a,refresh:m}}function oI(e){const[t,n]=E.useState([]),[r,a]=E.useState(!1),u=E.useCallback(async()=>{a(!0);try{const d=await fetch("/api/canvas/items");if(!d.ok)throw new Error(`HTTP ${d.status}`);const m=await d.json();n(m)}catch(d){console.error("Failed to fetch canvas items:",d)}finally{a(!1)}},[]);E.useEffect(()=>{u()},[u]),E.useEffect(()=>{e.some(d=>d.path.startsWith("/.canvas/"))&&u()},[e,u]);const o=E.useCallback(async d=>{try{await fetch(`/api/canvas/items/${d}`,{method:"DELETE"}),n(m=>m.filter(p=>p.id!==d))}catch(m){console.error("Failed to delete canvas item:",m)}},[]),c=E.useCallback(async()=>{try{await fetch("/api/canvas/items",{method:"DELETE"}),n([])}catch(d){console.error("Failed to clear canvas:",d)}},[]),f=E.useCallback(async()=>{try{const d=await fetch("/api/canvas/export");if(!d.ok)throw new Error(`HTTP ${d.status}`);return(await d.json()).content}catch(d){return console.error("Failed to export canvas:",d),""}},[]);return{items:t,loading:r,fetchItems:u,deleteItem:o,clearAll:c,exportMarkdown:f}}function uu(){return uu=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},uu.apply(null,arguments)}var Jc=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function vs(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}var mO,pO={exports:{}};/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/var Fp,vO,yO,sI=(mO||(mO=1,Fp=pO,(function(){var e={}.hasOwnProperty;function t(){for(var a="",u=0;u<arguments.length;u++){var o=arguments[u];o&&(a=r(a,n(o)))}return a}function n(a){if(typeof a=="string"||typeof a=="number")return a;if(typeof a!="object")return"";if(Array.isArray(a))return t.apply(null,a);if(a.toString!==Object.prototype.toString&&!a.toString.toString().includes("[native code]"))return a.toString();var u="";for(var o in a)e.call(a,o)&&a[o]&&(u=r(u,o));return u}function r(a,u){return u?a?a+" "+u:a+u:a}Fp.exports?(t.default=t,Fp.exports=t):window.classNames=t})()),pO.exports),Gy=vs(sI),gO,bO,cI=(yO||(yO=1,vO=function e(t,n){if(t===n)return!0;if(t&&n&&typeof t=="object"&&typeof n=="object"){if(t.constructor!==n.constructor)return!1;var r,a,u;if(Array.isArray(t)){if((r=t.length)!=n.length)return!1;for(a=r;a--!==0;)if(!e(t[a],n[a]))return!1;return!0}if(t instanceof Map&&n instanceof Map){if(t.size!==n.size)return!1;for(a of t.entries())if(!n.has(a[0]))return!1;for(a of t.entries())if(!e(a[1],n.get(a[0])))return!1;return!0}if(t instanceof Set&&n instanceof Set){if(t.size!==n.size)return!1;for(a of t.entries())if(!n.has(a[0]))return!1;return!0}if(ArrayBuffer.isView(t)&&ArrayBuffer.isView(n)){if((r=t.length)!=n.length)return!1;for(a=r;a--!==0;)if(t[a]!==n[a])return!1;return!0}if(t.constructor===RegExp)return t.source===n.source&&t.flags===n.flags;if(t.valueOf!==Object.prototype.valueOf)return t.valueOf()===n.valueOf();if(t.toString!==Object.prototype.toString)return t.toString()===n.toString();if((r=(u=Object.keys(t)).length)!==Object.keys(n).length)return!1;for(a=r;a--!==0;)if(!Object.prototype.hasOwnProperty.call(n,u[a]))return!1;for(a=r;a--!==0;){var o=u[a];if(!e(t[o],n[o]))return!1}return!0}return t!=t&&n!=n}),vO),fI=vs(cI),xO,wO,wr=vs((function(){if(bO)return gO;bO=1;var e=/^\s+|\s+$/g,t=/^[-+]0x[0-9a-f]+$/i,n=/^0b[01]+$/i,r=/^0o[0-7]+$/i,a=parseInt,u=Object.prototype.toString;function o(f){var d=typeof f;return!!f&&(d=="object"||d=="function")}function c(f){if(typeof f=="number")return f;if((function(p){return typeof p=="symbol"||(function(y){return!!y&&typeof y=="object"})(p)&&u.call(p)=="[object Symbol]"})(f))return NaN;if(o(f)){var d=typeof f.valueOf=="function"?f.valueOf():f;f=o(d)?d+"":d}if(typeof f!="string")return f===0?f:+f;f=f.replace(e,"");var m=n.test(f);return m||r.test(f)?a(f.slice(2),m?2:8):t.test(f)?NaN:+f}return gO=function(f,d,m){return m===void 0&&(m=d,d=void 0),m!==void 0&&(m=(m=c(m))==m?m:0),d!==void 0&&(d=(d=c(d))==d?d:0),(function(p,y,g){return p==p&&(g!==void 0&&(p=p<=g?p:g),y!==void 0&&(p=p>=y?p:y)),p})(c(f),d,m)}})()),dI=vs((function(){if(wO)return xO;wO=1;var e=/^\s+|\s+$/g,t=/^[-+]0x[0-9a-f]+$/i,n=/^0b[01]+$/i,r=/^0o[0-7]+$/i,a=parseInt,u=typeof Jc=="object"&&Jc&&Jc.Object===Object&&Jc,o=typeof self=="object"&&self&&self.Object===Object&&self,c=u||o||Function("return this")(),f=Object.prototype.toString,d=Math.max,m=Math.min,p=function(){return c.Date.now()};function y(x){var w=typeof x;return!!x&&(w=="object"||w=="function")}function g(x){if(typeof x=="number")return x;if((function(O){return typeof O=="symbol"||(function(_){return!!_&&typeof _=="object"})(O)&&f.call(O)=="[object Symbol]"})(x))return NaN;if(y(x)){var w=typeof x.valueOf=="function"?x.valueOf():x;x=y(w)?w+"":w}if(typeof x!="string")return x===0?x:+x;x=x.replace(e,"");var S=n.test(x);return S||r.test(x)?a(x.slice(2),S?2:8):t.test(x)?NaN:+x}return xO=function(x,w,S){var O,_,k,M,N,C,z=0,$=!1,H=!1,P=!0;if(typeof x!="function")throw new TypeError("Expected a function");function F(U){var Q=O,ue=_;return O=_=void 0,z=U,M=x.apply(ue,Q)}function I(U){var Q=U-C;return C===void 0||Q>=w||Q<0||H&&U-z>=k}function ee(){var U=p();if(I(U))return Z(U);N=setTimeout(ee,(function(Q){var ue=w-(Q-C);return H?m(ue,k-(Q-z)):ue})(U))}function Z(U){return N=void 0,P&&O?F(U):(O=_=void 0,M)}function Y(){var U=p(),Q=I(U);if(O=arguments,_=this,C=U,Q){if(N===void 0)return(function(ue){return z=ue,N=setTimeout(ee,w),$?F(ue):M})(C);if(H)return N=setTimeout(ee,w),F(C)}return N===void 0&&(N=setTimeout(ee,w)),M}return w=g(w)||0,y(S)&&($=!!S.leading,k=(H="maxWait"in S)?d(g(S.maxWait)||0,w):k,P="trailing"in S?!!S.trailing:P),Y.cancel=function(){N!==void 0&&clearTimeout(N),z=0,O=C=_=N=void 0},Y.flush=function(){return N===void 0?M:Z(p())},Y}})()),SO={width:void 0,height:void 0};function hI(e){const{ref:t,box:n="content-box"}=e,[{width:r,height:a},u]=E.useState(SO),o=(function(){const d=E.useRef(!1);return E.useEffect(()=>(d.current=!0,()=>{d.current=!1}),[]),E.useCallback(()=>d.current,[])})(),c=E.useRef(uu({},SO)),f=E.useRef(void 0);return f.current=e.onResize,E.useEffect(()=>{if(!t.current||typeof window>"u"||!("ResizeObserver"in window))return;const d=new ResizeObserver(([m])=>{const p=n==="border-box"?"borderBoxSize":n==="device-pixel-content-box"?"devicePixelContentBoxSize":"contentBoxSize",y=OO(m,p,"inlineSize"),g=OO(m,p,"blockSize");if(c.current.width!==y||c.current.height!==g){const x={width:y,height:g};c.current.width=y,c.current.height=g,f.current?f.current(x):o()&&u(x)}});return d.observe(t.current,{box:n}),()=>{d.disconnect()}},[n,t,o]),{width:r,height:a}}function OO(e,t,n){return e[t]?Array.isArray(e[t])?e[t][0][n]:e[t][n]:t==="contentBoxSize"?e.contentRect[n==="inlineSize"?"width":"height"]:void 0}var mI="allotment-module_splitView__L-yRc",pI="allotment-module_sashContainer__fzwJF",vI="allotment-module_splitViewContainer__rQnVa",mC="allotment-module_splitViewView__MGZ6O",yI="allotment-module_vertical__WSwwa",gI="allotment-module_horizontal__7doS8",bI="allotment-module_separatorBorder__x-rDS";let zo,pC=!1,vC=!1;typeof navigator=="object"&&(zo=navigator.userAgent,vC=zo.indexOf("Macintosh")>=0,pC=(zo.indexOf("Macintosh")>=0||zo.indexOf("iPad")>=0||zo.indexOf("iPhone")>=0)&&!!navigator.maxTouchPoints&&navigator.maxTouchPoints>0);const yC=pC,xI=vC,EO=typeof window<"u"&&window.document!==void 0&&window.document.createElement!==void 0?E.useLayoutEffect:E.useEffect;class wI{constructor(){this._size=void 0}getSize(){return this._size}setSize(t){this._size=t}}function ef(e,t){const n=e.length,r=n-t.length;return r>=0&&e.slice(r,n)===t}var AO,_O={exports:{}},SI=(AO||(AO=1,(function(e){var t=Object.prototype.hasOwnProperty,n="~";function r(){}function a(f,d,m){this.fn=f,this.context=d,this.once=m||!1}function u(f,d,m,p,y){if(typeof m!="function")throw new TypeError("The listener must be a function");var g=new a(m,p||f,y),x=n?n+d:d;return f._events[x]?f._events[x].fn?f._events[x]=[f._events[x],g]:f._events[x].push(g):(f._events[x]=g,f._eventsCount++),f}function o(f,d){--f._eventsCount===0?f._events=new r:delete f._events[d]}function c(){this._events=new r,this._eventsCount=0}Object.create&&(r.prototype=Object.create(null),new r().__proto__||(n=!1)),c.prototype.eventNames=function(){var f,d,m=[];if(this._eventsCount===0)return m;for(d in f=this._events)t.call(f,d)&&m.push(n?d.slice(1):d);return Object.getOwnPropertySymbols?m.concat(Object.getOwnPropertySymbols(f)):m},c.prototype.listeners=function(f){var d=n?n+f:f,m=this._events[d];if(!m)return[];if(m.fn)return[m.fn];for(var p=0,y=m.length,g=new Array(y);p<y;p++)g[p]=m[p].fn;return g},c.prototype.listenerCount=function(f){var d=n?n+f:f,m=this._events[d];return m?m.fn?1:m.length:0},c.prototype.emit=function(f,d,m,p,y,g){var x=n?n+f:f;if(!this._events[x])return!1;var w,S,O=this._events[x],_=arguments.length;if(O.fn){switch(O.once&&this.removeListener(f,O.fn,void 0,!0),_){case 1:return O.fn.call(O.context),!0;case 2:return O.fn.call(O.context,d),!0;case 3:return O.fn.call(O.context,d,m),!0;case 4:return O.fn.call(O.context,d,m,p),!0;case 5:return O.fn.call(O.context,d,m,p,y),!0;case 6:return O.fn.call(O.context,d,m,p,y,g),!0}for(S=1,w=new Array(_-1);S<_;S++)w[S-1]=arguments[S];O.fn.apply(O.context,w)}else{var k,M=O.length;for(S=0;S<M;S++)switch(O[S].once&&this.removeListener(f,O[S].fn,void 0,!0),_){case 1:O[S].fn.call(O[S].context);break;case 2:O[S].fn.call(O[S].context,d);break;case 3:O[S].fn.call(O[S].context,d,m);break;case 4:O[S].fn.call(O[S].context,d,m,p);break;default:if(!w)for(k=1,w=new Array(_-1);k<_;k++)w[k-1]=arguments[k];O[S].fn.apply(O[S].context,w)}}return!0},c.prototype.on=function(f,d,m){return u(this,f,d,m,!1)},c.prototype.once=function(f,d,m){return u(this,f,d,m,!0)},c.prototype.removeListener=function(f,d,m,p){var y=n?n+f:f;if(!this._events[y])return this;if(!d)return o(this,y),this;var g=this._events[y];if(g.fn)g.fn!==d||p&&!g.once||m&&g.context!==m||o(this,y);else{for(var x=0,w=[],S=g.length;x<S;x++)(g[x].fn!==d||p&&!g[x].once||m&&g[x].context!==m)&&w.push(g[x]);w.length?this._events[y]=w.length===1?w[0]:w:o(this,y)}return this},c.prototype.removeAllListeners=function(f){var d;return f?(d=n?n+f:f,this._events[d]&&o(this,d)):(this._events=new r,this._eventsCount=0),this},c.prototype.off=c.prototype.removeListener,c.prototype.addListener=c.prototype.on,c.prefixed=n,c.EventEmitter=c,e.exports=c})(_O)),_O.exports),u0=vs(SI);function kO(e,t){const n=e.indexOf(t);n>-1&&(e.splice(n,1),e.unshift(t))}function Vp(e,t){const n=e.indexOf(t);n>-1&&(e.splice(n,1),e.push(t))}function ar(e,t,n=1){const r=Math.max(0,Math.ceil((t-e)/n)),a=new Array(r);let u=-1;for(;++u<r;)a[u]=e+u*n;return a}var OI="sash-module_sash__K-9lB",EI="sash-module_disabled__Hm-wx",AI="sash-module_mac__Jf6OJ",CO="sash-module_vertical__pB-rs",_I="sash-module_minimum__-UKxp",kI="sash-module_maximum__TCWxD",TO="sash-module_horizontal__kFbiw",Yp="sash-module_hover__80W6I",Kp="sash-module_active__bJspD";let cr=(function(e){return e.Vertical="VERTICAL",e.Horizontal="HORIZONTAL",e})({}),qn=(function(e){return e.Disabled="DISABLED",e.Minimum="MINIMUM",e.Maximum="MAXIMUM",e.Enabled="ENABLED",e})({}),gC=yC?20:8;const bC=new u0;class jO extends u0{get state(){return this._state}set state(t){this._state!==t&&(this.el.classList.toggle(EI,t===qn.Disabled),this.el.classList.toggle("sash-disabled",t===qn.Disabled),this.el.classList.toggle(_I,t===qn.Minimum),this.el.classList.toggle("sash-minimum",t===qn.Minimum),this.el.classList.toggle(kI,t===qn.Maximum),this.el.classList.toggle("sash-maximum",t===qn.Maximum),this._state=t,this.emit("enablementChange",t))}constructor(t,n,r){var a;super(),this.el=void 0,this.layoutProvider=void 0,this.orientation=void 0,this.size=void 0,this.hoverDelay=300,this.hoverDelayer=dI(u=>u.classList.add("sash-hover",Yp),this.hoverDelay),this._state=qn.Enabled,this.onPointerStart=u=>{const o=u.pageX,c=u.pageY,f={startX:o,currentX:o,startY:c,currentY:c};this.el.classList.add("sash-active",Kp),this.emit("start",f),this.el.setPointerCapture(u.pointerId);const d=p=>{p.preventDefault();const y={startX:o,currentX:p.pageX,startY:c,currentY:p.pageY};this.emit("change",y)},m=p=>{p.preventDefault(),this.el.classList.remove("sash-active",Kp),this.hoverDelayer.cancel(),this.emit("end"),this.el.releasePointerCapture(p.pointerId),window.removeEventListener("pointermove",d),window.removeEventListener("pointerup",m)};window.addEventListener("pointermove",d),window.addEventListener("pointerup",m)},this.onPointerDoublePress=()=>{this.emit("reset")},this.onMouseEnter=()=>{this.el.classList.contains(Kp)?(this.hoverDelayer.cancel(),this.el.classList.add("sash-hover",Yp)):this.hoverDelayer(this.el)},this.onMouseLeave=()=>{this.hoverDelayer.cancel(),this.el.classList.remove("sash-hover",Yp)},this.el=document.createElement("div"),this.el.classList.add("sash",OI),this.el.dataset.testid="sash",t.append(this.el),xI&&this.el.classList.add("sash-mac",AI),this.el.addEventListener("pointerdown",this.onPointerStart),this.el.addEventListener("dblclick",this.onPointerDoublePress),this.el.addEventListener("mouseenter",this.onMouseEnter),this.el.addEventListener("mouseleave",this.onMouseLeave),typeof r.size=="number"?(this.size=r.size,r.orientation===cr.Vertical?this.el.style.width=`${this.size}px`:this.el.style.height=`${this.size}px`):(this.size=gC,bC.on("onDidChangeGlobalSize",u=>{this.size=u,this.layout()})),this.layoutProvider=n,this.orientation=(a=r.orientation)!=null?a:cr.Vertical,this.orientation===cr.Horizontal?(this.el.classList.add("sash-horizontal",TO),this.el.classList.remove("sash-vertical",CO)):(this.el.classList.remove("sash-horizontal",TO),this.el.classList.add("sash-vertical",CO)),this.layout()}layout(){if(this.orientation===cr.Vertical){const t=this.layoutProvider;this.el.style.left=t.getVerticalSashLeft(this)-this.size/2+"px",t.getVerticalSashTop&&(this.el.style.top=t.getVerticalSashTop(this)+"px"),t.getVerticalSashHeight&&(this.el.style.height=t.getVerticalSashHeight(this)+"px")}else{const t=this.layoutProvider;this.el.style.top=t.getHorizontalSashTop(this)-this.size/2+"px",t.getHorizontalSashLeft&&(this.el.style.left=t.getHorizontalSashLeft(this)+"px"),t.getHorizontalSashWidth&&(this.el.style.width=t.getHorizontalSashWidth(this)+"px")}}dispose(){this.el.removeEventListener("pointerdown",this.onPointerStart),this.el.removeEventListener("dblclick",this.onPointerDoublePress),this.el.removeEventListener("mouseenter",this.onMouseEnter),this.el.removeEventListener("mouseleave",()=>this.onMouseLeave),this.el.remove()}}let zf;var Gp;(Gp=zf||(zf={})).Distribute={type:"distribute"},Gp.Split=function(e){return{type:"split",index:e}},Gp.Invisible=function(e){return{type:"invisible",cachedVisibleSize:e}};let sr=(function(e){return e.Normal="NORMAL",e.Low="LOW",e.High="HIGH",e})({});class xC{constructor(t,n,r){this.container=void 0,this.view=void 0,this._size=void 0,this._cachedVisibleSize=void 0,this.container=t,this.view=n,this.container.classList.add("split-view-view",mC),this.container.dataset.testid="split-view-view",typeof r=="number"?(this._size=r,this._cachedVisibleSize=void 0,t.classList.add("split-view-view-visible")):(this._size=0,this._cachedVisibleSize=r.cachedVisibleSize)}set size(t){this._size=t}get size(){return this._size}get priority(){return this.view.priority}get snap(){return!!this.view.snap}get cachedVisibleSize(){return this._cachedVisibleSize}get visible(){return this._cachedVisibleSize===void 0}setVisible(t,n){t!==this.visible&&(t?(this.size=wr(this._cachedVisibleSize,this.viewMinimumSize,this.viewMaximumSize),this._cachedVisibleSize=void 0):(this._cachedVisibleSize=typeof n=="number"?n:this.size,this.size=0),this.container.classList.toggle("split-view-view-visible",t),this.view.setVisible&&this.view.setVisible(t))}get minimumSize(){return this.visible?this.view.minimumSize:0}get viewMinimumSize(){return this.view.minimumSize}get maximumSize(){return this.visible?this.view.maximumSize:0}get viewMaximumSize(){return this.view.maximumSize}set enabled(t){this.container.style.pointerEvents=t?"":"none"}layout(t){this.layoutContainer(t),this.view.layout(this.size,t)}}class CI extends xC{layoutContainer(t){this.container.style.left=`${t}px`,this.container.style.width=`${this.size}px`}}class TI extends xC{layoutContainer(t){this.container.style.top=`${t}px`,this.container.style.height=`${this.size}px`}}class jI extends u0{get startSnappingEnabled(){return this._startSnappingEnabled}set startSnappingEnabled(t){this._startSnappingEnabled!==t&&(this._startSnappingEnabled=t,this.updateSashEnablement())}get endSnappingEnabled(){return this._endSnappingEnabled}set endSnappingEnabled(t){this._endSnappingEnabled!==t&&(this._endSnappingEnabled=t,this.updateSashEnablement())}constructor(t,n={},r,a,u){var o,c;if(super(),this.onDidChange=void 0,this.onDidDragStart=void 0,this.onDidDragEnd=void 0,this.orientation=void 0,this.sashContainer=void 0,this.size=0,this.contentSize=0,this.proportions=void 0,this.viewItems=[],this.sashItems=[],this.sashDragState=void 0,this.proportionalLayout=void 0,this.getSashOrthogonalSize=void 0,this._startSnappingEnabled=!0,this._endSnappingEnabled=!0,this.onSashEnd=f=>{this.emit("sashchange",f),this.saveProportions();for(const d of this.viewItems)d.enabled=!0},this.orientation=(o=n.orientation)!=null?o:cr.Vertical,this.proportionalLayout=(c=n.proportionalLayout)!=null?c:!0,this.getSashOrthogonalSize=n.getSashOrthogonalSize,r&&(this.onDidChange=r),a&&(this.onDidDragStart=a),u&&(this.onDidDragEnd=u),this.sashContainer=document.createElement("div"),this.sashContainer.classList.add("sash-container",pI),t.prepend(this.sashContainer),n.descriptor){this.size=n.descriptor.size;for(const[f,d]of n.descriptor.views.entries()){const m=d.size,p=d.container,y=d.view;this.addView(p,y,m,f,!0)}this.contentSize=this.viewItems.reduce((f,d)=>f+d.size,0),this.saveProportions()}}addView(t,n,r,a=this.viewItems.length,u){let o;o=typeof r=="number"?r:r.type==="split"?this.getViewSize(r.index)/2:r.type==="invisible"?{cachedVisibleSize:r.cachedVisibleSize}:n.minimumSize;const c=this.orientation===cr.Vertical?new TI(t,n,o):new CI(t,n,o);if(this.viewItems.splice(a,0,c),this.viewItems.length>1){const f=this.orientation===cr.Vertical?new jO(this.sashContainer,{getHorizontalSashTop:p=>this.getSashPosition(p),getHorizontalSashWidth:this.getSashOrthogonalSize},{orientation:cr.Horizontal}):new jO(this.sashContainer,{getVerticalSashLeft:p=>this.getSashPosition(p),getVerticalSashHeight:this.getSashOrthogonalSize},{orientation:cr.Vertical}),d=this.orientation===cr.Vertical?p=>({sash:f,start:p.startY,current:p.currentY}):p=>({sash:f,start:p.startX,current:p.currentX});f.on("start",p=>{var y;this.emit("sashDragStart"),this.onSashStart(d(p));const g=this.viewItems.map(x=>x.size);(y=this.onDidDragStart)==null||y.call(this,g)}),f.on("change",p=>this.onSashChange(d(p))),f.on("end",()=>{var p;this.emit("sashDragEnd"),this.onSashEnd(this.sashItems.findIndex(g=>g.sash===f));const y=this.viewItems.map(g=>g.size);(p=this.onDidDragEnd)==null||p.call(this,y)}),f.on("reset",()=>{const p=this.sashItems.findIndex(S=>S.sash===f),y=ar(p,-1,-1),g=ar(p+1,this.viewItems.length),x=this.findFirstSnapIndex(y),w=this.findFirstSnapIndex(g);(typeof x!="number"||this.viewItems[x].visible)&&(typeof w!="number"||this.viewItems[w].visible)&&this.emit("sashreset",p)});const m={sash:f};this.sashItems.splice(a-1,0,m)}u||this.relayout(),u||typeof r=="number"||r.type!=="distribute"||this.distributeViewSizes()}removeView(t,n){if(t<0||t>=this.viewItems.length)throw new Error("Index out of bounds");const r=this.viewItems.splice(t,1)[0].view;if(this.viewItems.length>=1){const a=Math.max(t-1,0);this.sashItems.splice(a,1)[0].sash.dispose()}return this.relayout(),n&&n.type==="distribute"&&this.distributeViewSizes(),r}moveView(t,n,r){const a=this.getViewCachedVisibleSize(n),u=a===void 0?this.getViewSize(n):zf.Invisible(a),o=this.removeView(n);this.addView(t,o,u,r)}getViewCachedVisibleSize(t){if(t<0||t>=this.viewItems.length)throw new Error("Index out of bounds");return this.viewItems[t].cachedVisibleSize}layout(t=this.size){const n=Math.max(this.size,this.contentSize);if(this.size=t,this.proportions)for(let r=0;r<this.viewItems.length;r++){const a=this.viewItems[r];a.size=wr(Math.round(this.proportions[r]*t),a.minimumSize,a.maximumSize)}else{const r=ar(0,this.viewItems.length),a=r.filter(o=>this.viewItems[o].priority===sr.Low),u=r.filter(o=>this.viewItems[o].priority===sr.High);this.resize(this.viewItems.length-1,t-n,void 0,a,u)}this.distributeEmptySpace(),this.layoutViews()}resizeView(t,n){if(t<0||t>=this.viewItems.length)return;const r=ar(0,this.viewItems.length).filter(c=>c!==t),a=[...r.filter(c=>this.viewItems[c].priority===sr.Low),t],u=r.filter(c=>this.viewItems[c].priority===sr.High),o=this.viewItems[t];n=Math.round(n),n=wr(n,o.minimumSize,Math.min(o.maximumSize,this.size)),o.size=n,this.relayout(a,u)}resizeViews(t){for(let n=0;n<t.length;n++){const r=this.viewItems[n];let a=t[n];a=Math.round(a),a=wr(a,r.minimumSize,Math.min(r.maximumSize,this.size)),r.size=a}this.contentSize=this.viewItems.reduce((n,r)=>n+r.size,0),this.saveProportions(),this.layout(this.size)}getViewSize(t){return t<0||t>=this.viewItems.length?-1:this.viewItems[t].size}isViewVisible(t){if(t<0||t>=this.viewItems.length)throw new Error("Index out of bounds");return this.viewItems[t].visible}setViewVisible(t,n){if(t<0||t>=this.viewItems.length)throw new Error("Index out of bounds");this.viewItems[t].setVisible(n),this.distributeEmptySpace(t),this.layoutViews(),this.saveProportions()}distributeViewSizes(){const t=[];let n=0;for(const c of this.viewItems)c.maximumSize-c.minimumSize>0&&(t.push(c),n+=c.size);const r=Math.floor(n/t.length);for(const c of t)c.size=wr(r,c.minimumSize,c.maximumSize);const a=ar(0,this.viewItems.length),u=a.filter(c=>this.viewItems[c].priority===sr.Low),o=a.filter(c=>this.viewItems[c].priority===sr.High);this.relayout(u,o)}dispose(){this.sashItems.forEach(t=>t.sash.dispose()),this.sashItems=[],this.sashContainer.remove()}relayout(t,n){const r=this.viewItems.reduce((a,u)=>a+u.size,0);this.resize(this.viewItems.length-1,this.size-r,void 0,t,n),this.distributeEmptySpace(),this.layoutViews(),this.saveProportions()}onSashStart({sash:t,start:n}){const r=this.sashItems.findIndex(a=>a.sash===t);(a=>{const u=this.viewItems.map(_=>_.size);let o,c,f=Number.NEGATIVE_INFINITY,d=Number.POSITIVE_INFINITY;const m=ar(r,-1,-1),p=ar(r+1,this.viewItems.length),y=m.reduce((_,k)=>_+(this.viewItems[k].minimumSize-u[k]),0),g=m.reduce((_,k)=>_+(this.viewItems[k].viewMaximumSize-u[k]),0),x=p.length===0?Number.POSITIVE_INFINITY:p.reduce((_,k)=>_+(u[k]-this.viewItems[k].minimumSize),0),w=p.length===0?Number.NEGATIVE_INFINITY:p.reduce((_,k)=>_+(u[k]-this.viewItems[k].viewMaximumSize),0);f=Math.max(y,w),d=Math.min(x,g);const S=this.findFirstSnapIndex(m),O=this.findFirstSnapIndex(p);if(typeof S=="number"){const _=this.viewItems[S],k=Math.floor(_.viewMinimumSize/2);o={index:S,limitDelta:_.visible?f-k:f+k,size:_.size}}if(typeof O=="number"){const _=this.viewItems[O],k=Math.floor(_.viewMinimumSize/2);c={index:O,limitDelta:_.visible?d+k:d-k,size:_.size}}this.sashDragState={start:a,current:a,index:r,sizes:u,minDelta:f,maxDelta:d,snapBefore:o,snapAfter:c}})(n)}onSashChange({current:t}){const{index:n,start:r,sizes:a,minDelta:u,maxDelta:o,snapBefore:c,snapAfter:f}=this.sashDragState;this.sashDragState.current=t;const d=t-r;this.resize(n,d,a,void 0,void 0,u,o,c,f),this.distributeEmptySpace(),this.layoutViews()}getSashPosition(t){let n=0;for(let r=0;r<this.sashItems.length;r++)if(n+=this.viewItems[r].size,this.sashItems[r].sash===t)return n;return 0}resize(t,n,r=this.viewItems.map(m=>m.size),a,u,o=Number.NEGATIVE_INFINITY,c=Number.POSITIVE_INFINITY,f,d){if(t<0||t>=this.viewItems.length)return 0;const m=ar(t,-1,-1),p=ar(t+1,this.viewItems.length);if(u)for(const z of u)kO(m,z),kO(p,z);if(a)for(const z of a)Vp(m,z),Vp(p,z);const y=m.map(z=>this.viewItems[z]),g=m.map(z=>r[z]),x=p.map(z=>this.viewItems[z]),w=p.map(z=>r[z]),S=m.reduce((z,$)=>z+(this.viewItems[$].minimumSize-r[$]),0),O=m.reduce((z,$)=>z+(this.viewItems[$].maximumSize-r[$]),0),_=p.length===0?Number.POSITIVE_INFINITY:p.reduce((z,$)=>z+(r[$]-this.viewItems[$].minimumSize),0),k=p.length===0?Number.NEGATIVE_INFINITY:p.reduce((z,$)=>z+(r[$]-this.viewItems[$].maximumSize),0),M=Math.max(S,k,o),N=Math.min(_,O,c);let C=!1;if(f){const z=this.viewItems[f.index],$=n>=f.limitDelta;C=$!==z.visible,z.setVisible($,f.size)}if(!C&&d){const z=this.viewItems[d.index],$=n<d.limitDelta;C=$!==z.visible,z.setVisible($,d.size)}if(C)return this.resize(t,n,r,a,u,o,c);for(let z=0,$=n=wr(n,M,N);z<y.length;z++){const H=y[z],P=wr(g[z]+$,H.minimumSize,H.maximumSize);$-=P-g[z],H.size=P}for(let z=0,$=n;z<x.length;z++){const H=x[z],P=wr(w[z]-$,H.minimumSize,H.maximumSize);$+=P-w[z],H.size=P}return n}distributeEmptySpace(t){const n=this.viewItems.reduce((d,m)=>d+m.size,0);let r=this.size-n;const a=ar(0,this.viewItems.length),u=[],o=a.filter(d=>this.viewItems[d].priority===sr.Low),c=a.filter(d=>this.viewItems[d].priority===sr.Normal),f=a.filter(d=>this.viewItems[d].priority===sr.High);u.push(...f,...c,...o),typeof t=="number"&&Vp(u,t);for(let d=0;r!==0&&d<u.length;d++){const m=this.viewItems[u[d]],p=wr(m.size+r,m.minimumSize,m.maximumSize);r-=p-m.size,m.size=p}}layoutViews(){var t;this.contentSize=this.viewItems.reduce((r,a)=>r+a.size,0);let n=0;for(const r of this.viewItems)r.layout(n),n+=r.size;(t=this.onDidChange)!=null&&t.call(this,this.viewItems.map(r=>r.size)),this.sashItems.forEach(r=>r.sash.layout()),this.updateSashEnablement()}saveProportions(){this.proportionalLayout&&this.contentSize>0&&(this.proportions=this.viewItems.map(t=>t.size/this.contentSize))}updateSashEnablement(){let t=!1;const n=this.viewItems.map(f=>t=f.size-f.minimumSize>0||t);t=!1;const r=this.viewItems.map(f=>t=f.maximumSize-f.size>0||t),a=[...this.viewItems].reverse();t=!1;const u=a.map(f=>t=f.size-f.minimumSize>0||t).reverse();t=!1;const o=a.map(f=>t=f.maximumSize-f.size>0||t).reverse();let c=0;for(let f=0;f<this.sashItems.length;f++){const{sash:d}=this.sashItems[f];c+=this.viewItems[f].size;const m=!(n[f]&&o[f+1]),p=!(r[f]&&u[f+1]);if(m&&p){const y=ar(f,-1,-1),g=ar(f+1,this.viewItems.length),x=this.findFirstSnapIndex(y),w=this.findFirstSnapIndex(g),S=typeof x=="number"&&!this.viewItems[x].visible,O=typeof w=="number"&&!this.viewItems[w].visible;S&&u[f]&&(c>0||this.startSnappingEnabled)?d.state=qn.Minimum:O&&n[f]&&(c<this.contentSize||this.endSnappingEnabled)?d.state=qn.Maximum:d.state=qn.Disabled}else d.state=m&&!p?qn.Minimum:!m&&p?qn.Maximum:qn.Enabled}}findFirstSnapIndex(t){for(const n of t){const r=this.viewItems[n];if(r.visible&&r.snap)return n}for(const n of t){const r=this.viewItems[n];if(r.visible&&r.maximumSize-r.minimumSize>0)return;if(!r.visible&&r.snap)return n}}}class Xl{constructor(t){this.size=void 0,this.size=t}getPreferredSize(){return this.size}}class MO{constructor(t,n){this.proportion=void 0,this.layoutService=void 0,this.proportion=t,this.layoutService=n}getPreferredSize(){return this.proportion*this.layoutService.getSize()}}class tf{getPreferredSize(){}}class zO{get preferredSize(){return this.layoutStrategy.getPreferredSize()}set preferredSize(t){if(typeof t=="number")this.layoutStrategy=new Xl(t);else if(typeof t=="string"){const n=t.trim();if(ef(n,"%")){const r=Number(n.slice(0,-1))/100;this.layoutStrategy=new MO(r,this.layoutService)}else if(ef(n,"px")){const r=Number(n.slice(0,-2))/100;this.layoutStrategy=new Xl(r)}else if(typeof Number.parseFloat(n)=="number"){const r=Number.parseFloat(n);this.layoutStrategy=new Xl(r)}else this.layoutStrategy=new tf}else this.layoutStrategy=new tf}constructor(t,n){var r;if(this.minimumSize=0,this.maximumSize=Number.POSITIVE_INFINITY,this.element=void 0,this.priority=void 0,this.snap=void 0,this.layoutService=void 0,this.layoutStrategy=void 0,this.layoutService=t,this.element=n.element,this.minimumSize=typeof n.minimumSize=="number"?n.minimumSize:30,this.maximumSize=typeof n.maximumSize=="number"?n.maximumSize:Number.POSITIVE_INFINITY,typeof n.preferredSize=="number")this.layoutStrategy=new Xl(n.preferredSize);else if(typeof n.preferredSize=="string"){const a=n.preferredSize.trim();if(ef(a,"%")){const u=Number(a.slice(0,-1))/100;this.layoutStrategy=new MO(u,this.layoutService)}else if(ef(a,"px")){const u=Number(a.slice(0,-2));this.layoutStrategy=new Xl(u)}else if(typeof Number.parseFloat(a)=="number"){const u=Number.parseFloat(a);this.layoutStrategy=new Xl(u)}else this.layoutStrategy=new tf}else this.layoutStrategy=new tf;this.priority=(r=n.priority)!=null?r:sr.Normal,this.snap=typeof n.snap=="boolean"&&n.snap}layout(t){}}function DO(e){return e.minSize!==void 0||e.maxSize!==void 0||e.preferredSize!==void 0||e.priority!==void 0||e.visible!==void 0}const o0=E.forwardRef(({className:e,children:t},n)=>Lr.createElement("div",{ref:n,className:Gy("split-view-view",mC,e)},t));o0.displayName="Allotment.Pane";const wC=E.forwardRef(({children:e,className:t,id:n,maxSize:r=1/0,minSize:a=30,proportionalLayout:u=!0,separator:o=!0,sizes:c,defaultSizes:f=c,snap:d=!1,vertical:m=!1,onChange:p,onReset:y,onVisibleChange:g,onDragStart:x,onDragEnd:w},S)=>{const O=E.useRef(null),_=E.useRef([]),k=E.useRef(new Map),M=E.useRef(null),N=E.useRef(new Map),C=E.useRef(new wI),z=E.useRef([]),[$,H]=E.useState(!1),P=E.useMemo(()=>Lr.Children.toArray(e).filter(Lr.isValidElement),[e]),F=E.useCallback(I=>{var ee,Z;const Y=(ee=z.current)==null?void 0:ee[I];return typeof(Y==null?void 0:Y.preferredSize)=="number"&&((Z=M.current)!=null&&Z.resizeView(I,Math.round(Y.preferredSize)),!0)},[]);return E.useImperativeHandle(S,()=>({reset:()=>{if(y)y();else{var I;(I=M.current)==null||I.distributeViewSizes();for(let ee=0;ee<z.current.length;ee++)F(ee)}},resize:I=>{var ee;(ee=M.current)==null||ee.resizeViews(I)}})),EO(()=>{let I=!0;f&&N.current.size!==f.length&&(I=!1,console.warn(`Expected ${f.length} children based on defaultSizes but found ${N.current.size}`)),I&&f&&(_.current=P.map(Y=>Y.key));const ee=uu({orientation:m?cr.Vertical:cr.Horizontal,proportionalLayout:u},I&&f&&{descriptor:{size:f.reduce((Y,U)=>Y+U,0),views:f.map((Y,U)=>{var Q,ue,de,R;const L=k.current.get(_.current[U]),J=new zO(C.current,uu({element:document.createElement("div"),minimumSize:(Q=L==null?void 0:L.minSize)!=null?Q:a,maximumSize:(ue=L==null?void 0:L.maxSize)!=null?ue:r,priority:(de=L==null?void 0:L.priority)!=null?de:sr.Normal},(L==null?void 0:L.preferredSize)&&{preferredSize:L==null?void 0:L.preferredSize},{snap:(R=L==null?void 0:L.snap)!=null?R:d}));return z.current.push(J),{container:[...N.current.values()][U],size:Y,view:J}})}});M.current=new jI(O.current,ee,p,x,w),M.current.on("sashDragStart",()=>{var Y;(Y=O.current)==null||Y.classList.add("split-view-sash-dragging")}),M.current.on("sashDragEnd",()=>{var Y;(Y=O.current)==null||Y.classList.remove("split-view-sash-dragging")}),M.current.on("sashchange",Y=>{if(g&&M.current){const U=P.map(Q=>Q.key);for(let Q=0;Q<U.length;Q++){const ue=k.current.get(U[Q]);(ue==null?void 0:ue.visible)!==void 0&&ue.visible!==M.current.isViewVisible(Q)&&g(Q,M.current.isViewVisible(Q))}}}),M.current.on("sashreset",Y=>{if(y)y();else{var U;if(F(Y)||F(Y+1))return;(U=M.current)==null||U.distributeViewSizes()}});const Z=M.current;return()=>{Z.dispose()}},[]),EO(()=>{if($){const D=P.map(ge=>ge.key),oe=[..._.current],ye=D.filter(ge=>!_.current.includes(ge)),ve=D.filter(ge=>_.current.includes(ge)),Se=_.current.map(ge=>!D.includes(ge));for(let ge=Se.length-1;ge>=0;ge--){var I;Se[ge]&&((I=M.current)!=null&&I.removeView(ge),oe.splice(ge,1),z.current.splice(ge,1))}for(const ge of ye){var ee,Z,Y,U,Q;const K=k.current.get(ge),he=new zO(C.current,uu({element:document.createElement("div"),minimumSize:(ee=K==null?void 0:K.minSize)!=null?ee:a,maximumSize:(Z=K==null?void 0:K.maxSize)!=null?Z:r,priority:(Y=K==null?void 0:K.priority)!=null?Y:sr.Normal},(K==null?void 0:K.preferredSize)&&{preferredSize:K==null?void 0:K.preferredSize},{snap:(U=K==null?void 0:K.snap)!=null?U:d}));(Q=M.current)!=null&&Q.addView(N.current.get(ge),he,zf.Distribute,D.findIndex(be=>be===ge)),oe.splice(D.findIndex(be=>be===ge),0,ge),z.current.splice(D.findIndex(be=>be===ge),0,he)}for(;!fI(D,oe);)for(const[ge,K]of D.entries()){const he=oe.findIndex(be=>be===K);if(he!==ge){var ue;(ue=M.current)==null||ue.moveView(N.current.get(K),he,ge);const be=oe[he];oe.splice(he,1),oe.splice(ge,0,be);break}}for(const ge of ye){var de;const K=D.findIndex(be=>be===ge),he=z.current[K].preferredSize;he!==void 0&&((de=M.current)==null||de.resizeView(K,he))}for(const ge of[...ye,...ve]){var R,L;const K=k.current.get(ge),he=D.findIndex(be=>be===ge);K&&DO(K)&&K.visible!==void 0&&((R=M.current)==null?void 0:R.isViewVisible(he))!==K.visible&&((L=M.current)==null||L.setViewVisible(he,K.visible))}for(const ge of ve){const K=k.current.get(ge),he=D.findIndex(be=>be===ge);if(K&&DO(K)){var J;K.preferredSize!==void 0&&z.current[he].preferredSize!==K.preferredSize&&(z.current[he].preferredSize=K.preferredSize);let be=!1;K.minSize!==void 0&&z.current[he].minimumSize!==K.minSize&&(z.current[he].minimumSize=K.minSize,be=!0),K.maxSize!==void 0&&z.current[he].maximumSize!==K.maxSize&&(z.current[he].maximumSize=K.maxSize,be=!0),be&&((J=M.current)==null||J.layout())}}(ye.length>0||Se.length>0)&&(_.current=D)}},[P,$,r,a,d]),E.useEffect(()=>{M.current&&(M.current.onDidChange=p)},[p]),E.useEffect(()=>{M.current&&(M.current.onDidDragStart=x)},[x]),E.useEffect(()=>{M.current&&(M.current.onDidDragEnd=w)},[w]),hI({ref:O,onResize:({width:I,height:ee})=>{var Z;I&&ee&&((Z=M.current)!=null&&Z.layout(m?ee:I),C.current.setSize(m?ee:I),H(!0))}}),E.useEffect(()=>{yC&&MI(20)},[]),Lr.createElement("div",{ref:O,className:Gy("split-view",m?"split-view-vertical":"split-view-horizontal",{"split-view-separator-border":o},mI,m?yI:gI,{[bI]:o},t),id:n},Lr.createElement("div",{className:Gy("split-view-container",vI)},Lr.Children.toArray(e).map(I=>{if(!Lr.isValidElement(I))return null;const ee=I.key;return I.type.displayName==="Allotment.Pane"?(k.current.set(ee,I.props),Lr.cloneElement(I,{key:ee,ref:Z=>{const Y=I.ref;Y&&(Y.current=Z),Z?N.current.set(ee,Z):N.current.delete(ee)}})):Lr.createElement(o0,{key:ee,ref:Z=>{Z?N.current.set(ee,Z):N.current.delete(ee)}},I)})))});function MI(e){const t=wr(e,4,20),n=wr(e,1,8);document.documentElement.style.setProperty("--sash-size",t+"px"),document.documentElement.style.setProperty("--sash-hover-size",n+"px"),(function(r){gC=r,bC.emit("onDidChangeGlobalSize",r)})(t)}wC.displayName="Allotment";var Xp=Object.assign(wC,{Pane:o0});/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zI=e=>e.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),SC=(...e)=>e.filter((t,n,r)=>!!t&&t.trim()!==""&&r.indexOf(t)===n).join(" ").trim();/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var DI={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const NI=E.forwardRef(({color:e="currentColor",size:t=24,strokeWidth:n=2,absoluteStrokeWidth:r,className:a="",children:u,iconNode:o,...c},f)=>E.createElement("svg",{ref:f,...DI,width:t,height:t,stroke:e,strokeWidth:r?Number(n)*24/Number(t):n,className:SC("lucide",a),...c},[...o.map(([d,m])=>E.createElement(d,m)),...Array.isArray(u)?u:[u]]));/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const je=(e,t)=>{const n=E.forwardRef(({className:r,...a},u)=>E.createElement(NI,{ref:u,iconNode:t,className:SC(`lucide-${zI(e)}`,r),...a}));return n.displayName=`${e}`,n};/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const PI=je("ArrowUp",[["path",{d:"m5 12 7-7 7 7",key:"hav0vg"}],["path",{d:"M12 19V5",key:"x0mq9r"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const RI=je("Brain",[["path",{d:"M12 5a3 3 0 1 0-5.997.125 4 4 0 0 0-2.526 5.77 4 4 0 0 0 .556 6.588A4 4 0 1 0 12 18Z",key:"l5xja"}],["path",{d:"M12 5a3 3 0 1 1 5.997.125 4 4 0 0 1 2.526 5.77 4 4 0 0 1-.556 6.588A4 4 0 1 1 12 18Z",key:"ep3f8r"}],["path",{d:"M15 13a4.5 4.5 0 0 1-3-4 4.5 4.5 0 0 1-3 4",key:"1p4c4q"}],["path",{d:"M17.599 6.5a3 3 0 0 0 .399-1.375",key:"tmeiqw"}],["path",{d:"M6.003 5.125A3 3 0 0 0 6.401 6.5",key:"105sqy"}],["path",{d:"M3.477 10.896a4 4 0 0 1 .585-.396",key:"ql3yin"}],["path",{d:"M19.938 10.5a4 4 0 0 1 .585.396",key:"1qfode"}],["path",{d:"M6 18a4 4 0 0 1-1.967-.516",key:"2e4loj"}],["path",{d:"M19.967 17.484A4 4 0 0 1 18 18",key:"159ez6"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const II=je("Check",[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const OC=je("ChevronDown",[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const EC=je("ChevronRight",[["path",{d:"m9 18 6-6-6-6",key:"mthhwq"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const s0=je("CircleCheck",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"m9 12 2 2 4-4",key:"dzmm74"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const LI=je("CircleX",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"m15 9-6 6",key:"1uzhvr"}],["path",{d:"m9 9 6 6",key:"z0biqf"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Xy=je("Circle",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const BI=je("Code",[["polyline",{points:"16 18 22 12 16 6",key:"z7tu5w"}],["polyline",{points:"8 6 2 12 8 18",key:"1eg1df"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const AC=je("Download",[["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["polyline",{points:"7 10 12 15 17 10",key:"2ggqvy"}],["line",{x1:"12",x2:"12",y1:"15",y2:"3",key:"1vk2je"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const UI=je("Eye",[["path",{d:"M2.062 12.348a1 1 0 0 1 0-.696 10.75 10.75 0 0 1 19.876 0 1 1 0 0 1 0 .696 10.75 10.75 0 0 1-19.876 0",key:"1nclc0"}],["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const qI=je("FileCode",[["path",{d:"M10 12.5 8 15l2 2.5",key:"1tg20x"}],["path",{d:"m14 12.5 2 2.5-2 2.5",key:"yinavb"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}],["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7z",key:"1mlx9k"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nu=je("FileText",[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z",key:"1rqfz7"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}],["path",{d:"M10 9H8",key:"b1mrlr"}],["path",{d:"M16 13H8",key:"t4e002"}],["path",{d:"M16 17H8",key:"z1uh3a"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const HI=je("File",[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z",key:"1rqfz7"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $I=je("FolderOpen",[["path",{d:"m6 14 1.5-2.9A2 2 0 0 1 9.24 10H20a2 2 0 0 1 1.94 2.5l-1.54 6a2 2 0 0 1-1.95 1.5H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H18a2 2 0 0 1 2 2v2",key:"usdka0"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const FI=je("FolderPlus",[["path",{d:"M12 10v6",key:"1bos4e"}],["path",{d:"M9 13h6",key:"1uhe8q"}],["path",{d:"M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",key:"1kt360"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const VI=je("FolderTree",[["path",{d:"M20 10a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-2.5a1 1 0 0 1-.8-.4l-.9-1.2A1 1 0 0 0 15 3h-2a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1Z",key:"hod4my"}],["path",{d:"M20 21a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1h-2.9a1 1 0 0 1-.88-.55l-.42-.85a1 1 0 0 0-.92-.6H13a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1Z",key:"w4yl2u"}],["path",{d:"M3 5a2 2 0 0 0 2 2h3",key:"f2jnh7"}],["path",{d:"M3 3v13a2 2 0 0 0 2 2h3",key:"k8epm1"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Zy=je("Folder",[["path",{d:"M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",key:"1kt360"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const YI=je("GitBranch",[["line",{x1:"6",x2:"6",y1:"3",y2:"15",key:"17qcm7"}],["circle",{cx:"18",cy:"6",r:"3",key:"1h7g24"}],["circle",{cx:"6",cy:"18",r:"3",key:"fqmcym"}],["path",{d:"M18 9a9 9 0 0 1-9 9",key:"n2h4wq"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const KI=je("House",[["path",{d:"M15 21v-8a1 1 0 0 0-1-1h-4a1 1 0 0 0-1 1v8",key:"5wwlr5"}],["path",{d:"M3 10a2 2 0 0 1 .709-1.528l7-5.999a2 2 0 0 1 2.582 0l7 5.999A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z",key:"1d0kgt"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const GI=je("Image",[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",ry:"2",key:"1m3agn"}],["circle",{cx:"9",cy:"9",r:"2",key:"af1f0g"}],["path",{d:"m21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21",key:"1xmnt7"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const XI=je("Layers",[["path",{d:"M12.83 2.18a2 2 0 0 0-1.66 0L2.6 6.08a1 1 0 0 0 0 1.83l8.58 3.91a2 2 0 0 0 1.66 0l8.58-3.9a1 1 0 0 0 0-1.83z",key:"zw3jo"}],["path",{d:"M2 12a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 12",key:"1wduqc"}],["path",{d:"M2 17a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 17",key:"kqbvx6"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ZI=je("ListChecks",[["path",{d:"m3 17 2 2 4-4",key:"1jhpwq"}],["path",{d:"m3 7 2 2 4-4",key:"1obspn"}],["path",{d:"M13 6h8",key:"15sg57"}],["path",{d:"M13 12h8",key:"h98zly"}],["path",{d:"M13 18h8",key:"oe0vm4"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const _C=je("ListTodo",[["rect",{x:"3",y:"5",width:"6",height:"6",rx:"1",key:"1defrl"}],["path",{d:"m3 17 2 2 4-4",key:"1jhpwq"}],["path",{d:"M13 6h8",key:"15sg57"}],["path",{d:"M13 12h8",key:"h98zly"}],["path",{d:"M13 18h8",key:"oe0vm4"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const c0=je("LoaderCircle",[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const QI=je("Monitor",[["rect",{width:"20",height:"14",x:"2",y:"3",rx:"2",key:"48i651"}],["line",{x1:"8",x2:"16",y1:"21",y2:"21",key:"1svkeh"}],["line",{x1:"12",x2:"12",y1:"17",y2:"21",key:"vw1qmm"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const WI=je("Moon",[["path",{d:"M12 3a6 6 0 0 0 9 9 9 9 0 1 1-9-9Z",key:"a7tn18"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const JI=je("Palette",[["circle",{cx:"13.5",cy:"6.5",r:".5",fill:"currentColor",key:"1okk4w"}],["circle",{cx:"17.5",cy:"10.5",r:".5",fill:"currentColor",key:"f64h9f"}],["circle",{cx:"8.5",cy:"7.5",r:".5",fill:"currentColor",key:"fotxhn"}],["circle",{cx:"6.5",cy:"12.5",r:".5",fill:"currentColor",key:"qy21gx"}],["path",{d:"M12 2C6.5 2 2 6.5 2 12s4.5 10 10 10c.926 0 1.648-.746 1.648-1.688 0-.437-.18-.835-.437-1.125-.29-.289-.438-.652-.438-1.125a1.64 1.64 0 0 1 1.668-1.668h1.996c3.051 0 5.555-2.503 5.555-5.554C21.965 6.012 17.461 2 12 2z",key:"12rzf8"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e3=je("PanelRightClose",[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M15 3v18",key:"14nvp0"}],["path",{d:"m8 9 3 3-3 3",key:"12hl5m"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const t3=je("PanelRightOpen",[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M15 3v18",key:"14nvp0"}],["path",{d:"m10 15-3-3 3-3",key:"1pgupc"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const n3=je("Pencil",[["path",{d:"M21.174 6.812a1 1 0 0 0-3.986-3.987L3.842 16.174a2 2 0 0 0-.5.83l-1.321 4.352a.5.5 0 0 0 .623.622l4.353-1.32a2 2 0 0 0 .83-.497z",key:"1a8usu"}],["path",{d:"m15 5 4 4",key:"1mk7zo"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Zp=je("Search",[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["path",{d:"m21 21-4.3-4.3",key:"1qie3q"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const kC=je("Sparkles",[["path",{d:"M9.937 15.5A2 2 0 0 0 8.5 14.063l-6.135-1.582a.5.5 0 0 1 0-.962L8.5 9.936A2 2 0 0 0 9.937 8.5l1.582-6.135a.5.5 0 0 1 .963 0L14.063 8.5A2 2 0 0 0 15.5 9.937l6.135 1.581a.5.5 0 0 1 0 .964L15.5 14.063a2 2 0 0 0-1.437 1.437l-1.582 6.135a.5.5 0 0 1-.963 0z",key:"4pj2yx"}],["path",{d:"M20 3v4",key:"1olli1"}],["path",{d:"M22 5h-4",key:"1gvqau"}],["path",{d:"M4 17v2",key:"vumght"}],["path",{d:"M5 18H3",key:"zchphs"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const r3=je("Square",[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const i3=je("Sun",[["circle",{cx:"12",cy:"12",r:"4",key:"4exip2"}],["path",{d:"M12 2v2",key:"tus03m"}],["path",{d:"M12 20v2",key:"1lh1kg"}],["path",{d:"m4.93 4.93 1.41 1.41",key:"149t6j"}],["path",{d:"m17.66 17.66 1.41 1.41",key:"ptbguv"}],["path",{d:"M2 12h2",key:"1t8f8n"}],["path",{d:"M20 12h2",key:"1q8mjw"}],["path",{d:"m6.34 17.66-1.41 1.41",key:"1m8zz5"}],["path",{d:"m19.07 4.93-1.41 1.41",key:"1shlcs"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nf=je("Terminal",[["polyline",{points:"4 17 10 11 4 5",key:"akl6gq"}],["line",{x1:"12",x2:"20",y1:"19",y2:"19",key:"q2wloq"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const CC=je("Trash2",[["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6",key:"4alrt4"}],["path",{d:"M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2",key:"v07s0e"}],["line",{x1:"10",x2:"10",y1:"11",y2:"17",key:"1uufr5"}],["line",{x1:"14",x2:"14",y1:"11",y2:"17",key:"xtxkd"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const a3=je("TriangleAlert",[["path",{d:"m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3",key:"wmoenq"}],["path",{d:"M12 9v4",key:"juzpu7"}],["path",{d:"M12 17h.01",key:"p32p05"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const l3=je("Upload",[["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["polyline",{points:"17 8 12 3 7 8",key:"t8dd8p"}],["line",{x1:"12",x2:"12",y1:"3",y2:"15",key:"widbto"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const u3=je("Wrench",[["path",{d:"M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.77-3.77a6 6 0 0 1-7.94 7.94l-6.91 6.91a2.12 2.12 0 0 1-3-3l6.91-6.91a6 6 0 0 1 7.94-7.94l-3.76 3.76z",key:"cbrjhi"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const f0=je("X",[["path",{d:"M18 6 6 18",key:"1bl5f8"}],["path",{d:"m6 6 12 12",key:"d8bk6v"}]]);/**
 * @license lucide-react v0.468.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const o3=je("Zap",[["path",{d:"M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z",key:"1xq2db"}]]);function s3(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const c3=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,f3=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,d3={};function NO(e,t){return(d3.jsx?f3:c3).test(e)}const h3=/[ \t\n\f\r]/g;function m3(e){return typeof e=="object"?e.type==="text"?PO(e.value):!1:PO(e)}function PO(e){return e.replace(h3,"")===""}class ys{constructor(t,n,r){this.normal=n,this.property=t,r&&(this.space=r)}}ys.prototype.normal={};ys.prototype.property={};ys.prototype.space=void 0;function TC(e,t){const n={},r={};for(const a of e)Object.assign(n,a.property),Object.assign(r,a.normal);return new ys(n,r,t)}function Qy(e){return e.toLowerCase()}class Tn{constructor(t,n){this.attribute=n,this.property=t}}Tn.prototype.attribute="";Tn.prototype.booleanish=!1;Tn.prototype.boolean=!1;Tn.prototype.commaOrSpaceSeparated=!1;Tn.prototype.commaSeparated=!1;Tn.prototype.defined=!1;Tn.prototype.mustUseProperty=!1;Tn.prototype.number=!1;Tn.prototype.overloadedBoolean=!1;Tn.prototype.property="";Tn.prototype.spaceSeparated=!1;Tn.prototype.space=void 0;let p3=0;const ze=il(),Ct=il(),Wy=il(),ce=il(),lt=il(),ou=il(),Un=il();function il(){return 2**++p3}const Jy=Object.freeze(Object.defineProperty({__proto__:null,boolean:ze,booleanish:Ct,commaOrSpaceSeparated:Un,commaSeparated:ou,number:ce,overloadedBoolean:Wy,spaceSeparated:lt},Symbol.toStringTag,{value:"Module"})),Qp=Object.keys(Jy);class d0 extends Tn{constructor(t,n,r,a){let u=-1;if(super(t,n),RO(this,"space",a),typeof r=="number")for(;++u<Qp.length;){const o=Qp[u];RO(this,Qp[u],(r&Jy[o])===Jy[o])}}}d0.prototype.defined=!0;function RO(e,t,n){n&&(e[t]=n)}function Ou(e){const t={},n={};for(const[r,a]of Object.entries(e.properties)){const u=new d0(r,e.transform(e.attributes||{},r),a,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(u.mustUseProperty=!0),t[r]=u,n[Qy(r)]=r,n[Qy(u.attribute)]=r}return new ys(t,n,e.space)}const jC=Ou({properties:{ariaActiveDescendant:null,ariaAtomic:Ct,ariaAutoComplete:null,ariaBusy:Ct,ariaChecked:Ct,ariaColCount:ce,ariaColIndex:ce,ariaColSpan:ce,ariaControls:lt,ariaCurrent:null,ariaDescribedBy:lt,ariaDetails:null,ariaDisabled:Ct,ariaDropEffect:lt,ariaErrorMessage:null,ariaExpanded:Ct,ariaFlowTo:lt,ariaGrabbed:Ct,ariaHasPopup:null,ariaHidden:Ct,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:lt,ariaLevel:ce,ariaLive:null,ariaModal:Ct,ariaMultiLine:Ct,ariaMultiSelectable:Ct,ariaOrientation:null,ariaOwns:lt,ariaPlaceholder:null,ariaPosInSet:ce,ariaPressed:Ct,ariaReadOnly:Ct,ariaRelevant:null,ariaRequired:Ct,ariaRoleDescription:lt,ariaRowCount:ce,ariaRowIndex:ce,ariaRowSpan:ce,ariaSelected:Ct,ariaSetSize:ce,ariaSort:null,ariaValueMax:ce,ariaValueMin:ce,ariaValueNow:ce,ariaValueText:null,role:null},transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()}});function MC(e,t){return t in e?e[t]:t}function zC(e,t){return MC(e,t.toLowerCase())}const v3=Ou({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:ou,acceptCharset:lt,accessKey:lt,action:null,allow:null,allowFullScreen:ze,allowPaymentRequest:ze,allowUserMedia:ze,alt:null,as:null,async:ze,autoCapitalize:null,autoComplete:lt,autoFocus:ze,autoPlay:ze,blocking:lt,capture:null,charSet:null,checked:ze,cite:null,className:lt,cols:ce,colSpan:null,content:null,contentEditable:Ct,controls:ze,controlsList:lt,coords:ce|ou,crossOrigin:null,data:null,dateTime:null,decoding:null,default:ze,defer:ze,dir:null,dirName:null,disabled:ze,download:Wy,draggable:Ct,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:ze,formTarget:null,headers:lt,height:ce,hidden:Wy,high:ce,href:null,hrefLang:null,htmlFor:lt,httpEquiv:lt,id:null,imageSizes:null,imageSrcSet:null,inert:ze,inputMode:null,integrity:null,is:null,isMap:ze,itemId:null,itemProp:lt,itemRef:lt,itemScope:ze,itemType:lt,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:ze,low:ce,manifest:null,max:null,maxLength:ce,media:null,method:null,min:null,minLength:ce,multiple:ze,muted:ze,name:null,nonce:null,noModule:ze,noValidate:ze,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:ze,optimum:ce,pattern:null,ping:lt,placeholder:null,playsInline:ze,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:ze,referrerPolicy:null,rel:lt,required:ze,reversed:ze,rows:ce,rowSpan:ce,sandbox:lt,scope:null,scoped:ze,seamless:ze,selected:ze,shadowRootClonable:ze,shadowRootDelegatesFocus:ze,shadowRootMode:null,shape:null,size:ce,sizes:null,slot:null,span:ce,spellCheck:Ct,src:null,srcDoc:null,srcLang:null,srcSet:null,start:ce,step:null,style:null,tabIndex:ce,target:null,title:null,translate:null,type:null,typeMustMatch:ze,useMap:null,value:Ct,width:ce,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:lt,axis:null,background:null,bgColor:null,border:ce,borderColor:null,bottomMargin:ce,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:ze,declare:ze,event:null,face:null,frame:null,frameBorder:null,hSpace:ce,leftMargin:ce,link:null,longDesc:null,lowSrc:null,marginHeight:ce,marginWidth:ce,noResize:ze,noHref:ze,noShade:ze,noWrap:ze,object:null,profile:null,prompt:null,rev:null,rightMargin:ce,rules:null,scheme:null,scrolling:Ct,standby:null,summary:null,text:null,topMargin:ce,valueType:null,version:null,vAlign:null,vLink:null,vSpace:ce,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:ze,disableRemotePlayback:ze,prefix:null,property:null,results:ce,security:null,unselectable:null},space:"html",transform:zC}),y3=Ou({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:Un,accentHeight:ce,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:ce,amplitude:ce,arabicForm:null,ascent:ce,attributeName:null,attributeType:null,azimuth:ce,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:ce,by:null,calcMode:null,capHeight:ce,className:lt,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:ce,diffuseConstant:ce,direction:null,display:null,dur:null,divisor:ce,dominantBaseline:null,download:ze,dx:null,dy:null,edgeMode:null,editable:null,elevation:ce,enableBackground:null,end:null,event:null,exponent:ce,externalResourcesRequired:null,fill:null,fillOpacity:ce,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:ou,g2:ou,glyphName:ou,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:ce,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:ce,horizOriginX:ce,horizOriginY:ce,id:null,ideographic:ce,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:ce,k:ce,k1:ce,k2:ce,k3:ce,k4:ce,kernelMatrix:Un,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:ce,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:ce,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:ce,overlineThickness:ce,paintOrder:null,panose1:null,path:null,pathLength:ce,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:lt,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:ce,pointsAtY:ce,pointsAtZ:ce,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:Un,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:Un,rev:Un,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:Un,requiredFeatures:Un,requiredFonts:Un,requiredFormats:Un,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:ce,specularExponent:ce,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:ce,strikethroughThickness:ce,string:null,stroke:null,strokeDashArray:Un,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:ce,strokeOpacity:ce,strokeWidth:null,style:null,surfaceScale:ce,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:Un,tabIndex:ce,tableValues:null,target:null,targetX:ce,targetY:ce,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:Un,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:ce,underlineThickness:ce,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:ce,values:null,vAlphabetic:ce,vMathematical:ce,vectorEffect:null,vHanging:ce,vIdeographic:ce,version:null,vertAdvY:ce,vertOriginX:ce,vertOriginY:ce,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:ce,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:MC}),DC=Ou({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()}}),NC=Ou({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:zC}),PC=Ou({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()}}),g3={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},b3=/[A-Z]/g,IO=/-[a-z]/g,x3=/^data[-\w.:]+$/i;function w3(e,t){const n=Qy(t);let r=t,a=Tn;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&x3.test(t)){if(t.charAt(4)==="-"){const u=t.slice(5).replace(IO,O3);r="data"+u.charAt(0).toUpperCase()+u.slice(1)}else{const u=t.slice(4);if(!IO.test(u)){let o=u.replace(b3,S3);o.charAt(0)!=="-"&&(o="-"+o),t="data"+o}}a=d0}return new a(r,t)}function S3(e){return"-"+e.toLowerCase()}function O3(e){return e.charAt(1).toUpperCase()}const E3=TC([jC,v3,DC,NC,PC],"html"),h0=TC([jC,y3,DC,NC,PC],"svg");function A3(e){return e.join(" ").trim()}var Zl={},Wp,LO;function _3(){if(LO)return Wp;LO=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,a=/^:\s*/,u=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,o=/^[;\s]*/,c=/^\s+|\s+$/g,f=`
`,d="/",m="*",p="",y="comment",g="declaration";function x(S,O){if(typeof S!="string")throw new TypeError("First argument must be a string");if(!S)return[];O=O||{};var _=1,k=1;function M(Z){var Y=Z.match(t);Y&&(_+=Y.length);var U=Z.lastIndexOf(f);k=~U?Z.length-U:k+Z.length}function N(){var Z={line:_,column:k};return function(Y){return Y.position=new C(Z),H(),Y}}function C(Z){this.start=Z,this.end={line:_,column:k},this.source=O.source}C.prototype.content=S;function z(Z){var Y=new Error(O.source+":"+_+":"+k+": "+Z);if(Y.reason=Z,Y.filename=O.source,Y.line=_,Y.column=k,Y.source=S,!O.silent)throw Y}function $(Z){var Y=Z.exec(S);if(Y){var U=Y[0];return M(U),S=S.slice(U.length),Y}}function H(){$(n)}function P(Z){var Y;for(Z=Z||[];Y=F();)Y!==!1&&Z.push(Y);return Z}function F(){var Z=N();if(!(d!=S.charAt(0)||m!=S.charAt(1))){for(var Y=2;p!=S.charAt(Y)&&(m!=S.charAt(Y)||d!=S.charAt(Y+1));)++Y;if(Y+=2,p===S.charAt(Y-1))return z("End of comment missing");var U=S.slice(2,Y-2);return k+=2,M(U),S=S.slice(Y),k+=2,Z({type:y,comment:U})}}function I(){var Z=N(),Y=$(r);if(Y){if(F(),!$(a))return z("property missing ':'");var U=$(u),Q=Z({type:g,property:w(Y[0].replace(e,p)),value:U?w(U[0].replace(e,p)):p});return $(o),Q}}function ee(){var Z=[];P(Z);for(var Y;Y=I();)Y!==!1&&(Z.push(Y),P(Z));return Z}return H(),ee()}function w(S){return S?S.replace(c,p):p}return Wp=x,Wp}var BO;function k3(){if(BO)return Zl;BO=1;var e=Zl&&Zl.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(Zl,"__esModule",{value:!0}),Zl.default=n;const t=e(_3());function n(r,a){let u=null;if(!r||typeof r!="string")return u;const o=(0,t.default)(r),c=typeof a=="function";return o.forEach(f=>{if(f.type!=="declaration")return;const{property:d,value:m}=f;c?a(d,m,f):m&&(u=u||{},u[d]=m)}),u}return Zl}var Do={},UO;function C3(){if(UO)return Do;UO=1,Object.defineProperty(Do,"__esModule",{value:!0}),Do.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,r=/^-(webkit|moz|ms|o|khtml)-/,a=/^-(ms)-/,u=function(d){return!d||n.test(d)||e.test(d)},o=function(d,m){return m.toUpperCase()},c=function(d,m){return"".concat(m,"-")},f=function(d,m){return m===void 0&&(m={}),u(d)?d:(d=d.toLowerCase(),m.reactCompat?d=d.replace(a,c):d=d.replace(r,c),d.replace(t,o))};return Do.camelCase=f,Do}var No,qO;function T3(){if(qO)return No;qO=1;var e=No&&No.__importDefault||function(a){return a&&a.__esModule?a:{default:a}},t=e(k3()),n=C3();function r(a,u){var o={};return!a||typeof a!="string"||(0,t.default)(a,function(c,f){c&&f&&(o[(0,n.camelCase)(c,u)]=f)}),o}return r.default=r,No=r,No}var j3=T3();const M3=Tr(j3),RC=IC("end"),m0=IC("start");function IC(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function z3(e){const t=m0(e),n=RC(e);if(t&&n)return{start:t,end:n}}function Xo(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?HO(e.position):"start"in e||"end"in e?HO(e):"line"in e||"column"in e?eg(e):""}function eg(e){return $O(e&&e.line)+":"+$O(e&&e.column)}function HO(e){return eg(e&&e.start)+"-"+eg(e&&e.end)}function $O(e){return e&&typeof e=="number"?e:1}class un extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let a="",u={},o=!1;if(n&&("line"in n&&"column"in n?u={place:n}:"start"in n&&"end"in n?u={place:n}:"type"in n?u={ancestors:[n],place:n.position}:u={...n}),typeof t=="string"?a=t:!u.cause&&t&&(o=!0,a=t.message,u.cause=t),!u.ruleId&&!u.source&&typeof r=="string"){const f=r.indexOf(":");f===-1?u.ruleId=r:(u.source=r.slice(0,f),u.ruleId=r.slice(f+1))}if(!u.place&&u.ancestors&&u.ancestors){const f=u.ancestors[u.ancestors.length-1];f&&(u.place=f.position)}const c=u.place&&"start"in u.place?u.place.start:u.place;this.ancestors=u.ancestors||void 0,this.cause=u.cause||void 0,this.column=c?c.column:void 0,this.fatal=void 0,this.file="",this.message=a,this.line=c?c.line:void 0,this.name=Xo(u.place)||"1:1",this.place=u.place||void 0,this.reason=this.message,this.ruleId=u.ruleId||void 0,this.source=u.source||void 0,this.stack=o&&u.cause&&typeof u.cause.stack=="string"?u.cause.stack:"",this.actual=void 0,this.expected=void 0,this.note=void 0,this.url=void 0}}un.prototype.file="";un.prototype.name="";un.prototype.reason="";un.prototype.message="";un.prototype.stack="";un.prototype.column=void 0;un.prototype.line=void 0;un.prototype.ancestors=void 0;un.prototype.cause=void 0;un.prototype.fatal=void 0;un.prototype.place=void 0;un.prototype.ruleId=void 0;un.prototype.source=void 0;const p0={}.hasOwnProperty,D3=new Map,N3=/[A-Z]/g,P3=new Set(["table","tbody","thead","tfoot","tr"]),R3=new Set(["td","th"]),LC="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function I3(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=V3(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=F3(n,t.jsx,t.jsxs)}const a={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?h0:E3,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},u=BC(a,e,void 0);return u&&typeof u!="string"?u:a.create(e,a.Fragment,{children:u||void 0},void 0)}function BC(e,t,n){if(t.type==="element")return L3(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return B3(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return q3(e,t,n);if(t.type==="mdxjsEsm")return U3(e,t);if(t.type==="root")return H3(e,t,n);if(t.type==="text")return $3(e,t)}function L3(e,t,n){const r=e.schema;let a=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(a=h0,e.schema=a),e.ancestors.push(t);const u=qC(e,t.tagName,!1),o=Y3(e,t);let c=y0(e,t);return P3.has(t.tagName)&&(c=c.filter(function(f){return typeof f=="string"?!m3(f):!0})),UC(e,o,u,t),v0(o,c),e.ancestors.pop(),e.schema=r,e.create(t,u,o,n)}function B3(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return r.type,e.evaluater.evaluateExpression(r.expression)}Jo(e,t.position)}function U3(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);Jo(e,t.position)}function q3(e,t,n){const r=e.schema;let a=r;t.name==="svg"&&r.space==="html"&&(a=h0,e.schema=a),e.ancestors.push(t);const u=t.name===null?e.Fragment:qC(e,t.name,!0),o=K3(e,t),c=y0(e,t);return UC(e,o,u,t),v0(o,c),e.ancestors.pop(),e.schema=r,e.create(t,u,o,n)}function H3(e,t,n){const r={};return v0(r,y0(e,t)),e.create(t,e.Fragment,r,n)}function $3(e,t){return t.value}function UC(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function v0(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function F3(e,t,n){return r;function r(a,u,o,c){const d=Array.isArray(o.children)?n:t;return c?d(u,o,c):d(u,o)}}function V3(e,t){return n;function n(r,a,u,o){const c=Array.isArray(u.children),f=m0(r);return t(a,u,o,c,{columnNumber:f?f.column-1:void 0,fileName:e,lineNumber:f?f.line:void 0},void 0)}}function Y3(e,t){const n={};let r,a;for(a in t.properties)if(a!=="children"&&p0.call(t.properties,a)){const u=G3(e,a,t.properties[a]);if(u){const[o,c]=u;e.tableCellAlignToStyle&&o==="align"&&typeof c=="string"&&R3.has(t.tagName)?r=c:n[o]=c}}if(r){const u=n.style||(n.style={});u[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function K3(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const u=r.data.estree.body[0];u.type;const o=u.expression;o.type;const c=o.properties[0];c.type,Object.assign(n,e.evaluater.evaluateExpression(c.argument))}else Jo(e,t.position);else{const a=r.name;let u;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const c=r.value.data.estree.body[0];c.type,u=e.evaluater.evaluateExpression(c.expression)}else Jo(e,t.position);else u=r.value===null?!0:r.value;n[a]=u}return n}function y0(e,t){const n=[];let r=-1;const a=e.passKeys?new Map:D3;for(;++r<t.children.length;){const u=t.children[r];let o;if(e.passKeys){const f=u.type==="element"?u.tagName:u.type==="mdxJsxFlowElement"||u.type==="mdxJsxTextElement"?u.name:void 0;if(f){const d=a.get(f)||0;o=f+"-"+d,a.set(f,d+1)}}const c=BC(e,u,o);c!==void 0&&n.push(c)}return n}function G3(e,t,n){const r=w3(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?s3(n):A3(n)),r.property==="style"){let a=typeof n=="object"?n:X3(e,String(n));return e.stylePropertyNameCase==="css"&&(a=Z3(a)),["style",a]}return[e.elementAttributeNameCase==="react"&&r.space?g3[r.property]||r.property:r.attribute,n]}}function X3(e,t){try{return M3(t,{reactCompat:!0})}catch(n){if(e.ignoreInvalidStyle)return{};const r=n,a=new un("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:r,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw a.file=e.filePath||void 0,a.url=LC+"#cannot-parse-style-attribute",a}}function qC(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const a=t.split(".");let u=-1,o;for(;++u<a.length;){const c=NO(a[u])?{type:"Identifier",name:a[u]}:{type:"Literal",value:a[u]};o=o?{type:"MemberExpression",object:o,property:c,computed:!!(u&&c.type==="Literal"),optional:!1}:c}r=o}else r=NO(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const a=r.value;return p0.call(e.components,a)?e.components[a]:a}if(e.evaluater)return e.evaluater.evaluateExpression(r);Jo(e)}function Jo(e,t){const n=new un("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=LC+"#cannot-handle-mdx-estrees-without-createevaluater",n}function Z3(e){const t={};let n;for(n in e)p0.call(e,n)&&(t[Q3(n)]=e[n]);return t}function Q3(e){let t=e.replace(N3,W3);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function W3(e){return"-"+e.toLowerCase()}const Jp={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},J3={};function g0(e,t){const n=J3,r=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,a=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return HC(e,r,a)}function HC(e,t,n){if(e4(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return FO(e.children,t,n)}return Array.isArray(e)?FO(e,t,n):""}function FO(e,t,n){const r=[];let a=-1;for(;++a<e.length;)r[a]=HC(e[a],t,n);return r.join("")}function e4(e){return!!(e&&typeof e=="object")}const VO=document.createElement("i");function b0(e){const t="&"+e+";";VO.innerHTML=t;const n=VO.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function Fn(e,t,n,r){const a=e.length;let u=0,o;if(t<0?t=-t>a?0:a+t:t=t>a?a:t,n=n>0?n:0,r.length<1e4)o=Array.from(r),o.unshift(t,n),e.splice(...o);else for(n&&e.splice(t,n);u<r.length;)o=r.slice(u,u+1e4),o.unshift(t,0),e.splice(...o),u+=1e4,t+=1e4}function fr(e,t){return e.length>0?(Fn(e,e.length,0,t),e):t}const YO={}.hasOwnProperty;function $C(e){const t={};let n=-1;for(;++n<e.length;)t4(t,e[n]);return t}function t4(e,t){let n;for(n in t){const a=(YO.call(e,n)?e[n]:void 0)||(e[n]={}),u=t[n];let o;if(u)for(o in u){YO.call(a,o)||(a[o]=[]);const c=u[o];n4(a[o],Array.isArray(c)?c:c?[c]:[])}}}function n4(e,t){let n=-1;const r=[];for(;++n<t.length;)(t[n].add==="after"?e:r).push(t[n]);Fn(e,0,0,r)}function FC(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function Ar(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const dn=pa(/[A-Za-z]/),ln=pa(/[\dA-Za-z]/),r4=pa(/[#-'*+\--9=?A-Z^-~]/);function Df(e){return e!==null&&(e<32||e===127)}const tg=pa(/\d/),i4=pa(/[\dA-Fa-f]/),a4=pa(/[!-/:-@[-`{-~]/);function Ae(e){return e!==null&&e<-2}function it(e){return e!==null&&(e<0||e===32)}function Re(e){return e===-2||e===-1||e===32}const jd=pa(new RegExp("\\p{P}|\\p{S}","u")),Za=pa(/\s/);function pa(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function Eu(e){const t=[];let n=-1,r=0,a=0;for(;++n<e.length;){const u=e.charCodeAt(n);let o="";if(u===37&&ln(e.charCodeAt(n+1))&&ln(e.charCodeAt(n+2)))a=2;else if(u<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(u))||(o=String.fromCharCode(u));else if(u>55295&&u<57344){const c=e.charCodeAt(n+1);u<56320&&c>56319&&c<57344?(o=String.fromCharCode(u,c),a=1):o="�"}else o=String.fromCharCode(u);o&&(t.push(e.slice(r,n),encodeURIComponent(o)),r=n+a+1,o=""),a&&(n+=a,a=0)}return t.join("")+e.slice(r)}function He(e,t,n,r){const a=r?r-1:Number.POSITIVE_INFINITY;let u=0;return o;function o(f){return Re(f)?(e.enter(n),c(f)):t(f)}function c(f){return Re(f)&&u++<a?(e.consume(f),c):(e.exit(n),t(f))}}const l4={tokenize:u4};function u4(e){const t=e.attempt(this.parser.constructs.contentInitial,r,a);let n;return t;function r(c){if(c===null){e.consume(c);return}return e.enter("lineEnding"),e.consume(c),e.exit("lineEnding"),He(e,t,"linePrefix")}function a(c){return e.enter("paragraph"),u(c)}function u(c){const f=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=f),n=f,o(c)}function o(c){if(c===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(c);return}return Ae(c)?(e.consume(c),e.exit("chunkText"),u):(e.consume(c),o)}}const o4={tokenize:s4},KO={tokenize:c4};function s4(e){const t=this,n=[];let r=0,a,u,o;return c;function c(k){if(r<n.length){const M=n[r];return t.containerState=M[1],e.attempt(M[0].continuation,f,d)(k)}return d(k)}function f(k){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,a&&_();const M=t.events.length;let N=M,C;for(;N--;)if(t.events[N][0]==="exit"&&t.events[N][1].type==="chunkFlow"){C=t.events[N][1].end;break}O(r);let z=M;for(;z<t.events.length;)t.events[z][1].end={...C},z++;return Fn(t.events,N+1,0,t.events.slice(M)),t.events.length=z,d(k)}return c(k)}function d(k){if(r===n.length){if(!a)return y(k);if(a.currentConstruct&&a.currentConstruct.concrete)return x(k);t.interrupt=!!(a.currentConstruct&&!a._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(KO,m,p)(k)}function m(k){return a&&_(),O(r),y(k)}function p(k){return t.parser.lazy[t.now().line]=r!==n.length,o=t.now().offset,x(k)}function y(k){return t.containerState={},e.attempt(KO,g,x)(k)}function g(k){return r++,n.push([t.currentConstruct,t.containerState]),y(k)}function x(k){if(k===null){a&&_(),O(0),e.consume(k);return}return a=a||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:a,contentType:"flow",previous:u}),w(k)}function w(k){if(k===null){S(e.exit("chunkFlow"),!0),O(0),e.consume(k);return}return Ae(k)?(e.consume(k),S(e.exit("chunkFlow")),r=0,t.interrupt=void 0,c):(e.consume(k),w)}function S(k,M){const N=t.sliceStream(k);if(M&&N.push(null),k.previous=u,u&&(u.next=k),u=k,a.defineSkip(k.start),a.write(N),t.parser.lazy[k.start.line]){let C=a.events.length;for(;C--;)if(a.events[C][1].start.offset<o&&(!a.events[C][1].end||a.events[C][1].end.offset>o))return;const z=t.events.length;let $=z,H,P;for(;$--;)if(t.events[$][0]==="exit"&&t.events[$][1].type==="chunkFlow"){if(H){P=t.events[$][1].end;break}H=!0}for(O(r),C=z;C<t.events.length;)t.events[C][1].end={...P},C++;Fn(t.events,$+1,0,t.events.slice(z)),t.events.length=C}}function O(k){let M=n.length;for(;M-- >k;){const N=n[M];t.containerState=N[1],N[0].exit.call(t,e)}n.length=k}function _(){a.write([null]),u=void 0,a=void 0,t.containerState._closeFlow=void 0}}function c4(e,t,n){return He(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function fu(e){if(e===null||it(e)||Za(e))return 1;if(jd(e))return 2}function Md(e,t,n){const r=[];let a=-1;for(;++a<e.length;){const u=e[a].resolveAll;u&&!r.includes(u)&&(t=u(t,n),r.push(u))}return t}const ng={name:"attention",resolveAll:f4,tokenize:d4};function f4(e,t){let n=-1,r,a,u,o,c,f,d,m;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(r=n;r--;)if(e[r][0]==="exit"&&e[r][1].type==="attentionSequence"&&e[r][1]._open&&t.sliceSerialize(e[r][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[r][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[r][1].end.offset-e[r][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;f=e[r][1].end.offset-e[r][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const p={...e[r][1].end},y={...e[n][1].start};GO(p,-f),GO(y,f),o={type:f>1?"strongSequence":"emphasisSequence",start:p,end:{...e[r][1].end}},c={type:f>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:y},u={type:f>1?"strongText":"emphasisText",start:{...e[r][1].end},end:{...e[n][1].start}},a={type:f>1?"strong":"emphasis",start:{...o.start},end:{...c.end}},e[r][1].end={...o.start},e[n][1].start={...c.end},d=[],e[r][1].end.offset-e[r][1].start.offset&&(d=fr(d,[["enter",e[r][1],t],["exit",e[r][1],t]])),d=fr(d,[["enter",a,t],["enter",o,t],["exit",o,t],["enter",u,t]]),d=fr(d,Md(t.parser.constructs.insideSpan.null,e.slice(r+1,n),t)),d=fr(d,[["exit",u,t],["enter",c,t],["exit",c,t],["exit",a,t]]),e[n][1].end.offset-e[n][1].start.offset?(m=2,d=fr(d,[["enter",e[n][1],t],["exit",e[n][1],t]])):m=0,Fn(e,r-1,n-r+3,d),n=r+d.length-m-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function d4(e,t){const n=this.parser.constructs.attentionMarkers.null,r=this.previous,a=fu(r);let u;return o;function o(f){return u=f,e.enter("attentionSequence"),c(f)}function c(f){if(f===u)return e.consume(f),c;const d=e.exit("attentionSequence"),m=fu(f),p=!m||m===2&&a||n.includes(f),y=!a||a===2&&m||n.includes(r);return d._open=!!(u===42?p:p&&(a||!y)),d._close=!!(u===42?y:y&&(m||!p)),t(f)}}function GO(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const h4={name:"autolink",tokenize:m4};function m4(e,t,n){let r=0;return a;function a(g){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(g),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),u}function u(g){return dn(g)?(e.consume(g),o):g===64?n(g):d(g)}function o(g){return g===43||g===45||g===46||ln(g)?(r=1,c(g)):d(g)}function c(g){return g===58?(e.consume(g),r=0,f):(g===43||g===45||g===46||ln(g))&&r++<32?(e.consume(g),c):(r=0,d(g))}function f(g){return g===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(g),e.exit("autolinkMarker"),e.exit("autolink"),t):g===null||g===32||g===60||Df(g)?n(g):(e.consume(g),f)}function d(g){return g===64?(e.consume(g),m):r4(g)?(e.consume(g),d):n(g)}function m(g){return ln(g)?p(g):n(g)}function p(g){return g===46?(e.consume(g),r=0,m):g===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(g),e.exit("autolinkMarker"),e.exit("autolink"),t):y(g)}function y(g){if((g===45||ln(g))&&r++<63){const x=g===45?y:p;return e.consume(g),x}return n(g)}}const gs={partial:!0,tokenize:p4};function p4(e,t,n){return r;function r(u){return Re(u)?He(e,a,"linePrefix")(u):a(u)}function a(u){return u===null||Ae(u)?t(u):n(u)}}const VC={continuation:{tokenize:y4},exit:g4,name:"blockQuote",tokenize:v4};function v4(e,t,n){const r=this;return a;function a(o){if(o===62){const c=r.containerState;return c.open||(e.enter("blockQuote",{_container:!0}),c.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(o),e.exit("blockQuoteMarker"),u}return n(o)}function u(o){return Re(o)?(e.enter("blockQuotePrefixWhitespace"),e.consume(o),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(o))}}function y4(e,t,n){const r=this;return a;function a(o){return Re(o)?He(e,u,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(o):u(o)}function u(o){return e.attempt(VC,t,n)(o)}}function g4(e){e.exit("blockQuote")}const YC={name:"characterEscape",tokenize:b4};function b4(e,t,n){return r;function r(u){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(u),e.exit("escapeMarker"),a}function a(u){return a4(u)?(e.enter("characterEscapeValue"),e.consume(u),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(u)}}const KC={name:"characterReference",tokenize:x4};function x4(e,t,n){const r=this;let a=0,u,o;return c;function c(p){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(p),e.exit("characterReferenceMarker"),f}function f(p){return p===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(p),e.exit("characterReferenceMarkerNumeric"),d):(e.enter("characterReferenceValue"),u=31,o=ln,m(p))}function d(p){return p===88||p===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(p),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),u=6,o=i4,m):(e.enter("characterReferenceValue"),u=7,o=tg,m(p))}function m(p){if(p===59&&a){const y=e.exit("characterReferenceValue");return o===ln&&!b0(r.sliceSerialize(y))?n(p):(e.enter("characterReferenceMarker"),e.consume(p),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return o(p)&&a++<u?(e.consume(p),m):n(p)}}const XO={partial:!0,tokenize:S4},ZO={concrete:!0,name:"codeFenced",tokenize:w4};function w4(e,t,n){const r=this,a={partial:!0,tokenize:N};let u=0,o=0,c;return f;function f(C){return d(C)}function d(C){const z=r.events[r.events.length-1];return u=z&&z[1].type==="linePrefix"?z[2].sliceSerialize(z[1],!0).length:0,c=C,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),m(C)}function m(C){return C===c?(o++,e.consume(C),m):o<3?n(C):(e.exit("codeFencedFenceSequence"),Re(C)?He(e,p,"whitespace")(C):p(C))}function p(C){return C===null||Ae(C)?(e.exit("codeFencedFence"),r.interrupt?t(C):e.check(XO,w,M)(C)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),y(C))}function y(C){return C===null||Ae(C)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),p(C)):Re(C)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),He(e,g,"whitespace")(C)):C===96&&C===c?n(C):(e.consume(C),y)}function g(C){return C===null||Ae(C)?p(C):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),x(C))}function x(C){return C===null||Ae(C)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),p(C)):C===96&&C===c?n(C):(e.consume(C),x)}function w(C){return e.attempt(a,M,S)(C)}function S(C){return e.enter("lineEnding"),e.consume(C),e.exit("lineEnding"),O}function O(C){return u>0&&Re(C)?He(e,_,"linePrefix",u+1)(C):_(C)}function _(C){return C===null||Ae(C)?e.check(XO,w,M)(C):(e.enter("codeFlowValue"),k(C))}function k(C){return C===null||Ae(C)?(e.exit("codeFlowValue"),_(C)):(e.consume(C),k)}function M(C){return e.exit("codeFenced"),t(C)}function N(C,z,$){let H=0;return P;function P(Y){return C.enter("lineEnding"),C.consume(Y),C.exit("lineEnding"),F}function F(Y){return C.enter("codeFencedFence"),Re(Y)?He(C,I,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(Y):I(Y)}function I(Y){return Y===c?(C.enter("codeFencedFenceSequence"),ee(Y)):$(Y)}function ee(Y){return Y===c?(H++,C.consume(Y),ee):H>=o?(C.exit("codeFencedFenceSequence"),Re(Y)?He(C,Z,"whitespace")(Y):Z(Y)):$(Y)}function Z(Y){return Y===null||Ae(Y)?(C.exit("codeFencedFence"),z(Y)):$(Y)}}}function S4(e,t,n){const r=this;return a;function a(o){return o===null?n(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),u)}function u(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}const ev={name:"codeIndented",tokenize:E4},O4={partial:!0,tokenize:A4};function E4(e,t,n){const r=this;return a;function a(d){return e.enter("codeIndented"),He(e,u,"linePrefix",5)(d)}function u(d){const m=r.events[r.events.length-1];return m&&m[1].type==="linePrefix"&&m[2].sliceSerialize(m[1],!0).length>=4?o(d):n(d)}function o(d){return d===null?f(d):Ae(d)?e.attempt(O4,o,f)(d):(e.enter("codeFlowValue"),c(d))}function c(d){return d===null||Ae(d)?(e.exit("codeFlowValue"),o(d)):(e.consume(d),c)}function f(d){return e.exit("codeIndented"),t(d)}}function A4(e,t,n){const r=this;return a;function a(o){return r.parser.lazy[r.now().line]?n(o):Ae(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),a):He(e,u,"linePrefix",5)(o)}function u(o){const c=r.events[r.events.length-1];return c&&c[1].type==="linePrefix"&&c[2].sliceSerialize(c[1],!0).length>=4?t(o):Ae(o)?a(o):n(o)}}const _4={name:"codeText",previous:C4,resolve:k4,tokenize:T4};function k4(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="codeTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function C4(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function T4(e,t,n){let r=0,a,u;return o;function o(p){return e.enter("codeText"),e.enter("codeTextSequence"),c(p)}function c(p){return p===96?(e.consume(p),r++,c):(e.exit("codeTextSequence"),f(p))}function f(p){return p===null?n(p):p===32?(e.enter("space"),e.consume(p),e.exit("space"),f):p===96?(u=e.enter("codeTextSequence"),a=0,m(p)):Ae(p)?(e.enter("lineEnding"),e.consume(p),e.exit("lineEnding"),f):(e.enter("codeTextData"),d(p))}function d(p){return p===null||p===32||p===96||Ae(p)?(e.exit("codeTextData"),f(p)):(e.consume(p),d)}function m(p){return p===96?(e.consume(p),a++,m):a===r?(e.exit("codeTextSequence"),e.exit("codeText"),t(p)):(u.type="codeTextData",d(p))}}class j4{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const r=n??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(t,r):t>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(t,n,r){const a=n||0;this.setCursor(Math.trunc(t));const u=this.right.splice(this.right.length-a,Number.POSITIVE_INFINITY);return r&&Po(this.left,r),u.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),Po(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),Po(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);Po(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);Po(this.left,n.reverse())}}}function Po(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function GC(e){const t={};let n=-1,r,a,u,o,c,f,d;const m=new j4(e);for(;++n<m.length;){for(;n in t;)n=t[n];if(r=m.get(n),n&&r[1].type==="chunkFlow"&&m.get(n-1)[1].type==="listItemPrefix"&&(f=r[1]._tokenizer.events,u=0,u<f.length&&f[u][1].type==="lineEndingBlank"&&(u+=2),u<f.length&&f[u][1].type==="content"))for(;++u<f.length&&f[u][1].type!=="content";)f[u][1].type==="chunkText"&&(f[u][1]._isInFirstContentOfListItem=!0,u++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,M4(m,n)),n=t[n],d=!0);else if(r[1]._container){for(u=n,a=void 0;u--;)if(o=m.get(u),o[1].type==="lineEnding"||o[1].type==="lineEndingBlank")o[0]==="enter"&&(a&&(m.get(a)[1].type="lineEndingBlank"),o[1].type="lineEnding",a=u);else if(!(o[1].type==="linePrefix"||o[1].type==="listItemIndent"))break;a&&(r[1].end={...m.get(a)[1].start},c=m.slice(a,n),c.unshift(r),m.splice(a,n-a+1,c))}}return Fn(e,0,Number.POSITIVE_INFINITY,m.slice(0)),!d}function M4(e,t){const n=e.get(t)[1],r=e.get(t)[2];let a=t-1;const u=[];let o=n._tokenizer;o||(o=r.parser[n.contentType](n.start),n._contentTypeTextTrailing&&(o._contentTypeTextTrailing=!0));const c=o.events,f=[],d={};let m,p,y=-1,g=n,x=0,w=0;const S=[w];for(;g;){for(;e.get(++a)[1]!==g;);u.push(a),g._tokenizer||(m=r.sliceStream(g),g.next||m.push(null),p&&o.defineSkip(g.start),g._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=!0),o.write(m),g._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=void 0)),p=g,g=g.next}for(g=n;++y<c.length;)c[y][0]==="exit"&&c[y-1][0]==="enter"&&c[y][1].type===c[y-1][1].type&&c[y][1].start.line!==c[y][1].end.line&&(w=y+1,S.push(w),g._tokenizer=void 0,g.previous=void 0,g=g.next);for(o.events=[],g?(g._tokenizer=void 0,g.previous=void 0):S.pop(),y=S.length;y--;){const O=c.slice(S[y],S[y+1]),_=u.pop();f.push([_,_+O.length-1]),e.splice(_,2,O)}for(f.reverse(),y=-1;++y<f.length;)d[x+f[y][0]]=x+f[y][1],x+=f[y][1]-f[y][0]-1;return d}const z4={resolve:N4,tokenize:P4},D4={partial:!0,tokenize:R4};function N4(e){return GC(e),e}function P4(e,t){let n;return r;function r(c){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),a(c)}function a(c){return c===null?u(c):Ae(c)?e.check(D4,o,u)(c):(e.consume(c),a)}function u(c){return e.exit("chunkContent"),e.exit("content"),t(c)}function o(c){return e.consume(c),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,a}}function R4(e,t,n){const r=this;return a;function a(o){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),He(e,u,"linePrefix")}function u(o){if(o===null||Ae(o))return n(o);const c=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&c&&c[1].type==="linePrefix"&&c[2].sliceSerialize(c[1],!0).length>=4?t(o):e.interrupt(r.parser.constructs.flow,n,t)(o)}}function XC(e,t,n,r,a,u,o,c,f){const d=f||Number.POSITIVE_INFINITY;let m=0;return p;function p(O){return O===60?(e.enter(r),e.enter(a),e.enter(u),e.consume(O),e.exit(u),y):O===null||O===32||O===41||Df(O)?n(O):(e.enter(r),e.enter(o),e.enter(c),e.enter("chunkString",{contentType:"string"}),w(O))}function y(O){return O===62?(e.enter(u),e.consume(O),e.exit(u),e.exit(a),e.exit(r),t):(e.enter(c),e.enter("chunkString",{contentType:"string"}),g(O))}function g(O){return O===62?(e.exit("chunkString"),e.exit(c),y(O)):O===null||O===60||Ae(O)?n(O):(e.consume(O),O===92?x:g)}function x(O){return O===60||O===62||O===92?(e.consume(O),g):g(O)}function w(O){return!m&&(O===null||O===41||it(O))?(e.exit("chunkString"),e.exit(c),e.exit(o),e.exit(r),t(O)):m<d&&O===40?(e.consume(O),m++,w):O===41?(e.consume(O),m--,w):O===null||O===32||O===40||Df(O)?n(O):(e.consume(O),O===92?S:w)}function S(O){return O===40||O===41||O===92?(e.consume(O),w):w(O)}}function ZC(e,t,n,r,a,u){const o=this;let c=0,f;return d;function d(g){return e.enter(r),e.enter(a),e.consume(g),e.exit(a),e.enter(u),m}function m(g){return c>999||g===null||g===91||g===93&&!f||g===94&&!c&&"_hiddenFootnoteSupport"in o.parser.constructs?n(g):g===93?(e.exit(u),e.enter(a),e.consume(g),e.exit(a),e.exit(r),t):Ae(g)?(e.enter("lineEnding"),e.consume(g),e.exit("lineEnding"),m):(e.enter("chunkString",{contentType:"string"}),p(g))}function p(g){return g===null||g===91||g===93||Ae(g)||c++>999?(e.exit("chunkString"),m(g)):(e.consume(g),f||(f=!Re(g)),g===92?y:p)}function y(g){return g===91||g===92||g===93?(e.consume(g),c++,p):p(g)}}function QC(e,t,n,r,a,u){let o;return c;function c(y){return y===34||y===39||y===40?(e.enter(r),e.enter(a),e.consume(y),e.exit(a),o=y===40?41:y,f):n(y)}function f(y){return y===o?(e.enter(a),e.consume(y),e.exit(a),e.exit(r),t):(e.enter(u),d(y))}function d(y){return y===o?(e.exit(u),f(o)):y===null?n(y):Ae(y)?(e.enter("lineEnding"),e.consume(y),e.exit("lineEnding"),He(e,d,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),m(y))}function m(y){return y===o||y===null||Ae(y)?(e.exit("chunkString"),d(y)):(e.consume(y),y===92?p:m)}function p(y){return y===o||y===92?(e.consume(y),m):m(y)}}function Zo(e,t){let n;return r;function r(a){return Ae(a)?(e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),n=!0,r):Re(a)?He(e,r,n?"linePrefix":"lineSuffix")(a):t(a)}}const I4={name:"definition",tokenize:B4},L4={partial:!0,tokenize:U4};function B4(e,t,n){const r=this;let a;return u;function u(g){return e.enter("definition"),o(g)}function o(g){return ZC.call(r,e,c,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(g)}function c(g){return a=Ar(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),g===58?(e.enter("definitionMarker"),e.consume(g),e.exit("definitionMarker"),f):n(g)}function f(g){return it(g)?Zo(e,d)(g):d(g)}function d(g){return XC(e,m,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(g)}function m(g){return e.attempt(L4,p,p)(g)}function p(g){return Re(g)?He(e,y,"whitespace")(g):y(g)}function y(g){return g===null||Ae(g)?(e.exit("definition"),r.parser.defined.push(a),t(g)):n(g)}}function U4(e,t,n){return r;function r(c){return it(c)?Zo(e,a)(c):n(c)}function a(c){return QC(e,u,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(c)}function u(c){return Re(c)?He(e,o,"whitespace")(c):o(c)}function o(c){return c===null||Ae(c)?t(c):n(c)}}const q4={name:"hardBreakEscape",tokenize:H4};function H4(e,t,n){return r;function r(u){return e.enter("hardBreakEscape"),e.consume(u),a}function a(u){return Ae(u)?(e.exit("hardBreakEscape"),t(u)):n(u)}}const $4={name:"headingAtx",resolve:F4,tokenize:V4};function F4(e,t){let n=e.length-2,r=3,a,u;return e[r][1].type==="whitespace"&&(r+=2),n-2>r&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(r===n-1||n-4>r&&e[n-2][1].type==="whitespace")&&(n-=r+1===n?2:4),n>r&&(a={type:"atxHeadingText",start:e[r][1].start,end:e[n][1].end},u={type:"chunkText",start:e[r][1].start,end:e[n][1].end,contentType:"text"},Fn(e,r,n-r+1,[["enter",a,t],["enter",u,t],["exit",u,t],["exit",a,t]])),e}function V4(e,t,n){let r=0;return a;function a(m){return e.enter("atxHeading"),u(m)}function u(m){return e.enter("atxHeadingSequence"),o(m)}function o(m){return m===35&&r++<6?(e.consume(m),o):m===null||it(m)?(e.exit("atxHeadingSequence"),c(m)):n(m)}function c(m){return m===35?(e.enter("atxHeadingSequence"),f(m)):m===null||Ae(m)?(e.exit("atxHeading"),t(m)):Re(m)?He(e,c,"whitespace")(m):(e.enter("atxHeadingText"),d(m))}function f(m){return m===35?(e.consume(m),f):(e.exit("atxHeadingSequence"),c(m))}function d(m){return m===null||m===35||it(m)?(e.exit("atxHeadingText"),c(m)):(e.consume(m),d)}}const Y4=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],QO=["pre","script","style","textarea"],K4={concrete:!0,name:"htmlFlow",resolveTo:Z4,tokenize:Q4},G4={partial:!0,tokenize:J4},X4={partial:!0,tokenize:W4};function Z4(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function Q4(e,t,n){const r=this;let a,u,o,c,f;return d;function d(D){return m(D)}function m(D){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(D),p}function p(D){return D===33?(e.consume(D),y):D===47?(e.consume(D),u=!0,w):D===63?(e.consume(D),a=3,r.interrupt?t:R):dn(D)?(e.consume(D),o=String.fromCharCode(D),S):n(D)}function y(D){return D===45?(e.consume(D),a=2,g):D===91?(e.consume(D),a=5,c=0,x):dn(D)?(e.consume(D),a=4,r.interrupt?t:R):n(D)}function g(D){return D===45?(e.consume(D),r.interrupt?t:R):n(D)}function x(D){const oe="CDATA[";return D===oe.charCodeAt(c++)?(e.consume(D),c===oe.length?r.interrupt?t:I:x):n(D)}function w(D){return dn(D)?(e.consume(D),o=String.fromCharCode(D),S):n(D)}function S(D){if(D===null||D===47||D===62||it(D)){const oe=D===47,ye=o.toLowerCase();return!oe&&!u&&QO.includes(ye)?(a=1,r.interrupt?t(D):I(D)):Y4.includes(o.toLowerCase())?(a=6,oe?(e.consume(D),O):r.interrupt?t(D):I(D)):(a=7,r.interrupt&&!r.parser.lazy[r.now().line]?n(D):u?_(D):k(D))}return D===45||ln(D)?(e.consume(D),o+=String.fromCharCode(D),S):n(D)}function O(D){return D===62?(e.consume(D),r.interrupt?t:I):n(D)}function _(D){return Re(D)?(e.consume(D),_):P(D)}function k(D){return D===47?(e.consume(D),P):D===58||D===95||dn(D)?(e.consume(D),M):Re(D)?(e.consume(D),k):P(D)}function M(D){return D===45||D===46||D===58||D===95||ln(D)?(e.consume(D),M):N(D)}function N(D){return D===61?(e.consume(D),C):Re(D)?(e.consume(D),N):k(D)}function C(D){return D===null||D===60||D===61||D===62||D===96?n(D):D===34||D===39?(e.consume(D),f=D,z):Re(D)?(e.consume(D),C):$(D)}function z(D){return D===f?(e.consume(D),f=null,H):D===null||Ae(D)?n(D):(e.consume(D),z)}function $(D){return D===null||D===34||D===39||D===47||D===60||D===61||D===62||D===96||it(D)?N(D):(e.consume(D),$)}function H(D){return D===47||D===62||Re(D)?k(D):n(D)}function P(D){return D===62?(e.consume(D),F):n(D)}function F(D){return D===null||Ae(D)?I(D):Re(D)?(e.consume(D),F):n(D)}function I(D){return D===45&&a===2?(e.consume(D),U):D===60&&a===1?(e.consume(D),Q):D===62&&a===4?(e.consume(D),L):D===63&&a===3?(e.consume(D),R):D===93&&a===5?(e.consume(D),de):Ae(D)&&(a===6||a===7)?(e.exit("htmlFlowData"),e.check(G4,J,ee)(D)):D===null||Ae(D)?(e.exit("htmlFlowData"),ee(D)):(e.consume(D),I)}function ee(D){return e.check(X4,Z,J)(D)}function Z(D){return e.enter("lineEnding"),e.consume(D),e.exit("lineEnding"),Y}function Y(D){return D===null||Ae(D)?ee(D):(e.enter("htmlFlowData"),I(D))}function U(D){return D===45?(e.consume(D),R):I(D)}function Q(D){return D===47?(e.consume(D),o="",ue):I(D)}function ue(D){if(D===62){const oe=o.toLowerCase();return QO.includes(oe)?(e.consume(D),L):I(D)}return dn(D)&&o.length<8?(e.consume(D),o+=String.fromCharCode(D),ue):I(D)}function de(D){return D===93?(e.consume(D),R):I(D)}function R(D){return D===62?(e.consume(D),L):D===45&&a===2?(e.consume(D),R):I(D)}function L(D){return D===null||Ae(D)?(e.exit("htmlFlowData"),J(D)):(e.consume(D),L)}function J(D){return e.exit("htmlFlow"),t(D)}}function W4(e,t,n){const r=this;return a;function a(o){return Ae(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),u):n(o)}function u(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}function J4(e,t,n){return r;function r(a){return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),e.attempt(gs,t,n)}}const eL={name:"htmlText",tokenize:tL};function tL(e,t,n){const r=this;let a,u,o;return c;function c(R){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(R),f}function f(R){return R===33?(e.consume(R),d):R===47?(e.consume(R),N):R===63?(e.consume(R),k):dn(R)?(e.consume(R),$):n(R)}function d(R){return R===45?(e.consume(R),m):R===91?(e.consume(R),u=0,x):dn(R)?(e.consume(R),_):n(R)}function m(R){return R===45?(e.consume(R),g):n(R)}function p(R){return R===null?n(R):R===45?(e.consume(R),y):Ae(R)?(o=p,Q(R)):(e.consume(R),p)}function y(R){return R===45?(e.consume(R),g):p(R)}function g(R){return R===62?U(R):R===45?y(R):p(R)}function x(R){const L="CDATA[";return R===L.charCodeAt(u++)?(e.consume(R),u===L.length?w:x):n(R)}function w(R){return R===null?n(R):R===93?(e.consume(R),S):Ae(R)?(o=w,Q(R)):(e.consume(R),w)}function S(R){return R===93?(e.consume(R),O):w(R)}function O(R){return R===62?U(R):R===93?(e.consume(R),O):w(R)}function _(R){return R===null||R===62?U(R):Ae(R)?(o=_,Q(R)):(e.consume(R),_)}function k(R){return R===null?n(R):R===63?(e.consume(R),M):Ae(R)?(o=k,Q(R)):(e.consume(R),k)}function M(R){return R===62?U(R):k(R)}function N(R){return dn(R)?(e.consume(R),C):n(R)}function C(R){return R===45||ln(R)?(e.consume(R),C):z(R)}function z(R){return Ae(R)?(o=z,Q(R)):Re(R)?(e.consume(R),z):U(R)}function $(R){return R===45||ln(R)?(e.consume(R),$):R===47||R===62||it(R)?H(R):n(R)}function H(R){return R===47?(e.consume(R),U):R===58||R===95||dn(R)?(e.consume(R),P):Ae(R)?(o=H,Q(R)):Re(R)?(e.consume(R),H):U(R)}function P(R){return R===45||R===46||R===58||R===95||ln(R)?(e.consume(R),P):F(R)}function F(R){return R===61?(e.consume(R),I):Ae(R)?(o=F,Q(R)):Re(R)?(e.consume(R),F):H(R)}function I(R){return R===null||R===60||R===61||R===62||R===96?n(R):R===34||R===39?(e.consume(R),a=R,ee):Ae(R)?(o=I,Q(R)):Re(R)?(e.consume(R),I):(e.consume(R),Z)}function ee(R){return R===a?(e.consume(R),a=void 0,Y):R===null?n(R):Ae(R)?(o=ee,Q(R)):(e.consume(R),ee)}function Z(R){return R===null||R===34||R===39||R===60||R===61||R===96?n(R):R===47||R===62||it(R)?H(R):(e.consume(R),Z)}function Y(R){return R===47||R===62||it(R)?H(R):n(R)}function U(R){return R===62?(e.consume(R),e.exit("htmlTextData"),e.exit("htmlText"),t):n(R)}function Q(R){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(R),e.exit("lineEnding"),ue}function ue(R){return Re(R)?He(e,de,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(R):de(R)}function de(R){return e.enter("htmlTextData"),o(R)}}const x0={name:"labelEnd",resolveAll:aL,resolveTo:lL,tokenize:uL},nL={tokenize:oL},rL={tokenize:sL},iL={tokenize:cL};function aL(e){let t=-1;const n=[];for(;++t<e.length;){const r=e[t][1];if(n.push(e[t]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const a=r.type==="labelImage"?4:2;r.type="data",t+=a}}return e.length!==n.length&&Fn(e,0,e.length,n),e}function lL(e,t){let n=e.length,r=0,a,u,o,c;for(;n--;)if(a=e[n][1],u){if(a.type==="link"||a.type==="labelLink"&&a._inactive)break;e[n][0]==="enter"&&a.type==="labelLink"&&(a._inactive=!0)}else if(o){if(e[n][0]==="enter"&&(a.type==="labelImage"||a.type==="labelLink")&&!a._balanced&&(u=n,a.type!=="labelLink")){r=2;break}}else a.type==="labelEnd"&&(o=n);const f={type:e[u][1].type==="labelLink"?"link":"image",start:{...e[u][1].start},end:{...e[e.length-1][1].end}},d={type:"label",start:{...e[u][1].start},end:{...e[o][1].end}},m={type:"labelText",start:{...e[u+r+2][1].end},end:{...e[o-2][1].start}};return c=[["enter",f,t],["enter",d,t]],c=fr(c,e.slice(u+1,u+r+3)),c=fr(c,[["enter",m,t]]),c=fr(c,Md(t.parser.constructs.insideSpan.null,e.slice(u+r+4,o-3),t)),c=fr(c,[["exit",m,t],e[o-2],e[o-1],["exit",d,t]]),c=fr(c,e.slice(o+1)),c=fr(c,[["exit",f,t]]),Fn(e,u,e.length,c),e}function uL(e,t,n){const r=this;let a=r.events.length,u,o;for(;a--;)if((r.events[a][1].type==="labelImage"||r.events[a][1].type==="labelLink")&&!r.events[a][1]._balanced){u=r.events[a][1];break}return c;function c(y){return u?u._inactive?p(y):(o=r.parser.defined.includes(Ar(r.sliceSerialize({start:u.end,end:r.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(y),e.exit("labelMarker"),e.exit("labelEnd"),f):n(y)}function f(y){return y===40?e.attempt(nL,m,o?m:p)(y):y===91?e.attempt(rL,m,o?d:p)(y):o?m(y):p(y)}function d(y){return e.attempt(iL,m,p)(y)}function m(y){return t(y)}function p(y){return u._balanced=!0,n(y)}}function oL(e,t,n){return r;function r(p){return e.enter("resource"),e.enter("resourceMarker"),e.consume(p),e.exit("resourceMarker"),a}function a(p){return it(p)?Zo(e,u)(p):u(p)}function u(p){return p===41?m(p):XC(e,o,c,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(p)}function o(p){return it(p)?Zo(e,f)(p):m(p)}function c(p){return n(p)}function f(p){return p===34||p===39||p===40?QC(e,d,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(p):m(p)}function d(p){return it(p)?Zo(e,m)(p):m(p)}function m(p){return p===41?(e.enter("resourceMarker"),e.consume(p),e.exit("resourceMarker"),e.exit("resource"),t):n(p)}}function sL(e,t,n){const r=this;return a;function a(c){return ZC.call(r,e,u,o,"reference","referenceMarker","referenceString")(c)}function u(c){return r.parser.defined.includes(Ar(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(c):n(c)}function o(c){return n(c)}}function cL(e,t,n){return r;function r(u){return e.enter("reference"),e.enter("referenceMarker"),e.consume(u),e.exit("referenceMarker"),a}function a(u){return u===93?(e.enter("referenceMarker"),e.consume(u),e.exit("referenceMarker"),e.exit("reference"),t):n(u)}}const fL={name:"labelStartImage",resolveAll:x0.resolveAll,tokenize:dL};function dL(e,t,n){const r=this;return a;function a(c){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(c),e.exit("labelImageMarker"),u}function u(c){return c===91?(e.enter("labelMarker"),e.consume(c),e.exit("labelMarker"),e.exit("labelImage"),o):n(c)}function o(c){return c===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(c):t(c)}}const hL={name:"labelStartLink",resolveAll:x0.resolveAll,tokenize:mL};function mL(e,t,n){const r=this;return a;function a(o){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(o),e.exit("labelMarker"),e.exit("labelLink"),u}function u(o){return o===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(o):t(o)}}const tv={name:"lineEnding",tokenize:pL};function pL(e,t){return n;function n(r){return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),He(e,t,"linePrefix")}}const Af={name:"thematicBreak",tokenize:vL};function vL(e,t,n){let r=0,a;return u;function u(d){return e.enter("thematicBreak"),o(d)}function o(d){return a=d,c(d)}function c(d){return d===a?(e.enter("thematicBreakSequence"),f(d)):r>=3&&(d===null||Ae(d))?(e.exit("thematicBreak"),t(d)):n(d)}function f(d){return d===a?(e.consume(d),r++,f):(e.exit("thematicBreakSequence"),Re(d)?He(e,c,"whitespace")(d):c(d))}}const An={continuation:{tokenize:xL},exit:SL,name:"list",tokenize:bL},yL={partial:!0,tokenize:OL},gL={partial:!0,tokenize:wL};function bL(e,t,n){const r=this,a=r.events[r.events.length-1];let u=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0,o=0;return c;function c(g){const x=r.containerState.type||(g===42||g===43||g===45?"listUnordered":"listOrdered");if(x==="listUnordered"?!r.containerState.marker||g===r.containerState.marker:tg(g)){if(r.containerState.type||(r.containerState.type=x,e.enter(x,{_container:!0})),x==="listUnordered")return e.enter("listItemPrefix"),g===42||g===45?e.check(Af,n,d)(g):d(g);if(!r.interrupt||g===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),f(g)}return n(g)}function f(g){return tg(g)&&++o<10?(e.consume(g),f):(!r.interrupt||o<2)&&(r.containerState.marker?g===r.containerState.marker:g===41||g===46)?(e.exit("listItemValue"),d(g)):n(g)}function d(g){return e.enter("listItemMarker"),e.consume(g),e.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||g,e.check(gs,r.interrupt?n:m,e.attempt(yL,y,p))}function m(g){return r.containerState.initialBlankLine=!0,u++,y(g)}function p(g){return Re(g)?(e.enter("listItemPrefixWhitespace"),e.consume(g),e.exit("listItemPrefixWhitespace"),y):n(g)}function y(g){return r.containerState.size=u+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(g)}}function xL(e,t,n){const r=this;return r.containerState._closeFlow=void 0,e.check(gs,a,u);function a(c){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,He(e,t,"listItemIndent",r.containerState.size+1)(c)}function u(c){return r.containerState.furtherBlankLines||!Re(c)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,o(c)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,e.attempt(gL,t,o)(c))}function o(c){return r.containerState._closeFlow=!0,r.interrupt=void 0,He(e,e.attempt(An,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(c)}}function wL(e,t,n){const r=this;return He(e,a,"listItemIndent",r.containerState.size+1);function a(u){const o=r.events[r.events.length-1];return o&&o[1].type==="listItemIndent"&&o[2].sliceSerialize(o[1],!0).length===r.containerState.size?t(u):n(u)}}function SL(e){e.exit(this.containerState.type)}function OL(e,t,n){const r=this;return He(e,a,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function a(u){const o=r.events[r.events.length-1];return!Re(u)&&o&&o[1].type==="listItemPrefixWhitespace"?t(u):n(u)}}const WO={name:"setextUnderline",resolveTo:EL,tokenize:AL};function EL(e,t){let n=e.length,r,a,u;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){r=n;break}e[n][1].type==="paragraph"&&(a=n)}else e[n][1].type==="content"&&e.splice(n,1),!u&&e[n][1].type==="definition"&&(u=n);const o={type:"setextHeading",start:{...e[r][1].start},end:{...e[e.length-1][1].end}};return e[a][1].type="setextHeadingText",u?(e.splice(a,0,["enter",o,t]),e.splice(u+1,0,["exit",e[r][1],t]),e[r][1].end={...e[u][1].end}):e[r][1]=o,e.push(["exit",o,t]),e}function AL(e,t,n){const r=this;let a;return u;function u(d){let m=r.events.length,p;for(;m--;)if(r.events[m][1].type!=="lineEnding"&&r.events[m][1].type!=="linePrefix"&&r.events[m][1].type!=="content"){p=r.events[m][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||p)?(e.enter("setextHeadingLine"),a=d,o(d)):n(d)}function o(d){return e.enter("setextHeadingLineSequence"),c(d)}function c(d){return d===a?(e.consume(d),c):(e.exit("setextHeadingLineSequence"),Re(d)?He(e,f,"lineSuffix")(d):f(d))}function f(d){return d===null||Ae(d)?(e.exit("setextHeadingLine"),t(d)):n(d)}}const _L={tokenize:kL};function kL(e){const t=this,n=e.attempt(gs,r,e.attempt(this.parser.constructs.flowInitial,a,He(e,e.attempt(this.parser.constructs.flow,a,e.attempt(z4,a)),"linePrefix")));return n;function r(u){if(u===null){e.consume(u);return}return e.enter("lineEndingBlank"),e.consume(u),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function a(u){if(u===null){e.consume(u);return}return e.enter("lineEnding"),e.consume(u),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const CL={resolveAll:JC()},TL=WC("string"),jL=WC("text");function WC(e){return{resolveAll:JC(e==="text"?ML:void 0),tokenize:t};function t(n){const r=this,a=this.parser.constructs[e],u=n.attempt(a,o,c);return o;function o(m){return d(m)?u(m):c(m)}function c(m){if(m===null){n.consume(m);return}return n.enter("data"),n.consume(m),f}function f(m){return d(m)?(n.exit("data"),u(m)):(n.consume(m),f)}function d(m){if(m===null)return!0;const p=a[m];let y=-1;if(p)for(;++y<p.length;){const g=p[y];if(!g.previous||g.previous.call(r,r.previous))return!0}return!1}}}function JC(e){return t;function t(n,r){let a=-1,u;for(;++a<=n.length;)u===void 0?n[a]&&n[a][1].type==="data"&&(u=a,a++):(!n[a]||n[a][1].type!=="data")&&(a!==u+2&&(n[u][1].end=n[a-1][1].end,n.splice(u+2,a-u-2),a=u+2),u=void 0);return e?e(n,r):n}}function ML(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],a=t.sliceStream(r);let u=a.length,o=-1,c=0,f;for(;u--;){const d=a[u];if(typeof d=="string"){for(o=d.length;d.charCodeAt(o-1)===32;)c++,o--;if(o)break;o=-1}else if(d===-2)f=!0,c++;else if(d!==-1){u++;break}}if(t._contentTypeTextTrailing&&n===e.length&&(c=0),c){const d={type:n===e.length||f||c<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:u?o:r.start._bufferIndex+o,_index:r.start._index+u,line:r.end.line,column:r.end.column-c,offset:r.end.offset-c},end:{...r.end}};r.end={...d.start},r.start.offset===r.end.offset?Object.assign(r,d):(e.splice(n,0,["enter",d,t],["exit",d,t]),n+=2)}n++}return e}const zL={42:An,43:An,45:An,48:An,49:An,50:An,51:An,52:An,53:An,54:An,55:An,56:An,57:An,62:VC},DL={91:I4},NL={[-2]:ev,[-1]:ev,32:ev},PL={35:$4,42:Af,45:[WO,Af],60:K4,61:WO,95:Af,96:ZO,126:ZO},RL={38:KC,92:YC},IL={[-5]:tv,[-4]:tv,[-3]:tv,33:fL,38:KC,42:ng,60:[h4,eL],91:hL,92:[q4,YC],93:x0,95:ng,96:_4},LL={null:[ng,CL]},BL={null:[42,95]},UL={null:[]},qL=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:BL,contentInitial:DL,disable:UL,document:zL,flow:PL,flowInitial:NL,insideSpan:LL,string:RL,text:IL},Symbol.toStringTag,{value:"Module"}));function HL(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const a={},u=[];let o=[],c=[];const f={attempt:z(N),check:z(C),consume:_,enter:k,exit:M,interrupt:z(C,{interrupt:!0})},d={code:null,containerState:{},defineSkip:w,events:[],now:x,parser:e,previous:null,sliceSerialize:y,sliceStream:g,write:p};let m=t.tokenize.call(d,f);return t.resolveAll&&u.push(t),d;function p(F){return o=fr(o,F),S(),o[o.length-1]!==null?[]:($(t,0),d.events=Md(u,d.events,d),d.events)}function y(F,I){return FL(g(F),I)}function g(F){return $L(o,F)}function x(){const{_bufferIndex:F,_index:I,line:ee,column:Z,offset:Y}=r;return{_bufferIndex:F,_index:I,line:ee,column:Z,offset:Y}}function w(F){a[F.line]=F.column,P()}function S(){let F;for(;r._index<o.length;){const I=o[r._index];if(typeof I=="string")for(F=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===F&&r._bufferIndex<I.length;)O(I.charCodeAt(r._bufferIndex));else O(I)}}function O(F){m=m(F)}function _(F){Ae(F)?(r.line++,r.column=1,r.offset+=F===-3?2:1,P()):F!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===o[r._index].length&&(r._bufferIndex=-1,r._index++)),d.previous=F}function k(F,I){const ee=I||{};return ee.type=F,ee.start=x(),d.events.push(["enter",ee,d]),c.push(ee),ee}function M(F){const I=c.pop();return I.end=x(),d.events.push(["exit",I,d]),I}function N(F,I){$(F,I.from)}function C(F,I){I.restore()}function z(F,I){return ee;function ee(Z,Y,U){let Q,ue,de,R;return Array.isArray(Z)?J(Z):"tokenize"in Z?J([Z]):L(Z);function L(ve){return Se;function Se(ge){const K=ge!==null&&ve[ge],he=ge!==null&&ve.null,be=[...Array.isArray(K)?K:K?[K]:[],...Array.isArray(he)?he:he?[he]:[]];return J(be)(ge)}}function J(ve){return Q=ve,ue=0,ve.length===0?U:D(ve[ue])}function D(ve){return Se;function Se(ge){return R=H(),de=ve,ve.partial||(d.currentConstruct=ve),ve.name&&d.parser.constructs.disable.null.includes(ve.name)?ye():ve.tokenize.call(I?Object.assign(Object.create(d),I):d,f,oe,ye)(ge)}}function oe(ve){return F(de,R),Y}function ye(ve){return R.restore(),++ue<Q.length?D(Q[ue]):U}}}function $(F,I){F.resolveAll&&!u.includes(F)&&u.push(F),F.resolve&&Fn(d.events,I,d.events.length-I,F.resolve(d.events.slice(I),d)),F.resolveTo&&(d.events=F.resolveTo(d.events,d))}function H(){const F=x(),I=d.previous,ee=d.currentConstruct,Z=d.events.length,Y=Array.from(c);return{from:Z,restore:U};function U(){r=F,d.previous=I,d.currentConstruct=ee,d.events.length=Z,c=Y,P()}}function P(){r.line in a&&r.column<2&&(r.column=a[r.line],r.offset+=a[r.line]-1)}}function $L(e,t){const n=t.start._index,r=t.start._bufferIndex,a=t.end._index,u=t.end._bufferIndex;let o;if(n===a)o=[e[n].slice(r,u)];else{if(o=e.slice(n,a),r>-1){const c=o[0];typeof c=="string"?o[0]=c.slice(r):o.shift()}u>0&&o.push(e[a].slice(0,u))}return o}function FL(e,t){let n=-1;const r=[];let a;for(;++n<e.length;){const u=e[n];let o;if(typeof u=="string")o=u;else switch(u){case-5:{o="\r";break}case-4:{o=`
`;break}case-3:{o=`\r
`;break}case-2:{o=t?" ":"	";break}case-1:{if(!t&&a)continue;o=" ";break}default:o=String.fromCharCode(u)}a=u===-2,r.push(o)}return r.join("")}function VL(e){const r={constructs:$C([qL,...(e||{}).extensions||[]]),content:a(l4),defined:[],document:a(o4),flow:a(_L),lazy:{},string:a(TL),text:a(jL)};return r;function a(u){return o;function o(c){return HL(r,u,c)}}}function YL(e){for(;!GC(e););return e}const JO=/[\0\t\n\r]/g;function KL(){let e=1,t="",n=!0,r;return a;function a(u,o,c){const f=[];let d,m,p,y,g;for(u=t+(typeof u=="string"?u.toString():new TextDecoder(o||void 0).decode(u)),p=0,t="",n&&(u.charCodeAt(0)===65279&&p++,n=void 0);p<u.length;){if(JO.lastIndex=p,d=JO.exec(u),y=d&&d.index!==void 0?d.index:u.length,g=u.charCodeAt(y),!d){t=u.slice(p);break}if(g===10&&p===y&&r)f.push(-3),r=void 0;else switch(r&&(f.push(-5),r=void 0),p<y&&(f.push(u.slice(p,y)),e+=y-p),g){case 0:{f.push(65533),e++;break}case 9:{for(m=Math.ceil(e/4)*4,f.push(-2);e++<m;)f.push(-1);break}case 10:{f.push(-4),e=1;break}default:r=!0,e=1}p=y+1}return c&&(r&&f.push(-5),t&&f.push(t),f.push(null)),f}}const GL=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function XL(e){return e.replace(GL,ZL)}function ZL(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const a=n.charCodeAt(1),u=a===120||a===88;return FC(n.slice(u?2:1),u?16:10)}return b0(n)||e}const eT={}.hasOwnProperty;function QL(e,t,n){return typeof t!="string"&&(n=t,t=void 0),WL(n)(YL(VL(n).document().write(KL()(e,t,!0))))}function WL(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:u(sl),autolinkProtocol:H,autolinkEmail:H,atxHeading:u(St),blockQuote:u(he),characterEscape:H,characterReference:H,codeFenced:u(be),codeFencedFenceInfo:o,codeFencedFenceMeta:o,codeIndented:u(be,o),codeText:u(se,o),codeTextData:H,data:H,codeFlowValue:H,definition:u(jt),definitionDestinationString:o,definitionLabelString:o,definitionTitleString:o,emphasis:u(Ie),hardBreakEscape:u(Ot),hardBreakTrailing:u(Ot),htmlFlow:u(Gn,o),htmlFlowData:H,htmlText:u(Gn,o),htmlTextData:H,image:u(ba),label:o,link:u(sl),listItem:u(Ru),listItemValue:y,listOrdered:u(cl,p),listUnordered:u(cl),paragraph:u(Sh),reference:D,referenceString:o,resourceDestinationString:o,resourceTitleString:o,setextHeading:u(St),strong:u(Oh),thematicBreak:u(Eh)},exit:{atxHeading:f(),atxHeadingSequence:N,autolink:f(),autolinkEmail:K,autolinkProtocol:ge,blockQuote:f(),characterEscapeValue:P,characterReferenceMarkerHexadecimal:ye,characterReferenceMarkerNumeric:ye,characterReferenceValue:ve,characterReference:Se,codeFenced:f(S),codeFencedFence:w,codeFencedFenceInfo:g,codeFencedFenceMeta:x,codeFlowValue:P,codeIndented:f(O),codeText:f(Y),codeTextData:P,data:P,definition:f(),definitionDestinationString:M,definitionLabelString:_,definitionTitleString:k,emphasis:f(),hardBreakEscape:f(I),hardBreakTrailing:f(I),htmlFlow:f(ee),htmlFlowData:P,htmlText:f(Z),htmlTextData:P,image:f(Q),label:de,labelText:ue,lineEnding:F,link:f(U),listItem:f(),listOrdered:f(),listUnordered:f(),paragraph:f(),referenceString:oe,resourceDestinationString:R,resourceTitleString:L,resource:J,setextHeading:f($),setextHeadingLineSequence:z,setextHeadingText:C,strong:f(),thematicBreak:f()}};tT(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(ie){let fe={type:"root",children:[]};const ke={stack:[fe],tokenStack:[],config:t,enter:c,exit:d,buffer:o,resume:m,data:n},De=[];let Ke=-1;for(;++Ke<ie.length;)if(ie[Ke][1].type==="listOrdered"||ie[Ke][1].type==="listUnordered")if(ie[Ke][0]==="enter")De.push(Ke);else{const zn=De.pop();Ke=a(ie,zn,Ke)}for(Ke=-1;++Ke<ie.length;){const zn=t[ie[Ke][0]];eT.call(zn,ie[Ke][1].type)&&zn[ie[Ke][1].type].call(Object.assign({sliceSerialize:ie[Ke][2].sliceSerialize},ke),ie[Ke][1])}if(ke.tokenStack.length>0){const zn=ke.tokenStack[ke.tokenStack.length-1];(zn[1]||eE).call(ke,void 0,zn[0])}for(fe.position={start:oa(ie.length>0?ie[0][1].start:{line:1,column:1,offset:0}),end:oa(ie.length>0?ie[ie.length-2][1].end:{line:1,column:1,offset:0})},Ke=-1;++Ke<t.transforms.length;)fe=t.transforms[Ke](fe)||fe;return fe}function a(ie,fe,ke){let De=fe-1,Ke=-1,zn=!1,Gr,sn,Mt,yn;for(;++De<=ke;){const tt=ie[De];switch(tt[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{tt[0]==="enter"?Ke++:Ke--,yn=void 0;break}case"lineEndingBlank":{tt[0]==="enter"&&(Gr&&!yn&&!Ke&&!Mt&&(Mt=De),yn=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:yn=void 0}if(!Ke&&tt[0]==="enter"&&tt[1].type==="listItemPrefix"||Ke===-1&&tt[0]==="exit"&&(tt[1].type==="listUnordered"||tt[1].type==="listOrdered")){if(Gr){let Ii=De;for(sn=void 0;Ii--;){const yr=ie[Ii];if(yr[1].type==="lineEnding"||yr[1].type==="lineEndingBlank"){if(yr[0]==="exit")continue;sn&&(ie[sn][1].type="lineEndingBlank",zn=!0),yr[1].type="lineEnding",sn=Ii}else if(!(yr[1].type==="linePrefix"||yr[1].type==="blockQuotePrefix"||yr[1].type==="blockQuotePrefixWhitespace"||yr[1].type==="blockQuoteMarker"||yr[1].type==="listItemIndent"))break}Mt&&(!sn||Mt<sn)&&(Gr._spread=!0),Gr.end=Object.assign({},sn?ie[sn][1].start:tt[1].end),ie.splice(sn||De,0,["exit",Gr,tt[2]]),De++,ke++}if(tt[1].type==="listItemPrefix"){const Ii={type:"listItem",_spread:!1,start:Object.assign({},tt[1].start),end:void 0};Gr=Ii,ie.splice(De,0,["enter",Ii,tt[2]]),De++,ke++,Mt=void 0,yn=!0}}}return ie[fe][1]._spread=zn,ke}function u(ie,fe){return ke;function ke(De){c.call(this,ie(De),De),fe&&fe.call(this,De)}}function o(){this.stack.push({type:"fragment",children:[]})}function c(ie,fe,ke){this.stack[this.stack.length-1].children.push(ie),this.stack.push(ie),this.tokenStack.push([fe,ke||void 0]),ie.position={start:oa(fe.start),end:void 0}}function f(ie){return fe;function fe(ke){ie&&ie.call(this,ke),d.call(this,ke)}}function d(ie,fe){const ke=this.stack.pop(),De=this.tokenStack.pop();if(De)De[0].type!==ie.type&&(fe?fe.call(this,ie,De[0]):(De[1]||eE).call(this,ie,De[0]));else throw new Error("Cannot close `"+ie.type+"` ("+Xo({start:ie.start,end:ie.end})+"): it’s not open");ke.position.end=oa(ie.end)}function m(){return g0(this.stack.pop())}function p(){this.data.expectingFirstListItemValue=!0}function y(ie){if(this.data.expectingFirstListItemValue){const fe=this.stack[this.stack.length-2];fe.start=Number.parseInt(this.sliceSerialize(ie),10),this.data.expectingFirstListItemValue=void 0}}function g(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.lang=ie}function x(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.meta=ie}function w(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function S(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.value=ie.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function O(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.value=ie.replace(/(\r?\n|\r)$/g,"")}function _(ie){const fe=this.resume(),ke=this.stack[this.stack.length-1];ke.label=fe,ke.identifier=Ar(this.sliceSerialize(ie)).toLowerCase()}function k(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.title=ie}function M(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.url=ie}function N(ie){const fe=this.stack[this.stack.length-1];if(!fe.depth){const ke=this.sliceSerialize(ie).length;fe.depth=ke}}function C(){this.data.setextHeadingSlurpLineEnding=!0}function z(ie){const fe=this.stack[this.stack.length-1];fe.depth=this.sliceSerialize(ie).codePointAt(0)===61?1:2}function $(){this.data.setextHeadingSlurpLineEnding=void 0}function H(ie){const ke=this.stack[this.stack.length-1].children;let De=ke[ke.length-1];(!De||De.type!=="text")&&(De=on(),De.position={start:oa(ie.start),end:void 0},ke.push(De)),this.stack.push(De)}function P(ie){const fe=this.stack.pop();fe.value+=this.sliceSerialize(ie),fe.position.end=oa(ie.end)}function F(ie){const fe=this.stack[this.stack.length-1];if(this.data.atHardBreak){const ke=fe.children[fe.children.length-1];ke.position.end=oa(ie.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(fe.type)&&(H.call(this,ie),P.call(this,ie))}function I(){this.data.atHardBreak=!0}function ee(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.value=ie}function Z(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.value=ie}function Y(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.value=ie}function U(){const ie=this.stack[this.stack.length-1];if(this.data.inReference){const fe=this.data.referenceType||"shortcut";ie.type+="Reference",ie.referenceType=fe,delete ie.url,delete ie.title}else delete ie.identifier,delete ie.label;this.data.referenceType=void 0}function Q(){const ie=this.stack[this.stack.length-1];if(this.data.inReference){const fe=this.data.referenceType||"shortcut";ie.type+="Reference",ie.referenceType=fe,delete ie.url,delete ie.title}else delete ie.identifier,delete ie.label;this.data.referenceType=void 0}function ue(ie){const fe=this.sliceSerialize(ie),ke=this.stack[this.stack.length-2];ke.label=XL(fe),ke.identifier=Ar(fe).toLowerCase()}function de(){const ie=this.stack[this.stack.length-1],fe=this.resume(),ke=this.stack[this.stack.length-1];if(this.data.inReference=!0,ke.type==="link"){const De=ie.children;ke.children=De}else ke.alt=fe}function R(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.url=ie}function L(){const ie=this.resume(),fe=this.stack[this.stack.length-1];fe.title=ie}function J(){this.data.inReference=void 0}function D(){this.data.referenceType="collapsed"}function oe(ie){const fe=this.resume(),ke=this.stack[this.stack.length-1];ke.label=fe,ke.identifier=Ar(this.sliceSerialize(ie)).toLowerCase(),this.data.referenceType="full"}function ye(ie){this.data.characterReferenceType=ie.type}function ve(ie){const fe=this.sliceSerialize(ie),ke=this.data.characterReferenceType;let De;ke?(De=FC(fe,ke==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):De=b0(fe);const Ke=this.stack[this.stack.length-1];Ke.value+=De}function Se(ie){const fe=this.stack.pop();fe.position.end=oa(ie.end)}function ge(ie){P.call(this,ie);const fe=this.stack[this.stack.length-1];fe.url=this.sliceSerialize(ie)}function K(ie){P.call(this,ie);const fe=this.stack[this.stack.length-1];fe.url="mailto:"+this.sliceSerialize(ie)}function he(){return{type:"blockquote",children:[]}}function be(){return{type:"code",lang:null,meta:null,value:""}}function se(){return{type:"inlineCode",value:""}}function jt(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function Ie(){return{type:"emphasis",children:[]}}function St(){return{type:"heading",depth:0,children:[]}}function Ot(){return{type:"break"}}function Gn(){return{type:"html",value:""}}function ba(){return{type:"image",title:null,url:"",alt:null}}function sl(){return{type:"link",title:null,url:"",children:[]}}function cl(ie){return{type:"list",ordered:ie.type==="listOrdered",start:null,spread:ie._spread,children:[]}}function Ru(ie){return{type:"listItem",spread:ie._spread,checked:null,children:[]}}function Sh(){return{type:"paragraph",children:[]}}function Oh(){return{type:"strong",children:[]}}function on(){return{type:"text",value:""}}function Eh(){return{type:"thematicBreak"}}}function oa(e){return{line:e.line,column:e.column,offset:e.offset}}function tT(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?tT(e,r):JL(e,r)}}function JL(e,t){let n;for(n in t)if(eT.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function eE(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+Xo({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+Xo({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+Xo({start:t.start,end:t.end})+") is still open")}function e5(e){const t=this;t.parser=n;function n(r){return QL(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function t5(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function n5(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function r5(e,t){const n=t.value?t.value+`
`:"",r={},a=t.lang?t.lang.split(/\s+/):[];a.length>0&&(r.className=["language-"+a[0]]);let u={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(u.data={meta:t.meta}),e.patch(t,u),u=e.applyData(t,u),u={type:"element",tagName:"pre",properties:{},children:[u]},e.patch(t,u),u}function i5(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function a5(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function l5(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),a=Eu(r.toLowerCase()),u=e.footnoteOrder.indexOf(r);let o,c=e.footnoteCounts.get(r);c===void 0?(c=0,e.footnoteOrder.push(r),o=e.footnoteOrder.length):o=u+1,c+=1,e.footnoteCounts.set(r,c);const f={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+a,id:n+"fnref-"+a+(c>1?"-"+c:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(o)}]};e.patch(t,f);const d={type:"element",tagName:"sup",properties:{},children:[f]};return e.patch(t,d),e.applyData(t,d)}function u5(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function o5(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function nT(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const a=e.all(t),u=a[0];u&&u.type==="text"?u.value="["+u.value:a.unshift({type:"text",value:"["});const o=a[a.length-1];return o&&o.type==="text"?o.value+=r:a.push({type:"text",value:r}),a}function s5(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return nT(e,t);const a={src:Eu(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(a.title=r.title);const u={type:"element",tagName:"img",properties:a,children:[]};return e.patch(t,u),e.applyData(t,u)}function c5(e,t){const n={src:Eu(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function f5(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function d5(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return nT(e,t);const a={href:Eu(r.url||"")};r.title!==null&&r.title!==void 0&&(a.title=r.title);const u={type:"element",tagName:"a",properties:a,children:e.all(t)};return e.patch(t,u),e.applyData(t,u)}function h5(e,t){const n={href:Eu(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function m5(e,t,n){const r=e.all(t),a=n?p5(n):rT(t),u={},o=[];if(typeof t.checked=="boolean"){const m=r[0];let p;m&&m.type==="element"&&m.tagName==="p"?p=m:(p={type:"element",tagName:"p",properties:{},children:[]},r.unshift(p)),p.children.length>0&&p.children.unshift({type:"text",value:" "}),p.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),u.className=["task-list-item"]}let c=-1;for(;++c<r.length;){const m=r[c];(a||c!==0||m.type!=="element"||m.tagName!=="p")&&o.push({type:"text",value:`
`}),m.type==="element"&&m.tagName==="p"&&!a?o.push(...m.children):o.push(m)}const f=r[r.length-1];f&&(a||f.type!=="element"||f.tagName!=="p")&&o.push({type:"text",value:`
`});const d={type:"element",tagName:"li",properties:u,children:o};return e.patch(t,d),e.applyData(t,d)}function p5(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=rT(n[r])}return t}function rT(e){const t=e.spread;return t??e.children.length>1}function v5(e,t){const n={},r=e.all(t);let a=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++a<r.length;){const o=r[a];if(o.type==="element"&&o.tagName==="li"&&o.properties&&Array.isArray(o.properties.className)&&o.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const u={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,u),e.applyData(t,u)}function y5(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function g5(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function b5(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function x5(e,t){const n=e.all(t),r=n.shift(),a=[];if(r){const o={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],o),a.push(o)}if(n.length>0){const o={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},c=m0(t.children[1]),f=RC(t.children[t.children.length-1]);c&&f&&(o.position={start:c,end:f}),a.push(o)}const u={type:"element",tagName:"table",properties:{},children:e.wrap(a,!0)};return e.patch(t,u),e.applyData(t,u)}function w5(e,t,n){const r=n?n.children:void 0,u=(r?r.indexOf(t):1)===0?"th":"td",o=n&&n.type==="table"?n.align:void 0,c=o?o.length:t.children.length;let f=-1;const d=[];for(;++f<c;){const p=t.children[f],y={},g=o?o[f]:void 0;g&&(y.align=g);let x={type:"element",tagName:u,properties:y,children:[]};p&&(x.children=e.all(p),e.patch(p,x),x=e.applyData(p,x)),d.push(x)}const m={type:"element",tagName:"tr",properties:{},children:e.wrap(d,!0)};return e.patch(t,m),e.applyData(t,m)}function S5(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const tE=9,nE=32;function O5(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),a=0;const u=[];for(;r;)u.push(rE(t.slice(a,r.index),a>0,!0),r[0]),a=r.index+r[0].length,r=n.exec(t);return u.push(rE(t.slice(a),a>0,!1)),u.join("")}function rE(e,t,n){let r=0,a=e.length;if(t){let u=e.codePointAt(r);for(;u===tE||u===nE;)r++,u=e.codePointAt(r)}if(n){let u=e.codePointAt(a-1);for(;u===tE||u===nE;)a--,u=e.codePointAt(a-1)}return a>r?e.slice(r,a):""}function E5(e,t){const n={type:"text",value:O5(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function A5(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const _5={blockquote:t5,break:n5,code:r5,delete:i5,emphasis:a5,footnoteReference:l5,heading:u5,html:o5,imageReference:s5,image:c5,inlineCode:f5,linkReference:d5,link:h5,listItem:m5,list:v5,paragraph:y5,root:g5,strong:b5,table:x5,tableCell:S5,tableRow:w5,text:E5,thematicBreak:A5,toml:rf,yaml:rf,definition:rf,footnoteDefinition:rf};function rf(){}const iT=-1,zd=0,Qo=1,Nf=2,w0=3,S0=4,O0=5,E0=6,aT=7,lT=8,iE=typeof self=="object"?self:globalThis,k5=(e,t)=>{const n=(a,u)=>(e.set(u,a),a),r=a=>{if(e.has(a))return e.get(a);const[u,o]=t[a];switch(u){case zd:case iT:return n(o,a);case Qo:{const c=n([],a);for(const f of o)c.push(r(f));return c}case Nf:{const c=n({},a);for(const[f,d]of o)c[r(f)]=r(d);return c}case w0:return n(new Date(o),a);case S0:{const{source:c,flags:f}=o;return n(new RegExp(c,f),a)}case O0:{const c=n(new Map,a);for(const[f,d]of o)c.set(r(f),r(d));return c}case E0:{const c=n(new Set,a);for(const f of o)c.add(r(f));return c}case aT:{const{name:c,message:f}=o;return n(new iE[c](f),a)}case lT:return n(BigInt(o),a);case"BigInt":return n(Object(BigInt(o)),a);case"ArrayBuffer":return n(new Uint8Array(o).buffer,o);case"DataView":{const{buffer:c}=new Uint8Array(o);return n(new DataView(c),o)}}return n(new iE[u](o),a)};return r},aE=e=>k5(new Map,e)(0),Ql="",{toString:C5}={},{keys:T5}=Object,Ro=e=>{const t=typeof e;if(t!=="object"||!e)return[zd,t];const n=C5.call(e).slice(8,-1);switch(n){case"Array":return[Qo,Ql];case"Object":return[Nf,Ql];case"Date":return[w0,Ql];case"RegExp":return[S0,Ql];case"Map":return[O0,Ql];case"Set":return[E0,Ql];case"DataView":return[Qo,n]}return n.includes("Array")?[Qo,n]:n.includes("Error")?[aT,n]:[Nf,n]},af=([e,t])=>e===zd&&(t==="function"||t==="symbol"),j5=(e,t,n,r)=>{const a=(o,c)=>{const f=r.push(o)-1;return n.set(c,f),f},u=o=>{if(n.has(o))return n.get(o);let[c,f]=Ro(o);switch(c){case zd:{let m=o;switch(f){case"bigint":c=lT,m=o.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+f);m=null;break;case"undefined":return a([iT],o)}return a([c,m],o)}case Qo:{if(f){let y=o;return f==="DataView"?y=new Uint8Array(o.buffer):f==="ArrayBuffer"&&(y=new Uint8Array(o)),a([f,[...y]],o)}const m=[],p=a([c,m],o);for(const y of o)m.push(u(y));return p}case Nf:{if(f)switch(f){case"BigInt":return a([f,o.toString()],o);case"Boolean":case"Number":case"String":return a([f,o.valueOf()],o)}if(t&&"toJSON"in o)return u(o.toJSON());const m=[],p=a([c,m],o);for(const y of T5(o))(e||!af(Ro(o[y])))&&m.push([u(y),u(o[y])]);return p}case w0:return a([c,o.toISOString()],o);case S0:{const{source:m,flags:p}=o;return a([c,{source:m,flags:p}],o)}case O0:{const m=[],p=a([c,m],o);for(const[y,g]of o)(e||!(af(Ro(y))||af(Ro(g))))&&m.push([u(y),u(g)]);return p}case E0:{const m=[],p=a([c,m],o);for(const y of o)(e||!af(Ro(y)))&&m.push(u(y));return p}}const{message:d}=o;return a([c,{name:f,message:d}],o)};return u},lE=(e,{json:t,lossy:n}={})=>{const r=[];return j5(!(t||n),!!t,new Map,r)(e),r},Pf=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?aE(lE(e,t)):structuredClone(e):(e,t)=>aE(lE(e,t));function M5(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function z5(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function D5(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||M5,r=e.options.footnoteBackLabel||z5,a=e.options.footnoteLabel||"Footnotes",u=e.options.footnoteLabelTagName||"h2",o=e.options.footnoteLabelProperties||{className:["sr-only"]},c=[];let f=-1;for(;++f<e.footnoteOrder.length;){const d=e.footnoteById.get(e.footnoteOrder[f]);if(!d)continue;const m=e.all(d),p=String(d.identifier).toUpperCase(),y=Eu(p.toLowerCase());let g=0;const x=[],w=e.footnoteCounts.get(p);for(;w!==void 0&&++g<=w;){x.length>0&&x.push({type:"text",value:" "});let _=typeof n=="string"?n:n(f,g);typeof _=="string"&&(_={type:"text",value:_}),x.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+y+(g>1?"-"+g:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(f,g),className:["data-footnote-backref"]},children:Array.isArray(_)?_:[_]})}const S=m[m.length-1];if(S&&S.type==="element"&&S.tagName==="p"){const _=S.children[S.children.length-1];_&&_.type==="text"?_.value+=" ":S.children.push({type:"text",value:" "}),S.children.push(...x)}else m.push(...x);const O={type:"element",tagName:"li",properties:{id:t+"fn-"+y},children:e.wrap(m,!0)};e.patch(d,O),c.push(O)}if(c.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:u,properties:{...Pf(o),id:"footnote-label"},children:[{type:"text",value:a}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(c,!0)},{type:"text",value:`
`}]}}const Dd=(function(e){if(e==null)return I5;if(typeof e=="function")return Nd(e);if(typeof e=="object")return Array.isArray(e)?N5(e):P5(e);if(typeof e=="string")return R5(e);throw new Error("Expected function, string, or object as test")});function N5(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=Dd(e[n]);return Nd(r);function r(...a){let u=-1;for(;++u<t.length;)if(t[u].apply(this,a))return!0;return!1}}function P5(e){const t=e;return Nd(n);function n(r){const a=r;let u;for(u in e)if(a[u]!==t[u])return!1;return!0}}function R5(e){return Nd(t);function t(n){return n&&n.type===e}}function Nd(e){return t;function t(n,r,a){return!!(L5(n)&&e.call(this,n,typeof r=="number"?r:void 0,a||void 0))}}function I5(){return!0}function L5(e){return e!==null&&typeof e=="object"&&"type"in e}const uT=[],B5=!0,rg=!1,U5="skip";function oT(e,t,n,r){let a;typeof t=="function"&&typeof n!="function"?(r=n,n=t):a=t;const u=Dd(a),o=r?-1:1;c(e,void 0,[])();function c(f,d,m){const p=f&&typeof f=="object"?f:{};if(typeof p.type=="string"){const g=typeof p.tagName=="string"?p.tagName:typeof p.name=="string"?p.name:void 0;Object.defineProperty(y,"name",{value:"node ("+(f.type+(g?"<"+g+">":""))+")"})}return y;function y(){let g=uT,x,w,S;if((!t||u(f,d,m[m.length-1]||void 0))&&(g=q5(n(f,m)),g[0]===rg))return g;if("children"in f&&f.children){const O=f;if(O.children&&g[0]!==U5)for(w=(r?O.children.length:-1)+o,S=m.concat(O);w>-1&&w<O.children.length;){const _=O.children[w];if(x=c(_,w,S)(),x[0]===rg)return x;w=typeof x[1]=="number"?x[1]:w+o}}return g}}}function q5(e){return Array.isArray(e)?e:typeof e=="number"?[B5,e]:e==null?uT:[e]}function A0(e,t,n,r){let a,u,o;typeof t=="function"&&typeof n!="function"?(u=void 0,o=t,a=n):(u=t,o=n,a=r),oT(e,u,c,a);function c(f,d){const m=d[d.length-1],p=m?m.children.indexOf(f):void 0;return o(f,p,m)}}const ig={}.hasOwnProperty,H5={};function $5(e,t){const n=t||H5,r=new Map,a=new Map,u=new Map,o={..._5,...n.handlers},c={all:d,applyData:V5,definitionById:r,footnoteById:a,footnoteCounts:u,footnoteOrder:[],handlers:o,one:f,options:n,patch:F5,wrap:K5};return A0(e,function(m){if(m.type==="definition"||m.type==="footnoteDefinition"){const p=m.type==="definition"?r:a,y=String(m.identifier).toUpperCase();p.has(y)||p.set(y,m)}}),c;function f(m,p){const y=m.type,g=c.handlers[y];if(ig.call(c.handlers,y)&&g)return g(c,m,p);if(c.options.passThrough&&c.options.passThrough.includes(y)){if("children"in m){const{children:w,...S}=m,O=Pf(S);return O.children=c.all(m),O}return Pf(m)}return(c.options.unknownHandler||Y5)(c,m,p)}function d(m){const p=[];if("children"in m){const y=m.children;let g=-1;for(;++g<y.length;){const x=c.one(y[g],m);if(x){if(g&&y[g-1].type==="break"&&(!Array.isArray(x)&&x.type==="text"&&(x.value=uE(x.value)),!Array.isArray(x)&&x.type==="element")){const w=x.children[0];w&&w.type==="text"&&(w.value=uE(w.value))}Array.isArray(x)?p.push(...x):p.push(x)}}}return p}}function F5(e,t){e.position&&(t.position=z3(e))}function V5(e,t){let n=t;if(e&&e.data){const r=e.data.hName,a=e.data.hChildren,u=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const o="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:o}}n.type==="element"&&u&&Object.assign(n.properties,Pf(u)),"children"in n&&n.children&&a!==null&&a!==void 0&&(n.children=a)}return n}function Y5(e,t){const n=t.data||{},r="value"in t&&!(ig.call(n,"hProperties")||ig.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function K5(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function uE(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function oE(e,t){const n=$5(e,t),r=n.one(e,void 0),a=D5(n),u=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return a&&u.children.push({type:"text",value:`
`},a),u}function G5(e,t){return e&&"run"in e?async function(n,r){const a=oE(n,{file:r,...t});await e.run(a,r)}:function(n,r){return oE(n,{file:r,...e||t})}}function sE(e){if(e)throw e}var nv,cE;function X5(){if(cE)return nv;cE=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,a=function(d){return typeof Array.isArray=="function"?Array.isArray(d):t.call(d)==="[object Array]"},u=function(d){if(!d||t.call(d)!=="[object Object]")return!1;var m=e.call(d,"constructor"),p=d.constructor&&d.constructor.prototype&&e.call(d.constructor.prototype,"isPrototypeOf");if(d.constructor&&!m&&!p)return!1;var y;for(y in d);return typeof y>"u"||e.call(d,y)},o=function(d,m){n&&m.name==="__proto__"?n(d,m.name,{enumerable:!0,configurable:!0,value:m.newValue,writable:!0}):d[m.name]=m.newValue},c=function(d,m){if(m==="__proto__")if(e.call(d,m)){if(r)return r(d,m).value}else return;return d[m]};return nv=function f(){var d,m,p,y,g,x,w=arguments[0],S=1,O=arguments.length,_=!1;for(typeof w=="boolean"&&(_=w,w=arguments[1]||{},S=2),(w==null||typeof w!="object"&&typeof w!="function")&&(w={});S<O;++S)if(d=arguments[S],d!=null)for(m in d)p=c(w,m),y=c(d,m),w!==y&&(_&&y&&(u(y)||(g=a(y)))?(g?(g=!1,x=p&&a(p)?p:[]):x=p&&u(p)?p:{},o(w,{name:m,newValue:f(_,x,y)})):typeof y<"u"&&o(w,{name:m,newValue:y}));return w},nv}var Z5=X5();const rv=Tr(Z5);function ag(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function Q5(){const e=[],t={run:n,use:r};return t;function n(...a){let u=-1;const o=a.pop();if(typeof o!="function")throw new TypeError("Expected function as last argument, not "+o);c(null,...a);function c(f,...d){const m=e[++u];let p=-1;if(f){o(f);return}for(;++p<a.length;)(d[p]===null||d[p]===void 0)&&(d[p]=a[p]);a=d,m?W5(m,c)(...d):o(null,...d)}}function r(a){if(typeof a!="function")throw new TypeError("Expected `middelware` to be a function, not "+a);return e.push(a),t}}function W5(e,t){let n;return r;function r(...o){const c=e.length>o.length;let f;c&&o.push(a);try{f=e.apply(this,o)}catch(d){const m=d;if(c&&n)throw m;return a(m)}c||(f&&f.then&&typeof f.then=="function"?f.then(u,a):f instanceof Error?a(f):u(f))}function a(o,...c){n||(n=!0,t(o,...c))}function u(o){a(null,o)}}const Br={basename:J5,dirname:e6,extname:t6,join:n6,sep:"/"};function J5(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');bs(e);let n=0,r=-1,a=e.length,u;if(t===void 0||t.length===0||t.length>e.length){for(;a--;)if(e.codePointAt(a)===47){if(u){n=a+1;break}}else r<0&&(u=!0,r=a+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let o=-1,c=t.length-1;for(;a--;)if(e.codePointAt(a)===47){if(u){n=a+1;break}}else o<0&&(u=!0,o=a+1),c>-1&&(e.codePointAt(a)===t.codePointAt(c--)?c<0&&(r=a):(c=-1,r=o));return n===r?r=o:r<0&&(r=e.length),e.slice(n,r)}function e6(e){if(bs(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function t6(e){bs(e);let t=e.length,n=-1,r=0,a=-1,u=0,o;for(;t--;){const c=e.codePointAt(t);if(c===47){if(o){r=t+1;break}continue}n<0&&(o=!0,n=t+1),c===46?a<0?a=t:u!==1&&(u=1):a>-1&&(u=-1)}return a<0||n<0||u===0||u===1&&a===n-1&&a===r+1?"":e.slice(a,n)}function n6(...e){let t=-1,n;for(;++t<e.length;)bs(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":r6(n)}function r6(e){bs(e);const t=e.codePointAt(0)===47;let n=i6(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function i6(e,t){let n="",r=0,a=-1,u=0,o=-1,c,f;for(;++o<=e.length;){if(o<e.length)c=e.codePointAt(o);else{if(c===47)break;c=47}if(c===47){if(!(a===o-1||u===1))if(a!==o-1&&u===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(f=n.lastIndexOf("/"),f!==n.length-1){f<0?(n="",r=0):(n=n.slice(0,f),r=n.length-1-n.lastIndexOf("/")),a=o,u=0;continue}}else if(n.length>0){n="",r=0,a=o,u=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(a+1,o):n=e.slice(a+1,o),r=o-a-1;a=o,u=0}else c===46&&u>-1?u++:u=-1}return n}function bs(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const a6={cwd:l6};function l6(){return"/"}function lg(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function u6(e){if(typeof e=="string")e=new URL(e);else if(!lg(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return o6(e)}function o6(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const a=new TypeError("File URL path must not include encoded / characters");throw a.code="ERR_INVALID_FILE_URL_PATH",a}}return decodeURIComponent(t)}const iv=["history","path","basename","stem","extname","dirname"];class sT{constructor(t){let n;t?lg(t)?n={path:t}:typeof t=="string"||s6(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":a6.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<iv.length;){const u=iv[r];u in n&&n[u]!==void 0&&n[u]!==null&&(this[u]=u==="history"?[...n[u]]:n[u])}let a;for(a in n)iv.includes(a)||(this[a]=n[a])}get basename(){return typeof this.path=="string"?Br.basename(this.path):void 0}set basename(t){lv(t,"basename"),av(t,"basename"),this.path=Br.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?Br.dirname(this.path):void 0}set dirname(t){fE(this.basename,"dirname"),this.path=Br.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?Br.extname(this.path):void 0}set extname(t){if(av(t,"extname"),fE(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=Br.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){lg(t)&&(t=u6(t)),lv(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?Br.basename(this.path,this.extname):void 0}set stem(t){lv(t,"stem"),av(t,"stem"),this.path=Br.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const a=this.message(t,n,r);throw a.fatal=!0,a}info(t,n,r){const a=this.message(t,n,r);return a.fatal=void 0,a}message(t,n,r){const a=new un(t,n,r);return this.path&&(a.name=this.path+":"+a.name,a.file=this.path),a.fatal=!1,this.messages.push(a),a}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function av(e,t){if(e&&e.includes(Br.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+Br.sep+"`")}function lv(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function fE(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function s6(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const c6=(function(e){const r=this.constructor.prototype,a=r[e],u=function(){return a.apply(u,arguments)};return Object.setPrototypeOf(u,r),u}),f6={}.hasOwnProperty;class _0 extends c6{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=Q5()}copy(){const t=new _0;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(rv(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(sv("data",this.frozen),this.namespace[t]=n,this):f6.call(this.namespace,t)&&this.namespace[t]||void 0:t?(sv("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const a=n.call(t,...r);typeof a=="function"&&this.transformers.use(a)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=lf(t),r=this.parser||this.Parser;return uv("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),uv("process",this.parser||this.Parser),ov("process",this.compiler||this.Compiler),n?a(void 0,n):new Promise(a);function a(u,o){const c=lf(t),f=r.parse(c);r.run(f,c,function(m,p,y){if(m||!p||!y)return d(m);const g=p,x=r.stringify(g,y);m6(x)?y.value=x:y.result=x,d(m,y)});function d(m,p){m||!p?o(m):u?u(p):n(void 0,p)}}}processSync(t){let n=!1,r;return this.freeze(),uv("processSync",this.parser||this.Parser),ov("processSync",this.compiler||this.Compiler),this.process(t,a),hE("processSync","process",n),r;function a(u,o){n=!0,sE(u),r=o}}run(t,n,r){dE(t),this.freeze();const a=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?u(void 0,r):new Promise(u);function u(o,c){const f=lf(n);a.run(t,f,d);function d(m,p,y){const g=p||t;m?c(m):o?o(g):r(void 0,g,y)}}}runSync(t,n){let r=!1,a;return this.run(t,n,u),hE("runSync","run",r),a;function u(o,c){sE(o),a=c,r=!0}}stringify(t,n){this.freeze();const r=lf(n),a=this.compiler||this.Compiler;return ov("stringify",a),dE(t),a(t,r)}use(t,...n){const r=this.attachers,a=this.namespace;if(sv("use",this.frozen),t!=null)if(typeof t=="function")f(t,n);else if(typeof t=="object")Array.isArray(t)?c(t):o(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function u(d){if(typeof d=="function")f(d,[]);else if(typeof d=="object")if(Array.isArray(d)){const[m,...p]=d;f(m,p)}else o(d);else throw new TypeError("Expected usable value, not `"+d+"`")}function o(d){if(!("plugins"in d)&&!("settings"in d))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");c(d.plugins),d.settings&&(a.settings=rv(!0,a.settings,d.settings))}function c(d){let m=-1;if(d!=null)if(Array.isArray(d))for(;++m<d.length;){const p=d[m];u(p)}else throw new TypeError("Expected a list of plugins, not `"+d+"`")}function f(d,m){let p=-1,y=-1;for(;++p<r.length;)if(r[p][0]===d){y=p;break}if(y===-1)r.push([d,...m]);else if(m.length>0){let[g,...x]=m;const w=r[y][1];ag(w)&&ag(g)&&(g=rv(!0,w,g)),r[y]=[d,g,...x]}}}}const d6=new _0().freeze();function uv(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function ov(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function sv(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function dE(e){if(!ag(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function hE(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function lf(e){return h6(e)?e:new sT(e)}function h6(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function m6(e){return typeof e=="string"||p6(e)}function p6(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const v6="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",mE=[],pE={allowDangerousHtml:!0},y6=/^(https?|ircs?|mailto|xmpp)$/i,g6=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function k0(e){const t=b6(e),n=x6(e);return w6(t.runSync(t.parse(n),n),e)}function b6(e){const t=e.rehypePlugins||mE,n=e.remarkPlugins||mE,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...pE}:pE;return d6().use(e5).use(n).use(G5,r).use(t)}function x6(e){const t=e.children||"",n=new sT;return typeof t=="string"&&(n.value=t),n}function w6(e,t){const n=t.allowedElements,r=t.allowElement,a=t.components,u=t.disallowedElements,o=t.skipHtml,c=t.unwrapDisallowed,f=t.urlTransform||S6;for(const m of g6)Object.hasOwn(t,m.from)&&(""+m.from+(m.to?"use `"+m.to+"` instead":"remove it")+v6+m.id,void 0);return t.className&&(e={type:"element",tagName:"div",properties:{className:t.className},children:e.type==="root"?e.children:[e]}),A0(e,d),I3(e,{Fragment:T.Fragment,components:a,ignoreInvalidStyle:!0,jsx:T.jsx,jsxs:T.jsxs,passKeys:!0,passNode:!0});function d(m,p,y){if(m.type==="raw"&&y&&typeof p=="number")return o?y.children.splice(p,1):y.children[p]={type:"text",value:m.value},p;if(m.type==="element"){let g;for(g in Jp)if(Object.hasOwn(Jp,g)&&Object.hasOwn(m.properties,g)){const x=m.properties[g],w=Jp[g];(w===null||w.includes(m.tagName))&&(m.properties[g]=f(String(x||""),g,m))}}if(m.type==="element"){let g=n?!n.includes(m.tagName):u?u.includes(m.tagName):!1;if(!g&&r&&typeof p=="number"&&(g=!r(m,p,y)),g&&y&&typeof p=="number")return c&&m.children?y.children.splice(p,1,...m.children):y.children.splice(p,1),p}}}function S6(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),a=e.indexOf("/");return t===-1||a!==-1&&t>a||n!==-1&&t>n||r!==-1&&t>r||y6.test(e.slice(0,t))?e:""}function vE(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let r=0,a=n.indexOf(t);for(;a!==-1;)r++,a=n.indexOf(t,a+t.length);return r}function O6(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function E6(e,t,n){const a=Dd((n||{}).ignore||[]),u=A6(t);let o=-1;for(;++o<u.length;)oT(e,"text",c);function c(d,m){let p=-1,y;for(;++p<m.length;){const g=m[p],x=y?y.children:void 0;if(a(g,x?x.indexOf(g):void 0,y))return;y=g}if(y)return f(d,m)}function f(d,m){const p=m[m.length-1],y=u[o][0],g=u[o][1];let x=0;const S=p.children.indexOf(d);let O=!1,_=[];y.lastIndex=0;let k=y.exec(d.value);for(;k;){const M=k.index,N={index:k.index,input:k.input,stack:[...m,d]};let C=g(...k,N);if(typeof C=="string"&&(C=C.length>0?{type:"text",value:C}:void 0),C===!1?y.lastIndex=M+1:(x!==M&&_.push({type:"text",value:d.value.slice(x,M)}),Array.isArray(C)?_.push(...C):C&&_.push(C),x=M+k[0].length,O=!0),!y.global)break;k=y.exec(d.value)}return O?(x<d.value.length&&_.push({type:"text",value:d.value.slice(x)}),p.children.splice(S,1,..._)):_=[d],S+_.length}}function A6(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){const a=n[r];t.push([_6(a[0]),k6(a[1])])}return t}function _6(e){return typeof e=="string"?new RegExp(O6(e),"g"):e}function k6(e){return typeof e=="function"?e:function(){return e}}const cv="phrasing",fv=["autolink","link","image","label"];function C6(){return{transforms:[P6],enter:{literalAutolink:j6,literalAutolinkEmail:dv,literalAutolinkHttp:dv,literalAutolinkWww:dv},exit:{literalAutolink:N6,literalAutolinkEmail:D6,literalAutolinkHttp:M6,literalAutolinkWww:z6}}}function T6(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:cv,notInConstruct:fv},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:cv,notInConstruct:fv},{character:":",before:"[ps]",after:"\\/",inConstruct:cv,notInConstruct:fv}]}}function j6(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function dv(e){this.config.enter.autolinkProtocol.call(this,e)}function M6(e){this.config.exit.autolinkProtocol.call(this,e)}function z6(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function D6(e){this.config.exit.autolinkEmail.call(this,e)}function N6(e){this.exit(e)}function P6(e){E6(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,R6],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),I6]],{ignore:["link","linkReference"]})}function R6(e,t,n,r,a){let u="";if(!cT(a)||(/^w/i.test(t)&&(n=t+n,t="",u="http://"),!L6(n)))return!1;const o=B6(n+r);if(!o[0])return!1;const c={type:"link",title:null,url:u+t+o[0],children:[{type:"text",value:t+o[0]}]};return o[1]?[c,{type:"text",value:o[1]}]:c}function I6(e,t,n,r){return!cT(r,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function L6(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function B6(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")");const a=vE(e,"(");let u=vE(e,")");for(;r!==-1&&a>u;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),u++;return[e,n]}function cT(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||Za(n)||jd(n))&&(!t||n!==47)}fT.peek=G6;function U6(){this.buffer()}function q6(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function H6(){this.buffer()}function $6(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function F6(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Ar(this.sliceSerialize(e)).toLowerCase(),n.label=t}function V6(e){this.exit(e)}function Y6(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Ar(this.sliceSerialize(e)).toLowerCase(),n.label=t}function K6(e){this.exit(e)}function G6(){return"["}function fT(e,t,n,r){const a=n.createTracker(r);let u=a.move("[^");const o=n.enter("footnoteReference"),c=n.enter("reference");return u+=a.move(n.safe(n.associationId(e),{after:"]",before:u})),c(),o(),u+=a.move("]"),u}function X6(){return{enter:{gfmFootnoteCallString:U6,gfmFootnoteCall:q6,gfmFootnoteDefinitionLabelString:H6,gfmFootnoteDefinition:$6},exit:{gfmFootnoteCallString:F6,gfmFootnoteCall:V6,gfmFootnoteDefinitionLabelString:Y6,gfmFootnoteDefinition:K6}}}function Z6(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:fT},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(r,a,u,o){const c=u.createTracker(o);let f=c.move("[^");const d=u.enter("footnoteDefinition"),m=u.enter("label");return f+=c.move(u.safe(u.associationId(r),{before:f,after:"]"})),m(),f+=c.move("]:"),r.children&&r.children.length>0&&(c.shift(4),f+=c.move((t?`
`:" ")+u.indentLines(u.containerFlow(r,c.current()),t?dT:Q6))),d(),f}}function Q6(e,t,n){return t===0?e:dT(e,t,n)}function dT(e,t,n){return(n?"":"    ")+e}const W6=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];hT.peek=rB;function J6(){return{canContainEols:["delete"],enter:{strikethrough:tB},exit:{strikethrough:nB}}}function eB(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:W6}],handlers:{delete:hT}}}function tB(e){this.enter({type:"delete",children:[]},e)}function nB(e){this.exit(e)}function hT(e,t,n,r){const a=n.createTracker(r),u=n.enter("strikethrough");let o=a.move("~~");return o+=n.containerPhrasing(e,{...a.current(),before:o,after:"~"}),o+=a.move("~~"),u(),o}function rB(){return"~"}function iB(e){return e.length}function aB(e,t){const n=t||{},r=(n.align||[]).concat(),a=n.stringLength||iB,u=[],o=[],c=[],f=[];let d=0,m=-1;for(;++m<e.length;){const w=[],S=[];let O=-1;for(e[m].length>d&&(d=e[m].length);++O<e[m].length;){const _=lB(e[m][O]);if(n.alignDelimiters!==!1){const k=a(_);S[O]=k,(f[O]===void 0||k>f[O])&&(f[O]=k)}w.push(_)}o[m]=w,c[m]=S}let p=-1;if(typeof r=="object"&&"length"in r)for(;++p<d;)u[p]=yE(r[p]);else{const w=yE(r);for(;++p<d;)u[p]=w}p=-1;const y=[],g=[];for(;++p<d;){const w=u[p];let S="",O="";w===99?(S=":",O=":"):w===108?S=":":w===114&&(O=":");let _=n.alignDelimiters===!1?1:Math.max(1,f[p]-S.length-O.length);const k=S+"-".repeat(_)+O;n.alignDelimiters!==!1&&(_=S.length+_+O.length,_>f[p]&&(f[p]=_),g[p]=_),y[p]=k}o.splice(1,0,y),c.splice(1,0,g),m=-1;const x=[];for(;++m<o.length;){const w=o[m],S=c[m];p=-1;const O=[];for(;++p<d;){const _=w[p]||"";let k="",M="";if(n.alignDelimiters!==!1){const N=f[p]-(S[p]||0),C=u[p];C===114?k=" ".repeat(N):C===99?N%2?(k=" ".repeat(N/2+.5),M=" ".repeat(N/2-.5)):(k=" ".repeat(N/2),M=k):M=" ".repeat(N)}n.delimiterStart!==!1&&!p&&O.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&_==="")&&(n.delimiterStart!==!1||p)&&O.push(" "),n.alignDelimiters!==!1&&O.push(k),O.push(_),n.alignDelimiters!==!1&&O.push(M),n.padding!==!1&&O.push(" "),(n.delimiterEnd!==!1||p!==d-1)&&O.push("|")}x.push(n.delimiterEnd===!1?O.join("").replace(/ +$/,""):O.join(""))}return x.join(`
`)}function lB(e){return e==null?"":String(e)}function yE(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}function uB(e,t,n,r){const a=n.enter("blockquote"),u=n.createTracker(r);u.move("> "),u.shift(2);const o=n.indentLines(n.containerFlow(e,u.current()),oB);return a(),o}function oB(e,t,n){return">"+(n?"":" ")+e}function sB(e,t){return gE(e,t.inConstruct,!0)&&!gE(e,t.notInConstruct,!1)}function gE(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}function bE(e,t,n,r){let a=-1;for(;++a<n.unsafe.length;)if(n.unsafe[a].character===`
`&&sB(n.stack,n.unsafe[a]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function cB(e,t){const n=String(e);let r=n.indexOf(t),a=r,u=0,o=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===a?++u>o&&(o=u):u=1,a=r+t.length,r=n.indexOf(t,a);return o}function fB(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function dB(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function hB(e,t,n,r){const a=dB(n),u=e.value||"",o=a==="`"?"GraveAccent":"Tilde";if(fB(e,n)){const p=n.enter("codeIndented"),y=n.indentLines(u,mB);return p(),y}const c=n.createTracker(r),f=a.repeat(Math.max(cB(u,a)+1,3)),d=n.enter("codeFenced");let m=c.move(f);if(e.lang){const p=n.enter(`codeFencedLang${o}`);m+=c.move(n.safe(e.lang,{before:m,after:" ",encode:["`"],...c.current()})),p()}if(e.lang&&e.meta){const p=n.enter(`codeFencedMeta${o}`);m+=c.move(" "),m+=c.move(n.safe(e.meta,{before:m,after:`
`,encode:["`"],...c.current()})),p()}return m+=c.move(`
`),u&&(m+=c.move(u+`
`)),m+=c.move(f),d(),m}function mB(e,t,n){return(n?"":"    ")+e}function C0(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function pB(e,t,n,r){const a=C0(n),u=a==='"'?"Quote":"Apostrophe",o=n.enter("definition");let c=n.enter("label");const f=n.createTracker(r);let d=f.move("[");return d+=f.move(n.safe(n.associationId(e),{before:d,after:"]",...f.current()})),d+=f.move("]: "),c(),!e.url||/[\0- \u007F]/.test(e.url)?(c=n.enter("destinationLiteral"),d+=f.move("<"),d+=f.move(n.safe(e.url,{before:d,after:">",...f.current()})),d+=f.move(">")):(c=n.enter("destinationRaw"),d+=f.move(n.safe(e.url,{before:d,after:e.title?" ":`
`,...f.current()}))),c(),e.title&&(c=n.enter(`title${u}`),d+=f.move(" "+a),d+=f.move(n.safe(e.title,{before:d,after:a,...f.current()})),d+=f.move(a),c()),o(),d}function vB(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function es(e){return"&#x"+e.toString(16).toUpperCase()+";"}function Rf(e,t,n){const r=fu(e),a=fu(t);return r===void 0?a===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}mT.peek=yB;function mT(e,t,n,r){const a=vB(n),u=n.enter("emphasis"),o=n.createTracker(r),c=o.move(a);let f=o.move(n.containerPhrasing(e,{after:a,before:c,...o.current()}));const d=f.charCodeAt(0),m=Rf(r.before.charCodeAt(r.before.length-1),d,a);m.inside&&(f=es(d)+f.slice(1));const p=f.charCodeAt(f.length-1),y=Rf(r.after.charCodeAt(0),p,a);y.inside&&(f=f.slice(0,-1)+es(p));const g=o.move(a);return u(),n.attentionEncodeSurroundingInfo={after:y.outside,before:m.outside},c+f+g}function yB(e,t,n){return n.options.emphasis||"*"}function gB(e,t){let n=!1;return A0(e,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return n=!0,rg}),!!((!e.depth||e.depth<3)&&g0(e)&&(t.options.setext||n))}function bB(e,t,n,r){const a=Math.max(Math.min(6,e.depth||1),1),u=n.createTracker(r);if(gB(e,n)){const m=n.enter("headingSetext"),p=n.enter("phrasing"),y=n.containerPhrasing(e,{...u.current(),before:`
`,after:`
`});return p(),m(),y+`
`+(a===1?"=":"-").repeat(y.length-(Math.max(y.lastIndexOf("\r"),y.lastIndexOf(`
`))+1))}const o="#".repeat(a),c=n.enter("headingAtx"),f=n.enter("phrasing");u.move(o+" ");let d=n.containerPhrasing(e,{before:"# ",after:`
`,...u.current()});return/^[\t ]/.test(d)&&(d=es(d.charCodeAt(0))+d.slice(1)),d=d?o+" "+d:o,n.options.closeAtx&&(d+=" "+o),f(),c(),d}pT.peek=xB;function pT(e){return e.value||""}function xB(){return"<"}vT.peek=wB;function vT(e,t,n,r){const a=C0(n),u=a==='"'?"Quote":"Apostrophe",o=n.enter("image");let c=n.enter("label");const f=n.createTracker(r);let d=f.move("![");return d+=f.move(n.safe(e.alt,{before:d,after:"]",...f.current()})),d+=f.move("]("),c(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(c=n.enter("destinationLiteral"),d+=f.move("<"),d+=f.move(n.safe(e.url,{before:d,after:">",...f.current()})),d+=f.move(">")):(c=n.enter("destinationRaw"),d+=f.move(n.safe(e.url,{before:d,after:e.title?" ":")",...f.current()}))),c(),e.title&&(c=n.enter(`title${u}`),d+=f.move(" "+a),d+=f.move(n.safe(e.title,{before:d,after:a,...f.current()})),d+=f.move(a),c()),d+=f.move(")"),o(),d}function wB(){return"!"}yT.peek=SB;function yT(e,t,n,r){const a=e.referenceType,u=n.enter("imageReference");let o=n.enter("label");const c=n.createTracker(r);let f=c.move("![");const d=n.safe(e.alt,{before:f,after:"]",...c.current()});f+=c.move(d+"]["),o();const m=n.stack;n.stack=[],o=n.enter("reference");const p=n.safe(n.associationId(e),{before:f,after:"]",...c.current()});return o(),n.stack=m,u(),a==="full"||!d||d!==p?f+=c.move(p+"]"):a==="shortcut"?f=f.slice(0,-1):f+=c.move("]"),f}function SB(){return"!"}gT.peek=OB;function gT(e,t,n){let r=e.value||"",a="`",u=-1;for(;new RegExp("(^|[^`])"+a+"([^`]|$)").test(r);)a+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++u<n.unsafe.length;){const o=n.unsafe[u],c=n.compilePattern(o);let f;if(o.atBreak)for(;f=c.exec(r);){let d=f.index;r.charCodeAt(d)===10&&r.charCodeAt(d-1)===13&&d--,r=r.slice(0,d)+" "+r.slice(f.index+1)}}return a+r+a}function OB(){return"`"}function bT(e,t){const n=g0(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}xT.peek=EB;function xT(e,t,n,r){const a=C0(n),u=a==='"'?"Quote":"Apostrophe",o=n.createTracker(r);let c,f;if(bT(e,n)){const m=n.stack;n.stack=[],c=n.enter("autolink");let p=o.move("<");return p+=o.move(n.containerPhrasing(e,{before:p,after:">",...o.current()})),p+=o.move(">"),c(),n.stack=m,p}c=n.enter("link"),f=n.enter("label");let d=o.move("[");return d+=o.move(n.containerPhrasing(e,{before:d,after:"](",...o.current()})),d+=o.move("]("),f(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(f=n.enter("destinationLiteral"),d+=o.move("<"),d+=o.move(n.safe(e.url,{before:d,after:">",...o.current()})),d+=o.move(">")):(f=n.enter("destinationRaw"),d+=o.move(n.safe(e.url,{before:d,after:e.title?" ":")",...o.current()}))),f(),e.title&&(f=n.enter(`title${u}`),d+=o.move(" "+a),d+=o.move(n.safe(e.title,{before:d,after:a,...o.current()})),d+=o.move(a),f()),d+=o.move(")"),c(),d}function EB(e,t,n){return bT(e,n)?"<":"["}wT.peek=AB;function wT(e,t,n,r){const a=e.referenceType,u=n.enter("linkReference");let o=n.enter("label");const c=n.createTracker(r);let f=c.move("[");const d=n.containerPhrasing(e,{before:f,after:"]",...c.current()});f+=c.move(d+"]["),o();const m=n.stack;n.stack=[],o=n.enter("reference");const p=n.safe(n.associationId(e),{before:f,after:"]",...c.current()});return o(),n.stack=m,u(),a==="full"||!d||d!==p?f+=c.move(p+"]"):a==="shortcut"?f=f.slice(0,-1):f+=c.move("]"),f}function AB(){return"["}function T0(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function _B(e){const t=T0(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function kB(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function ST(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function CB(e,t,n,r){const a=n.enter("list"),u=n.bulletCurrent;let o=e.ordered?kB(n):T0(n);const c=e.ordered?o==="."?")":".":_B(n);let f=t&&n.bulletLastUsed?o===n.bulletLastUsed:!1;if(!e.ordered){const m=e.children?e.children[0]:void 0;if((o==="*"||o==="-")&&m&&(!m.children||!m.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(f=!0),ST(n)===o&&m){let p=-1;for(;++p<e.children.length;){const y=e.children[p];if(y&&y.type==="listItem"&&y.children&&y.children[0]&&y.children[0].type==="thematicBreak"){f=!0;break}}}}f&&(o=c),n.bulletCurrent=o;const d=n.containerFlow(e,r);return n.bulletLastUsed=o,n.bulletCurrent=u,a(),d}function TB(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function jB(e,t,n,r){const a=TB(n);let u=n.bulletCurrent||T0(n);t&&t.type==="list"&&t.ordered&&(u=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+u);let o=u.length+1;(a==="tab"||a==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(o=Math.ceil(o/4)*4);const c=n.createTracker(r);c.move(u+" ".repeat(o-u.length)),c.shift(o);const f=n.enter("listItem"),d=n.indentLines(n.containerFlow(e,c.current()),m);return f(),d;function m(p,y,g){return y?(g?"":" ".repeat(o))+p:(g?u:u+" ".repeat(o-u.length))+p}}function MB(e,t,n,r){const a=n.enter("paragraph"),u=n.enter("phrasing"),o=n.containerPhrasing(e,r);return u(),a(),o}const zB=Dd(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function DB(e,t,n,r){return(e.children.some(function(o){return zB(o)})?n.containerPhrasing:n.containerFlow).call(n,e,r)}function NB(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}OT.peek=PB;function OT(e,t,n,r){const a=NB(n),u=n.enter("strong"),o=n.createTracker(r),c=o.move(a+a);let f=o.move(n.containerPhrasing(e,{after:a,before:c,...o.current()}));const d=f.charCodeAt(0),m=Rf(r.before.charCodeAt(r.before.length-1),d,a);m.inside&&(f=es(d)+f.slice(1));const p=f.charCodeAt(f.length-1),y=Rf(r.after.charCodeAt(0),p,a);y.inside&&(f=f.slice(0,-1)+es(p));const g=o.move(a+a);return u(),n.attentionEncodeSurroundingInfo={after:y.outside,before:m.outside},c+f+g}function PB(e,t,n){return n.options.strong||"*"}function RB(e,t,n,r){return n.safe(e.value,r)}function IB(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function LB(e,t,n){const r=(ST(n)+(n.options.ruleSpaces?" ":"")).repeat(IB(n));return n.options.ruleSpaces?r.slice(0,-1):r}const ET={blockquote:uB,break:bE,code:hB,definition:pB,emphasis:mT,hardBreak:bE,heading:bB,html:pT,image:vT,imageReference:yT,inlineCode:gT,link:xT,linkReference:wT,list:CB,listItem:jB,paragraph:MB,root:DB,strong:OT,text:RB,thematicBreak:LB};function BB(){return{enter:{table:UB,tableData:xE,tableHeader:xE,tableRow:HB},exit:{codeText:$B,table:qB,tableData:hv,tableHeader:hv,tableRow:hv}}}function UB(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function qB(e){this.exit(e),this.data.inTable=void 0}function HB(e){this.enter({type:"tableRow",children:[]},e)}function hv(e){this.exit(e)}function xE(e){this.enter({type:"tableCell",children:[]},e)}function $B(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,FB));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function FB(e,t){return t==="|"?t:e}function VB(e){const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,a=t.stringLength,u=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:y,table:o,tableCell:f,tableRow:c}};function o(g,x,w,S){return d(m(g,w,S),g.align)}function c(g,x,w,S){const O=p(g,w,S),_=d([O]);return _.slice(0,_.indexOf(`
`))}function f(g,x,w,S){const O=w.enter("tableCell"),_=w.enter("phrasing"),k=w.containerPhrasing(g,{...S,before:u,after:u});return _(),O(),k}function d(g,x){return aB(g,{align:x,alignDelimiters:r,padding:n,stringLength:a})}function m(g,x,w){const S=g.children;let O=-1;const _=[],k=x.enter("table");for(;++O<S.length;)_[O]=p(S[O],x,w);return k(),_}function p(g,x,w){const S=g.children;let O=-1;const _=[],k=x.enter("tableRow");for(;++O<S.length;)_[O]=f(S[O],g,x,w);return k(),_}function y(g,x,w){let S=ET.inlineCode(g,x,w);return w.stack.includes("tableCell")&&(S=S.replace(/\|/g,"\\$&")),S}}function YB(){return{exit:{taskListCheckValueChecked:wE,taskListCheckValueUnchecked:wE,paragraph:GB}}}function KB(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:XB}}}function wE(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function GB(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const r=n.children[0];if(r&&r.type==="text"){const a=t.children;let u=-1,o;for(;++u<a.length;){const c=a[u];if(c.type==="paragraph"){o=c;break}}o===n&&(r.value=r.value.slice(1),r.value.length===0?n.children.shift():n.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,n.position.start=Object.assign({},r.position.start)))}}this.exit(e)}function XB(e,t,n,r){const a=e.children[0],u=typeof e.checked=="boolean"&&a&&a.type==="paragraph",o="["+(e.checked?"x":" ")+"] ",c=n.createTracker(r);u&&c.move(o);let f=ET.listItem(e,t,n,{...r,...c.current()});return u&&(f=f.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,d)),f;function d(m){return m+o}}function ZB(){return[C6(),X6(),J6(),BB(),YB()]}function QB(e){return{extensions:[T6(),Z6(e),eB(),VB(e),KB()]}}const WB={tokenize:i8,partial:!0},AT={tokenize:a8,partial:!0},_T={tokenize:l8,partial:!0},kT={tokenize:u8,partial:!0},JB={tokenize:o8,partial:!0},CT={name:"wwwAutolink",tokenize:n8,previous:jT},TT={name:"protocolAutolink",tokenize:r8,previous:MT},Ci={name:"emailAutolink",tokenize:t8,previous:zT},Kr={};function e8(){return{text:Kr}}let La=48;for(;La<123;)Kr[La]=Ci,La++,La===58?La=65:La===91&&(La=97);Kr[43]=Ci;Kr[45]=Ci;Kr[46]=Ci;Kr[95]=Ci;Kr[72]=[Ci,TT];Kr[104]=[Ci,TT];Kr[87]=[Ci,CT];Kr[119]=[Ci,CT];function t8(e,t,n){const r=this;let a,u;return o;function o(p){return!ug(p)||!zT.call(r,r.previous)||j0(r.events)?n(p):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),c(p))}function c(p){return ug(p)?(e.consume(p),c):p===64?(e.consume(p),f):n(p)}function f(p){return p===46?e.check(JB,m,d)(p):p===45||p===95||ln(p)?(u=!0,e.consume(p),f):m(p)}function d(p){return e.consume(p),a=!0,f}function m(p){return u&&a&&dn(r.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(p)):n(p)}}function n8(e,t,n){const r=this;return a;function a(o){return o!==87&&o!==119||!jT.call(r,r.previous)||j0(r.events)?n(o):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(WB,e.attempt(AT,e.attempt(_T,u),n),n)(o))}function u(o){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(o)}}function r8(e,t,n){const r=this;let a="",u=!1;return o;function o(p){return(p===72||p===104)&&MT.call(r,r.previous)&&!j0(r.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),a+=String.fromCodePoint(p),e.consume(p),c):n(p)}function c(p){if(dn(p)&&a.length<5)return a+=String.fromCodePoint(p),e.consume(p),c;if(p===58){const y=a.toLowerCase();if(y==="http"||y==="https")return e.consume(p),f}return n(p)}function f(p){return p===47?(e.consume(p),u?d:(u=!0,f)):n(p)}function d(p){return p===null||Df(p)||it(p)||Za(p)||jd(p)?n(p):e.attempt(AT,e.attempt(_T,m),n)(p)}function m(p){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(p)}}function i8(e,t,n){let r=0;return a;function a(o){return(o===87||o===119)&&r<3?(r++,e.consume(o),a):o===46&&r===3?(e.consume(o),u):n(o)}function u(o){return o===null?n(o):t(o)}}function a8(e,t,n){let r,a,u;return o;function o(d){return d===46||d===95?e.check(kT,f,c)(d):d===null||it(d)||Za(d)||d!==45&&jd(d)?f(d):(u=!0,e.consume(d),o)}function c(d){return d===95?r=!0:(a=r,r=void 0),e.consume(d),o}function f(d){return a||r||!u?n(d):t(d)}}function l8(e,t){let n=0,r=0;return a;function a(o){return o===40?(n++,e.consume(o),a):o===41&&r<n?u(o):o===33||o===34||o===38||o===39||o===41||o===42||o===44||o===46||o===58||o===59||o===60||o===63||o===93||o===95||o===126?e.check(kT,t,u)(o):o===null||it(o)||Za(o)?t(o):(e.consume(o),a)}function u(o){return o===41&&r++,e.consume(o),a}}function u8(e,t,n){return r;function r(c){return c===33||c===34||c===39||c===41||c===42||c===44||c===46||c===58||c===59||c===63||c===95||c===126?(e.consume(c),r):c===38?(e.consume(c),u):c===93?(e.consume(c),a):c===60||c===null||it(c)||Za(c)?t(c):n(c)}function a(c){return c===null||c===40||c===91||it(c)||Za(c)?t(c):r(c)}function u(c){return dn(c)?o(c):n(c)}function o(c){return c===59?(e.consume(c),r):dn(c)?(e.consume(c),o):n(c)}}function o8(e,t,n){return r;function r(u){return e.consume(u),a}function a(u){return ln(u)?n(u):t(u)}}function jT(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||it(e)}function MT(e){return!dn(e)}function zT(e){return!(e===47||ug(e))}function ug(e){return e===43||e===45||e===46||e===95||ln(e)}function j0(e){let t=e.length,n=!1;for(;t--;){const r=e[t][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){n=!0;break}if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const s8={tokenize:y8,partial:!0};function c8(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:m8,continuation:{tokenize:p8},exit:v8}},text:{91:{name:"gfmFootnoteCall",tokenize:h8},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:f8,resolveTo:d8}}}}function f8(e,t,n){const r=this;let a=r.events.length;const u=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let o;for(;a--;){const f=r.events[a][1];if(f.type==="labelImage"){o=f;break}if(f.type==="gfmFootnoteCall"||f.type==="labelLink"||f.type==="label"||f.type==="image"||f.type==="link")break}return c;function c(f){if(!o||!o._balanced)return n(f);const d=Ar(r.sliceSerialize({start:o.end,end:r.now()}));return d.codePointAt(0)!==94||!u.includes(d.slice(1))?n(f):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(f),e.exit("gfmFootnoteCallLabelMarker"),t(f))}}function d8(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},a={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};a.end.column++,a.end.offset++,a.end._bufferIndex++;const u={type:"gfmFootnoteCallString",start:Object.assign({},a.end),end:Object.assign({},e[e.length-1][1].start)},o={type:"chunkString",contentType:"string",start:Object.assign({},u.start),end:Object.assign({},u.end)},c=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",a,t],["exit",a,t],["enter",u,t],["enter",o,t],["exit",o,t],["exit",u,t],e[e.length-2],e[e.length-1],["exit",r,t]];return e.splice(n,e.length-n+1,...c),e}function h8(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let u=0,o;return c;function c(p){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(p),e.exit("gfmFootnoteCallLabelMarker"),f}function f(p){return p!==94?n(p):(e.enter("gfmFootnoteCallMarker"),e.consume(p),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",d)}function d(p){if(u>999||p===93&&!o||p===null||p===91||it(p))return n(p);if(p===93){e.exit("chunkString");const y=e.exit("gfmFootnoteCallString");return a.includes(Ar(r.sliceSerialize(y)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(p),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(p)}return it(p)||(o=!0),u++,e.consume(p),p===92?m:d}function m(p){return p===91||p===92||p===93?(e.consume(p),u++,d):d(p)}}function m8(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let u,o=0,c;return f;function f(x){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(x),e.exit("gfmFootnoteDefinitionLabelMarker"),d}function d(x){return x===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(x),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",m):n(x)}function m(x){if(o>999||x===93&&!c||x===null||x===91||it(x))return n(x);if(x===93){e.exit("chunkString");const w=e.exit("gfmFootnoteDefinitionLabelString");return u=Ar(r.sliceSerialize(w)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(x),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),y}return it(x)||(c=!0),o++,e.consume(x),x===92?p:m}function p(x){return x===91||x===92||x===93?(e.consume(x),o++,m):m(x)}function y(x){return x===58?(e.enter("definitionMarker"),e.consume(x),e.exit("definitionMarker"),a.includes(u)||a.push(u),He(e,g,"gfmFootnoteDefinitionWhitespace")):n(x)}function g(x){return t(x)}}function p8(e,t,n){return e.check(gs,t,e.attempt(s8,t,n))}function v8(e){e.exit("gfmFootnoteDefinition")}function y8(e,t,n){const r=this;return He(e,a,"gfmFootnoteDefinitionIndent",5);function a(u){const o=r.events[r.events.length-1];return o&&o[1].type==="gfmFootnoteDefinitionIndent"&&o[2].sliceSerialize(o[1],!0).length===4?t(u):n(u)}}function g8(e){let n=(e||{}).singleTilde;const r={name:"strikethrough",tokenize:u,resolveAll:a};return n==null&&(n=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function a(o,c){let f=-1;for(;++f<o.length;)if(o[f][0]==="enter"&&o[f][1].type==="strikethroughSequenceTemporary"&&o[f][1]._close){let d=f;for(;d--;)if(o[d][0]==="exit"&&o[d][1].type==="strikethroughSequenceTemporary"&&o[d][1]._open&&o[f][1].end.offset-o[f][1].start.offset===o[d][1].end.offset-o[d][1].start.offset){o[f][1].type="strikethroughSequence",o[d][1].type="strikethroughSequence";const m={type:"strikethrough",start:Object.assign({},o[d][1].start),end:Object.assign({},o[f][1].end)},p={type:"strikethroughText",start:Object.assign({},o[d][1].end),end:Object.assign({},o[f][1].start)},y=[["enter",m,c],["enter",o[d][1],c],["exit",o[d][1],c],["enter",p,c]],g=c.parser.constructs.insideSpan.null;g&&Fn(y,y.length,0,Md(g,o.slice(d+1,f),c)),Fn(y,y.length,0,[["exit",p,c],["enter",o[f][1],c],["exit",o[f][1],c],["exit",m,c]]),Fn(o,d-1,f-d+3,y),f=d+y.length-2;break}}for(f=-1;++f<o.length;)o[f][1].type==="strikethroughSequenceTemporary"&&(o[f][1].type="data");return o}function u(o,c,f){const d=this.previous,m=this.events;let p=0;return y;function y(x){return d===126&&m[m.length-1][1].type!=="characterEscape"?f(x):(o.enter("strikethroughSequenceTemporary"),g(x))}function g(x){const w=fu(d);if(x===126)return p>1?f(x):(o.consume(x),p++,g);if(p<2&&!n)return f(x);const S=o.exit("strikethroughSequenceTemporary"),O=fu(x);return S._open=!O||O===2&&!!w,S._close=!w||w===2&&!!O,c(x)}}}class b8{constructor(){this.map=[]}add(t,n,r){x8(this,t,n,r)}consume(t){if(this.map.sort(function(u,o){return u[0]-o[0]}),this.map.length===0)return;let n=this.map.length;const r=[];for(;n>0;)n-=1,r.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];r.push(t.slice()),t.length=0;let a=r.pop();for(;a;){for(const u of a)t.push(u);a=r.pop()}this.map.length=0}}function x8(e,t,n,r){let a=0;if(!(n===0&&r.length===0)){for(;a<e.map.length;){if(e.map[a][0]===t){e.map[a][1]+=n,e.map[a][2].push(...r);return}a+=1}e.map.push([t,n,r])}}function w8(e,t){let n=!1;const r=[];for(;t<e.length;){const a=e[t];if(n){if(a[0]==="enter")a[1].type==="tableContent"&&r.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(a[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const u=r.length-1;r[u]=r[u]==="left"?"center":"right"}}else if(a[1].type==="tableDelimiterRow")break}else a[0]==="enter"&&a[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return r}function S8(){return{flow:{null:{name:"table",tokenize:O8,resolveAll:E8}}}}function O8(e,t,n){const r=this;let a=0,u=0,o;return c;function c(P){let F=r.events.length-1;for(;F>-1;){const Z=r.events[F][1].type;if(Z==="lineEnding"||Z==="linePrefix")F--;else break}const I=F>-1?r.events[F][1].type:null,ee=I==="tableHead"||I==="tableRow"?C:f;return ee===C&&r.parser.lazy[r.now().line]?n(P):ee(P)}function f(P){return e.enter("tableHead"),e.enter("tableRow"),d(P)}function d(P){return P===124||(o=!0,u+=1),m(P)}function m(P){return P===null?n(P):Ae(P)?u>1?(u=0,r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(P),e.exit("lineEnding"),g):n(P):Re(P)?He(e,m,"whitespace")(P):(u+=1,o&&(o=!1,a+=1),P===124?(e.enter("tableCellDivider"),e.consume(P),e.exit("tableCellDivider"),o=!0,m):(e.enter("data"),p(P)))}function p(P){return P===null||P===124||it(P)?(e.exit("data"),m(P)):(e.consume(P),P===92?y:p)}function y(P){return P===92||P===124?(e.consume(P),p):p(P)}function g(P){return r.interrupt=!1,r.parser.lazy[r.now().line]?n(P):(e.enter("tableDelimiterRow"),o=!1,Re(P)?He(e,x,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(P):x(P))}function x(P){return P===45||P===58?S(P):P===124?(o=!0,e.enter("tableCellDivider"),e.consume(P),e.exit("tableCellDivider"),w):N(P)}function w(P){return Re(P)?He(e,S,"whitespace")(P):S(P)}function S(P){return P===58?(u+=1,o=!0,e.enter("tableDelimiterMarker"),e.consume(P),e.exit("tableDelimiterMarker"),O):P===45?(u+=1,O(P)):P===null||Ae(P)?M(P):N(P)}function O(P){return P===45?(e.enter("tableDelimiterFiller"),_(P)):N(P)}function _(P){return P===45?(e.consume(P),_):P===58?(o=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(P),e.exit("tableDelimiterMarker"),k):(e.exit("tableDelimiterFiller"),k(P))}function k(P){return Re(P)?He(e,M,"whitespace")(P):M(P)}function M(P){return P===124?x(P):P===null||Ae(P)?!o||a!==u?N(P):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(P)):N(P)}function N(P){return n(P)}function C(P){return e.enter("tableRow"),z(P)}function z(P){return P===124?(e.enter("tableCellDivider"),e.consume(P),e.exit("tableCellDivider"),z):P===null||Ae(P)?(e.exit("tableRow"),t(P)):Re(P)?He(e,z,"whitespace")(P):(e.enter("data"),$(P))}function $(P){return P===null||P===124||it(P)?(e.exit("data"),z(P)):(e.consume(P),P===92?H:$)}function H(P){return P===92||P===124?(e.consume(P),$):$(P)}}function E8(e,t){let n=-1,r=!0,a=0,u=[0,0,0,0],o=[0,0,0,0],c=!1,f=0,d,m,p;const y=new b8;for(;++n<e.length;){const g=e[n],x=g[1];g[0]==="enter"?x.type==="tableHead"?(c=!1,f!==0&&(SE(y,t,f,d,m),m=void 0,f=0),d={type:"table",start:Object.assign({},x.start),end:Object.assign({},x.end)},y.add(n,0,[["enter",d,t]])):x.type==="tableRow"||x.type==="tableDelimiterRow"?(r=!0,p=void 0,u=[0,0,0,0],o=[0,n+1,0,0],c&&(c=!1,m={type:"tableBody",start:Object.assign({},x.start),end:Object.assign({},x.end)},y.add(n,0,[["enter",m,t]])),a=x.type==="tableDelimiterRow"?2:m?3:1):a&&(x.type==="data"||x.type==="tableDelimiterMarker"||x.type==="tableDelimiterFiller")?(r=!1,o[2]===0&&(u[1]!==0&&(o[0]=o[1],p=uf(y,t,u,a,void 0,p),u=[0,0,0,0]),o[2]=n)):x.type==="tableCellDivider"&&(r?r=!1:(u[1]!==0&&(o[0]=o[1],p=uf(y,t,u,a,void 0,p)),u=o,o=[u[1],n,0,0])):x.type==="tableHead"?(c=!0,f=n):x.type==="tableRow"||x.type==="tableDelimiterRow"?(f=n,u[1]!==0?(o[0]=o[1],p=uf(y,t,u,a,n,p)):o[1]!==0&&(p=uf(y,t,o,a,n,p)),a=0):a&&(x.type==="data"||x.type==="tableDelimiterMarker"||x.type==="tableDelimiterFiller")&&(o[3]=n)}for(f!==0&&SE(y,t,f,d,m),y.consume(t.events),n=-1;++n<t.events.length;){const g=t.events[n];g[0]==="enter"&&g[1].type==="table"&&(g[1]._align=w8(t.events,n))}return e}function uf(e,t,n,r,a,u){const o=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",c="tableContent";n[0]!==0&&(u.end=Object.assign({},ru(t.events,n[0])),e.add(n[0],0,[["exit",u,t]]));const f=ru(t.events,n[1]);if(u={type:o,start:Object.assign({},f),end:Object.assign({},f)},e.add(n[1],0,[["enter",u,t]]),n[2]!==0){const d=ru(t.events,n[2]),m=ru(t.events,n[3]),p={type:c,start:Object.assign({},d),end:Object.assign({},m)};if(e.add(n[2],0,[["enter",p,t]]),r!==2){const y=t.events[n[2]],g=t.events[n[3]];if(y[1].end=Object.assign({},g[1].end),y[1].type="chunkText",y[1].contentType="text",n[3]>n[2]+1){const x=n[2]+1,w=n[3]-n[2]-1;e.add(x,w,[])}}e.add(n[3]+1,0,[["exit",p,t]])}return a!==void 0&&(u.end=Object.assign({},ru(t.events,a)),e.add(a,0,[["exit",u,t]]),u=void 0),u}function SE(e,t,n,r,a){const u=[],o=ru(t.events,n);a&&(a.end=Object.assign({},o),u.push(["exit",a,t])),r.end=Object.assign({},o),u.push(["exit",r,t]),e.add(n+1,0,u)}function ru(e,t){const n=e[t],r=n[0]==="enter"?"start":"end";return n[1][r]}const A8={name:"tasklistCheck",tokenize:k8};function _8(){return{text:{91:A8}}}function k8(e,t,n){const r=this;return a;function a(f){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?n(f):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(f),e.exit("taskListCheckMarker"),u)}function u(f){return it(f)?(e.enter("taskListCheckValueUnchecked"),e.consume(f),e.exit("taskListCheckValueUnchecked"),o):f===88||f===120?(e.enter("taskListCheckValueChecked"),e.consume(f),e.exit("taskListCheckValueChecked"),o):n(f)}function o(f){return f===93?(e.enter("taskListCheckMarker"),e.consume(f),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),c):n(f)}function c(f){return Ae(f)?t(f):Re(f)?e.check({tokenize:C8},t,n)(f):n(f)}}function C8(e,t,n){return He(e,r,"whitespace");function r(a){return a===null?n(a):t(a)}}function T8(e){return $C([e8(),c8(),g8(e),S8(),_8()])}const j8={};function M0(e){const t=this,n=e||j8,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),u=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),o=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(T8(n)),u.push(ZB()),o.push(QB(n))}const M8={execute:nf,execute_cell:nf,execute_all_cells:nf,bash:nf,write_file:nu,edit_file:nu,read_file:nu,create_cell:nu,modify_cell:nu,ls:Zp,glob:Zp,grep:Zp,write_todos:_C,think_tool:RI,task:YI,display_inline:GI};function z8(e){return(Array.isArray(e)?e:[]).map(n=>{if(n&&typeof n=="object"){const r=n;return{content:r.content??r.task??"",status:r.status??(r.done===!0?"completed":"pending")}}return{content:String(n),status:"pending"}})}function OE(e){const t=Object.keys(e);if(t.length===0)return null;const n=e[t[0]];if(n==null)return null;const r=typeof n=="string"?n:JSON.stringify(n);return r.length>100?r.slice(0,100)+"…":r}function D8({toolCall:e}){const[t,n]=E.useState(!1),r=M8[e.name]||u3,a=e.extraction,u=e.status==="running"?T.jsx(c0,{size:12,className:"animate-spin text-[var(--color-text-muted)]"}):e.status==="success"?T.jsx(s0,{size:12,className:"text-[var(--color-success)]"}):T.jsx(LI,{size:12,className:"text-[var(--color-error)]"}),o=e.durationMs!=null?e.durationMs<1e3?`${Math.round(e.durationMs)}ms`:`${(e.durationMs/1e3).toFixed(1)}s`:null;return T.jsxs("div",{className:"rounded border border-[var(--color-border)] bg-[var(--color-surface-2)] overflow-hidden",children:[T.jsxs("button",{onClick:()=>n(!t),className:"flex items-center gap-2 w-full px-3 py-1.5 text-left text-xs hover:bg-[var(--color-surface-3)] transition-colors",children:[T.jsx(EC,{size:12,className:`text-[var(--color-text-muted)] transition-transform ${t?"rotate-90":""}`}),T.jsx(r,{size:12,className:"text-[var(--color-text-muted)]"}),T.jsx("span",{className:"font-medium text-[var(--color-text-secondary)]",children:e.name}),OE(e.args)&&T.jsxs("code",{className:"text-[11px] text-[var(--color-text-muted)] truncate max-w-[300px]",children:["(",OE(e.args),")"]}),T.jsx("span",{className:"flex-1"}),o&&T.jsx("span",{className:"text-[11px] tabular-nums text-[var(--color-text-muted)]",children:o}),u]}),(a==null?void 0:a.extracted_type)==="reflection"&&T.jsx("div",{className:"border-t border-[var(--color-border)] px-3 py-2",children:T.jsx("p",{className:"text-xs italic text-[var(--color-text-secondary)] leading-relaxed",children:String(a.data)})}),(a==null?void 0:a.extracted_type)==="todos"&&T.jsx("div",{className:"border-t border-[var(--color-border)] px-3 py-2",children:T.jsx(L8,{todos:z8(a.data)})}),(a==null?void 0:a.extracted_type)==="display_inline"&&T.jsx("div",{className:"border-t border-[var(--color-border)]",children:T.jsx(N8,{data:a.data})}),t&&T.jsxs("div",{className:"border-t border-[var(--color-border)] px-3 py-2 space-y-2",children:[Object.keys(e.args).length>0&&T.jsxs("div",{children:[T.jsx("div",{className:"text-[11px] font-medium uppercase tracking-wide text-[var(--color-text-muted)] mb-1",children:"Arguments"}),T.jsx("pre",{className:"bg-[var(--color-surface-3)] rounded p-2 text-xs overflow-x-auto whitespace-pre-wrap break-all text-[var(--color-text)]",children:JSON.stringify(e.args,null,2)})]}),e.result!=null&&T.jsxs("div",{children:[T.jsx("div",{className:"text-[11px] font-medium uppercase tracking-wide text-[var(--color-text-muted)] mb-1",children:"Result"}),T.jsx("pre",{className:`rounded p-2 text-xs overflow-auto max-h-[400px] whitespace-pre-wrap break-all ${e.name==="execute"||e.name==="bash"||e.name==="execute_cell"?"bg-[#111827] text-emerald-400":"bg-[var(--color-surface-3)] text-[var(--color-text)]"}`,children:typeof e.result=="string"?e.result:JSON.stringify(e.result,null,2)})]}),e.errorMessage&&T.jsxs("div",{children:[T.jsx("div",{className:"text-[11px] font-medium uppercase tracking-wide text-[var(--color-error)] mb-1",children:"Error"}),T.jsx("pre",{className:"bg-red-50 dark:bg-red-950/30 text-[var(--color-error)] rounded p-2 text-xs overflow-x-auto whitespace-pre-wrap",children:e.errorMessage})]})]})]})}function N8({data:e}){const t=e.display_type,n=e.title,r=e.data,a=e.status,u=e.error;return a==="error"?T.jsxs("div",{className:"px-3 py-2 space-y-1",children:[n&&T.jsx("div",{className:"text-[11px] font-medium text-[var(--color-text-muted)]",children:n}),T.jsxs("div",{className:"flex items-start gap-2 text-xs text-[var(--color-error)]",children:[T.jsx(a3,{size:12,className:"flex-shrink-0 mt-0.5"}),T.jsx("span",{children:u||String(r)})]})]}):T.jsxs("div",{className:"px-3 py-2 space-y-1.5",children:[n&&T.jsx("div",{className:"text-[11px] font-medium text-[var(--color-text-muted)]",children:n}),t==="image"&&T.jsx("img",{src:typeof r=="string"&&r.startsWith("data:")?r:`data:image/png;base64,${r}`,alt:n||"Inline display",className:"max-w-full rounded"}),t==="html"&&T.jsx(R8,{html:String(r),title:n}),t==="plotly"&&T.jsx(I8,{data:r,title:n}),(t==="dataframe"||t==="csv")&&!!r&&typeof r=="object"&&"columns"in r&&T.jsx("div",{className:"overflow-x-auto max-h-[300px] overflow-y-auto",children:T.jsxs("table",{className:"w-full text-xs border-collapse",children:[T.jsx("thead",{children:T.jsx("tr",{children:r.columns.map(o=>T.jsx("th",{className:"border border-[var(--color-border)] bg-[var(--color-surface-3)] px-2 py-1 text-left font-medium text-[var(--color-text-secondary)]",children:o},o))})}),T.jsx("tbody",{children:r.data.map((o,c)=>T.jsx("tr",{children:o.map((f,d)=>T.jsx("td",{className:"border border-[var(--color-border)] px-2 py-1 text-[var(--color-text)]",children:String(f??"")},d))},c))})]})}),t==="pdf"&&typeof r=="string"&&T.jsx("iframe",{src:`data:application/pdf;base64,${r}`,title:n||"PDF preview",className:"w-full h-[500px] rounded border border-[var(--color-border)]"}),t==="json"&&T.jsx("pre",{className:"bg-[var(--color-surface-3)] rounded p-2 text-xs overflow-x-auto whitespace-pre-wrap break-all text-[var(--color-text)]",children:typeof r=="string"?r:JSON.stringify(r,null,2)}),t==="text"&&T.jsx("pre",{className:"text-xs whitespace-pre-wrap text-[var(--color-text)] leading-relaxed",children:String(r)})]})}const P8=`<script>
function _sendHeight(){
  var h=document.documentElement.scrollHeight;
  window.parent.postMessage({type:'iframe-resize',height:h},'*');
}
window.addEventListener('load',function(){_sendHeight();setTimeout(_sendHeight,200);setTimeout(_sendHeight,1000);});
new MutationObserver(_sendHeight).observe(document.body,{childList:true,subtree:true});
<\/script>`;function R8({html:e,title:t}){const n=E.useRef(null),[r,a]=E.useState(200);E.useEffect(()=>{const o=n.current;if(!o)return;const c=f=>{var d;if(f.source===o.contentWindow&&((d=f.data)==null?void 0:d.type)==="iframe-resize"){const m=Math.max(60,Math.min(f.data.height,600));a(m)}};return window.addEventListener("message",c),()=>window.removeEventListener("message",c)},[e]);const u=`<!DOCTYPE html>
<html><head><meta charset="utf-8"><style>
  body { margin: 0; padding: 8px; font-family: system-ui, sans-serif; font-size: 13px; }
  img, table, svg { max-width: 100%; }
</style></head><body>${e}${P8}</body></html>`;return T.jsx("iframe",{ref:n,srcDoc:u,title:t||"HTML preview",sandbox:"allow-scripts allow-same-origin",className:"w-full rounded border-0",style:{height:`${r}px`}})}function I8({data:e,title:t}){const n=E.useRef(null),[r,a]=E.useState(400);E.useEffect(()=>{const c=n.current;if(!c)return;const f=d=>{var m;if(d.source===c.contentWindow&&((m=d.data)==null?void 0:m.type)==="iframe-resize"){const p=Math.max(200,Math.min(d.data.height,600));a(p)}};return window.addEventListener("message",f),()=>window.removeEventListener("message",f)},[e]);const o=`<!DOCTYPE html>
<html><head><meta charset="utf-8">
<script src="https://cdn.plot.ly/plotly-2.35.2.min.js"><\/script>
<style>body{margin:0;padding:0;}</style>
</head><body>
<div id="chart" style="width:100%;"></div>
<script>
var spec=${JSON.stringify(e)};
var d=spec.data||[];
var l=Object.assign({margin:{t:30,r:20,b:40,l:50},autosize:true},spec.layout||{});
Plotly.newPlot('chart',d,l,{responsive:true,displayModeBar:false}).then(function(){
  var h=document.getElementById('chart').offsetHeight;
  window.parent.postMessage({type:'iframe-resize',height:h},'*');
});
<\/script></body></html>`;return T.jsx("iframe",{ref:n,srcDoc:o,title:t||"Plotly chart",sandbox:"allow-scripts allow-same-origin",className:"w-full rounded border-0",style:{height:`${r}px`}})}function L8({todos:e}){const t=e.filter(r=>r.status==="completed").length,n=e.length;return T.jsxs("div",{className:"space-y-1",children:[T.jsxs("div",{className:"text-[11px] text-[var(--color-text-muted)]",children:[t,"/",n," completed"]}),e.map((r,a)=>T.jsxs("div",{className:"flex items-center gap-2 text-xs",children:[r.status==="completed"?T.jsx(s0,{size:11,className:"text-[var(--color-success)] flex-shrink-0"}):r.status==="in_progress"?T.jsx(Xy,{size:11,className:"text-[var(--color-primary)] fill-[var(--color-primary)] flex-shrink-0"}):T.jsx(Xy,{size:11,className:"text-[var(--color-text-muted)] flex-shrink-0"}),T.jsx("span",{className:r.status==="completed"?"text-[var(--color-text-muted)] line-through":"text-[var(--color-text-secondary)]",children:r.content})]},a))]})}function B8(e){return e?new Date(e).toLocaleTimeString([],{hour:"2-digit",minute:"2-digit"}):""}function U8(e){if(e<1e3)return`${Math.round(e)}ms`;if(e<6e4)return`${(e/1e3).toFixed(1)}s`;const t=Math.floor(e/6e4),n=Math.round(e%6e4/1e3);return`${t}m ${n}s`}function q8(e,t){const[n,r]=E.useState(null);return E.useEffect(()=>{if(!e||!t){r(null);return}const a=()=>r(Date.now()-e);a();const u=setInterval(a,1e3);return()=>clearInterval(u)},[e,t]),n}function H8({message:e,agentName:t="Agent",showLabel:n=!0}){const r=e.role==="user",a=e.role==="system",u=e.role==="assistant",o=r?"You":t,c=q8(e.startedAt,e.isStreaming),f=e.durationMs??c;return a?T.jsx("div",{className:"py-1",children:T.jsx("p",{className:"text-xs italic text-[var(--color-text-muted)]",children:e.content})}):T.jsxs("div",{className:`group border-l-2 pl-3 ${r?"border-[var(--color-text-muted)]":"border-[var(--color-primary)]"}`,children:[n&&T.jsxs("div",{className:"flex items-center gap-2 mb-1",children:[T.jsx("span",{className:`text-[11px] font-semibold tracking-wider uppercase ${r?"text-[var(--color-text-secondary)]":"text-[var(--color-primary)]"}`,children:o}),e.timestamp&&T.jsx("span",{className:"text-[10px] text-[var(--color-text-muted)] tabular-nums opacity-0 group-hover:opacity-100 transition-opacity",children:B8(e.timestamp)}),u&&f!=null&&T.jsx("span",{className:"text-[10px] text-[var(--color-text-muted)] tabular-nums",children:U8(f)})]}),e.content&&T.jsx("div",{className:"text-sm text-[var(--color-text)] leading-relaxed",children:r?T.jsx("p",{className:"whitespace-pre-wrap",children:e.content}):T.jsx("div",{className:"markdown-content",children:T.jsx(k0,{remarkPlugins:[M0],children:e.content})})}),e.toolCalls.length>0&&T.jsx("div",{className:`space-y-1.5 ${e.content?"mt-2":""}`,children:e.toolCalls.map(d=>T.jsx(D8,{toolCall:d},d.id))})]})}function $8({messages:e,isStreaming:t,welcomeMessage:n,agentName:r,iconUrl:a,onSend:u,onCancel:o}){const[c,f]=E.useState(""),d=E.useRef(null),m=E.useRef(null),p=E.useRef(!0),y=E.useCallback(()=>{const S=d.current;S&&(p.current=S.scrollHeight-S.scrollTop-S.clientHeight<80)},[]);E.useEffect(()=>{p.current&&d.current&&(d.current.scrollTop=d.current.scrollHeight)},[e]);const g=()=>{const S=c.trim();!S||t||(p.current=!0,u(S),f(""),m.current&&(m.current.style.height="auto"))},x=S=>{S.key==="Enter"&&!S.shiftKey&&(S.preventDefault(),g())},w=S=>{f(S.target.value);const O=S.target;O.style.height="auto",O.style.height=Math.min(O.scrollHeight,200)+"px"};return T.jsxs("div",{className:"flex flex-col h-full bg-[var(--color-surface)]",children:[T.jsx("div",{ref:d,onScroll:y,className:"flex-1 overflow-y-auto",children:T.jsxs("div",{className:"max-w-4xl mx-auto px-5 py-6 space-y-5",children:[e.length===0&&T.jsxs("div",{className:"flex flex-col items-center justify-center py-16 gap-5",children:[a?T.jsx("img",{src:a,alt:"",className:"w-12 h-12 rounded-xl object-cover shadow-sm"}):T.jsx("div",{className:"w-12 h-12 rounded-xl bg-gradient-to-br from-[var(--color-primary)] to-[var(--color-primary-dark)] flex items-center justify-center shadow-sm",children:T.jsx(kC,{size:22,className:"text-white"})}),n?T.jsx("div",{className:"text-sm text-[var(--color-text-secondary)] markdown-content text-center max-w-md",children:T.jsx(k0,{remarkPlugins:[M0],children:n})}):T.jsxs("div",{className:"text-center",children:[T.jsx("p",{className:"text-sm font-medium text-[var(--color-text)]",children:"What can I help you with?"}),T.jsx("p",{className:"text-xs text-[var(--color-text-muted)] mt-1",children:"Ask a question to get started"})]})]}),e.map((S,O)=>T.jsx(H8,{message:S,agentName:r,showLabel:O===0||e[O-1].role!==S.role},S.id)),t&&e.length>0&&T.jsxs("div",{className:"flex items-center gap-2 text-xs text-[var(--color-text-muted)]",children:[T.jsxs("span",{className:"flex gap-1",children:[T.jsx("span",{className:"w-1.5 h-1.5 rounded-full bg-[var(--color-primary)] animate-bounce",style:{animationDelay:"0ms"}}),T.jsx("span",{className:"w-1.5 h-1.5 rounded-full bg-[var(--color-primary)] animate-bounce",style:{animationDelay:"150ms"}}),T.jsx("span",{className:"w-1.5 h-1.5 rounded-full bg-[var(--color-primary)] animate-bounce",style:{animationDelay:"300ms"}})]}),r," is working..."]})]})}),T.jsx("div",{className:"border-t border-[var(--color-border)]",children:T.jsxs("div",{className:"max-w-4xl mx-auto px-5 py-3",children:[T.jsxs("div",{className:"flex items-end gap-2 rounded-lg border border-[var(--color-border)] bg-[var(--color-surface-2)] px-3 py-2 focus-within:border-[var(--color-text-muted)] transition-colors",children:[T.jsx("textarea",{ref:m,value:c,onChange:w,onKeyDown:x,placeholder:"Send a message...",rows:1,className:"flex-1 resize-none bg-transparent text-sm text-[var(--color-text)] placeholder:text-[var(--color-text-muted)] focus:outline-none leading-relaxed"}),t?T.jsx("button",{onClick:o,className:"flex-shrink-0 w-7 h-7 flex items-center justify-center rounded-md bg-[var(--color-text)] text-[var(--color-surface)] hover:opacity-80 transition-opacity",title:"Stop",children:T.jsx(r3,{size:12,fill:"currentColor"})}):T.jsx("button",{onClick:g,disabled:!c.trim(),className:"flex-shrink-0 w-7 h-7 flex items-center justify-center rounded-md bg-[var(--color-text)] text-[var(--color-surface)] disabled:opacity-20 disabled:cursor-not-allowed hover:opacity-80 transition-opacity",title:"Send",children:T.jsx(PI,{size:14,strokeWidth:2.5})})]}),T.jsx("div",{className:"text-center mt-1.5",children:T.jsxs("span",{className:"text-[10px] text-[var(--color-text-muted)]",children:[T.jsx("kbd",{className:"px-1 py-0.5 rounded bg-[var(--color-surface-3)] text-[9px] font-mono",children:"Enter"})," to send, ",T.jsx("kbd",{className:"px-1 py-0.5 rounded bg-[var(--color-surface-3)] text-[9px] font-mono",children:"Shift+Enter"})," for new line"]})})]})})]})}const F8=new Set([".py",".js",".jsx",".ts",".tsx",".json",".yaml",".yml",".toml",".rs",".go",".java",".c",".cpp",".h",".hpp",".rb",".php",".sql",".sh",".bash",".r",".css",".html",".xml"]);function V8(e){var n;const t="."+((n=e.split(".").pop())==null?void 0:n.toLowerCase());return F8.has(t)?qI:[".md",".txt",".csv",".log"].some(r=>e.endsWith(r))?nu:HI}function Y8(e){return e==null?"":e<1024?`${e} B`:e<1024*1024?`${(e/1024).toFixed(1)} KB`:`${(e/(1024*1024)).toFixed(1)} MB`}function DT({entry:e,expandedDirs:t,depth:n,onToggleDir:r,onOpenFile:a,onEnterDir:u,onContextMenu:o}){const c=t.has(e.path);if(e.is_dir){const d=c?$I:Zy;return T.jsxs("div",{children:[T.jsxs("button",{onClick:()=>r(e.path),onDoubleClick:()=>u(e.path),onContextMenu:m=>o(m,e.path,e.name),className:"flex items-center gap-1.5 w-full px-2 py-1 text-sm hover:bg-[var(--color-surface-3)] rounded transition-colors",style:{paddingLeft:`${n*16+8}px`},children:[c?T.jsx(OC,{size:14,className:"text-[var(--color-text-muted)] flex-shrink-0"}):T.jsx(EC,{size:14,className:"text-[var(--color-text-muted)] flex-shrink-0"}),T.jsx(d,{size:14,className:"text-[var(--color-warning)] flex-shrink-0"}),T.jsx("span",{className:"truncate text-[var(--color-text)]",children:e.name})]}),c&&e.children&&T.jsx("div",{children:e.children.map(m=>T.jsx(DT,{entry:m,expandedDirs:t,depth:n+1,onToggleDir:r,onOpenFile:a,onEnterDir:u,onContextMenu:o},m.path))})]})}const f=V8(e.name);return T.jsxs("button",{onClick:()=>a(e.path),onContextMenu:d=>o(d,e.path,e.name),className:"flex items-center gap-1.5 w-full px-2 py-1 text-sm hover:bg-[var(--color-surface-3)] rounded transition-colors",style:{paddingLeft:`${n*16+22}px`},children:[T.jsx(f,{size:14,className:"text-[var(--color-text-secondary)] flex-shrink-0"}),T.jsx("span",{className:"truncate text-[var(--color-text)]",children:e.name}),e.size!=null&&T.jsx("span",{className:"ml-auto text-xs text-[var(--color-text-muted)] flex-shrink-0",children:Y8(e.size)})]})}function K8({entries:e,expandedDirs:t,loading:n,workspacePath:r,onToggleDir:a,onOpenFile:u,onEnterDir:o,onUpload:c,onCreateFolder:f,onDelete:d}){const[m,p]=E.useState(!1),[y,g]=E.useState(""),[x,w]=E.useState(null),S=E.useRef(null),O=E.useRef(null);E.useEffect(()=>{if(!x)return;const z=H=>{O.current&&!O.current.contains(H.target)&&w(null)},$=H=>{H.key==="Escape"&&w(null)};return document.addEventListener("mousedown",z),document.addEventListener("keydown",$),()=>{document.removeEventListener("mousedown",z),document.removeEventListener("keydown",$)}},[x]);const _=(z,$,H)=>{z.preventDefault(),w({x:z.clientX,y:z.clientY,path:$,name:H})},k=()=>{x&&(window.confirm(`Delete "${x.name}"?`)&&d(x.path),w(null))},M=()=>{const z=y.trim();z&&(f(z),g(""),p(!1))},N=z=>{const $=z.target.files;if($){for(let H=0;H<$.length;H++)c($[H]);z.target.value=""}},C=[];if(r!=="/"){const z=r.replace(/^\//,"").split("/");let $="";for(const H of z)$+="/"+H,C.push({label:H,path:$})}return T.jsxs("div",{className:"flex flex-col h-full",children:[T.jsxs("div",{className:"flex items-center gap-1 px-2 py-1.5 border-b border-[var(--color-border)]",children:[T.jsxs("div",{className:"flex items-center gap-0.5 flex-1 min-w-0 text-xs text-[var(--color-text-secondary)]",children:[T.jsx("button",{onClick:()=>o("/"),className:"p-0.5 rounded hover:bg-[var(--color-surface-3)] transition-colors flex-shrink-0",title:"Workspace root",children:T.jsx(KI,{size:13})}),C.map(z=>T.jsxs("span",{className:"flex items-center gap-0.5 min-w-0",children:[T.jsx("span",{className:"text-[var(--color-text-muted)]",children:"/"}),T.jsx("button",{onClick:()=>o(z.path),className:"truncate hover:underline",children:z.label})]},z.path))]}),T.jsx("button",{onClick:()=>p(z=>!z),className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors flex-shrink-0",title:"New folder",children:T.jsx(FI,{size:14,className:"text-[var(--color-text-secondary)]"})}),T.jsx("button",{onClick:()=>{var z;return(z=S.current)==null?void 0:z.click()},className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors flex-shrink-0",title:"Upload file",children:T.jsx(l3,{size:14,className:"text-[var(--color-text-secondary)]"})}),T.jsx("input",{ref:S,type:"file",multiple:!0,onChange:N,className:"hidden"})]}),m&&T.jsxs("div",{className:"flex items-center gap-1 px-2 py-1.5 border-b border-[var(--color-border)]",children:[T.jsx("input",{autoFocus:!0,value:y,onChange:z=>g(z.target.value),onKeyDown:z=>{z.key==="Enter"&&M(),z.key==="Escape"&&p(!1)},placeholder:"Folder name...",className:"flex-1 text-xs bg-transparent text-[var(--color-text)] placeholder:text-[var(--color-text-muted)] focus:outline-none border border-[var(--color-border)] rounded px-2 py-1"}),T.jsx("button",{onClick:M,className:"text-xs text-[var(--color-primary)] hover:underline px-1",children:"Create"})]}),T.jsx("div",{className:"flex-1 overflow-y-auto py-1",children:n&&e.length===0?T.jsxs("div",{className:"flex flex-col items-center justify-center h-full gap-2",children:[T.jsx(Zy,{size:20,className:"text-[var(--color-text-muted)] animate-pulse"}),T.jsx("span",{className:"text-sm text-[var(--color-text-muted)]",children:"Loading files..."})]}):e.length===0?T.jsxs("div",{className:"flex flex-col items-center justify-center h-full gap-3 px-6",children:[T.jsx("div",{className:"w-10 h-10 rounded-lg bg-[var(--color-surface-3)] flex items-center justify-center",children:T.jsx(Zy,{size:20,className:"text-[var(--color-text-muted)]"})}),T.jsxs("div",{className:"text-center",children:[T.jsx("p",{className:"text-sm font-medium text-[var(--color-text-secondary)]",children:"Workspace is empty"}),T.jsx("p",{className:"text-xs text-[var(--color-text-muted)] mt-1",children:"Upload files or create folders to get started"})]})]}):e.map(z=>T.jsx(DT,{entry:z,expandedDirs:t,depth:0,onToggleDir:a,onOpenFile:u,onEnterDir:o,onContextMenu:_},z.path))}),x&&T.jsx("div",{ref:O,className:"fixed z-50 bg-[var(--color-surface-2)] border border-[var(--color-border)] rounded-md shadow-lg py-1 min-w-[140px]",style:{left:x.x,top:x.y},children:T.jsxs("button",{onClick:k,className:"flex items-center gap-2 w-full px-3 py-1.5 text-xs text-[var(--color-error)] hover:bg-[var(--color-surface-3)] transition-colors",children:[T.jsx(CC,{size:13}),"Delete"]})})]})}function G8(e){return e<1024?`${e} B`:e<1024*1024?`${(e/1024).toFixed(1)} KB`:`${(e/(1024*1024)).toFixed(1)} MB`}function X8({file:e,onClose:t}){const[n,r]=E.useState(!1),a=e.preview_type!=="text"&&e.preview_type!=="binary",u=!!e.data;return T.jsxs("div",{className:"flex flex-col h-full bg-[var(--color-surface)]",children:[T.jsxs("div",{className:"flex items-center justify-between px-3 py-2 border-b border-[var(--color-border)] bg-[var(--color-surface-2)]",children:[T.jsxs("div",{className:"flex items-center gap-2 min-w-0",children:[T.jsx("span",{className:"text-sm font-medium text-[var(--color-text)] truncate",children:e.name}),T.jsx("span",{className:"text-xs text-[var(--color-text-muted)] flex-shrink-0",children:G8(e.size)})]}),T.jsxs("div",{className:"flex items-center gap-1 flex-shrink-0",children:[a&&u&&T.jsx("button",{onClick:()=>r(o=>!o),className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",title:n?"Preview":"View raw",children:n?T.jsx(UI,{size:14,className:"text-[var(--color-text-secondary)]"}):T.jsx(BI,{size:14,className:"text-[var(--color-text-secondary)]"})}),T.jsx("a",{href:`/api/files/download?path=${encodeURIComponent(e.path)}`,download:e.name,className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",title:"Download",children:T.jsx(AC,{size:14,className:"text-[var(--color-text-secondary)]"})}),T.jsx("button",{onClick:t,className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",children:T.jsx(f0,{size:14,className:"text-[var(--color-text-secondary)]"})})]})]}),T.jsx("div",{className:"flex-1 overflow-auto",children:n&&u?T.jsx(NT,{content:e.data}):T.jsx(Z8,{file:e})})]})}function Z8({file:e}){switch(e.preview_type){case"text":return T.jsx(NT,{content:e.data||""});case"image":return T.jsx("div",{className:"flex items-center justify-center p-6",children:T.jsx("img",{src:`data:${e.mime||"image/png"};base64,${e.data}`,alt:e.name,className:"max-w-full max-h-[80vh] rounded shadow-sm"})});case"html":return T.jsx("iframe",{srcDoc:e.data||"",title:e.name,className:"w-full h-full border-0",sandbox:"allow-scripts"});case"csv":return T.jsx(Q8,{headers:e.headers,rows:e.rows});case"pdf":return e.data?T.jsx("iframe",{src:`data:application/pdf;base64,${e.data}`,title:e.name,className:"w-full h-full border-0"}):T.jsxs("div",{className:"flex flex-col items-center justify-center h-full gap-4 text-[var(--color-text-secondary)]",children:[T.jsx("p",{className:"text-sm",children:"PDF preview is not available."}),T.jsxs("a",{href:`/api/files/download?path=${encodeURIComponent(e.path)}`,download:e.name,className:"text-sm text-[var(--color-primary)] hover:underline",children:["Download ",e.name]})]});case"binary":return T.jsxs("div",{className:"flex flex-col items-center justify-center h-full gap-4 text-[var(--color-text-secondary)]",children:[T.jsx("p",{className:"text-sm",children:"Binary file — cannot display."}),T.jsxs("a",{href:`/api/files/download?path=${encodeURIComponent(e.path)}`,download:e.name,className:"text-sm text-[var(--color-primary)] hover:underline",children:["Download ",e.name]})]})}}function NT({content:e}){const t=e.split(`
`);return T.jsx("pre",{className:"text-sm font-mono leading-relaxed",children:T.jsx("table",{className:"w-full border-collapse",children:T.jsx("tbody",{children:t.map((n,r)=>T.jsxs("tr",{className:"hover:bg-[var(--color-surface-2)]",children:[T.jsx("td",{className:"text-right pr-3 pl-3 py-0 select-none text-[var(--color-text-muted)] text-xs w-[1%] whitespace-nowrap",children:r+1}),T.jsx("td",{className:"pr-4 py-0 whitespace-pre text-[var(--color-text)]",children:n||" "})]},r))})})})}function Q8({headers:e,rows:t}){return!(e!=null&&e.length)||!(t!=null&&t.length)?T.jsx("div",{className:"p-4 text-sm text-[var(--color-text-muted)]",children:"Empty or invalid CSV file."}):T.jsxs("div",{className:"overflow-auto p-3",children:[T.jsxs("table",{className:"w-full border-collapse text-sm",children:[T.jsx("thead",{children:T.jsx("tr",{children:e.map(n=>T.jsx("th",{className:"px-3 py-1.5 text-left text-xs font-semibold bg-[var(--color-surface-3)] border border-[var(--color-border)] whitespace-nowrap",children:n},n))})}),T.jsx("tbody",{children:t.map((n,r)=>T.jsx("tr",{children:e.map(a=>T.jsx("td",{className:"px-3 py-1 border border-[var(--color-border)] text-[var(--color-text)] whitespace-nowrap",children:n[a]??""},a))},r))})]}),t.length>=50&&T.jsx("p",{className:"mt-2 text-xs text-[var(--color-text-muted)]",children:"Showing first 50 rows. Download to see all data."})]})}const W8="modulepreload",J8=function(e){return"/"+e},EE={},e9=function(t,n,r){let a=Promise.resolve();if(n&&n.length>0){let o=function(d){return Promise.all(d.map(m=>Promise.resolve(m).then(p=>({status:"fulfilled",value:p}),p=>({status:"rejected",reason:p}))))};document.getElementsByTagName("link");const c=document.querySelector("meta[property=csp-nonce]"),f=(c==null?void 0:c.nonce)||(c==null?void 0:c.getAttribute("nonce"));a=o(n.map(d=>{if(d=J8(d),d in EE)return;EE[d]=!0;const m=d.endsWith(".css"),p=m?'[rel="stylesheet"]':"";if(document.querySelector(`link[href="${d}"]${p}`))return;const y=document.createElement("link");if(y.rel=m?"stylesheet":W8,m||(y.as="script"),y.crossOrigin="",y.href=d,f&&y.setAttribute("nonce",f),document.head.appendChild(y),m)return new Promise((g,x)=>{y.addEventListener("load",g),y.addEventListener("error",()=>x(new Error(`Unable to preload CSS for ${d}`)))})}))}function u(o){const c=new Event("vite:preloadError",{cancelable:!0});if(c.payload=o,window.dispatchEvent(c),!c.defaultPrevented)throw o}return a.then(o=>{for(const c of o||[])c.status==="rejected"&&u(c.reason);return t().catch(u)})};function t9({item:e,onDelete:t}){const[n,r]=E.useState(!1);return T.jsxs("div",{className:"border border-[var(--color-border)] rounded-lg overflow-hidden bg-[var(--color-surface)]",children:[T.jsxs("div",{className:"flex items-center justify-between px-3 py-2 bg-[var(--color-surface-2)] border-b border-[var(--color-border)] cursor-pointer select-none",onClick:()=>r(a=>!a),children:[T.jsxs("div",{className:"flex items-center gap-2",children:[T.jsx(OC,{size:14,className:`text-[var(--color-text-muted)] transition-transform duration-150 ${n?"-rotate-90":""}`}),T.jsx("span",{className:"text-xs font-medium uppercase text-[var(--color-text-muted)]",children:e.type}),T.jsx("span",{className:"text-sm font-medium text-[var(--color-text)]",children:e.title})]}),T.jsx("button",{onClick:a=>{a.stopPropagation(),t(e.id)},className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",children:T.jsx(f0,{size:14,className:"text-[var(--color-text-secondary)]"})})]}),!n&&T.jsx("div",{className:"p-3",children:T.jsx(n9,{item:e})})]})}function n9({item:e}){switch(e.type){case"markdown":return T.jsx("div",{className:"markdown-content text-sm",children:T.jsx(k0,{remarkPlugins:[M0],children:typeof e.data=="string"?e.data:JSON.stringify(e.data)})});case"dataframe":return T.jsx(u9,{data:e.data});case"mermaid":return T.jsx(o9,{code:String(e.data)});case"image":case"matplotlib":return T.jsx(l9,{item:e});case"html":return T.jsx(i9,{html:typeof e.data=="string"?e.data:"",title:e.title});case"plotly":return T.jsx(a9,{data:e.data,title:e.title});default:return T.jsx("pre",{className:"text-xs bg-[var(--color-surface-3)] rounded p-3 overflow-x-auto",children:typeof e.data=="string"?e.data:JSON.stringify(e.data,null,2)})}}const r9=`<script>
function _sendHeight(){
  var h=document.documentElement.scrollHeight;
  window.parent.postMessage({type:'iframe-resize',height:h},'*');
}
window.addEventListener('load',function(){_sendHeight();setTimeout(_sendHeight,200);setTimeout(_sendHeight,1000);});
new MutationObserver(_sendHeight).observe(document.body,{childList:true,subtree:true});
<\/script>`;function i9({html:e,title:t}){const n=E.useRef(null),[r,a]=E.useState(200);E.useEffect(()=>{const o=n.current;if(!o)return;const c=f=>{var d;if(f.source===o.contentWindow&&((d=f.data)==null?void 0:d.type)==="iframe-resize"){const m=Math.max(60,Math.min(f.data.height,600));a(m)}};return window.addEventListener("message",c),()=>window.removeEventListener("message",c)},[e]);const u=`<!DOCTYPE html>
<html><head><meta charset="utf-8"><style>
  body { margin: 0; padding: 8px; font-family: system-ui, sans-serif; font-size: 13px; }
  img, table, svg { max-width: 100%; }
</style></head><body>${e}${r9}</body></html>`;return T.jsx("iframe",{ref:n,srcDoc:u,title:t||"HTML preview",sandbox:"allow-scripts allow-same-origin",className:"w-full rounded border-0",style:{height:`${r}px`}})}function a9({data:e,title:t}){const n=E.useRef(null),[r,a]=E.useState(400);E.useEffect(()=>{const c=n.current;if(!c)return;const f=d=>{var m;if(d.source===c.contentWindow&&((m=d.data)==null?void 0:m.type)==="iframe-resize"){const p=Math.max(200,Math.min(d.data.height,600));a(p)}};return window.addEventListener("message",f),()=>window.removeEventListener("message",f)},[e]);const o=`<!DOCTYPE html>
<html><head><meta charset="utf-8">
<script src="https://cdn.plot.ly/plotly-2.35.2.min.js"><\/script>
<style>body{margin:0;padding:0;}</style>
</head><body>
<div id="chart" style="width:100%;"></div>
<script>
var spec=${JSON.stringify(e)};
var d=spec.data||[];
var l=Object.assign({margin:{t:30,r:20,b:40,l:50},autosize:true},spec.layout||{});
Plotly.newPlot('chart',d,l,{responsive:true,displayModeBar:false}).then(function(){
  var h=document.getElementById('chart').offsetHeight;
  window.parent.postMessage({type:'iframe-resize',height:h},'*');
});
<\/script></body></html>`;return T.jsx("iframe",{ref:n,srcDoc:o,title:t||"Plotly chart",sandbox:"allow-scripts allow-same-origin",className:"w-full rounded border-0",style:{height:`${r}px`}})}function l9({item:e}){const t=typeof e.data=="string"?e.data:"",n=t.startsWith("data:")?t:t.length>100&&!t.includes("/")?`data:image/png;base64,${t}`:e.file?`/api/canvas/assets/${e.file}`:t;return T.jsx("img",{src:n,alt:e.title,className:"max-w-full rounded"})}function u9({data:e}){if(!Array.isArray(e)||e.length===0)return T.jsx("pre",{className:"text-xs",children:JSON.stringify(e,null,2)});const t=Object.keys(e[0]);return T.jsx("div",{className:"overflow-x-auto",children:T.jsxs("table",{className:"w-full border-collapse text-sm",children:[T.jsx("thead",{children:T.jsx("tr",{children:t.map(n=>T.jsx("th",{className:"px-3 py-1.5 text-left text-xs font-semibold bg-[var(--color-surface-3)] border border-[var(--color-border)]",children:n},n))})}),T.jsx("tbody",{children:e.map((n,r)=>T.jsx("tr",{children:t.map(a=>T.jsx("td",{className:"px-3 py-1 border border-[var(--color-border)] text-[var(--color-text)]",children:String(n[a]??"")},a))},r))})]})})}function o9({code:e}){const t=E.useRef(null);return E.useEffect(()=>{let n=!1;return(async()=>{try{const r=(await e9(async()=>{const{default:u}=await import("./mermaid.core-Crnh-dU0.js").then(o=>o.b6);return{default:u}},[])).default;if(r.initialize({startOnLoad:!1,theme:"default"}),n||!t.current)return;const{svg:a}=await r.render(`mermaid-${Date.now()}`,e);!n&&t.current&&(t.current.innerHTML=a)}catch(r){console.error("Mermaid render error:",r),t.current&&(t.current.textContent=e)}})(),()=>{n=!0}},[e]),T.jsx("div",{ref:t,className:"overflow-x-auto"})}function s9({items:e,onDelete:t,onClearAll:n,onExport:r}){const a=async()=>{const u=await r();if(!u)return;const o=new Blob([u],{type:"text/markdown"}),c=URL.createObjectURL(o),f=document.createElement("a");f.href=c,f.download="canvas.md",f.click(),URL.revokeObjectURL(c)};return e.length===0?T.jsxs("div",{className:"flex flex-col items-center justify-center h-full gap-3 px-6",children:[T.jsx("div",{className:"w-10 h-10 rounded-lg bg-[var(--color-surface-3)] flex items-center justify-center",children:T.jsx(XI,{size:20,className:"text-[var(--color-text-muted)]"})}),T.jsxs("div",{className:"text-center",children:[T.jsx("p",{className:"text-sm font-medium text-[var(--color-text-secondary)]",children:"No canvas items"}),T.jsx("p",{className:"text-xs text-[var(--color-text-muted)] mt-1",children:"Charts, tables, and visualizations will be collected here"})]})]}):T.jsxs("div",{className:"flex flex-col h-full",children:[T.jsxs("div",{className:"flex items-center justify-between px-3 py-2 border-b border-[var(--color-border)]",children:[T.jsxs("span",{className:"text-xs font-medium text-[var(--color-text-secondary)]",children:[e.length," item",e.length!==1?"s":""]}),T.jsxs("div",{className:"flex items-center gap-1",children:[T.jsx("button",{onClick:a,className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",title:"Export as Markdown",children:T.jsx(AC,{size:14,className:"text-[var(--color-text-secondary)]"})}),T.jsx("button",{onClick:n,className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",title:"Clear all",children:T.jsx(CC,{size:14,className:"text-[var(--color-text-secondary)]"})})]})]}),T.jsx("div",{className:"flex-1 overflow-y-auto p-3 space-y-3",children:e.map(u=>T.jsx(t9,{item:u,onDelete:t},u.id))})]})}function c9({todos:e}){if(e.length===0)return T.jsxs("div",{className:"flex flex-col items-center justify-center h-full gap-3 px-6",children:[T.jsx("div",{className:"w-10 h-10 rounded-lg bg-[var(--color-surface-3)] flex items-center justify-center",children:T.jsx(ZI,{size:20,className:"text-[var(--color-text-muted)]"})}),T.jsxs("div",{className:"text-center",children:[T.jsx("p",{className:"text-sm font-medium text-[var(--color-text-secondary)]",children:"No tasks yet"}),T.jsx("p",{className:"text-xs text-[var(--color-text-muted)] mt-1",children:"Tasks will appear here as the agent works"})]})]});const t=e.filter(a=>a.status==="completed").length,n=e.length,r=n>0?Math.round(t/n*100):0;return T.jsxs("div",{className:"flex flex-col h-full",children:[T.jsxs("div",{className:"px-4 py-2.5 border-b border-[var(--color-border)]",children:[T.jsxs("div",{className:"flex items-center justify-between mb-1.5",children:[T.jsx("span",{className:"text-[11px] font-medium uppercase tracking-wide text-[var(--color-text-muted)]",children:"Progress"}),T.jsxs("span",{className:"text-[11px] tabular-nums text-[var(--color-text-muted)]",children:[t,"/",n," (",r,"%)"]})]}),T.jsx("div",{className:"h-1 rounded-full bg-[var(--color-surface-3)]",children:T.jsx("div",{className:"h-full rounded-full bg-[var(--color-primary)] transition-all duration-300",style:{width:`${r}%`}})})]}),T.jsx("div",{className:"flex-1 overflow-y-auto px-4 py-2 space-y-1",children:e.map((a,u)=>T.jsxs("div",{className:"flex items-start gap-2.5 py-1",children:[a.status==="completed"?T.jsx(s0,{size:14,className:"text-[var(--color-success)] flex-shrink-0 mt-0.5"}):a.status==="in_progress"?T.jsx(c0,{size:14,className:"text-[var(--color-primary)] animate-spin flex-shrink-0 mt-0.5"}):T.jsx(Xy,{size:14,className:"text-[var(--color-text-muted)] flex-shrink-0 mt-0.5"}),T.jsx("span",{className:`text-sm leading-snug ${a.status==="completed"?"text-[var(--color-text-muted)] line-through":a.status==="in_progress"?"text-[var(--color-text)]":"text-[var(--color-text-secondary)]"}`,children:a.content})]},u))})]})}function f9({interrupt:e,onRespond:t}){const[n,r]=E.useState(null),[a,u]=E.useState(""),o=new Set(e.allowed_decisions),c=()=>{t(e.action_requests.map(()=>({type:"approve"})))},f=()=>{t(e.action_requests.map(()=>({type:"reject"})))},d=m=>{try{const p=JSON.parse(a),y=e.action_requests.map((g,x)=>x===m?{type:"edit",args:p}:{type:"approve"});t(y)}catch{}};return T.jsx("div",{className:"fixed inset-0 bg-black/40 flex items-center justify-center z-50 p-4 backdrop-blur-sm",children:T.jsxs("div",{className:"bg-[var(--color-surface)] rounded-lg shadow-xl border border-[var(--color-border)] max-w-lg w-full max-h-[80vh] overflow-y-auto",children:[T.jsxs("div",{className:"px-5 py-4 border-b border-[var(--color-border)]",children:[T.jsx("h3",{className:"text-sm font-semibold text-[var(--color-text)]",children:"Action Requires Approval"}),T.jsxs("p",{className:"text-xs text-[var(--color-text-muted)] mt-0.5",children:["The agent wants to perform the following action",e.action_requests.length>1?"s":""]})]}),T.jsx("div",{className:"px-5 py-4 space-y-3",children:e.action_requests.map((m,p)=>T.jsxs("div",{className:"border border-[var(--color-border)] rounded p-3",children:[T.jsx("div",{className:"mb-2",children:T.jsx("span",{className:"text-xs font-semibold uppercase tracking-wide text-[var(--color-text-secondary)]",children:m.tool})}),T.jsx("pre",{className:"bg-[var(--color-surface-3)] rounded p-2 text-xs overflow-x-auto whitespace-pre-wrap break-all text-[var(--color-text)]",children:JSON.stringify(m.args,null,2)}),n===p&&T.jsxs("div",{className:"mt-2",children:[T.jsx("textarea",{value:a,onChange:y=>u(y.target.value),className:"w-full h-24 p-2 text-xs font-mono bg-[var(--color-surface-3)] border border-[var(--color-border)] rounded resize-none focus:outline-none focus:border-[var(--color-text-muted)] text-[var(--color-text)]",placeholder:"Edit args JSON..."}),T.jsxs("div",{className:"flex gap-2 mt-1",children:[T.jsx("button",{onClick:()=>d(p),className:"px-3 py-1 text-xs font-medium bg-[var(--color-text)] text-[var(--color-surface)] rounded hover:opacity-80 transition-opacity",children:"Submit"}),T.jsx("button",{onClick:()=>r(null),className:"px-3 py-1 text-xs text-[var(--color-text-secondary)] hover:text-[var(--color-text)] transition-colors",children:"Cancel"})]})]})]},p))}),T.jsxs("div",{className:"px-5 py-3 border-t border-[var(--color-border)] flex justify-end gap-2",children:[o.has("edit")&&T.jsxs("button",{onClick:()=>{var m;r(0),u(JSON.stringify(((m=e.action_requests[0])==null?void 0:m.args)??{},null,2))},className:"flex items-center gap-1.5 px-3 py-1.5 text-xs font-medium text-[var(--color-text-secondary)] hover:text-[var(--color-text)] border border-[var(--color-border)] rounded hover:bg-[var(--color-surface-3)] transition-colors",children:[T.jsx(n3,{size:12}),"Edit"]}),o.has("reject")&&T.jsxs("button",{onClick:f,className:"flex items-center gap-1.5 px-3 py-1.5 text-xs font-medium text-[var(--color-error)] border border-[var(--color-error)]/30 rounded hover:bg-[var(--color-error)] hover:text-white transition-colors",children:[T.jsx(f0,{size:12}),"Reject"]}),o.has("approve")&&T.jsxs("button",{onClick:c,className:"flex items-center gap-1.5 px-3 py-1.5 text-xs font-medium bg-[var(--color-text)] text-[var(--color-surface)] rounded hover:opacity-80 transition-opacity",children:[T.jsx(II,{size:12}),"Approve"]})]})]})})}function d9({initialTheme:e="auto"}){const[t,n]=E.useState(e),r=E.useCallback(o=>{const c=o==="dark"||o==="auto"&&window.matchMedia("(prefers-color-scheme: dark)").matches;document.documentElement.classList.toggle("dark",c)},[]);E.useEffect(()=>{if(r(t),t==="auto"){const o=window.matchMedia("(prefers-color-scheme: dark)"),c=()=>r("auto");return o.addEventListener("change",c),()=>o.removeEventListener("change",c)}},[t,r]);const a=()=>{n(o=>o==="light"?"dark":o==="dark"?"auto":"light")},u=t==="light"?i3:t==="dark"?WI:QI;return T.jsx("button",{onClick:a,className:"p-1.5 rounded-md hover:bg-[var(--color-surface-3)] transition-colors",title:`Theme: ${t}`,children:T.jsx(u,{size:16,className:"text-[var(--color-text-secondary)]"})})}function PT(e){var t,n,r="";if(typeof e=="string"||typeof e=="number")r+=e;else if(typeof e=="object")if(Array.isArray(e)){var a=e.length;for(t=0;t<a;t++)e[t]&&(n=PT(e[t]))&&(r&&(r+=" "),r+=n)}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}function ft(){for(var e,t,n=0,r="",a=arguments.length;n<a;n++)(e=arguments[n])&&(t=PT(e))&&(r&&(r+=" "),r+=t);return r}var h9=["dangerouslySetInnerHTML","onCopy","onCopyCapture","onCut","onCutCapture","onPaste","onPasteCapture","onCompositionEnd","onCompositionEndCapture","onCompositionStart","onCompositionStartCapture","onCompositionUpdate","onCompositionUpdateCapture","onFocus","onFocusCapture","onBlur","onBlurCapture","onChange","onChangeCapture","onBeforeInput","onBeforeInputCapture","onInput","onInputCapture","onReset","onResetCapture","onSubmit","onSubmitCapture","onInvalid","onInvalidCapture","onLoad","onLoadCapture","onError","onErrorCapture","onKeyDown","onKeyDownCapture","onKeyPress","onKeyPressCapture","onKeyUp","onKeyUpCapture","onAbort","onAbortCapture","onCanPlay","onCanPlayCapture","onCanPlayThrough","onCanPlayThroughCapture","onDurationChange","onDurationChangeCapture","onEmptied","onEmptiedCapture","onEncrypted","onEncryptedCapture","onEnded","onEndedCapture","onLoadedData","onLoadedDataCapture","onLoadedMetadata","onLoadedMetadataCapture","onLoadStart","onLoadStartCapture","onPause","onPauseCapture","onPlay","onPlayCapture","onPlaying","onPlayingCapture","onProgress","onProgressCapture","onRateChange","onRateChangeCapture","onSeeked","onSeekedCapture","onSeeking","onSeekingCapture","onStalled","onStalledCapture","onSuspend","onSuspendCapture","onTimeUpdate","onTimeUpdateCapture","onVolumeChange","onVolumeChangeCapture","onWaiting","onWaitingCapture","onAuxClick","onAuxClickCapture","onClick","onClickCapture","onContextMenu","onContextMenuCapture","onDoubleClick","onDoubleClickCapture","onDrag","onDragCapture","onDragEnd","onDragEndCapture","onDragEnter","onDragEnterCapture","onDragExit","onDragExitCapture","onDragLeave","onDragLeaveCapture","onDragOver","onDragOverCapture","onDragStart","onDragStartCapture","onDrop","onDropCapture","onMouseDown","onMouseDownCapture","onMouseEnter","onMouseLeave","onMouseMove","onMouseMoveCapture","onMouseOut","onMouseOutCapture","onMouseOver","onMouseOverCapture","onMouseUp","onMouseUpCapture","onSelect","onSelectCapture","onTouchCancel","onTouchCancelCapture","onTouchEnd","onTouchEndCapture","onTouchMove","onTouchMoveCapture","onTouchStart","onTouchStartCapture","onPointerDown","onPointerDownCapture","onPointerMove","onPointerMoveCapture","onPointerUp","onPointerUpCapture","onPointerCancel","onPointerCancelCapture","onPointerEnter","onPointerEnterCapture","onPointerLeave","onPointerLeaveCapture","onPointerOver","onPointerOverCapture","onPointerOut","onPointerOutCapture","onGotPointerCapture","onGotPointerCaptureCapture","onLostPointerCapture","onLostPointerCaptureCapture","onScroll","onScrollCapture","onWheel","onWheelCapture","onAnimationStart","onAnimationStartCapture","onAnimationEnd","onAnimationEndCapture","onAnimationIteration","onAnimationIterationCapture","onTransitionEnd","onTransitionEndCapture"];function z0(e){if(typeof e!="string")return!1;var t=h9;return t.includes(e)}var m9=["aria-activedescendant","aria-atomic","aria-autocomplete","aria-busy","aria-checked","aria-colcount","aria-colindex","aria-colspan","aria-controls","aria-current","aria-describedby","aria-details","aria-disabled","aria-errormessage","aria-expanded","aria-flowto","aria-haspopup","aria-hidden","aria-invalid","aria-keyshortcuts","aria-label","aria-labelledby","aria-level","aria-live","aria-modal","aria-multiline","aria-multiselectable","aria-orientation","aria-owns","aria-placeholder","aria-posinset","aria-pressed","aria-readonly","aria-relevant","aria-required","aria-roledescription","aria-rowcount","aria-rowindex","aria-rowspan","aria-selected","aria-setsize","aria-sort","aria-valuemax","aria-valuemin","aria-valuenow","aria-valuetext","className","color","height","id","lang","max","media","method","min","name","style","target","width","role","tabIndex","accentHeight","accumulate","additive","alignmentBaseline","allowReorder","alphabetic","amplitude","arabicForm","ascent","attributeName","attributeType","autoReverse","azimuth","baseFrequency","baselineShift","baseProfile","bbox","begin","bias","by","calcMode","capHeight","clip","clipPath","clipPathUnits","clipRule","colorInterpolation","colorInterpolationFilters","colorProfile","colorRendering","contentScriptType","contentStyleType","cursor","cx","cy","d","decelerate","descent","diffuseConstant","direction","display","divisor","dominantBaseline","dur","dx","dy","edgeMode","elevation","enableBackground","end","exponent","externalResourcesRequired","fill","fillOpacity","fillRule","filter","filterRes","filterUnits","floodColor","floodOpacity","focusable","fontFamily","fontSize","fontSizeAdjust","fontStretch","fontStyle","fontVariant","fontWeight","format","from","fx","fy","g1","g2","glyphName","glyphOrientationHorizontal","glyphOrientationVertical","glyphRef","gradientTransform","gradientUnits","hanging","horizAdvX","horizOriginX","href","ideographic","imageRendering","in2","in","intercept","k1","k2","k3","k4","k","kernelMatrix","kernelUnitLength","kerning","keyPoints","keySplines","keyTimes","lengthAdjust","letterSpacing","lightingColor","limitingConeAngle","local","markerEnd","markerHeight","markerMid","markerStart","markerUnits","markerWidth","mask","maskContentUnits","maskUnits","mathematical","mode","numOctaves","offset","opacity","operator","order","orient","orientation","origin","overflow","overlinePosition","overlineThickness","paintOrder","panose1","pathLength","patternContentUnits","patternTransform","patternUnits","pointerEvents","pointsAtX","pointsAtY","pointsAtZ","preserveAlpha","preserveAspectRatio","primitiveUnits","r","radius","refX","refY","renderingIntent","repeatCount","repeatDur","requiredExtensions","requiredFeatures","restart","result","rotate","rx","ry","seed","shapeRendering","slope","spacing","specularConstant","specularExponent","speed","spreadMethod","startOffset","stdDeviation","stemh","stemv","stitchTiles","stopColor","stopOpacity","strikethroughPosition","strikethroughThickness","string","stroke","strokeDasharray","strokeDashoffset","strokeLinecap","strokeLinejoin","strokeMiterlimit","strokeOpacity","strokeWidth","surfaceScale","systemLanguage","tableValues","targetX","targetY","textAnchor","textDecoration","textLength","textRendering","to","transform","u1","u2","underlinePosition","underlineThickness","unicode","unicodeBidi","unicodeRange","unitsPerEm","vAlphabetic","values","vectorEffect","version","vertAdvY","vertOriginX","vertOriginY","vHanging","vIdeographic","viewTarget","visibility","vMathematical","widths","wordSpacing","writingMode","x1","x2","x","xChannelSelector","xHeight","xlinkActuate","xlinkArcrole","xlinkHref","xlinkRole","xlinkShow","xlinkTitle","xlinkType","xmlBase","xmlLang","xmlns","xmlnsXlink","xmlSpace","y1","y2","y","yChannelSelector","z","zoomAndPan","ref","key","angle"],p9=new Set(m9);function RT(e){return typeof e!="string"?!1:p9.has(e)}function IT(e){return typeof e=="string"&&e.startsWith("data-")}function bi(e){if(typeof e!="object"||e===null)return{};var t={};for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&(RT(n)||IT(n))&&(t[n]=e[n]);return t}function D0(e){if(e==null)return null;if(E.isValidElement(e)&&typeof e.props=="object"&&e.props!==null){var t=e.props;return bi(t)}return typeof e=="object"&&!Array.isArray(e)?bi(e):null}function hr(e){var t={};for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&(RT(n)||IT(n)||z0(n))&&(t[n]=e[n]);return t}var v9=["children","width","height","viewBox","className","style","title","desc"];function og(){return og=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},og.apply(null,arguments)}function y9(e,t){if(e==null)return{};var n,r,a=g9(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function g9(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var LT=E.forwardRef((e,t)=>{var{children:n,width:r,height:a,viewBox:u,className:o,style:c,title:f,desc:d}=e,m=y9(e,v9),p=u||{width:r,height:a,x:0,y:0},y=ft("recharts-surface",o);return E.createElement("svg",og({},hr(m),{className:y,width:r,height:a,style:c,viewBox:"".concat(p.x," ").concat(p.y," ").concat(p.width," ").concat(p.height),ref:t}),E.createElement("title",null,f),E.createElement("desc",null,d),n)}),b9=["children","className"];function sg(){return sg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},sg.apply(null,arguments)}function x9(e,t){if(e==null)return{};var n,r,a=w9(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function w9(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var xi=E.forwardRef((e,t)=>{var{children:n,className:r}=e,a=x9(e,b9),u=ft("recharts-layer",r);return E.createElement("g",sg({className:u},hr(a),{ref:t}),n)}),BT=hC(),S9=E.createContext(null);function ut(e){return function(){return e}}const lne=Math.abs,une=Math.atan2,UT=Math.cos,one=Math.max,sne=Math.min,If=Math.sin,jr=Math.sqrt,cne=1e-12,du=Math.PI,AE=du/2,Pd=2*du;function fne(e){return e>1?0:e<-1?du:Math.acos(e)}function dne(e){return e>=1?AE:e<=-1?-AE:Math.asin(e)}const cg=Math.PI,fg=2*cg,Ua=1e-6,O9=fg-Ua;function qT(e){this._+=e[0];for(let t=1,n=e.length;t<n;++t)this._+=arguments[t]+e[t]}function E9(e){let t=Math.floor(e);if(!(t>=0))throw new Error(`invalid digits: ${e}`);if(t>15)return qT;const n=10**t;return function(r){this._+=r[0];for(let a=1,u=r.length;a<u;++a)this._+=Math.round(arguments[a]*n)/n+r[a]}}class A9{constructor(t){this._x0=this._y0=this._x1=this._y1=null,this._="",this._append=t==null?qT:E9(t)}moveTo(t,n){this._append`M${this._x0=this._x1=+t},${this._y0=this._y1=+n}`}closePath(){this._x1!==null&&(this._x1=this._x0,this._y1=this._y0,this._append`Z`)}lineTo(t,n){this._append`L${this._x1=+t},${this._y1=+n}`}quadraticCurveTo(t,n,r,a){this._append`Q${+t},${+n},${this._x1=+r},${this._y1=+a}`}bezierCurveTo(t,n,r,a,u,o){this._append`C${+t},${+n},${+r},${+a},${this._x1=+u},${this._y1=+o}`}arcTo(t,n,r,a,u){if(t=+t,n=+n,r=+r,a=+a,u=+u,u<0)throw new Error(`negative radius: ${u}`);let o=this._x1,c=this._y1,f=r-t,d=a-n,m=o-t,p=c-n,y=m*m+p*p;if(this._x1===null)this._append`M${this._x1=t},${this._y1=n}`;else if(y>Ua)if(!(Math.abs(p*f-d*m)>Ua)||!u)this._append`L${this._x1=t},${this._y1=n}`;else{let g=r-o,x=a-c,w=f*f+d*d,S=g*g+x*x,O=Math.sqrt(w),_=Math.sqrt(y),k=u*Math.tan((cg-Math.acos((w+y-S)/(2*O*_)))/2),M=k/_,N=k/O;Math.abs(M-1)>Ua&&this._append`L${t+M*m},${n+M*p}`,this._append`A${u},${u},0,0,${+(p*g>m*x)},${this._x1=t+N*f},${this._y1=n+N*d}`}}arc(t,n,r,a,u,o){if(t=+t,n=+n,r=+r,o=!!o,r<0)throw new Error(`negative radius: ${r}`);let c=r*Math.cos(a),f=r*Math.sin(a),d=t+c,m=n+f,p=1^o,y=o?a-u:u-a;this._x1===null?this._append`M${d},${m}`:(Math.abs(this._x1-d)>Ua||Math.abs(this._y1-m)>Ua)&&this._append`L${d},${m}`,r&&(y<0&&(y=y%fg+fg),y>O9?this._append`A${r},${r},0,1,${p},${t-c},${n-f}A${r},${r},0,1,${p},${this._x1=d},${this._y1=m}`:y>Ua&&this._append`A${r},${r},0,${+(y>=cg)},${p},${this._x1=t+r*Math.cos(u)},${this._y1=n+r*Math.sin(u)}`)}rect(t,n,r,a){this._append`M${this._x0=this._x1=+t},${this._y0=this._y1=+n}h${r=+r}v${+a}h${-r}Z`}toString(){return this._}}function N0(e){let t=3;return e.digits=function(n){if(!arguments.length)return t;if(n==null)t=null;else{const r=Math.floor(n);if(!(r>=0))throw new RangeError(`invalid digits: ${n}`);t=r}return e},()=>new A9(t)}function P0(e){return typeof e=="object"&&"length"in e?e:Array.from(e)}function HT(e){this._context=e}HT.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;default:this._context.lineTo(e,t);break}}};function Rd(e){return new HT(e)}function $T(e){return e[0]}function FT(e){return e[1]}function VT(e,t){var n=ut(!0),r=null,a=Rd,u=null,o=N0(c);e=typeof e=="function"?e:e===void 0?$T:ut(e),t=typeof t=="function"?t:t===void 0?FT:ut(t);function c(f){var d,m=(f=P0(f)).length,p,y=!1,g;for(r==null&&(u=a(g=o())),d=0;d<=m;++d)!(d<m&&n(p=f[d],d,f))===y&&((y=!y)?u.lineStart():u.lineEnd()),y&&u.point(+e(p,d,f),+t(p,d,f));if(g)return u=null,g+""||null}return c.x=function(f){return arguments.length?(e=typeof f=="function"?f:ut(+f),c):e},c.y=function(f){return arguments.length?(t=typeof f=="function"?f:ut(+f),c):t},c.defined=function(f){return arguments.length?(n=typeof f=="function"?f:ut(!!f),c):n},c.curve=function(f){return arguments.length?(a=f,r!=null&&(u=a(r)),c):a},c.context=function(f){return arguments.length?(f==null?r=u=null:u=a(r=f),c):r},c}function of(e,t,n){var r=null,a=ut(!0),u=null,o=Rd,c=null,f=N0(d);e=typeof e=="function"?e:e===void 0?$T:ut(+e),t=typeof t=="function"?t:ut(t===void 0?0:+t),n=typeof n=="function"?n:n===void 0?FT:ut(+n);function d(p){var y,g,x,w=(p=P0(p)).length,S,O=!1,_,k=new Array(w),M=new Array(w);for(u==null&&(c=o(_=f())),y=0;y<=w;++y){if(!(y<w&&a(S=p[y],y,p))===O)if(O=!O)g=y,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),x=y-1;x>=g;--x)c.point(k[x],M[x]);c.lineEnd(),c.areaEnd()}O&&(k[y]=+e(S,y,p),M[y]=+t(S,y,p),c.point(r?+r(S,y,p):k[y],n?+n(S,y,p):M[y]))}if(_)return c=null,_+""||null}function m(){return VT().defined(a).curve(o).context(u)}return d.x=function(p){return arguments.length?(e=typeof p=="function"?p:ut(+p),r=null,d):e},d.x0=function(p){return arguments.length?(e=typeof p=="function"?p:ut(+p),d):e},d.x1=function(p){return arguments.length?(r=p==null?null:typeof p=="function"?p:ut(+p),d):r},d.y=function(p){return arguments.length?(t=typeof p=="function"?p:ut(+p),n=null,d):t},d.y0=function(p){return arguments.length?(t=typeof p=="function"?p:ut(+p),d):t},d.y1=function(p){return arguments.length?(n=p==null?null:typeof p=="function"?p:ut(+p),d):n},d.lineX0=d.lineY0=function(){return m().x(e).y(t)},d.lineY1=function(){return m().x(e).y(n)},d.lineX1=function(){return m().x(r).y(t)},d.defined=function(p){return arguments.length?(a=typeof p=="function"?p:ut(!!p),d):a},d.curve=function(p){return arguments.length?(o=p,u!=null&&(c=o(u)),d):o},d.context=function(p){return arguments.length?(p==null?u=c=null:c=o(u=p),d):u},d}class YT{constructor(t,n){this._context=t,this._x=n}areaStart(){this._line=0}areaEnd(){this._line=NaN}lineStart(){this._point=0}lineEnd(){(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line}point(t,n){switch(t=+t,n=+n,this._point){case 0:{this._point=1,this._line?this._context.lineTo(t,n):this._context.moveTo(t,n);break}case 1:this._point=2;default:{this._x?this._context.bezierCurveTo(this._x0=(this._x0+t)/2,this._y0,this._x0,n,t,n):this._context.bezierCurveTo(this._x0,this._y0=(this._y0+n)/2,t,this._y0,t,n);break}}this._x0=t,this._y0=n}}function _9(e){return new YT(e,!0)}function k9(e){return new YT(e,!1)}const R0={draw(e,t){const n=jr(t/du);e.moveTo(n,0),e.arc(0,0,n,0,Pd)}},C9={draw(e,t){const n=jr(t/5)/2;e.moveTo(-3*n,-n),e.lineTo(-n,-n),e.lineTo(-n,-3*n),e.lineTo(n,-3*n),e.lineTo(n,-n),e.lineTo(3*n,-n),e.lineTo(3*n,n),e.lineTo(n,n),e.lineTo(n,3*n),e.lineTo(-n,3*n),e.lineTo(-n,n),e.lineTo(-3*n,n),e.closePath()}},KT=jr(1/3),T9=KT*2,j9={draw(e,t){const n=jr(t/T9),r=n*KT;e.moveTo(0,-n),e.lineTo(r,0),e.lineTo(0,n),e.lineTo(-r,0),e.closePath()}},M9={draw(e,t){const n=jr(t),r=-n/2;e.rect(r,r,n,n)}},z9=.8908130915292852,GT=If(du/10)/If(7*du/10),D9=If(Pd/10)*GT,N9=-UT(Pd/10)*GT,P9={draw(e,t){const n=jr(t*z9),r=D9*n,a=N9*n;e.moveTo(0,-n),e.lineTo(r,a);for(let u=1;u<5;++u){const o=Pd*u/5,c=UT(o),f=If(o);e.lineTo(f*n,-c*n),e.lineTo(c*r-f*a,f*r+c*a)}e.closePath()}},mv=jr(3),R9={draw(e,t){const n=-jr(t/(mv*3));e.moveTo(0,n*2),e.lineTo(-mv*n,-n),e.lineTo(mv*n,-n),e.closePath()}},lr=-.5,ur=jr(3)/2,dg=1/jr(12),I9=(dg/2+1)*3,L9={draw(e,t){const n=jr(t/I9),r=n/2,a=n*dg,u=r,o=n*dg+n,c=-u,f=o;e.moveTo(r,a),e.lineTo(u,o),e.lineTo(c,f),e.lineTo(lr*r-ur*a,ur*r+lr*a),e.lineTo(lr*u-ur*o,ur*u+lr*o),e.lineTo(lr*c-ur*f,ur*c+lr*f),e.lineTo(lr*r+ur*a,lr*a-ur*r),e.lineTo(lr*u+ur*o,lr*o-ur*u),e.lineTo(lr*c+ur*f,lr*f-ur*c),e.closePath()}};function B9(e,t){let n=null,r=N0(a);e=typeof e=="function"?e:ut(e||R0),t=typeof t=="function"?t:ut(t===void 0?64:+t);function a(){let u;if(n||(n=u=r()),e.apply(this,arguments).draw(n,+t.apply(this,arguments)),u)return n=null,u+""||null}return a.type=function(u){return arguments.length?(e=typeof u=="function"?u:ut(u),a):e},a.size=function(u){return arguments.length?(t=typeof u=="function"?u:ut(+u),a):t},a.context=function(u){return arguments.length?(n=u??null,a):n},a}function Lf(){}function Bf(e,t,n){e._context.bezierCurveTo((2*e._x0+e._x1)/3,(2*e._y0+e._y1)/3,(e._x0+2*e._x1)/3,(e._y0+2*e._y1)/3,(e._x0+4*e._x1+t)/6,(e._y0+4*e._y1+n)/6)}function XT(e){this._context=e}XT.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:Bf(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1);break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:Bf(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function U9(e){return new XT(e)}function ZT(e){this._context=e}ZT.prototype={areaStart:Lf,areaEnd:Lf,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:{this._context.moveTo(this._x2,this._y2),this._context.closePath();break}case 2:{this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break}case 3:{this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4);break}}},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._x2=e,this._y2=t;break;case 1:this._point=2,this._x3=e,this._y3=t;break;case 2:this._point=3,this._x4=e,this._y4=t,this._context.moveTo((this._x0+4*this._x1+e)/6,(this._y0+4*this._y1+t)/6);break;default:Bf(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function q9(e){return new ZT(e)}function QT(e){this._context=e}QT.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===3)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var n=(this._x0+4*this._x1+e)/6,r=(this._y0+4*this._y1+t)/6;this._line?this._context.lineTo(n,r):this._context.moveTo(n,r);break;case 3:this._point=4;default:Bf(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function H9(e){return new QT(e)}function WT(e){this._context=e}WT.prototype={areaStart:Lf,areaEnd:Lf,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(e,t){e=+e,t=+t,this._point?this._context.lineTo(e,t):(this._point=1,this._context.moveTo(e,t))}};function $9(e){return new WT(e)}function _E(e){return e<0?-1:1}function kE(e,t,n){var r=e._x1-e._x0,a=t-e._x1,u=(e._y1-e._y0)/(r||a<0&&-0),o=(n-e._y1)/(a||r<0&&-0),c=(u*a+o*r)/(r+a);return(_E(u)+_E(o))*Math.min(Math.abs(u),Math.abs(o),.5*Math.abs(c))||0}function CE(e,t){var n=e._x1-e._x0;return n?(3*(e._y1-e._y0)/n-t)/2:t}function pv(e,t,n){var r=e._x0,a=e._y0,u=e._x1,o=e._y1,c=(u-r)/3;e._context.bezierCurveTo(r+c,a+c*t,u-c,o-c*n,u,o)}function Uf(e){this._context=e}Uf.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:pv(this,this._t0,CE(this,this._t0));break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){var n=NaN;if(e=+e,t=+t,!(e===this._x1&&t===this._y1)){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3,pv(this,CE(this,n=kE(this,e,t)),n);break;default:pv(this,this._t0,n=kE(this,e,t));break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t,this._t0=n}}};function JT(e){this._context=new ej(e)}(JT.prototype=Object.create(Uf.prototype)).point=function(e,t){Uf.prototype.point.call(this,t,e)};function ej(e){this._context=e}ej.prototype={moveTo:function(e,t){this._context.moveTo(t,e)},closePath:function(){this._context.closePath()},lineTo:function(e,t){this._context.lineTo(t,e)},bezierCurveTo:function(e,t,n,r,a,u){this._context.bezierCurveTo(t,e,r,n,u,a)}};function F9(e){return new Uf(e)}function V9(e){return new JT(e)}function tj(e){this._context=e}tj.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var e=this._x,t=this._y,n=e.length;if(n)if(this._line?this._context.lineTo(e[0],t[0]):this._context.moveTo(e[0],t[0]),n===2)this._context.lineTo(e[1],t[1]);else for(var r=TE(e),a=TE(t),u=0,o=1;o<n;++u,++o)this._context.bezierCurveTo(r[0][u],a[0][u],r[1][u],a[1][u],e[o],t[o]);(this._line||this._line!==0&&n===1)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(e,t){this._x.push(+e),this._y.push(+t)}};function TE(e){var t,n=e.length-1,r,a=new Array(n),u=new Array(n),o=new Array(n);for(a[0]=0,u[0]=2,o[0]=e[0]+2*e[1],t=1;t<n-1;++t)a[t]=1,u[t]=4,o[t]=4*e[t]+2*e[t+1];for(a[n-1]=2,u[n-1]=7,o[n-1]=8*e[n-1]+e[n],t=1;t<n;++t)r=a[t]/u[t-1],u[t]-=r,o[t]-=r*o[t-1];for(a[n-1]=o[n-1]/u[n-1],t=n-2;t>=0;--t)a[t]=(o[t]-a[t+1])/u[t];for(u[n-1]=(e[n]+a[n-1])/2,t=0;t<n-1;++t)u[t]=2*e[t+1]-a[t+1];return[a,u]}function Y9(e){return new tj(e)}function Id(e,t){this._context=e,this._t=t}Id.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&this._point===2&&this._context.lineTo(this._x,this._y),(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;default:{if(this._t<=0)this._context.lineTo(this._x,t),this._context.lineTo(e,t);else{var n=this._x*(1-this._t)+e*this._t;this._context.lineTo(n,this._y),this._context.lineTo(n,t)}break}}this._x=e,this._y=t}};function K9(e){return new Id(e,.5)}function G9(e){return new Id(e,0)}function X9(e){return new Id(e,1)}function Qa(e,t){if((o=e.length)>1)for(var n=1,r,a,u=e[t[0]],o,c=u.length;n<o;++n)for(a=u,u=e[t[n]],r=0;r<c;++r)u[r][1]+=u[r][0]=isNaN(a[r][1])?a[r][0]:a[r][1]}function hg(e){for(var t=e.length,n=new Array(t);--t>=0;)n[t]=t;return n}function Z9(e,t){return e[t]}function Q9(e){const t=[];return t.key=e,t}function W9(){var e=ut([]),t=hg,n=Qa,r=Z9;function a(u){var o=Array.from(e.apply(this,arguments),Q9),c,f=o.length,d=-1,m;for(const p of u)for(c=0,++d;c<f;++c)(o[c][d]=[0,+r(p,o[c].key,d,u)]).data=p;for(c=0,m=P0(t(o));c<f;++c)o[m[c]].index=c;return n(o,m),o}return a.keys=function(u){return arguments.length?(e=typeof u=="function"?u:ut(Array.from(u)),a):e},a.value=function(u){return arguments.length?(r=typeof u=="function"?u:ut(+u),a):r},a.order=function(u){return arguments.length?(t=u==null?hg:typeof u=="function"?u:ut(Array.from(u)),a):t},a.offset=function(u){return arguments.length?(n=u??Qa,a):n},a}function J9(e,t){if((r=e.length)>0){for(var n,r,a=0,u=e[0].length,o;a<u;++a){for(o=n=0;n<r;++n)o+=e[n][a][1]||0;if(o)for(n=0;n<r;++n)e[n][a][1]/=o}Qa(e,t)}}function eU(e,t){if((a=e.length)>0){for(var n=0,r=e[t[0]],a,u=r.length;n<u;++n){for(var o=0,c=0;o<a;++o)c+=e[o][n][1]||0;r[n][1]+=r[n][0]=-c/2}Qa(e,t)}}function tU(e,t){if(!(!((o=e.length)>0)||!((u=(a=e[t[0]]).length)>0))){for(var n=0,r=1,a,u,o;r<u;++r){for(var c=0,f=0,d=0;c<o;++c){for(var m=e[t[c]],p=m[r][1]||0,y=m[r-1][1]||0,g=(p-y)/2,x=0;x<c;++x){var w=e[t[x]],S=w[r][1]||0,O=w[r-1][1]||0;g+=S-O}f+=p,d+=g*p}a[r-1][1]+=a[r-1][0]=n,f&&(n-=d/f)}a[r-1][1]+=a[r-1][0]=n,Qa(e,t)}}var vv={},yv={},jE;function nU(){return jE||(jE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n==="__proto__"}e.isUnsafeProperty=t})(yv)),yv}var gv={},ME;function nj(){return ME||(ME=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){switch(typeof n){case"number":case"symbol":return!1;case"string":return n.includes(".")||n.includes("[")||n.includes("]")}}e.isDeepKey=t})(gv)),gv}var bv={},zE;function I0(){return zE||(zE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){var r;return typeof n=="string"||typeof n=="symbol"?n:Object.is((r=n==null?void 0:n.valueOf)==null?void 0:r.call(n),-0)?"-0":String(n)}e.toKey=t})(bv)),bv}var xv={},wv={},DE;function rU(){return DE||(DE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){if(n==null)return"";if(typeof n=="string")return n;if(Array.isArray(n))return n.map(t).join(",");const r=String(n);return r==="0"&&Object.is(Number(n),-0)?"-0":r}e.toString=t})(wv)),wv}var NE;function L0(){return NE||(NE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=rU(),n=I0();function r(a){if(Array.isArray(a))return a.map(n.toKey);if(typeof a=="symbol")return[a];a=t.toString(a);const u=[],o=a.length;if(o===0)return u;let c=0,f="",d="",m=!1;for(a.charCodeAt(0)===46&&(u.push(""),c++);c<o;){const p=a[c];d?p==="\\"&&c+1<o?(c++,f+=a[c]):p===d?d="":f+=p:m?p==='"'||p==="'"?d=p:p==="]"?(m=!1,u.push(f),f=""):f+=p:p==="["?(m=!0,f&&(u.push(f),f="")):p==="."?f&&(u.push(f),f=""):f+=p,c++}return f&&u.push(f),u}e.toPath=r})(xv)),xv}var PE;function B0(){return PE||(PE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=nU(),n=nj(),r=I0(),a=L0();function u(c,f,d){if(c==null)return d;switch(typeof f){case"string":{if(t.isUnsafeProperty(f))return d;const m=c[f];return m===void 0?n.isDeepKey(f)?u(c,a.toPath(f),d):d:m}case"number":case"symbol":{typeof f=="number"&&(f=r.toKey(f));const m=c[f];return m===void 0?d:m}default:{if(Array.isArray(f))return o(c,f,d);if(Object.is(f==null?void 0:f.valueOf(),-0)?f="-0":f=String(f),t.isUnsafeProperty(f))return d;const m=c[f];return m===void 0?d:m}}}function o(c,f,d){if(f.length===0)return d;let m=c;for(let p=0;p<f.length;p++){if(m==null||t.isUnsafeProperty(f[p]))return d;m=m[f[p]]}return m===void 0?d:m}e.get=u})(vv)),vv}var Sv,RE;function iU(){return RE||(RE=1,Sv=B0().get),Sv}var aU=iU();const hu=Tr(aU);var lU=4;function da(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:lU,n=10**t,r=Math.round(e*n)/n;return Object.is(r,-0)?0:r}function gt(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return e.reduce((a,u,o)=>{var c=n[o-1];return typeof c=="string"?a+c+u:c!==void 0?a+da(c)+u:a+u},"")}var _n=e=>e===0?0:e>0?1:-1,$r=e=>typeof e=="number"&&e!=+e,Wa=e=>typeof e=="string"&&e.indexOf("%")===e.length-1,we=e=>(typeof e=="number"||e instanceof Number)&&!$r(e),Fr=e=>we(e)||typeof e=="string",uU=0,ts=e=>{var t=++uU;return"".concat(e||"").concat(t)},kr=function(t,n){var r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:0,a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1;if(!we(t)&&typeof t!="string")return r;var u;if(Wa(t)){if(n==null)return r;var o=t.indexOf("%");u=n*parseFloat(t.slice(0,o))/100}else u=+t;return $r(u)&&(u=r),a&&n!=null&&u>n&&(u=n),u},rj=e=>{if(!Array.isArray(e))return!1;for(var t=e.length,n={},r=0;r<t;r++)if(!n[String(e[r])])n[String(e[r])]=!0;else return!0;return!1};function Jt(e,t,n){return we(e)&&we(t)?da(e+n*(t-e)):t}function oU(e,t,n){if(!(!e||!e.length))return e.find(r=>r&&(typeof t=="function"?t(r):hu(r,t))===n)}var qt=e=>e===null||typeof e>"u",xs=e=>qt(e)?e:"".concat(e.charAt(0).toUpperCase()).concat(e.slice(1));function kn(e){return e!=null}function Au(){}var sU=["type","size","sizeType"];function mg(){return mg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},mg.apply(null,arguments)}function IE(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function LE(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?IE(Object(n),!0).forEach(function(r){cU(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):IE(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function cU(e,t,n){return(t=fU(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function fU(e){var t=dU(e,"string");return typeof t=="symbol"?t:t+""}function dU(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function hU(e,t){if(e==null)return{};var n,r,a=mU(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function mU(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var ij={symbolCircle:R0,symbolCross:C9,symbolDiamond:j9,symbolSquare:M9,symbolStar:P9,symbolTriangle:R9,symbolWye:L9},pU=Math.PI/180,vU=e=>{var t="symbol".concat(xs(e));return ij[t]||R0},yU=(e,t,n)=>{if(t==="area")return e;switch(n){case"cross":return 5*e*e/9;case"diamond":return .5*e*e/Math.sqrt(3);case"square":return e*e;case"star":{var r=18*pU;return 1.25*e*e*(Math.tan(r)-Math.tan(r*2)*Math.tan(r)**2)}case"triangle":return Math.sqrt(3)*e*e/4;case"wye":return(21-10*Math.sqrt(3))*e*e/8;default:return Math.PI*e*e/4}},gU=(e,t)=>{ij["symbol".concat(xs(e))]=t},aj=e=>{var{type:t="circle",size:n=64,sizeType:r="area"}=e,a=hU(e,sU),u=LE(LE({},a),{},{type:t,size:n,sizeType:r}),o="circle";typeof t=="string"&&(o=t);var c=()=>{var y=vU(o),g=B9().type(y).size(yU(n,r,o)),x=g();if(x!==null)return x},{className:f,cx:d,cy:m}=u,p=hr(u);return we(d)&&we(m)&&we(n)?E.createElement("path",mg({},p,{className:ft("recharts-symbols",f),transform:"translate(".concat(d,", ").concat(m,")"),d:c()})):null};aj.registerSymbol=gU;var lj=e=>"radius"in e&&"startAngle"in e&&"endAngle"in e,bU=(e,t)=>{if(!e||typeof e=="function"||typeof e=="boolean")return null;var n=e;if(E.isValidElement(e)&&(n=e.props),typeof n!="object"&&typeof n!="function")return null;var r={};return Object.keys(n).forEach(a=>{z0(a)&&(r[a]=(u=>n[a](n,u)))}),r},xU=(e,t,n)=>r=>(e(t,n,r),null),U0=(e,t,n)=>{if(e===null||typeof e!="object"&&typeof e!="function")return null;var r=null;return Object.keys(e).forEach(a=>{var u=e[a];z0(a)&&typeof u=="function"&&(r||(r={}),r[a]=xU(u,t,n))}),r};function BE(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function wU(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?BE(Object(n),!0).forEach(function(r){SU(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):BE(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function SU(e,t,n){return(t=OU(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function OU(e){var t=EU(e,"string");return typeof t=="symbol"?t:t+""}function EU(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function Kn(e,t){var n=wU({},e),r=t,a=Object.keys(t),u=a.reduce((o,c)=>(o[c]===void 0&&r[c]!==void 0&&(o[c]=r[c]),o),n);return u}var Ov={},Ev={},UE;function AU(){return UE||(UE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r){const a=new Map;for(let u=0;u<n.length;u++){const o=n[u],c=r(o,u,n);a.has(c)||a.set(c,o)}return Array.from(a.values())}e.uniqBy=t})(Ev)),Ev}var Av={},qE;function _U(){return qE||(qE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r){return function(...a){return n.apply(this,a.slice(0,r))}}e.ary=t})(Av)),Av}var _v={},HE;function uj(){return HE||(HE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n}e.identity=t})(_v)),_v}var kv={},Cv={},Tv={},$E;function kU(){return $E||($E=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return Number.isSafeInteger(n)&&n>=0}e.isLength=t})(Tv)),Tv}var FE;function q0(){return FE||(FE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=kU();function n(r){return r!=null&&typeof r!="function"&&t.isLength(r.length)}e.isArrayLike=n})(Cv)),Cv}var jv={},VE;function CU(){return VE||(VE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return typeof n=="object"&&n!==null}e.isObjectLike=t})(jv)),jv}var YE;function TU(){return YE||(YE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=q0(),n=CU();function r(a){return n.isObjectLike(a)&&t.isArrayLike(a)}e.isArrayLikeObject=r})(kv)),kv}var Mv={},zv={},KE;function jU(){return KE||(KE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=B0();function n(r){return function(a){return t.get(a,r)}}e.property=n})(zv)),zv}var Dv={},Nv={},Pv={},Rv={},GE;function oj(){return GE||(GE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n!==null&&(typeof n=="object"||typeof n=="function")}e.isObject=t})(Rv)),Rv}var Iv={},XE;function sj(){return XE||(XE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n==null||typeof n!="object"&&typeof n!="function"}e.isPrimitive=t})(Iv)),Iv}var Lv={},ZE;function cj(){return ZE||(ZE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r){return n===r||Number.isNaN(n)&&Number.isNaN(r)}e.isEqualsSameValueZero=t})(Lv)),Lv}var QE;function MU(){return QE||(QE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=oj(),n=sj(),r=cj();function a(m,p,y){return typeof y!="function"?a(m,p,()=>{}):u(m,p,function g(x,w,S,O,_,k){const M=y(x,w,S,O,_,k);return M!==void 0?!!M:u(x,w,g,k)},new Map)}function u(m,p,y,g){if(p===m)return!0;switch(typeof p){case"object":return o(m,p,y,g);case"function":return Object.keys(p).length>0?u(m,{...p},y,g):r.isEqualsSameValueZero(m,p);default:return t.isObject(m)?typeof p=="string"?p==="":!0:r.isEqualsSameValueZero(m,p)}}function o(m,p,y,g){if(p==null)return!0;if(Array.isArray(p))return f(m,p,y,g);if(p instanceof Map)return c(m,p,y,g);if(p instanceof Set)return d(m,p,y,g);const x=Object.keys(p);if(m==null||n.isPrimitive(m))return x.length===0;if(x.length===0)return!0;if(g!=null&&g.has(p))return g.get(p)===m;g==null||g.set(p,m);try{for(let w=0;w<x.length;w++){const S=x[w];if(!n.isPrimitive(m)&&!(S in m)||p[S]===void 0&&m[S]!==void 0||p[S]===null&&m[S]!==null||!y(m[S],p[S],S,m,p,g))return!1}return!0}finally{g==null||g.delete(p)}}function c(m,p,y,g){if(p.size===0)return!0;if(!(m instanceof Map))return!1;for(const[x,w]of p.entries()){const S=m.get(x);if(y(S,w,x,m,p,g)===!1)return!1}return!0}function f(m,p,y,g){if(p.length===0)return!0;if(!Array.isArray(m))return!1;const x=new Set;for(let w=0;w<p.length;w++){const S=p[w];let O=!1;for(let _=0;_<m.length;_++){if(x.has(_))continue;const k=m[_];let M=!1;if(y(k,S,w,m,p,g)&&(M=!0),M){x.add(_),O=!0;break}}if(!O)return!1}return!0}function d(m,p,y,g){return p.size===0?!0:m instanceof Set?f([...m],[...p],y,g):!1}e.isMatchWith=a,e.isSetMatch=d})(Pv)),Pv}var WE;function fj(){return WE||(WE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=MU();function n(r,a){return t.isMatchWith(r,a,()=>{})}e.isMatch=n})(Nv)),Nv}var Bv={},Uv={},qv={},JE;function zU(){return JE||(JE=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return Object.getOwnPropertySymbols(n).filter(r=>Object.prototype.propertyIsEnumerable.call(n,r))}e.getSymbols=t})(qv)),qv}var Hv={},eA;function H0(){return eA||(eA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n==null?n===void 0?"[object Undefined]":"[object Null]":Object.prototype.toString.call(n)}e.getTag=t})(Hv)),Hv}var $v={},tA;function dj(){return tA||(tA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t="[object RegExp]",n="[object String]",r="[object Number]",a="[object Boolean]",u="[object Arguments]",o="[object Symbol]",c="[object Date]",f="[object Map]",d="[object Set]",m="[object Array]",p="[object Function]",y="[object ArrayBuffer]",g="[object Object]",x="[object Error]",w="[object DataView]",S="[object Uint8Array]",O="[object Uint8ClampedArray]",_="[object Uint16Array]",k="[object Uint32Array]",M="[object BigUint64Array]",N="[object Int8Array]",C="[object Int16Array]",z="[object Int32Array]",$="[object BigInt64Array]",H="[object Float32Array]",P="[object Float64Array]";e.argumentsTag=u,e.arrayBufferTag=y,e.arrayTag=m,e.bigInt64ArrayTag=$,e.bigUint64ArrayTag=M,e.booleanTag=a,e.dataViewTag=w,e.dateTag=c,e.errorTag=x,e.float32ArrayTag=H,e.float64ArrayTag=P,e.functionTag=p,e.int16ArrayTag=C,e.int32ArrayTag=z,e.int8ArrayTag=N,e.mapTag=f,e.numberTag=r,e.objectTag=g,e.regexpTag=t,e.setTag=d,e.stringTag=n,e.symbolTag=o,e.uint16ArrayTag=_,e.uint32ArrayTag=k,e.uint8ArrayTag=S,e.uint8ClampedArrayTag=O})($v)),$v}var Fv={},nA;function DU(){return nA||(nA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return ArrayBuffer.isView(n)&&!(n instanceof DataView)}e.isTypedArray=t})(Fv)),Fv}var rA;function hj(){return rA||(rA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=zU(),n=H0(),r=dj(),a=sj(),u=DU();function o(m,p){return c(m,void 0,m,new Map,p)}function c(m,p,y,g=new Map,x=void 0){const w=x==null?void 0:x(m,p,y,g);if(w!==void 0)return w;if(a.isPrimitive(m))return m;if(g.has(m))return g.get(m);if(Array.isArray(m)){const S=new Array(m.length);g.set(m,S);for(let O=0;O<m.length;O++)S[O]=c(m[O],O,y,g,x);return Object.hasOwn(m,"index")&&(S.index=m.index),Object.hasOwn(m,"input")&&(S.input=m.input),S}if(m instanceof Date)return new Date(m.getTime());if(m instanceof RegExp){const S=new RegExp(m.source,m.flags);return S.lastIndex=m.lastIndex,S}if(m instanceof Map){const S=new Map;g.set(m,S);for(const[O,_]of m)S.set(O,c(_,O,y,g,x));return S}if(m instanceof Set){const S=new Set;g.set(m,S);for(const O of m)S.add(c(O,void 0,y,g,x));return S}if(typeof Buffer<"u"&&Buffer.isBuffer(m))return m.subarray();if(u.isTypedArray(m)){const S=new(Object.getPrototypeOf(m)).constructor(m.length);g.set(m,S);for(let O=0;O<m.length;O++)S[O]=c(m[O],O,y,g,x);return S}if(m instanceof ArrayBuffer||typeof SharedArrayBuffer<"u"&&m instanceof SharedArrayBuffer)return m.slice(0);if(m instanceof DataView){const S=new DataView(m.buffer.slice(0),m.byteOffset,m.byteLength);return g.set(m,S),f(S,m,y,g,x),S}if(typeof File<"u"&&m instanceof File){const S=new File([m],m.name,{type:m.type});return g.set(m,S),f(S,m,y,g,x),S}if(typeof Blob<"u"&&m instanceof Blob){const S=new Blob([m],{type:m.type});return g.set(m,S),f(S,m,y,g,x),S}if(m instanceof Error){const S=new m.constructor;return g.set(m,S),S.message=m.message,S.name=m.name,S.stack=m.stack,S.cause=m.cause,f(S,m,y,g,x),S}if(m instanceof Boolean){const S=new Boolean(m.valueOf());return g.set(m,S),f(S,m,y,g,x),S}if(m instanceof Number){const S=new Number(m.valueOf());return g.set(m,S),f(S,m,y,g,x),S}if(m instanceof String){const S=new String(m.valueOf());return g.set(m,S),f(S,m,y,g,x),S}if(typeof m=="object"&&d(m)){const S=Object.create(Object.getPrototypeOf(m));return g.set(m,S),f(S,m,y,g,x),S}return m}function f(m,p,y=m,g,x){const w=[...Object.keys(p),...t.getSymbols(p)];for(let S=0;S<w.length;S++){const O=w[S],_=Object.getOwnPropertyDescriptor(m,O);(_==null||_.writable)&&(m[O]=c(p[O],O,y,g,x))}}function d(m){switch(n.getTag(m)){case r.argumentsTag:case r.arrayTag:case r.arrayBufferTag:case r.dataViewTag:case r.booleanTag:case r.dateTag:case r.float32ArrayTag:case r.float64ArrayTag:case r.int8ArrayTag:case r.int16ArrayTag:case r.int32ArrayTag:case r.mapTag:case r.numberTag:case r.objectTag:case r.regexpTag:case r.setTag:case r.stringTag:case r.symbolTag:case r.uint8ArrayTag:case r.uint8ClampedArrayTag:case r.uint16ArrayTag:case r.uint32ArrayTag:return!0;default:return!1}}e.cloneDeepWith=o,e.cloneDeepWithImpl=c,e.copyProperties=f})(Uv)),Uv}var iA;function NU(){return iA||(iA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=hj();function n(r){return t.cloneDeepWithImpl(r,void 0,r,new Map,void 0)}e.cloneDeep=n})(Bv)),Bv}var aA;function PU(){return aA||(aA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=fj(),n=NU();function r(a){return a=n.cloneDeep(a),u=>t.isMatch(u,a)}e.matches=r})(Dv)),Dv}var Vv={},Yv={},Kv={},lA;function RU(){return lA||(lA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=hj(),n=H0(),r=dj();function a(u,o){return t.cloneDeepWith(u,(c,f,d,m)=>{const p=o==null?void 0:o(c,f,d,m);if(p!==void 0)return p;if(typeof u=="object"){if(n.getTag(u)===r.objectTag&&typeof u.constructor!="function"){const y={};return m.set(u,y),t.copyProperties(y,u,d,m),y}switch(Object.prototype.toString.call(u)){case r.numberTag:case r.stringTag:case r.booleanTag:{const y=new u.constructor(u==null?void 0:u.valueOf());return t.copyProperties(y,u),y}case r.argumentsTag:{const y={};return t.copyProperties(y,u),y.length=u.length,y[Symbol.iterator]=u[Symbol.iterator],y}default:return}}})}e.cloneDeepWith=a})(Kv)),Kv}var uA;function IU(){return uA||(uA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=RU();function n(r){return t.cloneDeepWith(r)}e.cloneDeep=n})(Yv)),Yv}var Gv={},Xv={},oA;function mj(){return oA||(oA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=/^(?:0|[1-9]\d*)$/;function n(r,a=Number.MAX_SAFE_INTEGER){switch(typeof r){case"number":return Number.isInteger(r)&&r>=0&&r<a;case"symbol":return!1;case"string":return t.test(r)}}e.isIndex=n})(Xv)),Xv}var Zv={},sA;function LU(){return sA||(sA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=H0();function n(r){return r!==null&&typeof r=="object"&&t.getTag(r)==="[object Arguments]"}e.isArguments=n})(Zv)),Zv}var cA;function BU(){return cA||(cA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=nj(),n=mj(),r=LU(),a=L0();function u(o,c){let f;if(Array.isArray(c)?f=c:typeof c=="string"&&t.isDeepKey(c)&&(o==null?void 0:o[c])==null?f=a.toPath(c):f=[c],f.length===0)return!1;let d=o;for(let m=0;m<f.length;m++){const p=f[m];if((d==null||!Object.hasOwn(d,p))&&!((Array.isArray(d)||r.isArguments(d))&&n.isIndex(p)&&p<d.length))return!1;d=d[p]}return!0}e.has=u})(Gv)),Gv}var fA;function UU(){return fA||(fA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=fj(),n=I0(),r=IU(),a=B0(),u=BU();function o(c,f){switch(typeof c){case"object":{Object.is(c==null?void 0:c.valueOf(),-0)&&(c="-0");break}case"number":{c=n.toKey(c);break}}return f=r.cloneDeep(f),function(d){const m=a.get(d,c);return m===void 0?u.has(d,c):f===void 0?m===void 0:t.isMatch(m,f)}}e.matchesProperty=o})(Vv)),Vv}var dA;function qU(){return dA||(dA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=uj(),n=jU(),r=PU(),a=UU();function u(o){if(o==null)return t.identity;switch(typeof o){case"function":return o;case"object":return Array.isArray(o)&&o.length===2?a.matchesProperty(o[0],o[1]):r.matches(o);case"string":case"symbol":case"number":return n.property(o)}}e.iteratee=u})(Mv)),Mv}var hA;function HU(){return hA||(hA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=AU(),n=_U(),r=uj(),a=TU(),u=qU();function o(c,f=r.identity){return a.isArrayLikeObject(c)?t.uniqBy(Array.from(c),n.ary(u.iteratee(f),1)):[]}e.uniqBy=o})(Ov)),Ov}var Qv,mA;function $U(){return mA||(mA=1,Qv=HU().uniqBy),Qv}var FU=$U();const pA=Tr(FU);function VU(e,t,n){return t===!0?pA(e,n):typeof t=="function"?pA(e,t):e}var Wv={exports:{}},Jv={},ey={exports:{}},ty={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var vA;function YU(){if(vA)return ty;vA=1;var e=Su();function t(p,y){return p===y&&(p!==0||1/p===1/y)||p!==p&&y!==y}var n=typeof Object.is=="function"?Object.is:t,r=e.useState,a=e.useEffect,u=e.useLayoutEffect,o=e.useDebugValue;function c(p,y){var g=y(),x=r({inst:{value:g,getSnapshot:y}}),w=x[0].inst,S=x[1];return u(function(){w.value=g,w.getSnapshot=y,f(w)&&S({inst:w})},[p,g,y]),a(function(){return f(w)&&S({inst:w}),p(function(){f(w)&&S({inst:w})})},[p]),o(g),g}function f(p){var y=p.getSnapshot;p=p.value;try{var g=y();return!n(p,g)}catch{return!0}}function d(p,y){return y()}var m=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?d:c;return ty.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:m,ty}var yA;function KU(){return yA||(yA=1,ey.exports=YU()),ey.exports}/**
 * @license React
 * use-sync-external-store-shim/with-selector.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var gA;function GU(){if(gA)return Jv;gA=1;var e=Su(),t=KU();function n(d,m){return d===m&&(d!==0||1/d===1/m)||d!==d&&m!==m}var r=typeof Object.is=="function"?Object.is:n,a=t.useSyncExternalStore,u=e.useRef,o=e.useEffect,c=e.useMemo,f=e.useDebugValue;return Jv.useSyncExternalStoreWithSelector=function(d,m,p,y,g){var x=u(null);if(x.current===null){var w={hasValue:!1,value:null};x.current=w}else w=x.current;x=c(function(){function O(C){if(!_){if(_=!0,k=C,C=y(C),g!==void 0&&w.hasValue){var z=w.value;if(g(z,C))return M=z}return M=C}if(z=M,r(k,C))return z;var $=y(C);return g!==void 0&&g(z,$)?(k=C,z):(k=C,M=$)}var _=!1,k,M,N=p===void 0?null:p;return[function(){return O(m())},N===null?void 0:function(){return O(N())}]},[m,p,y,g]);var S=a(d,x[0],x[1]);return o(function(){w.hasValue=!0,w.value=S},[S]),f(S),S},Jv}var bA;function XU(){return bA||(bA=1,Wv.exports=GU()),Wv.exports}var ZU=XU(),$0=E.createContext(null),QU=e=>e,wt=()=>{var e=E.useContext($0);return e?e.store.dispatch:QU},_f=()=>{},WU=()=>_f,JU=(e,t)=>e===t;function Ee(e){var t=E.useContext($0),n=E.useMemo(()=>t?r=>{if(r!=null)return e(r)}:_f,[t,e]);return ZU.useSyncExternalStoreWithSelector(t?t.subscription.addNestedSub:WU,t?t.store.getState:_f,t?t.store.getState:_f,n,JU)}function eq(e,t=`expected a function, instead received ${typeof e}`){if(typeof e!="function")throw new TypeError(t)}function tq(e,t=`expected an object, instead received ${typeof e}`){if(typeof e!="object")throw new TypeError(t)}function nq(e,t="expected all items to be functions, instead received the following types: "){if(!e.every(n=>typeof n=="function")){const n=e.map(r=>typeof r=="function"?`function ${r.name||"unnamed"}()`:typeof r).join(", ");throw new TypeError(`${t}[${n}]`)}}var xA=e=>Array.isArray(e)?e:[e];function rq(e){const t=Array.isArray(e[0])?e[0]:e;return nq(t,"createSelector expects all input-selectors to be functions, but received the following types: "),t}function iq(e,t){const n=[],{length:r}=e;for(let a=0;a<r;a++)n.push(e[a].apply(null,t));return n}var aq=class{constructor(e){this.value=e}deref(){return this.value}},lq=typeof WeakRef<"u"?WeakRef:aq,uq=0,wA=1;function sf(){return{s:uq,v:void 0,o:null,p:null}}function pj(e,t={}){let n=sf();const{resultEqualityCheck:r}=t;let a,u=0;function o(){var p;let c=n;const{length:f}=arguments;for(let y=0,g=f;y<g;y++){const x=arguments[y];if(typeof x=="function"||typeof x=="object"&&x!==null){let w=c.o;w===null&&(c.o=w=new WeakMap);const S=w.get(x);S===void 0?(c=sf(),w.set(x,c)):c=S}else{let w=c.p;w===null&&(c.p=w=new Map);const S=w.get(x);S===void 0?(c=sf(),w.set(x,c)):c=S}}const d=c;let m;if(c.s===wA)m=c.v;else if(m=e.apply(null,arguments),u++,r){const y=((p=a==null?void 0:a.deref)==null?void 0:p.call(a))??a;y!=null&&r(y,m)&&(m=y,u!==0&&u--),a=typeof m=="object"&&m!==null||typeof m=="function"?new lq(m):m}return d.s=wA,d.v=m,m}return o.clearCache=()=>{n=sf(),o.resetResultsCount()},o.resultsCount=()=>u,o.resetResultsCount=()=>{u=0},o}function oq(e,...t){const n=typeof e=="function"?{memoize:e,memoizeOptions:t}:e,r=(...a)=>{let u=0,o=0,c,f={},d=a.pop();typeof d=="object"&&(f=d,d=a.pop()),eq(d,`createSelector expects an output function after the inputs, but received: [${typeof d}]`);const m={...n,...f},{memoize:p,memoizeOptions:y=[],argsMemoize:g=pj,argsMemoizeOptions:x=[]}=m,w=xA(y),S=xA(x),O=rq(a),_=p(function(){return u++,d.apply(null,arguments)},...w),k=g(function(){o++;const N=iq(O,arguments);return c=_.apply(null,N),c},...S);return Object.assign(k,{resultFunc:d,memoizedResultFunc:_,dependencies:O,dependencyRecomputations:()=>o,resetDependencyRecomputations:()=>{o=0},lastResult:()=>c,recomputations:()=>u,resetRecomputations:()=>{u=0},memoize:p,argsMemoize:g})};return Object.assign(r,{withTypes:()=>r}),r}var te=oq(pj),sq=Object.assign((e,t=te)=>{tq(e,`createStructuredSelector expects first argument to be an object where each property is a selector, instead received a ${typeof e}`);const n=Object.keys(e),r=n.map(u=>e[u]);return t(r,(...u)=>u.reduce((o,c,f)=>(o[n[f]]=c,o),{}))},{withTypes:()=>sq}),ny={},ry={},iy={},SA;function cq(){return SA||(SA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(r){return typeof r=="symbol"?1:r===null?2:r===void 0?3:r!==r?4:0}const n=(r,a,u)=>{if(r!==a){const o=t(r),c=t(a);if(o===c&&o===0){if(r<a)return u==="desc"?1:-1;if(r>a)return u==="desc"?-1:1}return u==="desc"?c-o:o-c}return 0};e.compareValues=n})(iy)),iy}var ay={},ly={},OA;function vj(){return OA||(OA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return typeof n=="symbol"||n instanceof Symbol}e.isSymbol=t})(ly)),ly}var EA;function fq(){return EA||(EA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=vj(),n=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,r=/^\w*$/;function a(u,o){return Array.isArray(u)?!1:typeof u=="number"||typeof u=="boolean"||u==null||t.isSymbol(u)?!0:typeof u=="string"&&(r.test(u)||!n.test(u))||o!=null&&Object.hasOwn(o,u)}e.isKey=a})(ay)),ay}var AA;function dq(){return AA||(AA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=cq(),n=fq(),r=L0();function a(u,o,c,f){if(u==null)return[];c=f?void 0:c,Array.isArray(u)||(u=Object.values(u)),Array.isArray(o)||(o=o==null?[null]:[o]),o.length===0&&(o=[null]),Array.isArray(c)||(c=c==null?[]:[c]),c=c.map(g=>String(g));const d=(g,x)=>{let w=g;for(let S=0;S<x.length&&w!=null;++S)w=w[x[S]];return w},m=(g,x)=>x==null||g==null?x:typeof g=="object"&&"key"in g?Object.hasOwn(x,g.key)?x[g.key]:d(x,g.path):typeof g=="function"?g(x):Array.isArray(g)?d(x,g):typeof x=="object"?x[g]:x,p=o.map(g=>(Array.isArray(g)&&g.length===1&&(g=g[0]),g==null||typeof g=="function"||Array.isArray(g)||n.isKey(g)?g:{key:g,path:r.toPath(g)}));return u.map(g=>({original:g,criteria:p.map(x=>m(x,g))})).slice().sort((g,x)=>{for(let w=0;w<p.length;w++){const S=t.compareValues(g.criteria[w],x.criteria[w],c[w]);if(S!==0)return S}return 0}).map(g=>g.original)}e.orderBy=a})(ry)),ry}var uy={},_A;function hq(){return _A||(_A=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r=1){const a=[],u=Math.floor(r),o=(c,f)=>{for(let d=0;d<c.length;d++){const m=c[d];Array.isArray(m)&&f<u?o(m,f+1):a.push(m)}};return o(n,0),a}e.flatten=t})(uy)),uy}var oy={},kA;function yj(){return kA||(kA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=mj(),n=q0(),r=oj(),a=cj();function u(o,c,f){return r.isObject(f)&&(typeof c=="number"&&n.isArrayLike(f)&&t.isIndex(c)&&c<f.length||typeof c=="string"&&c in f)?a.isEqualsSameValueZero(f[c],o):!1}e.isIterateeCall=u})(oy)),oy}var CA;function mq(){return CA||(CA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=dq(),n=hq(),r=yj();function a(u,...o){const c=o.length;return c>1&&r.isIterateeCall(u,o[0],o[1])?o=[]:c>2&&r.isIterateeCall(o[0],o[1],o[2])&&(o=[o[0]]),t.orderBy(u,n.flatten(o),["asc"])}e.sortBy=a})(ny)),ny}var sy,TA;function pq(){return TA||(TA=1,sy=mq().sortBy),sy}var vq=pq();const Ld=Tr(vq);var gj=e=>e.legend.settings,yq=e=>e.legend.size,gq=e=>e.legend.payload;te([gq,gj],(e,t)=>{var{itemSorter:n}=t,r=e.flat(1);return n?Ld(r,n):r});var cf=1;function bq(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],[t,n]=E.useState({height:0,left:0,top:0,width:0}),r=E.useCallback(a=>{if(a!=null){var u=a.getBoundingClientRect(),o={height:u.height,left:u.left,top:u.top,width:u.width};(Math.abs(o.height-t.height)>cf||Math.abs(o.left-t.left)>cf||Math.abs(o.top-t.top)>cf||Math.abs(o.width-t.width)>cf)&&n({height:o.height,left:o.left,top:o.top,width:o.width})}},[t.width,t.height,t.top,t.left,...e]);return[t,r]}function Qt(e){return`Minified Redux error #${e}; visit https://redux.js.org/Errors?code=${e} for the full message or use the non-minified dev environment for full errors. `}var xq=typeof Symbol=="function"&&Symbol.observable||"@@observable",jA=xq,cy=()=>Math.random().toString(36).substring(7).split("").join("."),wq={INIT:`@@redux/INIT${cy()}`,REPLACE:`@@redux/REPLACE${cy()}`,PROBE_UNKNOWN_ACTION:()=>`@@redux/PROBE_UNKNOWN_ACTION${cy()}`},qf=wq;function F0(e){if(typeof e!="object"||e===null)return!1;let t=e;for(;Object.getPrototypeOf(t)!==null;)t=Object.getPrototypeOf(t);return Object.getPrototypeOf(e)===t||Object.getPrototypeOf(e)===null}function bj(e,t,n){if(typeof e!="function")throw new Error(Qt(2));if(typeof t=="function"&&typeof n=="function"||typeof n=="function"&&typeof arguments[3]=="function")throw new Error(Qt(0));if(typeof t=="function"&&typeof n>"u"&&(n=t,t=void 0),typeof n<"u"){if(typeof n!="function")throw new Error(Qt(1));return n(bj)(e,t)}let r=e,a=t,u=new Map,o=u,c=0,f=!1;function d(){o===u&&(o=new Map,u.forEach((S,O)=>{o.set(O,S)}))}function m(){if(f)throw new Error(Qt(3));return a}function p(S){if(typeof S!="function")throw new Error(Qt(4));if(f)throw new Error(Qt(5));let O=!0;d();const _=c++;return o.set(_,S),function(){if(O){if(f)throw new Error(Qt(6));O=!1,d(),o.delete(_),u=null}}}function y(S){if(!F0(S))throw new Error(Qt(7));if(typeof S.type>"u")throw new Error(Qt(8));if(typeof S.type!="string")throw new Error(Qt(17));if(f)throw new Error(Qt(9));try{f=!0,a=r(a,S)}finally{f=!1}return(u=o).forEach(_=>{_()}),S}function g(S){if(typeof S!="function")throw new Error(Qt(10));r=S,y({type:qf.REPLACE})}function x(){const S=p;return{subscribe(O){if(typeof O!="object"||O===null)throw new Error(Qt(11));function _(){const M=O;M.next&&M.next(m())}return _(),{unsubscribe:S(_)}},[jA](){return this}}}return y({type:qf.INIT}),{dispatch:y,subscribe:p,getState:m,replaceReducer:g,[jA]:x}}function Sq(e){Object.keys(e).forEach(t=>{const n=e[t];if(typeof n(void 0,{type:qf.INIT})>"u")throw new Error(Qt(12));if(typeof n(void 0,{type:qf.PROBE_UNKNOWN_ACTION()})>"u")throw new Error(Qt(13))})}function xj(e){const t=Object.keys(e),n={};for(let u=0;u<t.length;u++){const o=t[u];typeof e[o]=="function"&&(n[o]=e[o])}const r=Object.keys(n);let a;try{Sq(n)}catch(u){a=u}return function(o={},c){if(a)throw a;let f=!1;const d={};for(let m=0;m<r.length;m++){const p=r[m],y=n[p],g=o[p],x=y(g,c);if(typeof x>"u")throw c&&c.type,new Error(Qt(14));d[p]=x,f=f||x!==g}return f=f||r.length!==Object.keys(o).length,f?d:o}}function Hf(...e){return e.length===0?t=>t:e.length===1?e[0]:e.reduce((t,n)=>(...r)=>t(n(...r)))}function Oq(...e){return t=>(n,r)=>{const a=t(n,r);let u=()=>{throw new Error(Qt(15))};const o={getState:a.getState,dispatch:(f,...d)=>u(f,...d)},c=e.map(f=>f(o));return u=Hf(...c)(a.dispatch),{...a,dispatch:u}}}function wj(e){return F0(e)&&"type"in e&&typeof e.type=="string"}var Sj=Symbol.for("immer-nothing"),MA=Symbol.for("immer-draftable"),pn=Symbol.for("immer-state");function Sr(e,...t){throw new Error(`[Immer] minified error nr: ${e}. Full error at: https://bit.ly/3cXEKWf`)}var $n=Object,mu=$n.getPrototypeOf,$f="constructor",Bd="prototype",pg="configurable",Ff="enumerable",kf="writable",ns="value",wi=e=>!!e&&!!e[pn];function Cr(e){var t;return e?Oj(e)||qd(e)||!!e[MA]||!!((t=e[$f])!=null&&t[MA])||Hd(e)||$d(e):!1}var Eq=$n[Bd][$f].toString(),zA=new WeakMap;function Oj(e){if(!e||!V0(e))return!1;const t=mu(e);if(t===null||t===$n[Bd])return!0;const n=$n.hasOwnProperty.call(t,$f)&&t[$f];if(n===Object)return!0;if(!iu(n))return!1;let r=zA.get(n);return r===void 0&&(r=Function.toString.call(n),zA.set(n,r)),r===Eq}function Ud(e,t,n=!0){ws(e)===0?(n?Reflect.ownKeys(e):$n.keys(e)).forEach(a=>{t(a,e[a],e)}):e.forEach((r,a)=>t(a,r,e))}function ws(e){const t=e[pn];return t?t.type_:qd(e)?1:Hd(e)?2:$d(e)?3:0}var DA=(e,t,n=ws(e))=>n===2?e.has(t):$n[Bd].hasOwnProperty.call(e,t),vg=(e,t,n=ws(e))=>n===2?e.get(t):e[t],Vf=(e,t,n,r=ws(e))=>{r===2?e.set(t,n):r===3?e.add(n):e[t]=n};function Aq(e,t){return e===t?e!==0||1/e===1/t:e!==e&&t!==t}var qd=Array.isArray,Hd=e=>e instanceof Map,$d=e=>e instanceof Set,V0=e=>typeof e=="object",iu=e=>typeof e=="function",fy=e=>typeof e=="boolean";function _q(e){const t=+e;return Number.isInteger(t)&&String(t)===e}var hi=e=>e.copy_||e.base_,Y0=e=>e.modified_?e.copy_:e.base_;function yg(e,t){if(Hd(e))return new Map(e);if($d(e))return new Set(e);if(qd(e))return Array[Bd].slice.call(e);const n=Oj(e);if(t===!0||t==="class_only"&&!n){const r=$n.getOwnPropertyDescriptors(e);delete r[pn];let a=Reflect.ownKeys(r);for(let u=0;u<a.length;u++){const o=a[u],c=r[o];c[kf]===!1&&(c[kf]=!0,c[pg]=!0),(c.get||c.set)&&(r[o]={[pg]:!0,[kf]:!0,[Ff]:c[Ff],[ns]:e[o]})}return $n.create(mu(e),r)}else{const r=mu(e);if(r!==null&&n)return{...e};const a=$n.create(r);return $n.assign(a,e)}}function K0(e,t=!1){return Fd(e)||wi(e)||!Cr(e)||(ws(e)>1&&$n.defineProperties(e,{set:ff,add:ff,clear:ff,delete:ff}),$n.freeze(e),t&&Ud(e,(n,r)=>{K0(r,!0)},!1)),e}function kq(){Sr(2)}var ff={[ns]:kq};function Fd(e){return e===null||!V0(e)?!0:$n.isFrozen(e)}var Yf="MapSet",gg="Patches",NA="ArrayMethods",Ej={};function Ja(e){const t=Ej[e];return t||Sr(0,e),t}var PA=e=>!!Ej[e],rs,Aj=()=>rs,Cq=(e,t)=>({drafts_:[],parent_:e,immer_:t,canAutoFreeze_:!0,unfinalizedDrafts_:0,handledSet_:new Set,processedForPatches_:new Set,mapSetPlugin_:PA(Yf)?Ja(Yf):void 0,arrayMethodsPlugin_:PA(NA)?Ja(NA):void 0});function RA(e,t){t&&(e.patchPlugin_=Ja(gg),e.patches_=[],e.inversePatches_=[],e.patchListener_=t)}function bg(e){xg(e),e.drafts_.forEach(Tq),e.drafts_=null}function xg(e){e===rs&&(rs=e.parent_)}var IA=e=>rs=Cq(rs,e);function Tq(e){const t=e[pn];t.type_===0||t.type_===1?t.revoke_():t.revoked_=!0}function LA(e,t){t.unfinalizedDrafts_=t.drafts_.length;const n=t.drafts_[0];if(e!==void 0&&e!==n){n[pn].modified_&&(bg(t),Sr(4)),Cr(e)&&(e=BA(t,e));const{patchPlugin_:a}=t;a&&a.generateReplacementPatches_(n[pn].base_,e,t)}else e=BA(t,n);return jq(t,e,!0),bg(t),t.patches_&&t.patchListener_(t.patches_,t.inversePatches_),e!==Sj?e:void 0}function BA(e,t){if(Fd(t))return t;const n=t[pn];if(!n)return Kf(t,e.handledSet_,e);if(!Vd(n,e))return t;if(!n.modified_)return n.base_;if(!n.finalized_){const{callbacks_:r}=n;if(r)for(;r.length>0;)r.pop()(e);Cj(n,e)}return n.copy_}function jq(e,t,n=!1){!e.parent_&&e.immer_.autoFreeze_&&e.canAutoFreeze_&&K0(t,n)}function _j(e){e.finalized_=!0,e.scope_.unfinalizedDrafts_--}var Vd=(e,t)=>e.scope_===t,Mq=[];function kj(e,t,n,r){const a=hi(e),u=e.type_;if(r!==void 0&&vg(a,r,u)===t){Vf(a,r,n,u);return}if(!e.draftLocations_){const c=e.draftLocations_=new Map;Ud(a,(f,d)=>{if(wi(d)){const m=c.get(d)||[];m.push(f),c.set(d,m)}})}const o=e.draftLocations_.get(t)??Mq;for(const c of o)Vf(a,c,n,u)}function zq(e,t,n){e.callbacks_.push(function(a){var c;const u=t;if(!u||!Vd(u,a))return;(c=a.mapSetPlugin_)==null||c.fixSetContents(u);const o=Y0(u);kj(e,u.draft_??u,o,n),Cj(u,a)})}function Cj(e,t){var r;if(e.modified_&&!e.finalized_&&(e.type_===3||e.type_===1&&e.allIndicesReassigned_||(((r=e.assigned_)==null?void 0:r.size)??0)>0)){const{patchPlugin_:a}=t;if(a){const u=a.getPath(e);u&&a.generatePatches_(e,u,t)}_j(e)}}function Dq(e,t,n){const{scope_:r}=e;if(wi(n)){const a=n[pn];Vd(a,r)&&a.callbacks_.push(function(){Cf(e);const o=Y0(a);kj(e,n,o,t)})}else Cr(n)&&e.callbacks_.push(function(){const u=hi(e);e.type_===3?u.has(n)&&Kf(n,r.handledSet_,r):vg(u,t,e.type_)===n&&r.drafts_.length>1&&(e.assigned_.get(t)??!1)===!0&&e.copy_&&Kf(vg(e.copy_,t,e.type_),r.handledSet_,r)})}function Kf(e,t,n){return!n.immer_.autoFreeze_&&n.unfinalizedDrafts_<1||wi(e)||t.has(e)||!Cr(e)||Fd(e)||(t.add(e),Ud(e,(r,a)=>{if(wi(a)){const u=a[pn];if(Vd(u,n)){const o=Y0(u);Vf(e,r,o,e.type_),_j(u)}}else Cr(a)&&Kf(a,t,n)})),e}function Nq(e,t){const n=qd(e),r={type_:n?1:0,scope_:t?t.scope_:Aj(),modified_:!1,finalized_:!1,assigned_:void 0,parent_:t,base_:e,draft_:null,copy_:null,revoke_:null,isManual_:!1,callbacks_:void 0};let a=r,u=Gf;n&&(a=[r],u=is);const{revoke:o,proxy:c}=Proxy.revocable(a,u);return r.draft_=c,r.revoke_=o,[c,r]}var Gf={get(e,t){if(t===pn)return e;let n=e.scope_.arrayMethodsPlugin_;const r=e.type_===1&&typeof t=="string";if(r&&n!=null&&n.isArrayOperationMethod(t))return n.createMethodInterceptor(e,t);const a=hi(e);if(!DA(a,t,e.type_))return Pq(e,a,t);const u=a[t];if(e.finalized_||!Cr(u)||r&&e.operationMethod&&(n!=null&&n.isMutatingArrayMethod(e.operationMethod))&&_q(t))return u;if(u===dy(e.base_,t)){Cf(e);const o=e.type_===1?+t:t,c=Sg(e.scope_,u,e,o);return e.copy_[o]=c}return u},has(e,t){return t in hi(e)},ownKeys(e){return Reflect.ownKeys(hi(e))},set(e,t,n){const r=Tj(hi(e),t);if(r!=null&&r.set)return r.set.call(e.draft_,n),!0;if(!e.modified_){const a=dy(hi(e),t),u=a==null?void 0:a[pn];if(u&&u.base_===n)return e.copy_[t]=n,e.assigned_.set(t,!1),!0;if(Aq(n,a)&&(n!==void 0||DA(e.base_,t,e.type_)))return!0;Cf(e),wg(e)}return e.copy_[t]===n&&(n!==void 0||t in e.copy_)||Number.isNaN(n)&&Number.isNaN(e.copy_[t])||(e.copy_[t]=n,e.assigned_.set(t,!0),Dq(e,t,n)),!0},deleteProperty(e,t){return Cf(e),dy(e.base_,t)!==void 0||t in e.base_?(e.assigned_.set(t,!1),wg(e)):e.assigned_.delete(t),e.copy_&&delete e.copy_[t],!0},getOwnPropertyDescriptor(e,t){const n=hi(e),r=Reflect.getOwnPropertyDescriptor(n,t);return r&&{[kf]:!0,[pg]:e.type_!==1||t!=="length",[Ff]:r[Ff],[ns]:n[t]}},defineProperty(){Sr(11)},getPrototypeOf(e){return mu(e.base_)},setPrototypeOf(){Sr(12)}},is={};for(let e in Gf){let t=Gf[e];is[e]=function(){const n=arguments;return n[0]=n[0][0],t.apply(this,n)}}is.deleteProperty=function(e,t){return is.set.call(this,e,t,void 0)};is.set=function(e,t,n){return Gf.set.call(this,e[0],t,n,e[0])};function dy(e,t){const n=e[pn];return(n?hi(n):e)[t]}function Pq(e,t,n){var a;const r=Tj(t,n);return r?ns in r?r[ns]:(a=r.get)==null?void 0:a.call(e.draft_):void 0}function Tj(e,t){if(!(t in e))return;let n=mu(e);for(;n;){const r=Object.getOwnPropertyDescriptor(n,t);if(r)return r;n=mu(n)}}function wg(e){e.modified_||(e.modified_=!0,e.parent_&&wg(e.parent_))}function Cf(e){e.copy_||(e.assigned_=new Map,e.copy_=yg(e.base_,e.scope_.immer_.useStrictShallowCopy_))}var Rq=class{constructor(t){this.autoFreeze_=!0,this.useStrictShallowCopy_=!1,this.useStrictIteration_=!1,this.produce=(n,r,a)=>{if(iu(n)&&!iu(r)){const o=r;r=n;const c=this;return function(d=o,...m){return c.produce(d,p=>r.call(this,p,...m))}}iu(r)||Sr(6),a!==void 0&&!iu(a)&&Sr(7);let u;if(Cr(n)){const o=IA(this),c=Sg(o,n,void 0);let f=!0;try{u=r(c),f=!1}finally{f?bg(o):xg(o)}return RA(o,a),LA(u,o)}else if(!n||!V0(n)){if(u=r(n),u===void 0&&(u=n),u===Sj&&(u=void 0),this.autoFreeze_&&K0(u,!0),a){const o=[],c=[];Ja(gg).generateReplacementPatches_(n,u,{patches_:o,inversePatches_:c}),a(o,c)}return u}else Sr(1,n)},this.produceWithPatches=(n,r)=>{if(iu(n))return(c,...f)=>this.produceWithPatches(c,d=>n(d,...f));let a,u;return[this.produce(n,r,(c,f)=>{a=c,u=f}),a,u]},fy(t==null?void 0:t.autoFreeze)&&this.setAutoFreeze(t.autoFreeze),fy(t==null?void 0:t.useStrictShallowCopy)&&this.setUseStrictShallowCopy(t.useStrictShallowCopy),fy(t==null?void 0:t.useStrictIteration)&&this.setUseStrictIteration(t.useStrictIteration)}createDraft(t){Cr(t)||Sr(8),wi(t)&&(t=_r(t));const n=IA(this),r=Sg(n,t,void 0);return r[pn].isManual_=!0,xg(n),r}finishDraft(t,n){const r=t&&t[pn];(!r||!r.isManual_)&&Sr(9);const{scope_:a}=r;return RA(a,n),LA(void 0,a)}setAutoFreeze(t){this.autoFreeze_=t}setUseStrictShallowCopy(t){this.useStrictShallowCopy_=t}setUseStrictIteration(t){this.useStrictIteration_=t}shouldUseStrictIteration(){return this.useStrictIteration_}applyPatches(t,n){let r;for(r=n.length-1;r>=0;r--){const u=n[r];if(u.path.length===0&&u.op==="replace"){t=u.value;break}}r>-1&&(n=n.slice(r+1));const a=Ja(gg).applyPatches_;return wi(t)?a(t,n):this.produce(t,u=>a(u,n))}};function Sg(e,t,n,r){const[a,u]=Hd(t)?Ja(Yf).proxyMap_(t,n):$d(t)?Ja(Yf).proxySet_(t,n):Nq(t,n);return((n==null?void 0:n.scope_)??Aj()).drafts_.push(a),u.callbacks_=(n==null?void 0:n.callbacks_)??[],u.key_=r,n&&r!==void 0?zq(n,u,r):u.callbacks_.push(function(f){var m;(m=f.mapSetPlugin_)==null||m.fixSetContents(u);const{patchPlugin_:d}=f;u.modified_&&d&&d.generatePatches_(u,[],f)}),a}function _r(e){return wi(e)||Sr(10,e),jj(e)}function jj(e){if(!Cr(e)||Fd(e))return e;const t=e[pn];let n,r=!0;if(t){if(!t.modified_)return t.base_;t.finalized_=!0,n=yg(e,t.scope_.immer_.useStrictShallowCopy_),r=t.scope_.immer_.shouldUseStrictIteration()}else n=yg(e,!0);return Ud(n,(a,u)=>{Vf(n,a,jj(u))},r),t&&(t.finalized_=!1),n}var Iq=new Rq,Mj=Iq.produce;function zj(e){return({dispatch:n,getState:r})=>a=>u=>typeof u=="function"?u(n,r,e):a(u)}var Lq=zj(),Bq=zj,Uq=typeof window<"u"&&window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__?window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__:function(){if(arguments.length!==0)return typeof arguments[0]=="object"?Hf:Hf.apply(null,arguments)};function mr(e,t){function n(...r){if(t){let a=t(...r);if(!a)throw new Error(Vn(0));return{type:e,payload:a.payload,..."meta"in a&&{meta:a.meta},..."error"in a&&{error:a.error}}}return{type:e,payload:r[0]}}return n.toString=()=>`${e}`,n.type=e,n.match=r=>wj(r)&&r.type===e,n}var Dj=class Yo extends Array{constructor(...t){super(...t),Object.setPrototypeOf(this,Yo.prototype)}static get[Symbol.species](){return Yo}concat(...t){return super.concat.apply(this,t)}prepend(...t){return t.length===1&&Array.isArray(t[0])?new Yo(...t[0].concat(this)):new Yo(...t.concat(this))}};function UA(e){return Cr(e)?Mj(e,()=>{}):e}function df(e,t,n){return e.has(t)?e.get(t):e.set(t,n(t)).get(t)}function qq(e){return typeof e=="boolean"}var Hq=()=>function(t){const{thunk:n=!0,immutableCheck:r=!0,serializableCheck:a=!0,actionCreatorCheck:u=!0}=t??{};let o=new Dj;return n&&(qq(n)?o.push(Lq):o.push(Bq(n.extraArgument))),o},Nj="RTK_autoBatch",ht=()=>e=>({payload:e,meta:{[Nj]:!0}}),qA=e=>t=>{setTimeout(t,e)},Pj=(e={type:"raf"})=>t=>(...n)=>{const r=t(...n);let a=!0,u=!1,o=!1;const c=new Set,f=e.type==="tick"?queueMicrotask:e.type==="raf"?typeof window<"u"&&window.requestAnimationFrame?window.requestAnimationFrame:qA(10):e.type==="callback"?e.queueNotification:qA(e.timeout),d=()=>{o=!1,u&&(u=!1,c.forEach(m=>m()))};return Object.assign({},r,{subscribe(m){const p=()=>a&&m(),y=r.subscribe(p);return c.add(m),()=>{y(),c.delete(m)}},dispatch(m){var p;try{return a=!((p=m==null?void 0:m.meta)!=null&&p[Nj]),u=!a,u&&(o||(o=!0,f(d))),r.dispatch(m)}finally{a=!0}}})},$q=e=>function(n){const{autoBatch:r=!0}=n??{};let a=new Dj(e);return r&&a.push(Pj(typeof r=="object"?r:void 0)),a};function Fq(e){const t=Hq(),{reducer:n=void 0,middleware:r,devTools:a=!0,preloadedState:u=void 0,enhancers:o=void 0}=e||{};let c;if(typeof n=="function")c=n;else if(F0(n))c=xj(n);else throw new Error(Vn(1));let f;typeof r=="function"?f=r(t):f=t();let d=Hf;a&&(d=Uq({trace:!1,...typeof a=="object"&&a}));const m=Oq(...f),p=$q(m);let y=typeof o=="function"?o(p):p();const g=d(...y);return bj(c,u,g)}function Rj(e){const t={},n=[];let r;const a={addCase(u,o){const c=typeof u=="string"?u:u.type;if(!c)throw new Error(Vn(28));if(c in t)throw new Error(Vn(29));return t[c]=o,a},addAsyncThunk(u,o){return o.pending&&(t[u.pending.type]=o.pending),o.rejected&&(t[u.rejected.type]=o.rejected),o.fulfilled&&(t[u.fulfilled.type]=o.fulfilled),o.settled&&n.push({matcher:u.settled,reducer:o.settled}),a},addMatcher(u,o){return n.push({matcher:u,reducer:o}),a},addDefaultCase(u){return r=u,a}};return e(a),[t,n,r]}function Vq(e){return typeof e=="function"}function Yq(e,t){let[n,r,a]=Rj(t),u;if(Vq(e))u=()=>UA(e());else{const c=UA(e);u=()=>c}function o(c=u(),f){let d=[n[f.type],...r.filter(({matcher:m})=>m(f)).map(({reducer:m})=>m)];return d.filter(m=>!!m).length===0&&(d=[a]),d.reduce((m,p)=>{if(p)if(wi(m)){const g=p(m,f);return g===void 0?m:g}else{if(Cr(m))return Mj(m,y=>p(y,f));{const y=p(m,f);if(y===void 0){if(m===null)return m;throw Error("A case reducer on a non-draftable value must not return undefined")}return y}}return m},c)}return o.getInitialState=u,o}var Kq="ModuleSymbhasOwnPr-0123456789ABCDEFGHNRVfgctiUvz_KqYTJkLxpZXIjQW",Gq=(e=21)=>{let t="",n=e;for(;n--;)t+=Kq[Math.random()*64|0];return t},Xq=Symbol.for("rtk-slice-createasyncthunk");function Zq(e,t){return`${e}/${t}`}function Qq({creators:e}={}){var n;const t=(n=e==null?void 0:e.asyncThunk)==null?void 0:n[Xq];return function(a){const{name:u,reducerPath:o=u}=a;if(!u)throw new Error(Vn(11));const c=(typeof a.reducers=="function"?a.reducers(Jq()):a.reducers)||{},f=Object.keys(c),d={sliceCaseReducersByName:{},sliceCaseReducersByType:{},actionCreators:{},sliceMatchers:[]},m={addCase(M,N){const C=typeof M=="string"?M:M.type;if(!C)throw new Error(Vn(12));if(C in d.sliceCaseReducersByType)throw new Error(Vn(13));return d.sliceCaseReducersByType[C]=N,m},addMatcher(M,N){return d.sliceMatchers.push({matcher:M,reducer:N}),m},exposeAction(M,N){return d.actionCreators[M]=N,m},exposeCaseReducer(M,N){return d.sliceCaseReducersByName[M]=N,m}};f.forEach(M=>{const N=c[M],C={reducerName:M,type:Zq(u,M),createNotation:typeof a.reducers=="function"};tH(N)?rH(C,N,m,t):eH(C,N,m)});function p(){const[M={},N=[],C=void 0]=typeof a.extraReducers=="function"?Rj(a.extraReducers):[a.extraReducers],z={...M,...d.sliceCaseReducersByType};return Yq(a.initialState,$=>{for(let H in z)$.addCase(H,z[H]);for(let H of d.sliceMatchers)$.addMatcher(H.matcher,H.reducer);for(let H of N)$.addMatcher(H.matcher,H.reducer);C&&$.addDefaultCase(C)})}const y=M=>M,g=new Map,x=new WeakMap;let w;function S(M,N){return w||(w=p()),w(M,N)}function O(){return w||(w=p()),w.getInitialState()}function _(M,N=!1){function C($){let H=$[M];return typeof H>"u"&&N&&(H=df(x,C,O)),H}function z($=y){const H=df(g,N,()=>new WeakMap);return df(H,$,()=>{const P={};for(const[F,I]of Object.entries(a.selectors??{}))P[F]=Wq(I,$,()=>df(x,$,O),N);return P})}return{reducerPath:M,getSelectors:z,get selectors(){return z(C)},selectSlice:C}}const k={name:u,reducer:S,actions:d.actionCreators,caseReducers:d.sliceCaseReducersByName,getInitialState:O,..._(o),injectInto(M,{reducerPath:N,...C}={}){const z=N??o;return M.inject({reducerPath:z,reducer:S},C),{...k,..._(z,!0)}}};return k}}function Wq(e,t,n,r){function a(u,...o){let c=t(u);return typeof c>"u"&&r&&(c=n()),e(c,...o)}return a.unwrapped=e,a}var jn=Qq();function Jq(){function e(t,n){return{_reducerDefinitionType:"asyncThunk",payloadCreator:t,...n}}return e.withTypes=()=>e,{reducer(t){return Object.assign({[t.name](...n){return t(...n)}}[t.name],{_reducerDefinitionType:"reducer"})},preparedReducer(t,n){return{_reducerDefinitionType:"reducerWithPrepare",prepare:t,reducer:n}},asyncThunk:e}}function eH({type:e,reducerName:t,createNotation:n},r,a){let u,o;if("reducer"in r){if(n&&!nH(r))throw new Error(Vn(17));u=r.reducer,o=r.prepare}else u=r;a.addCase(e,u).exposeCaseReducer(t,u).exposeAction(t,o?mr(e,o):mr(e))}function tH(e){return e._reducerDefinitionType==="asyncThunk"}function nH(e){return e._reducerDefinitionType==="reducerWithPrepare"}function rH({type:e,reducerName:t},n,r,a){if(!a)throw new Error(Vn(18));const{payloadCreator:u,fulfilled:o,pending:c,rejected:f,settled:d,options:m}=n,p=a(e,u,m);r.exposeAction(t,p),o&&r.addCase(p.fulfilled,o),c&&r.addCase(p.pending,c),f&&r.addCase(p.rejected,f),d&&r.addMatcher(p.settled,d),r.exposeCaseReducer(t,{fulfilled:o||hf,pending:c||hf,rejected:f||hf,settled:d||hf})}function hf(){}var iH="task",Ij="listener",Lj="completed",G0="cancelled",aH=`task-${G0}`,lH=`task-${Lj}`,Og=`${Ij}-${G0}`,uH=`${Ij}-${Lj}`,Yd=class{constructor(e){Ip(this,"name","TaskAbortError");Ip(this,"message");this.code=e,this.message=`${iH} ${G0} (reason: ${e})`}},X0=(e,t)=>{if(typeof e!="function")throw new TypeError(Vn(32))},Xf=()=>{},Bj=(e,t=Xf)=>(e.catch(t),e),Uj=(e,t)=>(e.addEventListener("abort",t,{once:!0}),()=>e.removeEventListener("abort",t)),Ka=e=>{if(e.aborted)throw new Yd(e.reason)};function qj(e,t){let n=Xf;return new Promise((r,a)=>{const u=()=>a(new Yd(e.reason));if(e.aborted){u();return}n=Uj(e,u),t.finally(()=>n()).then(r,a)}).finally(()=>{n=Xf})}var oH=async(e,t)=>{try{return await Promise.resolve(),{status:"ok",value:await e()}}catch(n){return{status:n instanceof Yd?"cancelled":"rejected",error:n}}finally{t==null||t()}},Zf=e=>t=>Bj(qj(e,t).then(n=>(Ka(e),n))),Hj=e=>{const t=Zf(e);return n=>t(new Promise(r=>setTimeout(r,n)))},{assign:su}=Object,HA={},Kd="listenerMiddleware",sH=(e,t)=>{const n=r=>Uj(e,()=>r.abort(e.reason));return(r,a)=>{X0(r);const u=new AbortController;n(u);const o=oH(async()=>{Ka(e),Ka(u.signal);const c=await r({pause:Zf(u.signal),delay:Hj(u.signal),signal:u.signal});return Ka(u.signal),c},()=>u.abort(lH));return a!=null&&a.autoJoin&&t.push(o.catch(Xf)),{result:Zf(e)(o),cancel(){u.abort(aH)}}}},cH=(e,t)=>{const n=async(r,a)=>{Ka(t);let u=()=>{};const c=[new Promise((f,d)=>{let m=e({predicate:r,effect:(p,y)=>{y.unsubscribe(),f([p,y.getState(),y.getOriginalState()])}});u=()=>{m(),d()}})];a!=null&&c.push(new Promise(f=>setTimeout(f,a,null)));try{const f=await qj(t,Promise.race(c));return Ka(t),f}finally{u()}};return(r,a)=>Bj(n(r,a))},$j=e=>{let{type:t,actionCreator:n,matcher:r,predicate:a,effect:u}=e;if(t)a=mr(t).match;else if(n)t=n.type,a=n.match;else if(r)a=r;else if(!a)throw new Error(Vn(21));return X0(u),{predicate:a,type:t,effect:u}},Fj=su(e=>{const{type:t,predicate:n,effect:r}=$j(e);return{id:Gq(),effect:r,type:t,predicate:n,pending:new Set,unsubscribe:()=>{throw new Error(Vn(22))}}},{withTypes:()=>Fj}),$A=(e,t)=>{const{type:n,effect:r,predicate:a}=$j(t);return Array.from(e.values()).find(u=>(typeof n=="string"?u.type===n:u.predicate===a)&&u.effect===r)},Eg=e=>{e.pending.forEach(t=>{t.abort(Og)})},fH=(e,t)=>()=>{for(const n of t.keys())Eg(n);e.clear()},FA=(e,t,n)=>{try{e(t,n)}catch(r){setTimeout(()=>{throw r},0)}},Vj=su(mr(`${Kd}/add`),{withTypes:()=>Vj}),dH=mr(`${Kd}/removeAll`),Yj=su(mr(`${Kd}/remove`),{withTypes:()=>Yj}),hH=(...e)=>{console.error(`${Kd}/error`,...e)},Ss=(e={})=>{const t=new Map,n=new Map,r=g=>{const x=n.get(g)??0;n.set(g,x+1)},a=g=>{const x=n.get(g)??1;x===1?n.delete(g):n.set(g,x-1)},{extra:u,onError:o=hH}=e;X0(o);const c=g=>(g.unsubscribe=()=>t.delete(g.id),t.set(g.id,g),x=>{g.unsubscribe(),x!=null&&x.cancelActive&&Eg(g)}),f=g=>{const x=$A(t,g)??Fj(g);return c(x)};su(f,{withTypes:()=>f});const d=g=>{const x=$A(t,g);return x&&(x.unsubscribe(),g.cancelActive&&Eg(x)),!!x};su(d,{withTypes:()=>d});const m=async(g,x,w,S)=>{const O=new AbortController,_=cH(f,O.signal),k=[];try{g.pending.add(O),r(g),await Promise.resolve(g.effect(x,su({},w,{getOriginalState:S,condition:(M,N)=>_(M,N).then(Boolean),take:_,delay:Hj(O.signal),pause:Zf(O.signal),extra:u,signal:O.signal,fork:sH(O.signal,k),unsubscribe:g.unsubscribe,subscribe:()=>{t.set(g.id,g)},cancelActiveListeners:()=>{g.pending.forEach((M,N,C)=>{M!==O&&(M.abort(Og),C.delete(M))})},cancel:()=>{O.abort(Og),g.pending.delete(O)},throwIfCancelled:()=>{Ka(O.signal)}})))}catch(M){M instanceof Yd||FA(o,M,{raisedBy:"effect"})}finally{await Promise.all(k),O.abort(uH),a(g),g.pending.delete(O)}},p=fH(t,n);return{middleware:g=>x=>w=>{if(!wj(w))return x(w);if(Vj.match(w))return f(w.payload);if(dH.match(w)){p();return}if(Yj.match(w))return d(w.payload);let S=g.getState();const O=()=>{if(S===HA)throw new Error(Vn(23));return S};let _;try{if(_=x(w),t.size>0){const k=g.getState(),M=Array.from(t.values());for(const N of M){let C=!1;try{C=N.predicate(w,k,S)}catch(z){C=!1,FA(o,z,{raisedBy:"predicate"})}C&&m(N,w,g,O)}}}finally{S=HA}return _},startListening:f,stopListening:d,clearListeners:p}};function Vn(e){return`Minified Redux Toolkit error #${e}; visit https://redux-toolkit.js.org/Errors?code=${e} for the full message or use the non-minified dev environment for full errors. `}var mH={layoutType:"horizontal",width:0,height:0,margin:{top:5,right:5,bottom:5,left:5},scale:1},Kj=jn({name:"chartLayout",initialState:mH,reducers:{setLayout(e,t){e.layoutType=t.payload},setChartSize(e,t){e.width=t.payload.width,e.height=t.payload.height},setMargin(e,t){var n,r,a,u;e.margin.top=(n=t.payload.top)!==null&&n!==void 0?n:0,e.margin.right=(r=t.payload.right)!==null&&r!==void 0?r:0,e.margin.bottom=(a=t.payload.bottom)!==null&&a!==void 0?a:0,e.margin.left=(u=t.payload.left)!==null&&u!==void 0?u:0},setScale(e,t){e.scale=t.payload}}}),{setMargin:pH,setLayout:vH,setChartSize:yH,setScale:gH}=Kj.actions,bH=Kj.reducer;function Gj(e,t,n){return Array.isArray(e)&&e&&t+n!==0?e.slice(t,n+1):e}function qe(e){return Number.isFinite(e)}function Vr(e){return typeof e=="number"&&e>0&&Number.isFinite(e)}function VA(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function au(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?VA(Object(n),!0).forEach(function(r){xH(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):VA(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function xH(e,t,n){return(t=wH(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function wH(e){var t=SH(e,"string");return typeof t=="symbol"?t:t+""}function SH(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function tn(e,t,n){return qt(e)||qt(t)?n:Fr(t)?hu(e,t,n):typeof t=="function"?t(e):n}var OH=(e,t,n)=>{if(t&&n){var{width:r,height:a}=n,{align:u,verticalAlign:o,layout:c}=t;if((c==="vertical"||c==="horizontal"&&o==="middle")&&u!=="center"&&we(e[u]))return au(au({},e),{},{[u]:e[u]+(r||0)});if((c==="horizontal"||c==="vertical"&&u==="center")&&o!=="middle"&&we(e[o]))return au(au({},e),{},{[o]:e[o]+(a||0)})}return e},va=(e,t)=>e==="horizontal"&&t==="xAxis"||e==="vertical"&&t==="yAxis"||e==="centric"&&t==="angleAxis"||e==="radial"&&t==="radiusAxis",Xj=(e,t,n,r)=>{if(r)return e.map(c=>c.coordinate);var a,u,o=e.map(c=>(c.coordinate===t&&(a=!0),c.coordinate===n&&(u=!0),c.coordinate));return a||o.push(t),u||o.push(n),o},Zj=(e,t,n)=>{if(!e)return null;var{duplicateDomain:r,type:a,range:u,scale:o,realScaleType:c,isCategorical:f,categoricalDomain:d,tickCount:m,ticks:p,niceTicks:y,axisType:g}=e;if(!o)return null;var x=c==="scaleBand"&&o.bandwidth?o.bandwidth()/2:2,w=a==="category"&&o.bandwidth?o.bandwidth()/x:0;if(w=g==="angleAxis"&&u&&u.length>=2?_n(u[0]-u[1])*2*w:w,p||y){var S=(p||y||[]).map((O,_)=>{var k=r?r.indexOf(O):O,M=o.map(k);return qe(M)?{coordinate:M+w,value:O,offset:w,index:_}:null}).filter(kn);return S}return f&&d?d.map((O,_)=>{var k=o.map(O);return qe(k)?{coordinate:k+w,value:O,index:_,offset:w}:null}).filter(kn):o.ticks&&m!=null?o.ticks(m).map((O,_)=>{var k=o.map(O);return qe(k)?{coordinate:k+w,value:O,index:_,offset:w}:null}).filter(kn):o.domain().map((O,_)=>{var k=o.map(O);return qe(k)?{coordinate:k+w,value:r?r[O]:O,index:_,offset:w}:null}).filter(kn)},EH=(e,t)=>{if(!t||t.length!==2||!we(t[0])||!we(t[1]))return e;var n=Math.min(t[0],t[1]),r=Math.max(t[0],t[1]),a=[e[0],e[1]];return(!we(e[0])||e[0]<n)&&(a[0]=n),(!we(e[1])||e[1]>r)&&(a[1]=r),a[0]>r&&(a[0]=r),a[1]<n&&(a[1]=n),a},AH=e=>{var t,n=e.length;if(!(n<=0)){var r=(t=e[0])===null||t===void 0?void 0:t.length;if(!(r==null||r<=0))for(var a=0;a<r;++a)for(var u=0,o=0,c=0;c<n;++c){var f=e[c],d=f==null?void 0:f[a];if(d!=null){var m=d[1],p=d[0],y=$r(m)?p:m;y>=0?(d[0]=u,u+=y,d[1]=u):(d[0]=o,o+=y,d[1]=o)}}}},_H=e=>{var t,n=e.length;if(!(n<=0)){var r=(t=e[0])===null||t===void 0?void 0:t.length;if(!(r==null||r<=0))for(var a=0;a<r;++a)for(var u=0,o=0;o<n;++o){var c=e[o],f=c==null?void 0:c[a];if(f!=null){var d=$r(f[1])?f[0]:f[1];d>=0?(f[0]=u,u+=d,f[1]=u):(f[0]=0,f[1]=0)}}}},kH={sign:AH,expand:J9,none:Qa,silhouette:eU,wiggle:tU,positive:_H},CH=(e,t,n)=>{var r,a=(r=kH[n])!==null&&r!==void 0?r:Qa,u=W9().keys(t).value((c,f)=>Number(tn(c,f,0))).order(hg).offset(a),o=u(e);return o.forEach((c,f)=>{c.forEach((d,m)=>{var p=tn(e[m],t[f],0);Array.isArray(p)&&p.length===2&&we(p[0])&&we(p[1])&&(d[0]=p[0],d[1]=p[1])})}),o};function TH(e){return e==null?void 0:String(e)}var YA=e=>{var{axis:t,ticks:n,offset:r,bandSize:a,entry:u,index:o}=e;if(t.type==="category")return n[o]?n[o].coordinate+r:null;var c=tn(u,t.dataKey,t.scale.domain()[o]);if(qt(c))return null;var f=t.scale.map(c);return we(f)?f-a/2+r:null},jH=e=>{var{numericAxis:t}=e,n=t.scale.domain();if(t.type==="number"){var r=Math.min(n[0],n[1]),a=Math.max(n[0],n[1]);return r<=0&&a>=0?0:a<0?a:r}return n[0]},MH=e=>{var t=e.flat(2).filter(we);return[Math.min(...t),Math.max(...t)]},zH=e=>[e[0]===1/0?0:e[0],e[1]===-1/0?0:e[1]],DH=(e,t,n)=>{if(e!=null)return zH(Object.keys(e).reduce((r,a)=>{var u=e[a];if(!u)return r;var{stackedData:o}=u,c=o.reduce((f,d)=>{var m=Gj(d,t,n),p=MH(m);return!qe(p[0])||!qe(p[1])?f:[Math.min(f[0],p[0]),Math.max(f[1],p[1])]},[1/0,-1/0]);return[Math.min(c[0],r[0]),Math.max(c[1],r[1])]},[1/0,-1/0]))},KA=/^dataMin[\s]*-[\s]*([0-9]+([.]{1}[0-9]+){0,1})$/,GA=/^dataMax[\s]*\+[\s]*([0-9]+([.]{1}[0-9]+){0,1})$/,Qf=(e,t,n)=>{if(e&&e.scale&&e.scale.bandwidth){var r=e.scale.bandwidth();if(!n||r>0)return r}if(e&&t&&t.length>=2){for(var a=Ld(t,m=>m.coordinate),u=1/0,o=1,c=a.length;o<c;o++){var f=a[o],d=a[o-1];u=Math.min(((f==null?void 0:f.coordinate)||0)-((d==null?void 0:d.coordinate)||0),u)}return u===1/0?0:u}return n?void 0:0};function XA(e){var{tooltipEntrySettings:t,dataKey:n,payload:r,value:a,name:u}=e;return au(au({},t),{},{dataKey:n,payload:r,value:a,name:u})}function Qj(e,t){if(e)return String(e);if(typeof t=="string")return t}var NH=(e,t)=>{if(t==="horizontal")return e.chartX;if(t==="vertical")return e.chartY},PH=(e,t)=>t==="centric"?e.angle:e.radius,Ti=e=>e.layout.width,ji=e=>e.layout.height,RH=e=>e.layout.scale,Wj=e=>e.layout.margin,Gd=te(e=>e.cartesianAxis.xAxis,e=>Object.values(e)),Xd=te(e=>e.cartesianAxis.yAxis,e=>Object.values(e)),IH="data-recharts-item-index",LH="data-recharts-item-id",Os=60;function ZA(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function mf(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?ZA(Object(n),!0).forEach(function(r){BH(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):ZA(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function BH(e,t,n){return(t=UH(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function UH(e){var t=qH(e,"string");return typeof t=="symbol"?t:t+""}function qH(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var HH=e=>e.brush.height;function $H(e){var t=Xd(e);return t.reduce((n,r)=>{if(r.orientation==="left"&&!r.mirror&&!r.hide){var a=typeof r.width=="number"?r.width:Os;return n+a}return n},0)}function FH(e){var t=Xd(e);return t.reduce((n,r)=>{if(r.orientation==="right"&&!r.mirror&&!r.hide){var a=typeof r.width=="number"?r.width:Os;return n+a}return n},0)}function VH(e){var t=Gd(e);return t.reduce((n,r)=>r.orientation==="top"&&!r.mirror&&!r.hide?n+r.height:n,0)}function YH(e){var t=Gd(e);return t.reduce((n,r)=>r.orientation==="bottom"&&!r.mirror&&!r.hide?n+r.height:n,0)}var Ht=te([Ti,ji,Wj,HH,$H,FH,VH,YH,gj,yq],(e,t,n,r,a,u,o,c,f,d)=>{var m={left:(n.left||0)+a,right:(n.right||0)+u},p={top:(n.top||0)+o,bottom:(n.bottom||0)+c},y=mf(mf({},p),m),g=y.bottom;y.bottom+=r,y=OH(y,f,d);var x=e-y.left-y.right,w=t-y.top-y.bottom;return mf(mf({brushBottom:g},y),{},{width:Math.max(x,0),height:Math.max(w,0)})}),KH=te(Ht,e=>({x:e.left,y:e.top,width:e.width,height:e.height})),Z0=te(Ti,ji,(e,t)=>({x:0,y:0,width:e,height:t})),GH=E.createContext(null),Mn=()=>E.useContext(GH)!=null,Zd=e=>e.brush,Qd=te([Zd,Ht,Wj],(e,t,n)=>({height:e.height,x:we(e.x)?e.x:t.left,y:we(e.y)?e.y:t.top+t.height+t.brushBottom-((n==null?void 0:n.bottom)||0),width:we(e.width)?e.width:t.width})),hy={},my={},py={},QA;function XH(){return QA||(QA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r,{signal:a,edges:u}={}){let o,c=null;const f=u!=null&&u.includes("leading"),d=u==null||u.includes("trailing"),m=()=>{c!==null&&(n.apply(o,c),o=void 0,c=null)},p=()=>{d&&m(),w()};let y=null;const g=()=>{y!=null&&clearTimeout(y),y=setTimeout(()=>{y=null,p()},r)},x=()=>{y!==null&&(clearTimeout(y),y=null)},w=()=>{x(),o=void 0,c=null},S=()=>{m()},O=function(..._){if(a!=null&&a.aborted)return;o=this,c=_;const k=y==null;g(),f&&k&&m()};return O.schedule=g,O.cancel=w,O.flush=S,a==null||a.addEventListener("abort",w,{once:!0}),O}e.debounce=t})(py)),py}var WA;function ZH(){return WA||(WA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=XH();function n(r,a=0,u={}){typeof u!="object"&&(u={});const{leading:o=!1,trailing:c=!0,maxWait:f}=u,d=Array(2);o&&(d[0]="leading"),c&&(d[1]="trailing");let m,p=null;const y=t.debounce(function(...w){m=r.apply(this,w),p=null},a,{edges:d}),g=function(...w){return f!=null&&(p===null&&(p=Date.now()),Date.now()-p>=f)?(m=r.apply(this,w),p=Date.now(),y.cancel(),y.schedule(),m):(y.apply(this,w),m)},x=()=>(y.flush(),m);return g.cancel=y.cancel,g.flush=x,g}e.debounce=n})(my)),my}var JA;function QH(){return JA||(JA=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=ZH();function n(r,a=0,u={}){const{leading:o=!0,trailing:c=!0}=u;return t.debounce(r,a,{leading:o,maxWait:a,trailing:c})}e.throttle=n})(hy)),hy}var vy,e2;function WH(){return e2||(e2=1,vy=QH().throttle),vy}var JH=WH();const e7=Tr(JH);var Wf=function(t,n){for(var r=arguments.length,a=new Array(r>2?r-2:0),u=2;u<r;u++)a[u-2]=arguments[u];if(typeof console<"u"&&console.warn&&(n===void 0&&console.warn("LogUtils requires an error message argument"),!t))if(n===void 0)console.warn("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var o=0;console.warn(n.replace(/%s/g,()=>a[o++]))}},Ur={width:"100%",height:"100%",debounce:0,minWidth:0,initialDimension:{width:-1,height:-1}},Jj=(e,t,n)=>{var{width:r=Ur.width,height:a=Ur.height,aspect:u,maxHeight:o}=n,c=Wa(r)?e:Number(r),f=Wa(a)?t:Number(a);return u&&u>0&&(c?f=c/u:f&&(c=f*u),o&&f!=null&&f>o&&(f=o)),{calculatedWidth:c,calculatedHeight:f}},t7={width:0,height:0,overflow:"visible"},n7={width:0,overflowX:"visible"},r7={height:0,overflowY:"visible"},i7={},a7=e=>{var{width:t,height:n}=e,r=Wa(t),a=Wa(n);return r&&a?t7:r?n7:a?r7:i7};function l7(e){var{width:t,height:n,aspect:r}=e,a=t,u=n;return a===void 0&&u===void 0?(a=Ur.width,u=Ur.height):a===void 0?a=r&&r>0?void 0:Ur.width:u===void 0&&(u=r&&r>0?void 0:Ur.height),{width:a,height:u}}function Ag(){return Ag=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ag.apply(null,arguments)}function t2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function n2(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?t2(Object(n),!0).forEach(function(r){u7(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):t2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function u7(e,t,n){return(t=o7(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function o7(e){var t=s7(e,"string");return typeof t=="symbol"?t:t+""}function s7(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var eM=E.createContext(Ur.initialDimension);function c7(e){return Vr(e.width)&&Vr(e.height)}function tM(e){var{children:t,width:n,height:r}=e,a=E.useMemo(()=>({width:n,height:r}),[n,r]);return c7(a)?E.createElement(eM.Provider,{value:a},t):null}var Q0=()=>E.useContext(eM),f7=E.forwardRef((e,t)=>{var{aspect:n,initialDimension:r=Ur.initialDimension,width:a,height:u,minWidth:o=Ur.minWidth,minHeight:c,maxHeight:f,children:d,debounce:m=Ur.debounce,id:p,className:y,onResize:g,style:x={}}=e,w=E.useRef(null),S=E.useRef();S.current=g,E.useImperativeHandle(t,()=>w.current);var[O,_]=E.useState({containerWidth:r.width,containerHeight:r.height}),k=E.useCallback(($,H)=>{_(P=>{var F=Math.round($),I=Math.round(H);return P.containerWidth===F&&P.containerHeight===I?P:{containerWidth:F,containerHeight:I}})},[]);E.useEffect(()=>{if(w.current==null||typeof ResizeObserver>"u")return Au;var $=I=>{var ee,Z=I[0];if(Z!=null){var{width:Y,height:U}=Z.contentRect;k(Y,U),(ee=S.current)===null||ee===void 0||ee.call(S,Y,U)}};m>0&&($=e7($,m,{trailing:!0,leading:!1}));var H=new ResizeObserver($),{width:P,height:F}=w.current.getBoundingClientRect();return k(P,F),H.observe(w.current),()=>{H.disconnect()}},[k,m]);var{containerWidth:M,containerHeight:N}=O;Wf(!n||n>0,"The aspect(%s) must be greater than zero.",n);var{calculatedWidth:C,calculatedHeight:z}=Jj(M,N,{width:a,height:u,aspect:n,maxHeight:f});return Wf(C!=null&&C>0||z!=null&&z>0,`The width(%s) and height(%s) of chart should be greater than 0,
       please check the style of container, or the props width(%s) and height(%s),
       or add a minWidth(%s) or minHeight(%s) or use aspect(%s) to control the
       height and width.`,C,z,a,u,o,c,n),E.createElement("div",{id:p?"".concat(p):void 0,className:ft("recharts-responsive-container",y),style:n2(n2({},x),{},{width:a,height:u,minWidth:o,minHeight:c,maxHeight:f}),ref:w},E.createElement("div",{style:a7({width:a,height:u})},E.createElement(tM,{width:C,height:z},d)))}),d7=E.forwardRef((e,t)=>{var n=Q0();if(Vr(n.width)&&Vr(n.height))return e.children;var{width:r,height:a}=l7({width:e.width,height:e.height,aspect:e.aspect}),{calculatedWidth:u,calculatedHeight:o}=Jj(void 0,void 0,{width:r,height:a,aspect:e.aspect,maxHeight:e.maxHeight});return we(u)&&we(o)?E.createElement(tM,{width:u,height:o},e.children):E.createElement(f7,Ag({},e,{width:r,height:a,ref:t}))});function W0(e){if(e)return{x:e.x,y:e.y,upperWidth:"upperWidth"in e?e.upperWidth:e.width,lowerWidth:"lowerWidth"in e?e.lowerWidth:e.width,width:e.width,height:e.height}}var Wd=()=>{var e,t=Mn(),n=Ee(KH),r=Ee(Qd),a=(e=Ee(Zd))===null||e===void 0?void 0:e.padding;return!t||!r||!a?n:{width:r.width-a.left-a.right,height:r.height-a.top-a.bottom,x:a.left,y:a.top}},h7={top:0,bottom:0,left:0,right:0,width:0,height:0,brushBottom:0},nM=()=>{var e;return(e=Ee(Ht))!==null&&e!==void 0?e:h7},rM=()=>Ee(Ti),iM=()=>Ee(ji),at=e=>e.layout.layoutType,_u=()=>Ee(at),aM=()=>{var e=_u();if(e==="horizontal"||e==="vertical")return e},lM=e=>{var t=e.layout.layoutType;if(t==="centric"||t==="radial")return t},m7=()=>{var e=_u();return e!==void 0},Es=e=>{var t=wt(),n=Mn(),{width:r,height:a}=e,u=Q0(),o=r,c=a;return u&&(o=u.width>0?u.width:r,c=u.height>0?u.height:a),E.useEffect(()=>{!n&&Vr(o)&&Vr(c)&&t(yH({width:o,height:c}))},[t,n,o,c]),null},uM=Symbol.for("immer-nothing"),r2=Symbol.for("immer-draftable"),Yn=Symbol.for("immer-state");function Or(e,...t){throw new Error(`[Immer] minified error nr: ${e}. Full error at: https://bit.ly/3cXEKWf`)}var as=Object.getPrototypeOf;function pu(e){return!!e&&!!e[Yn]}function el(e){var t;return e?oM(e)||Array.isArray(e)||!!e[r2]||!!((t=e.constructor)!=null&&t[r2])||As(e)||eh(e):!1}var p7=Object.prototype.constructor.toString(),i2=new WeakMap;function oM(e){if(!e||typeof e!="object")return!1;const t=Object.getPrototypeOf(e);if(t===null||t===Object.prototype)return!0;const n=Object.hasOwnProperty.call(t,"constructor")&&t.constructor;if(n===Object)return!0;if(typeof n!="function")return!1;let r=i2.get(n);return r===void 0&&(r=Function.toString.call(n),i2.set(n,r)),r===p7}function Jf(e,t,n=!0){Jd(e)===0?(n?Reflect.ownKeys(e):Object.keys(e)).forEach(a=>{t(a,e[a],e)}):e.forEach((r,a)=>t(a,r,e))}function Jd(e){const t=e[Yn];return t?t.type_:Array.isArray(e)?1:As(e)?2:eh(e)?3:0}function _g(e,t){return Jd(e)===2?e.has(t):Object.prototype.hasOwnProperty.call(e,t)}function sM(e,t,n){const r=Jd(e);r===2?e.set(t,n):r===3?e.add(n):e[t]=n}function v7(e,t){return e===t?e!==0||1/e===1/t:e!==e&&t!==t}function As(e){return e instanceof Map}function eh(e){return e instanceof Set}function qa(e){return e.copy_||e.base_}function kg(e,t){if(As(e))return new Map(e);if(eh(e))return new Set(e);if(Array.isArray(e))return Array.prototype.slice.call(e);const n=oM(e);if(t===!0||t==="class_only"&&!n){const r=Object.getOwnPropertyDescriptors(e);delete r[Yn];let a=Reflect.ownKeys(r);for(let u=0;u<a.length;u++){const o=a[u],c=r[o];c.writable===!1&&(c.writable=!0,c.configurable=!0),(c.get||c.set)&&(r[o]={configurable:!0,writable:!0,enumerable:c.enumerable,value:e[o]})}return Object.create(as(e),r)}else{const r=as(e);if(r!==null&&n)return{...e};const a=Object.create(r);return Object.assign(a,e)}}function J0(e,t=!1){return th(e)||pu(e)||!el(e)||(Jd(e)>1&&Object.defineProperties(e,{set:pf,add:pf,clear:pf,delete:pf}),Object.freeze(e),t&&Object.values(e).forEach(n=>J0(n,!0))),e}function y7(){Or(2)}var pf={value:y7};function th(e){return e===null||typeof e!="object"?!0:Object.isFrozen(e)}var g7={};function tl(e){const t=g7[e];return t||Or(0,e),t}var ls;function cM(){return ls}function b7(e,t){return{drafts_:[],parent_:e,immer_:t,canAutoFreeze_:!0,unfinalizedDrafts_:0}}function a2(e,t){t&&(tl("Patches"),e.patches_=[],e.inversePatches_=[],e.patchListener_=t)}function Cg(e){Tg(e),e.drafts_.forEach(x7),e.drafts_=null}function Tg(e){e===ls&&(ls=e.parent_)}function l2(e){return ls=b7(ls,e)}function x7(e){const t=e[Yn];t.type_===0||t.type_===1?t.revoke_():t.revoked_=!0}function u2(e,t){t.unfinalizedDrafts_=t.drafts_.length;const n=t.drafts_[0];return e!==void 0&&e!==n?(n[Yn].modified_&&(Cg(t),Or(4)),el(e)&&(e=ed(t,e),t.parent_||td(t,e)),t.patches_&&tl("Patches").generateReplacementPatches_(n[Yn].base_,e,t.patches_,t.inversePatches_)):e=ed(t,n,[]),Cg(t),t.patches_&&t.patchListener_(t.patches_,t.inversePatches_),e!==uM?e:void 0}function ed(e,t,n){if(th(t))return t;const r=e.immer_.shouldUseStrictIteration(),a=t[Yn];if(!a)return Jf(t,(u,o)=>o2(e,a,t,u,o,n),r),t;if(a.scope_!==e)return t;if(!a.modified_)return td(e,a.base_,!0),a.base_;if(!a.finalized_){a.finalized_=!0,a.scope_.unfinalizedDrafts_--;const u=a.copy_;let o=u,c=!1;a.type_===3&&(o=new Set(u),u.clear(),c=!0),Jf(o,(f,d)=>o2(e,a,u,f,d,n,c),r),td(e,u,!1),n&&e.patches_&&tl("Patches").generatePatches_(a,n,e.patches_,e.inversePatches_)}return a.copy_}function o2(e,t,n,r,a,u,o){if(a==null||typeof a!="object"&&!o)return;const c=th(a);if(!(c&&!o)){if(pu(a)){const f=u&&t&&t.type_!==3&&!_g(t.assigned_,r)?u.concat(r):void 0,d=ed(e,a,f);if(sM(n,r,d),pu(d))e.canAutoFreeze_=!1;else return}else o&&n.add(a);if(el(a)&&!c){if(!e.immer_.autoFreeze_&&e.unfinalizedDrafts_<1||t&&t.base_&&t.base_[r]===a&&c)return;ed(e,a),(!t||!t.scope_.parent_)&&typeof r!="symbol"&&(As(n)?n.has(r):Object.prototype.propertyIsEnumerable.call(n,r))&&td(e,a)}}}function td(e,t,n=!1){!e.parent_&&e.immer_.autoFreeze_&&e.canAutoFreeze_&&J0(t,n)}function w7(e,t){const n=Array.isArray(e),r={type_:n?1:0,scope_:t?t.scope_:cM(),modified_:!1,finalized_:!1,assigned_:{},parent_:t,base_:e,draft_:null,copy_:null,revoke_:null,isManual_:!1};let a=r,u=eb;n&&(a=[r],u=us);const{revoke:o,proxy:c}=Proxy.revocable(a,u);return r.draft_=c,r.revoke_=o,c}var eb={get(e,t){if(t===Yn)return e;const n=qa(e);if(!_g(n,t))return S7(e,n,t);const r=n[t];return e.finalized_||!el(r)?r:r===yy(e.base_,t)?(gy(e),e.copy_[t]=Mg(r,e)):r},has(e,t){return t in qa(e)},ownKeys(e){return Reflect.ownKeys(qa(e))},set(e,t,n){const r=fM(qa(e),t);if(r!=null&&r.set)return r.set.call(e.draft_,n),!0;if(!e.modified_){const a=yy(qa(e),t),u=a==null?void 0:a[Yn];if(u&&u.base_===n)return e.copy_[t]=n,e.assigned_[t]=!1,!0;if(v7(n,a)&&(n!==void 0||_g(e.base_,t)))return!0;gy(e),jg(e)}return e.copy_[t]===n&&(n!==void 0||t in e.copy_)||Number.isNaN(n)&&Number.isNaN(e.copy_[t])||(e.copy_[t]=n,e.assigned_[t]=!0),!0},deleteProperty(e,t){return yy(e.base_,t)!==void 0||t in e.base_?(e.assigned_[t]=!1,gy(e),jg(e)):delete e.assigned_[t],e.copy_&&delete e.copy_[t],!0},getOwnPropertyDescriptor(e,t){const n=qa(e),r=Reflect.getOwnPropertyDescriptor(n,t);return r&&{writable:!0,configurable:e.type_!==1||t!=="length",enumerable:r.enumerable,value:n[t]}},defineProperty(){Or(11)},getPrototypeOf(e){return as(e.base_)},setPrototypeOf(){Or(12)}},us={};Jf(eb,(e,t)=>{us[e]=function(){return arguments[0]=arguments[0][0],t.apply(this,arguments)}});us.deleteProperty=function(e,t){return us.set.call(this,e,t,void 0)};us.set=function(e,t,n){return eb.set.call(this,e[0],t,n,e[0])};function yy(e,t){const n=e[Yn];return(n?qa(n):e)[t]}function S7(e,t,n){var a;const r=fM(t,n);return r?"value"in r?r.value:(a=r.get)==null?void 0:a.call(e.draft_):void 0}function fM(e,t){if(!(t in e))return;let n=as(e);for(;n;){const r=Object.getOwnPropertyDescriptor(n,t);if(r)return r;n=as(n)}}function jg(e){e.modified_||(e.modified_=!0,e.parent_&&jg(e.parent_))}function gy(e){e.copy_||(e.copy_=kg(e.base_,e.scope_.immer_.useStrictShallowCopy_))}var O7=class{constructor(e){this.autoFreeze_=!0,this.useStrictShallowCopy_=!1,this.useStrictIteration_=!0,this.produce=(t,n,r)=>{if(typeof t=="function"&&typeof n!="function"){const u=n;n=t;const o=this;return function(f=u,...d){return o.produce(f,m=>n.call(this,m,...d))}}typeof n!="function"&&Or(6),r!==void 0&&typeof r!="function"&&Or(7);let a;if(el(t)){const u=l2(this),o=Mg(t,void 0);let c=!0;try{a=n(o),c=!1}finally{c?Cg(u):Tg(u)}return a2(u,r),u2(a,u)}else if(!t||typeof t!="object"){if(a=n(t),a===void 0&&(a=t),a===uM&&(a=void 0),this.autoFreeze_&&J0(a,!0),r){const u=[],o=[];tl("Patches").generateReplacementPatches_(t,a,u,o),r(u,o)}return a}else Or(1,t)},this.produceWithPatches=(t,n)=>{if(typeof t=="function")return(o,...c)=>this.produceWithPatches(o,f=>t(f,...c));let r,a;return[this.produce(t,n,(o,c)=>{r=o,a=c}),r,a]},typeof(e==null?void 0:e.autoFreeze)=="boolean"&&this.setAutoFreeze(e.autoFreeze),typeof(e==null?void 0:e.useStrictShallowCopy)=="boolean"&&this.setUseStrictShallowCopy(e.useStrictShallowCopy),typeof(e==null?void 0:e.useStrictIteration)=="boolean"&&this.setUseStrictIteration(e.useStrictIteration)}createDraft(e){el(e)||Or(8),pu(e)&&(e=E7(e));const t=l2(this),n=Mg(e,void 0);return n[Yn].isManual_=!0,Tg(t),n}finishDraft(e,t){const n=e&&e[Yn];(!n||!n.isManual_)&&Or(9);const{scope_:r}=n;return a2(r,t),u2(void 0,r)}setAutoFreeze(e){this.autoFreeze_=e}setUseStrictShallowCopy(e){this.useStrictShallowCopy_=e}setUseStrictIteration(e){this.useStrictIteration_=e}shouldUseStrictIteration(){return this.useStrictIteration_}applyPatches(e,t){let n;for(n=t.length-1;n>=0;n--){const a=t[n];if(a.path.length===0&&a.op==="replace"){e=a.value;break}}n>-1&&(t=t.slice(n+1));const r=tl("Patches").applyPatches_;return pu(e)?r(e,t):this.produce(e,a=>r(a,t))}};function Mg(e,t){const n=As(e)?tl("MapSet").proxyMap_(e,t):eh(e)?tl("MapSet").proxySet_(e,t):w7(e,t);return(t?t.scope_:cM()).drafts_.push(n),n}function E7(e){return pu(e)||Or(10,e),dM(e)}function dM(e){if(!el(e)||th(e))return e;const t=e[Yn];let n,r=!0;if(t){if(!t.modified_)return t.base_;t.finalized_=!0,n=kg(e,t.scope_.immer_.useStrictShallowCopy_),r=t.scope_.immer_.shouldUseStrictIteration()}else n=kg(e,!0);return Jf(n,(a,u)=>{sM(n,a,dM(u))},r),t&&(t.finalized_=!1),n}var A7=new O7;A7.produce;var _7={settings:{layout:"horizontal",align:"center",verticalAlign:"middle",itemSorter:"value"},size:{width:0,height:0},payload:[]},hM=jn({name:"legend",initialState:_7,reducers:{setLegendSize(e,t){e.size.width=t.payload.width,e.size.height=t.payload.height},setLegendSettings(e,t){e.settings.align=t.payload.align,e.settings.layout=t.payload.layout,e.settings.verticalAlign=t.payload.verticalAlign,e.settings.itemSorter=t.payload.itemSorter},addLegendPayload:{reducer(e,t){e.payload.push(t.payload)},prepare:ht()},replaceLegendPayload:{reducer(e,t){var{prev:n,next:r}=t.payload,a=_r(e).payload.indexOf(n);a>-1&&(e.payload[a]=r)},prepare:ht()},removeLegendPayload:{reducer(e,t){var n=_r(e).payload.indexOf(t.payload);n>-1&&e.payload.splice(n,1)},prepare:ht()}}}),{setLegendSize:mne,setLegendSettings:pne,addLegendPayload:k7,replaceLegendPayload:C7,removeLegendPayload:T7}=hM.actions,j7=hM.reducer;function zg(){return zg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},zg.apply(null,arguments)}function s2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Io(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?s2(Object(n),!0).forEach(function(r){M7(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):s2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function M7(e,t,n){return(t=z7(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function z7(e){var t=D7(e,"string");return typeof t=="symbol"?t:t+""}function D7(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function N7(e){return Array.isArray(e)&&Fr(e[0])&&Fr(e[1])?e.join(" ~ "):e}var Wl={separator:" : ",contentStyle:{margin:0,padding:10,backgroundColor:"#fff",border:"1px solid #ccc",whiteSpace:"nowrap"},itemStyle:{display:"block",paddingTop:4,paddingBottom:4,color:"#000"},labelStyle:{},accessibilityLayer:!1},P7=e=>{var{separator:t=Wl.separator,contentStyle:n,itemStyle:r,labelStyle:a=Wl.labelStyle,payload:u,formatter:o,itemSorter:c,wrapperClassName:f,labelClassName:d,label:m,labelFormatter:p,accessibilityLayer:y=Wl.accessibilityLayer}=e,g=()=>{if(u&&u.length){var N={padding:0,margin:0},C=(c?Ld(u,c):u).map((z,$)=>{if(z.type==="none")return null;var H=z.formatter||o||N7,{value:P,name:F}=z,I=P,ee=F;if(H){var Z=H(P,F,z,$,u);if(Array.isArray(Z))[I,ee]=Z;else if(Z!=null)I=Z;else return null}var Y=Io(Io({},Wl.itemStyle),{},{color:z.color||Wl.itemStyle.color},r);return E.createElement("li",{className:"recharts-tooltip-item",key:"tooltip-item-".concat($),style:Y},Fr(ee)?E.createElement("span",{className:"recharts-tooltip-item-name"},ee):null,Fr(ee)?E.createElement("span",{className:"recharts-tooltip-item-separator"},t):null,E.createElement("span",{className:"recharts-tooltip-item-value"},I),E.createElement("span",{className:"recharts-tooltip-item-unit"},z.unit||""))});return E.createElement("ul",{className:"recharts-tooltip-item-list",style:N},C)}return null},x=Io(Io({},Wl.contentStyle),n),w=Io({margin:0},a),S=!qt(m),O=S?m:"",_=ft("recharts-default-tooltip",f),k=ft("recharts-tooltip-label",d);S&&p&&u!==void 0&&u!==null&&(O=p(m,u));var M=y?{role:"status","aria-live":"assertive"}:{};return E.createElement("div",zg({className:_,style:x},M),E.createElement("p",{className:k,style:w},E.isValidElement(O)?O:"".concat(O)),g())},Lo="recharts-tooltip-wrapper",R7={visibility:"hidden"};function I7(e){var{coordinate:t,translateX:n,translateY:r}=e;return ft(Lo,{["".concat(Lo,"-right")]:we(n)&&t&&we(t.x)&&n>=t.x,["".concat(Lo,"-left")]:we(n)&&t&&we(t.x)&&n<t.x,["".concat(Lo,"-bottom")]:we(r)&&t&&we(t.y)&&r>=t.y,["".concat(Lo,"-top")]:we(r)&&t&&we(t.y)&&r<t.y})}function c2(e){var{allowEscapeViewBox:t,coordinate:n,key:r,offset:a,position:u,reverseDirection:o,tooltipDimension:c,viewBox:f,viewBoxDimension:d}=e;if(u&&we(u[r]))return u[r];var m=n[r]-c-(a>0?a:0),p=n[r]+a;if(t[r])return o[r]?m:p;var y=f[r];if(y==null)return 0;if(o[r]){var g=m,x=y;return g<x?Math.max(p,y):Math.max(m,y)}if(d==null)return 0;var w=p+c,S=y+d;return w>S?Math.max(m,y):Math.max(p,y)}function L7(e){var{translateX:t,translateY:n,useTranslate3d:r}=e;return{transform:r?"translate3d(".concat(t,"px, ").concat(n,"px, 0)"):"translate(".concat(t,"px, ").concat(n,"px)")}}function B7(e){var{allowEscapeViewBox:t,coordinate:n,offsetTop:r,offsetLeft:a,position:u,reverseDirection:o,tooltipBox:c,useTranslate3d:f,viewBox:d}=e,m,p,y;return c.height>0&&c.width>0&&n?(p=c2({allowEscapeViewBox:t,coordinate:n,key:"x",offset:a,position:u,reverseDirection:o,tooltipDimension:c.width,viewBox:d,viewBoxDimension:d.width}),y=c2({allowEscapeViewBox:t,coordinate:n,key:"y",offset:r,position:u,reverseDirection:o,tooltipDimension:c.height,viewBox:d,viewBoxDimension:d.height}),m=L7({translateX:p,translateY:y,useTranslate3d:f})):m=R7,{cssProperties:m,cssClasses:I7({translateX:p,translateY:y,coordinate:n})}}function f2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function vf(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?f2(Object(n),!0).forEach(function(r){Dg(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):f2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function Dg(e,t,n){return(t=U7(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function U7(e){var t=q7(e,"string");return typeof t=="symbol"?t:t+""}function q7(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}class H7 extends E.PureComponent{constructor(){super(...arguments),Dg(this,"state",{dismissed:!1,dismissedAtCoordinate:{x:0,y:0}}),Dg(this,"handleKeyDown",t=>{if(t.key==="Escape"){var n,r,a,u;this.setState({dismissed:!0,dismissedAtCoordinate:{x:(n=(r=this.props.coordinate)===null||r===void 0?void 0:r.x)!==null&&n!==void 0?n:0,y:(a=(u=this.props.coordinate)===null||u===void 0?void 0:u.y)!==null&&a!==void 0?a:0}})}})}componentDidMount(){document.addEventListener("keydown",this.handleKeyDown)}componentWillUnmount(){document.removeEventListener("keydown",this.handleKeyDown)}componentDidUpdate(){var t,n;this.state.dismissed&&(((t=this.props.coordinate)===null||t===void 0?void 0:t.x)!==this.state.dismissedAtCoordinate.x||((n=this.props.coordinate)===null||n===void 0?void 0:n.y)!==this.state.dismissedAtCoordinate.y)&&(this.state.dismissed=!1)}render(){var{active:t,allowEscapeViewBox:n,animationDuration:r,animationEasing:a,children:u,coordinate:o,hasPayload:c,isAnimationActive:f,offset:d,position:m,reverseDirection:p,useTranslate3d:y,viewBox:g,wrapperStyle:x,lastBoundingBox:w,innerRef:S,hasPortalFromProps:O}=this.props,_=typeof d=="number"?d:d.x,k=typeof d=="number"?d:d.y,{cssClasses:M,cssProperties:N}=B7({allowEscapeViewBox:n,coordinate:o,offsetLeft:_,offsetTop:k,position:m,reverseDirection:p,tooltipBox:{height:w.height,width:w.width},useTranslate3d:y,viewBox:g}),C=O?{}:vf(vf({transition:f&&t?"transform ".concat(r,"ms ").concat(a):void 0},N),{},{pointerEvents:"none",visibility:!this.state.dismissed&&t&&c?"visible":"hidden",position:"absolute",top:0,left:0}),z=vf(vf({},C),{},{visibility:!this.state.dismissed&&t&&c?"visible":"hidden"},x);return E.createElement("div",{xmlns:"http://www.w3.org/1999/xhtml",tabIndex:-1,className:M,style:z,ref:S},u)}}var mM=()=>{var e;return(e=Ee(t=>t.rootProps.accessibilityLayer))!==null&&e!==void 0?e:!0};function Ng(){return Ng=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ng.apply(null,arguments)}function d2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function h2(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?d2(Object(n),!0).forEach(function(r){$7(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):d2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function $7(e,t,n){return(t=F7(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function F7(e){var t=V7(e,"string");return typeof t=="symbol"?t:t+""}function V7(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var m2={curveBasisClosed:q9,curveBasisOpen:H9,curveBasis:U9,curveBumpX:_9,curveBumpY:k9,curveLinearClosed:$9,curveLinear:Rd,curveMonotoneX:F9,curveMonotoneY:V9,curveNatural:Y9,curveStep:K9,curveStepAfter:X9,curveStepBefore:G9},nd=e=>qe(e.x)&&qe(e.y),p2=e=>e.base!=null&&nd(e.base)&&nd(e),Bo=e=>e.x,Uo=e=>e.y,Y7=(e,t)=>{if(typeof e=="function")return e;var n="curve".concat(xs(e));if((n==="curveMonotone"||n==="curveBump")&&t){var r=m2["".concat(n).concat(t==="vertical"?"Y":"X")];if(r)return r}return m2[n]||Rd},v2={connectNulls:!1,type:"linear"},K7=e=>{var{type:t=v2.type,points:n=[],baseLine:r,layout:a,connectNulls:u=v2.connectNulls}=e,o=Y7(t,a),c=u?n.filter(nd):n;if(Array.isArray(r)){var f,d=n.map((x,w)=>h2(h2({},x),{},{base:r[w]}));a==="vertical"?f=of().y(Uo).x1(Bo).x0(x=>x.base.x):f=of().x(Bo).y1(Uo).y0(x=>x.base.y);var m=f.defined(p2).curve(o),p=u?d.filter(p2):d;return m(p)}var y;a==="vertical"&&we(r)?y=of().y(Uo).x1(Bo).x0(r):we(r)?y=of().x(Bo).y1(Uo).y0(r):y=VT().x(Bo).y(Uo);var g=y.defined(nd).curve(o);return g(c)},pM=e=>{var{className:t,points:n,path:r,pathRef:a}=e,u=_u();if((!n||!n.length)&&!r)return null;var o={type:e.type,points:e.points,baseLine:e.baseLine,layout:e.layout||u,connectNulls:e.connectNulls},c=n&&n.length?K7(o):r;return E.createElement("path",Ng({},bi(e),bU(e),{className:ft("recharts-curve",t),d:c===null?void 0:c,ref:a}))},G7=["x","y","top","left","width","height","className"];function Pg(){return Pg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Pg.apply(null,arguments)}function y2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function X7(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?y2(Object(n),!0).forEach(function(r){Z7(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):y2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function Z7(e,t,n){return(t=Q7(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Q7(e){var t=W7(e,"string");return typeof t=="symbol"?t:t+""}function W7(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function J7(e,t){if(e==null)return{};var n,r,a=e$(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function e$(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var t$=(e,t,n,r,a,u)=>"M".concat(e,",").concat(a,"v").concat(r,"M").concat(u,",").concat(t,"h").concat(n),n$=e=>{var{x:t=0,y:n=0,top:r=0,left:a=0,width:u=0,height:o=0,className:c}=e,f=J7(e,G7),d=X7({x:t,y:n,top:r,left:a,width:u,height:o},f);return!we(t)||!we(n)||!we(u)||!we(o)||!we(r)||!we(a)?null:E.createElement("path",Pg({},hr(d),{className:ft("recharts-cross",c),d:t$(t,n,u,o,r,a)}))};function r$(e,t,n,r){var a=r/2;return{stroke:"none",fill:"#ccc",x:e==="horizontal"?t.x-a:n.left+.5,y:e==="horizontal"?n.top+.5:t.y-a,width:e==="horizontal"?r:n.width-1,height:e==="horizontal"?n.height-1:r}}function g2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function b2(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?g2(Object(n),!0).forEach(function(r){i$(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):g2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function i$(e,t,n){return(t=a$(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function a$(e){var t=l$(e,"string");return typeof t=="symbol"?t:t+""}function l$(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var u$=e=>e.replace(/([A-Z])/g,t=>"-".concat(t.toLowerCase())),vM=(e,t,n)=>e.map(r=>"".concat(u$(r)," ").concat(t,"ms ").concat(n)).join(","),o$=(e,t)=>[Object.keys(e),Object.keys(t)].reduce((n,r)=>n.filter(a=>r.includes(a))),os=(e,t)=>Object.keys(t).reduce((n,r)=>b2(b2({},n),{},{[r]:e(r,t[r])}),{});function x2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Dt(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?x2(Object(n),!0).forEach(function(r){s$(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):x2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function s$(e,t,n){return(t=c$(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function c$(e){var t=f$(e,"string");return typeof t=="symbol"?t:t+""}function f$(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var rd=(e,t,n)=>e+(t-e)*n,Rg=e=>{var{from:t,to:n}=e;return t!==n},yM=(e,t,n)=>{var r=os((a,u)=>{if(Rg(u)){var[o,c]=e(u.from,u.to,u.velocity);return Dt(Dt({},u),{},{from:o,velocity:c})}return u},t);return n<1?os((a,u)=>Rg(u)&&r[a]!=null?Dt(Dt({},u),{},{velocity:rd(u.velocity,r[a].velocity,n),from:rd(u.from,r[a].from,n)}):u,t):yM(e,r,n-1)};function d$(e,t,n,r,a,u){var o,c=r.reduce((y,g)=>Dt(Dt({},y),{},{[g]:{from:e[g],velocity:0,to:t[g]}}),{}),f=()=>os((y,g)=>g.from,c),d=()=>!Object.values(c).filter(Rg).length,m=null,p=y=>{o||(o=y);var g=y-o,x=g/n.dt;c=yM(n,c,x),a(Dt(Dt(Dt({},e),t),f())),o=y,d()||(m=u.setTimeout(p))};return()=>(m=u.setTimeout(p),()=>{var y;(y=m)===null||y===void 0||y()})}function h$(e,t,n,r,a,u,o){var c=null,f=a.reduce((p,y)=>{var g=e[y],x=t[y];return g==null||x==null?p:Dt(Dt({},p),{},{[y]:[g,x]})},{}),d,m=p=>{d||(d=p);var y=(p-d)/r,g=os((w,S)=>rd(...S,n(y)),f);if(u(Dt(Dt(Dt({},e),t),g)),y<1)c=o.setTimeout(m);else{var x=os((w,S)=>rd(...S,n(1)),f);u(Dt(Dt(Dt({},e),t),x))}};return()=>(c=o.setTimeout(m),()=>{var p;(p=c)===null||p===void 0||p()})}const m$=(e,t,n,r,a,u)=>{var o=o$(e,t);return n==null?()=>(a(Dt(Dt({},e),t)),()=>{}):n.isStepper===!0?d$(e,t,n,o,a,u):h$(e,t,n,r,o,a,u)};var id=1e-4,gM=(e,t)=>[0,3*e,3*t-6*e,3*e-3*t+1],bM=(e,t)=>e.map((n,r)=>n*t**r).reduce((n,r)=>n+r),w2=(e,t)=>n=>{var r=gM(e,t);return bM(r,n)},p$=(e,t)=>n=>{var r=gM(e,t),a=[...r.map((u,o)=>u*o).slice(1),0];return bM(a,n)},v$=e=>{var t,n=e.split("(");if(n.length!==2||n[0]!=="cubic-bezier")return null;var r=(t=n[1])===null||t===void 0||(t=t.split(")")[0])===null||t===void 0?void 0:t.split(",");if(r==null||r.length!==4)return null;var a=r.map(u=>parseFloat(u));return[a[0],a[1],a[2],a[3]]},y$=function(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];if(n.length===1)switch(n[0]){case"linear":return[0,0,1,1];case"ease":return[.25,.1,.25,1];case"ease-in":return[.42,0,1,1];case"ease-out":return[.42,0,.58,1];case"ease-in-out":return[0,0,.58,1];default:{var a=v$(n[0]);if(a)return a}}return n.length===4?n:[0,0,1,1]},g$=(e,t,n,r)=>{var a=w2(e,n),u=w2(t,r),o=p$(e,n),c=d=>d>1?1:d<0?0:d,f=d=>{for(var m=d>1?1:d,p=m,y=0;y<8;++y){var g=a(p)-m,x=o(p);if(Math.abs(g-m)<id||x<id)return u(p);p=c(p-g/x)}return u(p)};return f.isStepper=!1,f},S2=function(){return g$(...y$(...arguments))},b$=function(){var t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},{stiff:n=100,damping:r=8,dt:a=17}=t,u=(o,c,f)=>{var d=-(o-c)*n,m=f*r,p=f+(d-m)*a/1e3,y=f*a/1e3+o;return Math.abs(y-c)<id&&Math.abs(p)<id?[c,0]:[y,p]};return u.isStepper=!0,u.dt=a,u},x$=e=>{if(typeof e=="string")switch(e){case"ease":case"ease-in-out":case"ease-out":case"ease-in":case"linear":return S2(e);case"spring":return b$();default:if(e.split("(")[0]==="cubic-bezier")return S2(e)}return typeof e=="function"?e:null};function w$(e){var t,n=()=>null,r=!1,a=null,u=o=>{if(!r){if(Array.isArray(o)){if(!o.length)return;var c=o,[f,...d]=c;if(typeof f=="number"){a=e.setTimeout(u.bind(null,d),f);return}u(f),a=e.setTimeout(u.bind(null,d));return}typeof o=="string"&&(t=o,n(t)),typeof o=="object"&&(t=o,n(t)),typeof o=="function"&&o()}};return{stop:()=>{r=!0},start:o=>{r=!1,a&&(a(),a=null),u(o)},subscribe:o=>(n=o,()=>{n=()=>null}),getTimeoutController:()=>e}}class S${setTimeout(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0,r=performance.now(),a=null,u=o=>{o-r>=n?t(o):typeof requestAnimationFrame=="function"&&(a=requestAnimationFrame(u))};return a=requestAnimationFrame(u),()=>{a!=null&&cancelAnimationFrame(a)}}}function O$(){return w$(new S$)}var E$=E.createContext(O$);function A$(e,t){var n=E.useContext(E$);return E.useMemo(()=>t??n(e),[e,t,n])}var _$=()=>!(typeof window<"u"&&window.document&&window.document.createElement&&window.setTimeout),nh={isSsr:_$()},k$={begin:0,duration:1e3,easing:"ease",isActive:!0,canBegin:!0,onAnimationEnd:()=>{},onAnimationStart:()=>{}},O2={t:0},by={t:1};function tb(e){var t=Kn(e,k$),{isActive:n,canBegin:r,duration:a,easing:u,begin:o,onAnimationEnd:c,onAnimationStart:f,children:d}=t,m=n==="auto"?!nh.isSsr:n,p=A$(t.animationId,t.animationManager),[y,g]=E.useState(m?O2:by),x=E.useRef(null);return E.useEffect(()=>{m||g(by)},[m]),E.useEffect(()=>{if(!m||!r)return Au;var w=m$(O2,by,x$(u),a,g,p.getTimeoutController()),S=()=>{x.current=w()};return p.start([f,o,S,a,c]),()=>{p.stop(),x.current&&x.current(),c()}},[m,r,a,u,o,f,c,p]),d(y.t)}function nb(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"animation-",n=E.useRef(ts(t)),r=E.useRef(e);return r.current!==e&&(n.current=ts(t),r.current=e),n.current}var C$=["radius"],T$=["radius"],E2,A2,_2,k2,C2,T2,j2,M2,z2,D2;function N2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function P2(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?N2(Object(n),!0).forEach(function(r){j$(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):N2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function j$(e,t,n){return(t=M$(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function M$(e){var t=z$(e,"string");return typeof t=="symbol"?t:t+""}function z$(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function ad(){return ad=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},ad.apply(null,arguments)}function R2(e,t){if(e==null)return{};var n,r,a=D$(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function D$(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function Pr(e,t){return t||(t=e.slice(0)),Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(t)}}))}var I2=(e,t,n,r,a)=>{var u=da(n),o=da(r),c=Math.min(Math.abs(u)/2,Math.abs(o)/2),f=o>=0?1:-1,d=u>=0?1:-1,m=o>=0&&u>=0||o<0&&u<0?1:0,p;if(c>0&&Array.isArray(a)){for(var y=[0,0,0,0],g=0,x=4;g<x;g++){var w,S=(w=a[g])!==null&&w!==void 0?w:0;y[g]=S>c?c:S}p=gt(E2||(E2=Pr(["M",",",""])),e,t+f*y[0]),y[0]>0&&(p+=gt(A2||(A2=Pr(["A ",",",",0,0,",",",",",""])),y[0],y[0],m,e+d*y[0],t)),p+=gt(_2||(_2=Pr(["L ",",",""])),e+n-d*y[1],t),y[1]>0&&(p+=gt(k2||(k2=Pr(["A ",",",",0,0,",`,
        `,",",""])),y[1],y[1],m,e+n,t+f*y[1])),p+=gt(C2||(C2=Pr(["L ",",",""])),e+n,t+r-f*y[2]),y[2]>0&&(p+=gt(T2||(T2=Pr(["A ",",",",0,0,",`,
        `,",",""])),y[2],y[2],m,e+n-d*y[2],t+r)),p+=gt(j2||(j2=Pr(["L ",",",""])),e+d*y[3],t+r),y[3]>0&&(p+=gt(M2||(M2=Pr(["A ",",",",0,0,",`,
        `,",",""])),y[3],y[3],m,e,t+r-f*y[3])),p+="Z"}else if(c>0&&a===+a&&a>0){var O=Math.min(c,a);p=gt(z2||(z2=Pr(["M ",",",`
            A `,",",",0,0,",",",",",`
            L `,",",`
            A `,",",",0,0,",",",",",`
            L `,",",`
            A `,",",",0,0,",",",",",`
            L `,",",`
            A `,",",",0,0,",",",","," Z"])),e,t+f*O,O,O,m,e+d*O,t,e+n-d*O,t,O,O,m,e+n,t+f*O,e+n,t+r-f*O,O,O,m,e+n-d*O,t+r,e+d*O,t+r,O,O,m,e,t+r-f*O)}else p=gt(D2||(D2=Pr(["M ",","," h "," v "," h "," Z"])),e,t,n,r,-n);return p},L2={x:0,y:0,width:0,height:0,radius:0,isAnimationActive:!1,isUpdateAnimationActive:!1,animationBegin:0,animationDuration:1500,animationEasing:"ease"},xM=e=>{var t=Kn(e,L2),n=E.useRef(null),[r,a]=E.useState(-1);E.useEffect(()=>{if(n.current&&n.current.getTotalLength)try{var Q=n.current.getTotalLength();Q&&a(Q)}catch{}},[]);var{x:u,y:o,width:c,height:f,radius:d,className:m}=t,{animationEasing:p,animationDuration:y,animationBegin:g,isAnimationActive:x,isUpdateAnimationActive:w}=t,S=E.useRef(c),O=E.useRef(f),_=E.useRef(u),k=E.useRef(o),M=E.useMemo(()=>({x:u,y:o,width:c,height:f,radius:d}),[u,o,c,f,d]),N=nb(M,"rectangle-");if(u!==+u||o!==+o||c!==+c||f!==+f||c===0||f===0)return null;var C=ft("recharts-rectangle",m);if(!w){var z=hr(t),{radius:$}=z,H=R2(z,C$);return E.createElement("path",ad({},H,{x:da(u),y:da(o),width:da(c),height:da(f),radius:typeof d=="number"?d:void 0,className:C,d:I2(u,o,c,f,d)}))}var P=S.current,F=O.current,I=_.current,ee=k.current,Z="0px ".concat(r===-1?1:r,"px"),Y="".concat(r,"px 0px"),U=vM(["strokeDasharray"],y,typeof p=="string"?p:L2.animationEasing);return E.createElement(tb,{animationId:N,key:N,canBegin:r>0,duration:y,easing:p,isActive:w,begin:g},Q=>{var ue=Jt(P,c,Q),de=Jt(F,f,Q),R=Jt(I,u,Q),L=Jt(ee,o,Q);n.current&&(S.current=ue,O.current=de,_.current=R,k.current=L);var J;x?Q>0?J={transition:U,strokeDasharray:Y}:J={strokeDasharray:Z}:J={strokeDasharray:Y};var D=hr(t),{radius:oe}=D,ye=R2(D,T$);return E.createElement("path",ad({},ye,{radius:typeof d=="number"?d:void 0,className:C,d:I2(R,L,ue,de,d),ref:n,style:P2(P2({},J),t.style)}))})};function B2(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function U2(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?B2(Object(n),!0).forEach(function(r){N$(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):B2(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function N$(e,t,n){return(t=P$(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function P$(e){var t=R$(e,"string");return typeof t=="symbol"?t:t+""}function R$(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var ld=Math.PI/180,I$=e=>e*180/Math.PI,en=(e,t,n,r)=>({x:e+Math.cos(-ld*r)*n,y:t+Math.sin(-ld*r)*n}),L$=function(t,n){var r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{top:0,right:0,bottom:0,left:0};return Math.min(Math.abs(t-(r.left||0)-(r.right||0)),Math.abs(n-(r.top||0)-(r.bottom||0)))/2},B$=(e,t)=>{var{x:n,y:r}=e,{x:a,y:u}=t;return Math.sqrt((n-a)**2+(r-u)**2)},U$=(e,t)=>{var{x:n,y:r}=e,{cx:a,cy:u}=t,o=B$({x:n,y:r},{x:a,y:u});if(o<=0)return{radius:o,angle:0};var c=(n-a)/o,f=Math.acos(c);return r>u&&(f=2*Math.PI-f),{radius:o,angle:I$(f),angleInRadian:f}},q$=e=>{var{startAngle:t,endAngle:n}=e,r=Math.floor(t/360),a=Math.floor(n/360),u=Math.min(r,a);return{startAngle:t-u*360,endAngle:n-u*360}},H$=(e,t)=>{var{startAngle:n,endAngle:r}=t,a=Math.floor(n/360),u=Math.floor(r/360),o=Math.min(a,u);return e+o*360},$$=(e,t)=>{var{chartX:n,chartY:r}=e,{radius:a,angle:u}=U$({x:n,y:r},t),{innerRadius:o,outerRadius:c}=t;if(a<o||a>c||a===0)return null;var{startAngle:f,endAngle:d}=q$(t),m=u,p;if(f<=d){for(;m>d;)m-=360;for(;m<f;)m+=360;p=m>=f&&m<=d}else{for(;m>f;)m-=360;for(;m<d;)m+=360;p=m>=d&&m<=f}return p?U2(U2({},t),{},{radius:a,angle:H$(m,t)}):null};function wM(e){var{cx:t,cy:n,radius:r,startAngle:a,endAngle:u}=e,o=en(t,n,r,a),c=en(t,n,r,u);return{points:[o,c],cx:t,cy:n,radius:r,startAngle:a,endAngle:u}}var q2,H2,$2,F2,V2,Y2,K2;function Ig(){return Ig=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ig.apply(null,arguments)}function $a(e,t){return t||(t=e.slice(0)),Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(t)}}))}var F$=(e,t)=>{var n=_n(t-e),r=Math.min(Math.abs(t-e),359.999);return n*r},yf=e=>{var{cx:t,cy:n,radius:r,angle:a,sign:u,isExternal:o,cornerRadius:c,cornerIsExternal:f}=e,d=c*(o?1:-1)+r,m=Math.asin(c/d)/ld,p=f?a:a+u*m,y=en(t,n,d,p),g=en(t,n,r,p),x=f?a-u*m:a,w=en(t,n,d*Math.cos(m*ld),x);return{center:y,circleTangency:g,lineTangency:w,theta:m}},SM=e=>{var{cx:t,cy:n,innerRadius:r,outerRadius:a,startAngle:u,endAngle:o}=e,c=F$(u,o),f=u+c,d=en(t,n,a,u),m=en(t,n,a,f),p=gt(q2||(q2=$a(["M ",",",`
    A `,",",`,0,
    `,",",`,
    `,",",`
  `])),d.x,d.y,a,a,+(Math.abs(c)>180),+(u>f),m.x,m.y);if(r>0){var y=en(t,n,r,u),g=en(t,n,r,f);p+=gt(H2||(H2=$a(["L ",",",`
            A `,",",`,0,
            `,",",`,
            `,","," Z"])),g.x,g.y,r,r,+(Math.abs(c)>180),+(u<=f),y.x,y.y)}else p+=gt($2||($2=$a(["L ",","," Z"])),t,n);return p},V$=e=>{var{cx:t,cy:n,innerRadius:r,outerRadius:a,cornerRadius:u,forceCornerRadius:o,cornerIsExternal:c,startAngle:f,endAngle:d}=e,m=_n(d-f),{circleTangency:p,lineTangency:y,theta:g}=yf({cx:t,cy:n,radius:a,angle:f,sign:m,cornerRadius:u,cornerIsExternal:c}),{circleTangency:x,lineTangency:w,theta:S}=yf({cx:t,cy:n,radius:a,angle:d,sign:-m,cornerRadius:u,cornerIsExternal:c}),O=c?Math.abs(f-d):Math.abs(f-d)-g-S;if(O<0)return o?gt(F2||(F2=$a(["M ",",",`
        a`,",",",0,0,1,",`,0
        a`,",",",0,0,1,",`,0
      `])),y.x,y.y,u,u,u*2,u,u,-u*2):SM({cx:t,cy:n,innerRadius:r,outerRadius:a,startAngle:f,endAngle:d});var _=gt(V2||(V2=$a(["M ",",",`
    A`,",",",0,0,",",",",",`
    A`,",",",0,",",",",",",",`
    A`,",",",0,0,",",",",",`
  `])),y.x,y.y,u,u,+(m<0),p.x,p.y,a,a,+(O>180),+(m<0),x.x,x.y,u,u,+(m<0),w.x,w.y);if(r>0){var{circleTangency:k,lineTangency:M,theta:N}=yf({cx:t,cy:n,radius:r,angle:f,sign:m,isExternal:!0,cornerRadius:u,cornerIsExternal:c}),{circleTangency:C,lineTangency:z,theta:$}=yf({cx:t,cy:n,radius:r,angle:d,sign:-m,isExternal:!0,cornerRadius:u,cornerIsExternal:c}),H=c?Math.abs(f-d):Math.abs(f-d)-N-$;if(H<0&&u===0)return"".concat(_,"L").concat(t,",").concat(n,"Z");_+=gt(Y2||(Y2=$a(["L",",",`
      A`,",",",0,0,",",",",",`
      A`,",",",0,",",",",",",",`
      A`,",",",0,0,",",",",","Z"])),z.x,z.y,u,u,+(m<0),C.x,C.y,r,r,+(H>180),+(m>0),k.x,k.y,u,u,+(m<0),M.x,M.y)}else _+=gt(K2||(K2=$a(["L",",","Z"])),t,n);return _},Y$={cx:0,cy:0,innerRadius:0,outerRadius:0,startAngle:0,endAngle:0,cornerRadius:0,forceCornerRadius:!1,cornerIsExternal:!1},OM=e=>{var t=Kn(e,Y$),{cx:n,cy:r,innerRadius:a,outerRadius:u,cornerRadius:o,forceCornerRadius:c,cornerIsExternal:f,startAngle:d,endAngle:m,className:p}=t;if(u<a||d===m)return null;var y=ft("recharts-sector",p),g=u-a,x=kr(o,g,0,!0),w;return x>0&&Math.abs(d-m)<360?w=V$({cx:n,cy:r,innerRadius:a,outerRadius:u,cornerRadius:Math.min(x,g/2),forceCornerRadius:c,cornerIsExternal:f,startAngle:d,endAngle:m}):w=SM({cx:n,cy:r,innerRadius:a,outerRadius:u,startAngle:d,endAngle:m}),E.createElement("path",Ig({},hr(t),{className:y,d:w}))};function K$(e,t,n){if(e==="horizontal")return[{x:t.x,y:n.top},{x:t.x,y:n.top+n.height}];if(e==="vertical")return[{x:n.left,y:t.y},{x:n.left+n.width,y:t.y}];if(lj(t)){if(e==="centric"){var{cx:r,cy:a,innerRadius:u,outerRadius:o,angle:c}=t,f=en(r,a,u,c),d=en(r,a,o,c);return[{x:f.x,y:f.y},{x:d.x,y:d.y}]}return wM(t)}}var xy={},wy={},Sy={},G2;function G$(){return G2||(G2=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=vj();function n(r){return t.isSymbol(r)?NaN:Number(r)}e.toNumber=n})(Sy)),Sy}var X2;function X$(){return X2||(X2=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=G$();function n(r){return r?(r=t.toNumber(r),r===1/0||r===-1/0?(r<0?-1:1)*Number.MAX_VALUE:r===r?r:0):r===0?r:0}e.toFinite=n})(wy)),wy}var Z2;function Z$(){return Z2||(Z2=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=yj(),n=X$();function r(a,u,o){o&&typeof o!="number"&&t.isIterateeCall(a,u,o)&&(u=o=void 0),a=n.toFinite(a),u===void 0?(u=a,a=0):u=n.toFinite(u),o=o===void 0?a<u?1:-1:n.toFinite(o);const c=Math.max(Math.ceil((u-a)/(o||1)),0),f=new Array(c);for(let d=0;d<c;d++)f[d]=a,a+=o;return f}e.range=r})(xy)),xy}var Oy,Q2;function Q$(){return Q2||(Q2=1,Oy=Z$().range),Oy}var W$=Q$();const EM=Tr(W$);function ha(e,t){return e==null||t==null?NaN:e<t?-1:e>t?1:e>=t?0:NaN}function J$(e,t){return e==null||t==null?NaN:t<e?-1:t>e?1:t>=e?0:NaN}function rb(e){let t,n,r;e.length!==2?(t=ha,n=(c,f)=>ha(e(c),f),r=(c,f)=>e(c)-f):(t=e===ha||e===J$?e:eF,n=e,r=e);function a(c,f,d=0,m=c.length){if(d<m){if(t(f,f)!==0)return m;do{const p=d+m>>>1;n(c[p],f)<0?d=p+1:m=p}while(d<m)}return d}function u(c,f,d=0,m=c.length){if(d<m){if(t(f,f)!==0)return m;do{const p=d+m>>>1;n(c[p],f)<=0?d=p+1:m=p}while(d<m)}return d}function o(c,f,d=0,m=c.length){const p=a(c,f,d,m-1);return p>d&&r(c[p-1],f)>-r(c[p],f)?p-1:p}return{left:a,center:o,right:u}}function eF(){return 0}function AM(e){return e===null?NaN:+e}function*tF(e,t){for(let n of e)n!=null&&(n=+n)>=n&&(yield n)}const nF=rb(ha),_s=nF.right;rb(AM).center;class W2 extends Map{constructor(t,n=aF){if(super(),Object.defineProperties(this,{_intern:{value:new Map},_key:{value:n}}),t!=null)for(const[r,a]of t)this.set(r,a)}get(t){return super.get(J2(this,t))}has(t){return super.has(J2(this,t))}set(t,n){return super.set(rF(this,t),n)}delete(t){return super.delete(iF(this,t))}}function J2({_intern:e,_key:t},n){const r=t(n);return e.has(r)?e.get(r):n}function rF({_intern:e,_key:t},n){const r=t(n);return e.has(r)?e.get(r):(e.set(r,n),n)}function iF({_intern:e,_key:t},n){const r=t(n);return e.has(r)&&(n=e.get(r),e.delete(r)),n}function aF(e){return e!==null&&typeof e=="object"?e.valueOf():e}function lF(e=ha){if(e===ha)return _M;if(typeof e!="function")throw new TypeError("compare is not a function");return(t,n)=>{const r=e(t,n);return r||r===0?r:(e(n,n)===0)-(e(t,t)===0)}}function _M(e,t){return(e==null||!(e>=e))-(t==null||!(t>=t))||(e<t?-1:e>t?1:0)}const uF=Math.sqrt(50),oF=Math.sqrt(10),sF=Math.sqrt(2);function ud(e,t,n){const r=(t-e)/Math.max(0,n),a=Math.floor(Math.log10(r)),u=r/Math.pow(10,a),o=u>=uF?10:u>=oF?5:u>=sF?2:1;let c,f,d;return a<0?(d=Math.pow(10,-a)/o,c=Math.round(e*d),f=Math.round(t*d),c/d<e&&++c,f/d>t&&--f,d=-d):(d=Math.pow(10,a)*o,c=Math.round(e/d),f=Math.round(t/d),c*d<e&&++c,f*d>t&&--f),f<c&&.5<=n&&n<2?ud(e,t,n*2):[c,f,d]}function Lg(e,t,n){if(t=+t,e=+e,n=+n,!(n>0))return[];if(e===t)return[e];const r=t<e,[a,u,o]=r?ud(t,e,n):ud(e,t,n);if(!(u>=a))return[];const c=u-a+1,f=new Array(c);if(r)if(o<0)for(let d=0;d<c;++d)f[d]=(u-d)/-o;else for(let d=0;d<c;++d)f[d]=(u-d)*o;else if(o<0)for(let d=0;d<c;++d)f[d]=(a+d)/-o;else for(let d=0;d<c;++d)f[d]=(a+d)*o;return f}function Bg(e,t,n){return t=+t,e=+e,n=+n,ud(e,t,n)[2]}function Ug(e,t,n){t=+t,e=+e,n=+n;const r=t<e,a=r?Bg(t,e,n):Bg(e,t,n);return(r?-1:1)*(a<0?1/-a:a)}function e_(e,t){let n;if(t===void 0)for(const r of e)r!=null&&(n<r||n===void 0&&r>=r)&&(n=r);else{let r=-1;for(let a of e)(a=t(a,++r,e))!=null&&(n<a||n===void 0&&a>=a)&&(n=a)}return n}function t_(e,t){let n;if(t===void 0)for(const r of e)r!=null&&(n>r||n===void 0&&r>=r)&&(n=r);else{let r=-1;for(let a of e)(a=t(a,++r,e))!=null&&(n>a||n===void 0&&a>=a)&&(n=a)}return n}function kM(e,t,n=0,r=1/0,a){if(t=Math.floor(t),n=Math.floor(Math.max(0,n)),r=Math.floor(Math.min(e.length-1,r)),!(n<=t&&t<=r))return e;for(a=a===void 0?_M:lF(a);r>n;){if(r-n>600){const f=r-n+1,d=t-n+1,m=Math.log(f),p=.5*Math.exp(2*m/3),y=.5*Math.sqrt(m*p*(f-p)/f)*(d-f/2<0?-1:1),g=Math.max(n,Math.floor(t-d*p/f+y)),x=Math.min(r,Math.floor(t+(f-d)*p/f+y));kM(e,t,g,x,a)}const u=e[t];let o=n,c=r;for(qo(e,n,t),a(e[r],u)>0&&qo(e,n,r);o<c;){for(qo(e,o,c),++o,--c;a(e[o],u)<0;)++o;for(;a(e[c],u)>0;)--c}a(e[n],u)===0?qo(e,n,c):(++c,qo(e,c,r)),c<=t&&(n=c+1),t<=c&&(r=c-1)}return e}function qo(e,t,n){const r=e[t];e[t]=e[n],e[n]=r}function cF(e,t,n){if(e=Float64Array.from(tF(e)),!(!(r=e.length)||isNaN(t=+t))){if(t<=0||r<2)return t_(e);if(t>=1)return e_(e);var r,a=(r-1)*t,u=Math.floor(a),o=e_(kM(e,u).subarray(0,u+1)),c=t_(e.subarray(u+1));return o+(c-o)*(a-u)}}function fF(e,t,n=AM){if(!(!(r=e.length)||isNaN(t=+t))){if(t<=0||r<2)return+n(e[0],0,e);if(t>=1)return+n(e[r-1],r-1,e);var r,a=(r-1)*t,u=Math.floor(a),o=+n(e[u],u,e),c=+n(e[u+1],u+1,e);return o+(c-o)*(a-u)}}function dF(e,t,n){e=+e,t=+t,n=(a=arguments.length)<2?(t=e,e=0,1):a<3?1:+n;for(var r=-1,a=Math.max(0,Math.ceil((t-e)/n))|0,u=new Array(a);++r<a;)u[r]=e+r*n;return u}function vr(e,t){switch(arguments.length){case 0:break;case 1:this.range(e);break;default:this.range(t).domain(e);break}return this}function Mi(e,t){switch(arguments.length){case 0:break;case 1:{typeof e=="function"?this.interpolator(e):this.range(e);break}default:{this.domain(e),typeof t=="function"?this.interpolator(t):this.range(t);break}}return this}const qg=Symbol("implicit");function ib(){var e=new W2,t=[],n=[],r=qg;function a(u){let o=e.get(u);if(o===void 0){if(r!==qg)return r;e.set(u,o=t.push(u)-1)}return n[o%n.length]}return a.domain=function(u){if(!arguments.length)return t.slice();t=[],e=new W2;for(const o of u)e.has(o)||e.set(o,t.push(o)-1);return a},a.range=function(u){return arguments.length?(n=Array.from(u),a):n.slice()},a.unknown=function(u){return arguments.length?(r=u,a):r},a.copy=function(){return ib(t,n).unknown(r)},vr.apply(a,arguments),a}function ab(){var e=ib().unknown(void 0),t=e.domain,n=e.range,r=0,a=1,u,o,c=!1,f=0,d=0,m=.5;delete e.unknown;function p(){var y=t().length,g=a<r,x=g?a:r,w=g?r:a;u=(w-x)/Math.max(1,y-f+d*2),c&&(u=Math.floor(u)),x+=(w-x-u*(y-f))*m,o=u*(1-f),c&&(x=Math.round(x),o=Math.round(o));var S=dF(y).map(function(O){return x+u*O});return n(g?S.reverse():S)}return e.domain=function(y){return arguments.length?(t(y),p()):t()},e.range=function(y){return arguments.length?([r,a]=y,r=+r,a=+a,p()):[r,a]},e.rangeRound=function(y){return[r,a]=y,r=+r,a=+a,c=!0,p()},e.bandwidth=function(){return o},e.step=function(){return u},e.round=function(y){return arguments.length?(c=!!y,p()):c},e.padding=function(y){return arguments.length?(f=Math.min(1,d=+y),p()):f},e.paddingInner=function(y){return arguments.length?(f=Math.min(1,y),p()):f},e.paddingOuter=function(y){return arguments.length?(d=+y,p()):d},e.align=function(y){return arguments.length?(m=Math.max(0,Math.min(1,y)),p()):m},e.copy=function(){return ab(t(),[r,a]).round(c).paddingInner(f).paddingOuter(d).align(m)},vr.apply(p(),arguments)}function CM(e){var t=e.copy;return e.padding=e.paddingOuter,delete e.paddingInner,delete e.paddingOuter,e.copy=function(){return CM(t())},e}function hF(){return CM(ab.apply(null,arguments).paddingInner(1))}function lb(e,t,n){e.prototype=t.prototype=n,n.constructor=e}function TM(e,t){var n=Object.create(e.prototype);for(var r in t)n[r]=t[r];return n}function ks(){}var ss=.7,od=1/ss,cu="\\s*([+-]?\\d+)\\s*",cs="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*",Hr="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*",mF=/^#([0-9a-f]{3,8})$/,pF=new RegExp(`^rgb\\(${cu},${cu},${cu}\\)$`),vF=new RegExp(`^rgb\\(${Hr},${Hr},${Hr}\\)$`),yF=new RegExp(`^rgba\\(${cu},${cu},${cu},${cs}\\)$`),gF=new RegExp(`^rgba\\(${Hr},${Hr},${Hr},${cs}\\)$`),bF=new RegExp(`^hsl\\(${cs},${Hr},${Hr}\\)$`),xF=new RegExp(`^hsla\\(${cs},${Hr},${Hr},${cs}\\)$`),n_={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};lb(ks,fs,{copy(e){return Object.assign(new this.constructor,this,e)},displayable(){return this.rgb().displayable()},hex:r_,formatHex:r_,formatHex8:wF,formatHsl:SF,formatRgb:i_,toString:i_});function r_(){return this.rgb().formatHex()}function wF(){return this.rgb().formatHex8()}function SF(){return jM(this).formatHsl()}function i_(){return this.rgb().formatRgb()}function fs(e){var t,n;return e=(e+"").trim().toLowerCase(),(t=mF.exec(e))?(n=t[1].length,t=parseInt(t[1],16),n===6?a_(t):n===3?new Cn(t>>8&15|t>>4&240,t>>4&15|t&240,(t&15)<<4|t&15,1):n===8?gf(t>>24&255,t>>16&255,t>>8&255,(t&255)/255):n===4?gf(t>>12&15|t>>8&240,t>>8&15|t>>4&240,t>>4&15|t&240,((t&15)<<4|t&15)/255):null):(t=pF.exec(e))?new Cn(t[1],t[2],t[3],1):(t=vF.exec(e))?new Cn(t[1]*255/100,t[2]*255/100,t[3]*255/100,1):(t=yF.exec(e))?gf(t[1],t[2],t[3],t[4]):(t=gF.exec(e))?gf(t[1]*255/100,t[2]*255/100,t[3]*255/100,t[4]):(t=bF.exec(e))?o_(t[1],t[2]/100,t[3]/100,1):(t=xF.exec(e))?o_(t[1],t[2]/100,t[3]/100,t[4]):n_.hasOwnProperty(e)?a_(n_[e]):e==="transparent"?new Cn(NaN,NaN,NaN,0):null}function a_(e){return new Cn(e>>16&255,e>>8&255,e&255,1)}function gf(e,t,n,r){return r<=0&&(e=t=n=NaN),new Cn(e,t,n,r)}function OF(e){return e instanceof ks||(e=fs(e)),e?(e=e.rgb(),new Cn(e.r,e.g,e.b,e.opacity)):new Cn}function Hg(e,t,n,r){return arguments.length===1?OF(e):new Cn(e,t,n,r??1)}function Cn(e,t,n,r){this.r=+e,this.g=+t,this.b=+n,this.opacity=+r}lb(Cn,Hg,TM(ks,{brighter(e){return e=e==null?od:Math.pow(od,e),new Cn(this.r*e,this.g*e,this.b*e,this.opacity)},darker(e){return e=e==null?ss:Math.pow(ss,e),new Cn(this.r*e,this.g*e,this.b*e,this.opacity)},rgb(){return this},clamp(){return new Cn(Ga(this.r),Ga(this.g),Ga(this.b),sd(this.opacity))},displayable(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:l_,formatHex:l_,formatHex8:EF,formatRgb:u_,toString:u_}));function l_(){return`#${Fa(this.r)}${Fa(this.g)}${Fa(this.b)}`}function EF(){return`#${Fa(this.r)}${Fa(this.g)}${Fa(this.b)}${Fa((isNaN(this.opacity)?1:this.opacity)*255)}`}function u_(){const e=sd(this.opacity);return`${e===1?"rgb(":"rgba("}${Ga(this.r)}, ${Ga(this.g)}, ${Ga(this.b)}${e===1?")":`, ${e})`}`}function sd(e){return isNaN(e)?1:Math.max(0,Math.min(1,e))}function Ga(e){return Math.max(0,Math.min(255,Math.round(e)||0))}function Fa(e){return e=Ga(e),(e<16?"0":"")+e.toString(16)}function o_(e,t,n,r){return r<=0?e=t=n=NaN:n<=0||n>=1?e=t=NaN:t<=0&&(e=NaN),new Er(e,t,n,r)}function jM(e){if(e instanceof Er)return new Er(e.h,e.s,e.l,e.opacity);if(e instanceof ks||(e=fs(e)),!e)return new Er;if(e instanceof Er)return e;e=e.rgb();var t=e.r/255,n=e.g/255,r=e.b/255,a=Math.min(t,n,r),u=Math.max(t,n,r),o=NaN,c=u-a,f=(u+a)/2;return c?(t===u?o=(n-r)/c+(n<r)*6:n===u?o=(r-t)/c+2:o=(t-n)/c+4,c/=f<.5?u+a:2-u-a,o*=60):c=f>0&&f<1?0:o,new Er(o,c,f,e.opacity)}function AF(e,t,n,r){return arguments.length===1?jM(e):new Er(e,t,n,r??1)}function Er(e,t,n,r){this.h=+e,this.s=+t,this.l=+n,this.opacity=+r}lb(Er,AF,TM(ks,{brighter(e){return e=e==null?od:Math.pow(od,e),new Er(this.h,this.s,this.l*e,this.opacity)},darker(e){return e=e==null?ss:Math.pow(ss,e),new Er(this.h,this.s,this.l*e,this.opacity)},rgb(){var e=this.h%360+(this.h<0)*360,t=isNaN(e)||isNaN(this.s)?0:this.s,n=this.l,r=n+(n<.5?n:1-n)*t,a=2*n-r;return new Cn(Ey(e>=240?e-240:e+120,a,r),Ey(e,a,r),Ey(e<120?e+240:e-120,a,r),this.opacity)},clamp(){return new Er(s_(this.h),bf(this.s),bf(this.l),sd(this.opacity))},displayable(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl(){const e=sd(this.opacity);return`${e===1?"hsl(":"hsla("}${s_(this.h)}, ${bf(this.s)*100}%, ${bf(this.l)*100}%${e===1?")":`, ${e})`}`}}));function s_(e){return e=(e||0)%360,e<0?e+360:e}function bf(e){return Math.max(0,Math.min(1,e||0))}function Ey(e,t,n){return(e<60?t+(n-t)*e/60:e<180?n:e<240?t+(n-t)*(240-e)/60:t)*255}const rh=e=>()=>e;function MM(e,t){return function(n){return e+n*t}}function _F(e,t,n){return e=Math.pow(e,n),t=Math.pow(t,n)-e,n=1/n,function(r){return Math.pow(e+r*t,n)}}function vne(e,t){var n=t-e;return n?MM(e,n>180||n<-180?n-360*Math.round(n/360):n):rh(isNaN(e)?t:e)}function kF(e){return(e=+e)==1?zM:function(t,n){return n-t?_F(t,n,e):rh(isNaN(t)?n:t)}}function zM(e,t){var n=t-e;return n?MM(e,n):rh(isNaN(e)?t:e)}const c_=(function e(t){var n=kF(t);function r(a,u){var o=n((a=Hg(a)).r,(u=Hg(u)).r),c=n(a.g,u.g),f=n(a.b,u.b),d=zM(a.opacity,u.opacity);return function(m){return a.r=o(m),a.g=c(m),a.b=f(m),a.opacity=d(m),a+""}}return r.gamma=e,r})(1);function CF(e,t){t||(t=[]);var n=e?Math.min(t.length,e.length):0,r=t.slice(),a;return function(u){for(a=0;a<n;++a)r[a]=e[a]*(1-u)+t[a]*u;return r}}function TF(e){return ArrayBuffer.isView(e)&&!(e instanceof DataView)}function jF(e,t){var n=t?t.length:0,r=e?Math.min(n,e.length):0,a=new Array(r),u=new Array(n),o;for(o=0;o<r;++o)a[o]=ku(e[o],t[o]);for(;o<n;++o)u[o]=t[o];return function(c){for(o=0;o<r;++o)u[o]=a[o](c);return u}}function MF(e,t){var n=new Date;return e=+e,t=+t,function(r){return n.setTime(e*(1-r)+t*r),n}}function cd(e,t){return e=+e,t=+t,function(n){return e*(1-n)+t*n}}function zF(e,t){var n={},r={},a;(e===null||typeof e!="object")&&(e={}),(t===null||typeof t!="object")&&(t={});for(a in t)a in e?n[a]=ku(e[a],t[a]):r[a]=t[a];return function(u){for(a in n)r[a]=n[a](u);return r}}var $g=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,Ay=new RegExp($g.source,"g");function DF(e){return function(){return e}}function NF(e){return function(t){return e(t)+""}}function PF(e,t){var n=$g.lastIndex=Ay.lastIndex=0,r,a,u,o=-1,c=[],f=[];for(e=e+"",t=t+"";(r=$g.exec(e))&&(a=Ay.exec(t));)(u=a.index)>n&&(u=t.slice(n,u),c[o]?c[o]+=u:c[++o]=u),(r=r[0])===(a=a[0])?c[o]?c[o]+=a:c[++o]=a:(c[++o]=null,f.push({i:o,x:cd(r,a)})),n=Ay.lastIndex;return n<t.length&&(u=t.slice(n),c[o]?c[o]+=u:c[++o]=u),c.length<2?f[0]?NF(f[0].x):DF(t):(t=f.length,function(d){for(var m=0,p;m<t;++m)c[(p=f[m]).i]=p.x(d);return c.join("")})}function ku(e,t){var n=typeof t,r;return t==null||n==="boolean"?rh(t):(n==="number"?cd:n==="string"?(r=fs(t))?(t=r,c_):PF:t instanceof fs?c_:t instanceof Date?MF:TF(t)?CF:Array.isArray(t)?jF:typeof t.valueOf!="function"&&typeof t.toString!="function"||isNaN(t)?zF:cd)(e,t)}function ub(e,t){return e=+e,t=+t,function(n){return Math.round(e*(1-n)+t*n)}}function RF(e,t){t===void 0&&(t=e,e=ku);for(var n=0,r=t.length-1,a=t[0],u=new Array(r<0?0:r);n<r;)u[n]=e(a,a=t[++n]);return function(o){var c=Math.max(0,Math.min(r-1,Math.floor(o*=r)));return u[c](o-c)}}function IF(e){return function(){return e}}function fd(e){return+e}var f_=[0,1];function hn(e){return e}function Fg(e,t){return(t-=e=+e)?function(n){return(n-e)/t}:IF(isNaN(t)?NaN:.5)}function LF(e,t){var n;return e>t&&(n=e,e=t,t=n),function(r){return Math.max(e,Math.min(t,r))}}function BF(e,t,n){var r=e[0],a=e[1],u=t[0],o=t[1];return a<r?(r=Fg(a,r),u=n(o,u)):(r=Fg(r,a),u=n(u,o)),function(c){return u(r(c))}}function UF(e,t,n){var r=Math.min(e.length,t.length)-1,a=new Array(r),u=new Array(r),o=-1;for(e[r]<e[0]&&(e=e.slice().reverse(),t=t.slice().reverse());++o<r;)a[o]=Fg(e[o],e[o+1]),u[o]=n(t[o],t[o+1]);return function(c){var f=_s(e,c,1,r)-1;return u[f](a[f](c))}}function Cs(e,t){return t.domain(e.domain()).range(e.range()).interpolate(e.interpolate()).clamp(e.clamp()).unknown(e.unknown())}function ih(){var e=f_,t=f_,n=ku,r,a,u,o=hn,c,f,d;function m(){var y=Math.min(e.length,t.length);return o!==hn&&(o=LF(e[0],e[y-1])),c=y>2?UF:BF,f=d=null,p}function p(y){return y==null||isNaN(y=+y)?u:(f||(f=c(e.map(r),t,n)))(r(o(y)))}return p.invert=function(y){return o(a((d||(d=c(t,e.map(r),cd)))(y)))},p.domain=function(y){return arguments.length?(e=Array.from(y,fd),m()):e.slice()},p.range=function(y){return arguments.length?(t=Array.from(y),m()):t.slice()},p.rangeRound=function(y){return t=Array.from(y),n=ub,m()},p.clamp=function(y){return arguments.length?(o=y?!0:hn,m()):o!==hn},p.interpolate=function(y){return arguments.length?(n=y,m()):n},p.unknown=function(y){return arguments.length?(u=y,p):u},function(y,g){return r=y,a=g,m()}}function ob(){return ih()(hn,hn)}function qF(e){return Math.abs(e=Math.round(e))>=1e21?e.toLocaleString("en").replace(/,/g,""):e.toString(10)}function dd(e,t){if(!isFinite(e)||e===0)return null;var n=(e=t?e.toExponential(t-1):e.toExponential()).indexOf("e"),r=e.slice(0,n);return[r.length>1?r[0]+r.slice(2):r,+e.slice(n+1)]}function vu(e){return e=dd(Math.abs(e)),e?e[1]:NaN}function HF(e,t){return function(n,r){for(var a=n.length,u=[],o=0,c=e[0],f=0;a>0&&c>0&&(f+c+1>r&&(c=Math.max(1,r-f)),u.push(n.substring(a-=c,a+c)),!((f+=c+1)>r));)c=e[o=(o+1)%e.length];return u.reverse().join(t)}}function $F(e){return function(t){return t.replace(/[0-9]/g,function(n){return e[+n]})}}var FF=/^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;function ds(e){if(!(t=FF.exec(e)))throw new Error("invalid format: "+e);var t;return new sb({fill:t[1],align:t[2],sign:t[3],symbol:t[4],zero:t[5],width:t[6],comma:t[7],precision:t[8]&&t[8].slice(1),trim:t[9],type:t[10]})}ds.prototype=sb.prototype;function sb(e){this.fill=e.fill===void 0?" ":e.fill+"",this.align=e.align===void 0?">":e.align+"",this.sign=e.sign===void 0?"-":e.sign+"",this.symbol=e.symbol===void 0?"":e.symbol+"",this.zero=!!e.zero,this.width=e.width===void 0?void 0:+e.width,this.comma=!!e.comma,this.precision=e.precision===void 0?void 0:+e.precision,this.trim=!!e.trim,this.type=e.type===void 0?"":e.type+""}sb.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?"0":"")+(this.width===void 0?"":Math.max(1,this.width|0))+(this.comma?",":"")+(this.precision===void 0?"":"."+Math.max(0,this.precision|0))+(this.trim?"~":"")+this.type};function VF(e){e:for(var t=e.length,n=1,r=-1,a;n<t;++n)switch(e[n]){case".":r=a=n;break;case"0":r===0&&(r=n),a=n;break;default:if(!+e[n])break e;r>0&&(r=0);break}return r>0?e.slice(0,r)+e.slice(a+1):e}var hd;function YF(e,t){var n=dd(e,t);if(!n)return hd=void 0,e.toPrecision(t);var r=n[0],a=n[1],u=a-(hd=Math.max(-8,Math.min(8,Math.floor(a/3)))*3)+1,o=r.length;return u===o?r:u>o?r+new Array(u-o+1).join("0"):u>0?r.slice(0,u)+"."+r.slice(u):"0."+new Array(1-u).join("0")+dd(e,Math.max(0,t+u-1))[0]}function d_(e,t){var n=dd(e,t);if(!n)return e+"";var r=n[0],a=n[1];return a<0?"0."+new Array(-a).join("0")+r:r.length>a+1?r.slice(0,a+1)+"."+r.slice(a+1):r+new Array(a-r.length+2).join("0")}const h_={"%":(e,t)=>(e*100).toFixed(t),b:e=>Math.round(e).toString(2),c:e=>e+"",d:qF,e:(e,t)=>e.toExponential(t),f:(e,t)=>e.toFixed(t),g:(e,t)=>e.toPrecision(t),o:e=>Math.round(e).toString(8),p:(e,t)=>d_(e*100,t),r:d_,s:YF,X:e=>Math.round(e).toString(16).toUpperCase(),x:e=>Math.round(e).toString(16)};function m_(e){return e}var p_=Array.prototype.map,v_=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"];function KF(e){var t=e.grouping===void 0||e.thousands===void 0?m_:HF(p_.call(e.grouping,Number),e.thousands+""),n=e.currency===void 0?"":e.currency[0]+"",r=e.currency===void 0?"":e.currency[1]+"",a=e.decimal===void 0?".":e.decimal+"",u=e.numerals===void 0?m_:$F(p_.call(e.numerals,String)),o=e.percent===void 0?"%":e.percent+"",c=e.minus===void 0?"−":e.minus+"",f=e.nan===void 0?"NaN":e.nan+"";function d(p,y){p=ds(p);var g=p.fill,x=p.align,w=p.sign,S=p.symbol,O=p.zero,_=p.width,k=p.comma,M=p.precision,N=p.trim,C=p.type;C==="n"?(k=!0,C="g"):h_[C]||(M===void 0&&(M=12),N=!0,C="g"),(O||g==="0"&&x==="=")&&(O=!0,g="0",x="=");var z=(y&&y.prefix!==void 0?y.prefix:"")+(S==="$"?n:S==="#"&&/[boxX]/.test(C)?"0"+C.toLowerCase():""),$=(S==="$"?r:/[%p]/.test(C)?o:"")+(y&&y.suffix!==void 0?y.suffix:""),H=h_[C],P=/[defgprs%]/.test(C);M=M===void 0?6:/[gprs]/.test(C)?Math.max(1,Math.min(21,M)):Math.max(0,Math.min(20,M));function F(I){var ee=z,Z=$,Y,U,Q;if(C==="c")Z=H(I)+Z,I="";else{I=+I;var ue=I<0||1/I<0;if(I=isNaN(I)?f:H(Math.abs(I),M),N&&(I=VF(I)),ue&&+I==0&&w!=="+"&&(ue=!1),ee=(ue?w==="("?w:c:w==="-"||w==="("?"":w)+ee,Z=(C==="s"&&!isNaN(I)&&hd!==void 0?v_[8+hd/3]:"")+Z+(ue&&w==="("?")":""),P){for(Y=-1,U=I.length;++Y<U;)if(Q=I.charCodeAt(Y),48>Q||Q>57){Z=(Q===46?a+I.slice(Y+1):I.slice(Y))+Z,I=I.slice(0,Y);break}}}k&&!O&&(I=t(I,1/0));var de=ee.length+I.length+Z.length,R=de<_?new Array(_-de+1).join(g):"";switch(k&&O&&(I=t(R+I,R.length?_-Z.length:1/0),R=""),x){case"<":I=ee+I+Z+R;break;case"=":I=ee+R+I+Z;break;case"^":I=R.slice(0,de=R.length>>1)+ee+I+Z+R.slice(de);break;default:I=R+ee+I+Z;break}return u(I)}return F.toString=function(){return p+""},F}function m(p,y){var g=Math.max(-8,Math.min(8,Math.floor(vu(y)/3)))*3,x=Math.pow(10,-g),w=d((p=ds(p),p.type="f",p),{suffix:v_[8+g/3]});return function(S){return w(x*S)}}return{format:d,formatPrefix:m}}var xf,cb,DM;GF({thousands:",",grouping:[3],currency:["$",""]});function GF(e){return xf=KF(e),cb=xf.format,DM=xf.formatPrefix,xf}function XF(e){return Math.max(0,-vu(Math.abs(e)))}function ZF(e,t){return Math.max(0,Math.max(-8,Math.min(8,Math.floor(vu(t)/3)))*3-vu(Math.abs(e)))}function QF(e,t){return e=Math.abs(e),t=Math.abs(t)-e,Math.max(0,vu(t)-vu(e))+1}function NM(e,t,n,r){var a=Ug(e,t,n),u;switch(r=ds(r??",f"),r.type){case"s":{var o=Math.max(Math.abs(e),Math.abs(t));return r.precision==null&&!isNaN(u=ZF(a,o))&&(r.precision=u),DM(r,o)}case"":case"e":case"g":case"p":case"r":{r.precision==null&&!isNaN(u=QF(a,Math.max(Math.abs(e),Math.abs(t))))&&(r.precision=u-(r.type==="e"));break}case"f":case"%":{r.precision==null&&!isNaN(u=XF(a))&&(r.precision=u-(r.type==="%")*2);break}}return cb(r)}function ya(e){var t=e.domain;return e.ticks=function(n){var r=t();return Lg(r[0],r[r.length-1],n??10)},e.tickFormat=function(n,r){var a=t();return NM(a[0],a[a.length-1],n??10,r)},e.nice=function(n){n==null&&(n=10);var r=t(),a=0,u=r.length-1,o=r[a],c=r[u],f,d,m=10;for(c<o&&(d=o,o=c,c=d,d=a,a=u,u=d);m-- >0;){if(d=Bg(o,c,n),d===f)return r[a]=o,r[u]=c,t(r);if(d>0)o=Math.floor(o/d)*d,c=Math.ceil(c/d)*d;else if(d<0)o=Math.ceil(o*d)/d,c=Math.floor(c*d)/d;else break;f=d}return e},e}function PM(){var e=ob();return e.copy=function(){return Cs(e,PM())},vr.apply(e,arguments),ya(e)}function RM(e){var t;function n(r){return r==null||isNaN(r=+r)?t:r}return n.invert=n,n.domain=n.range=function(r){return arguments.length?(e=Array.from(r,fd),n):e.slice()},n.unknown=function(r){return arguments.length?(t=r,n):t},n.copy=function(){return RM(e).unknown(t)},e=arguments.length?Array.from(e,fd):[0,1],ya(n)}function IM(e,t){e=e.slice();var n=0,r=e.length-1,a=e[n],u=e[r],o;return u<a&&(o=n,n=r,r=o,o=a,a=u,u=o),e[n]=t.floor(a),e[r]=t.ceil(u),e}function y_(e){return Math.log(e)}function g_(e){return Math.exp(e)}function WF(e){return-Math.log(-e)}function JF(e){return-Math.exp(-e)}function eV(e){return isFinite(e)?+("1e"+e):e<0?0:e}function tV(e){return e===10?eV:e===Math.E?Math.exp:t=>Math.pow(e,t)}function nV(e){return e===Math.E?Math.log:e===10&&Math.log10||e===2&&Math.log2||(e=Math.log(e),t=>Math.log(t)/e)}function b_(e){return(t,n)=>-e(-t,n)}function fb(e){const t=e(y_,g_),n=t.domain;let r=10,a,u;function o(){return a=nV(r),u=tV(r),n()[0]<0?(a=b_(a),u=b_(u),e(WF,JF)):e(y_,g_),t}return t.base=function(c){return arguments.length?(r=+c,o()):r},t.domain=function(c){return arguments.length?(n(c),o()):n()},t.ticks=c=>{const f=n();let d=f[0],m=f[f.length-1];const p=m<d;p&&([d,m]=[m,d]);let y=a(d),g=a(m),x,w;const S=c==null?10:+c;let O=[];if(!(r%1)&&g-y<S){if(y=Math.floor(y),g=Math.ceil(g),d>0){for(;y<=g;++y)for(x=1;x<r;++x)if(w=y<0?x/u(-y):x*u(y),!(w<d)){if(w>m)break;O.push(w)}}else for(;y<=g;++y)for(x=r-1;x>=1;--x)if(w=y>0?x/u(-y):x*u(y),!(w<d)){if(w>m)break;O.push(w)}O.length*2<S&&(O=Lg(d,m,S))}else O=Lg(y,g,Math.min(g-y,S)).map(u);return p?O.reverse():O},t.tickFormat=(c,f)=>{if(c==null&&(c=10),f==null&&(f=r===10?"s":","),typeof f!="function"&&(!(r%1)&&(f=ds(f)).precision==null&&(f.trim=!0),f=cb(f)),c===1/0)return f;const d=Math.max(1,r*c/t.ticks().length);return m=>{let p=m/u(Math.round(a(m)));return p*r<r-.5&&(p*=r),p<=d?f(m):""}},t.nice=()=>n(IM(n(),{floor:c=>u(Math.floor(a(c))),ceil:c=>u(Math.ceil(a(c)))})),t}function LM(){const e=fb(ih()).domain([1,10]);return e.copy=()=>Cs(e,LM()).base(e.base()),vr.apply(e,arguments),e}function x_(e){return function(t){return Math.sign(t)*Math.log1p(Math.abs(t/e))}}function w_(e){return function(t){return Math.sign(t)*Math.expm1(Math.abs(t))*e}}function db(e){var t=1,n=e(x_(t),w_(t));return n.constant=function(r){return arguments.length?e(x_(t=+r),w_(t)):t},ya(n)}function BM(){var e=db(ih());return e.copy=function(){return Cs(e,BM()).constant(e.constant())},vr.apply(e,arguments)}function S_(e){return function(t){return t<0?-Math.pow(-t,e):Math.pow(t,e)}}function rV(e){return e<0?-Math.sqrt(-e):Math.sqrt(e)}function iV(e){return e<0?-e*e:e*e}function hb(e){var t=e(hn,hn),n=1;function r(){return n===1?e(hn,hn):n===.5?e(rV,iV):e(S_(n),S_(1/n))}return t.exponent=function(a){return arguments.length?(n=+a,r()):n},ya(t)}function mb(){var e=hb(ih());return e.copy=function(){return Cs(e,mb()).exponent(e.exponent())},vr.apply(e,arguments),e}function aV(){return mb.apply(null,arguments).exponent(.5)}function O_(e){return Math.sign(e)*e*e}function lV(e){return Math.sign(e)*Math.sqrt(Math.abs(e))}function UM(){var e=ob(),t=[0,1],n=!1,r;function a(u){var o=lV(e(u));return isNaN(o)?r:n?Math.round(o):o}return a.invert=function(u){return e.invert(O_(u))},a.domain=function(u){return arguments.length?(e.domain(u),a):e.domain()},a.range=function(u){return arguments.length?(e.range((t=Array.from(u,fd)).map(O_)),a):t.slice()},a.rangeRound=function(u){return a.range(u).round(!0)},a.round=function(u){return arguments.length?(n=!!u,a):n},a.clamp=function(u){return arguments.length?(e.clamp(u),a):e.clamp()},a.unknown=function(u){return arguments.length?(r=u,a):r},a.copy=function(){return UM(e.domain(),t).round(n).clamp(e.clamp()).unknown(r)},vr.apply(a,arguments),ya(a)}function qM(){var e=[],t=[],n=[],r;function a(){var o=0,c=Math.max(1,t.length);for(n=new Array(c-1);++o<c;)n[o-1]=fF(e,o/c);return u}function u(o){return o==null||isNaN(o=+o)?r:t[_s(n,o)]}return u.invertExtent=function(o){var c=t.indexOf(o);return c<0?[NaN,NaN]:[c>0?n[c-1]:e[0],c<n.length?n[c]:e[e.length-1]]},u.domain=function(o){if(!arguments.length)return e.slice();e=[];for(let c of o)c!=null&&!isNaN(c=+c)&&e.push(c);return e.sort(ha),a()},u.range=function(o){return arguments.length?(t=Array.from(o),a()):t.slice()},u.unknown=function(o){return arguments.length?(r=o,u):r},u.quantiles=function(){return n.slice()},u.copy=function(){return qM().domain(e).range(t).unknown(r)},vr.apply(u,arguments)}function HM(){var e=0,t=1,n=1,r=[.5],a=[0,1],u;function o(f){return f!=null&&f<=f?a[_s(r,f,0,n)]:u}function c(){var f=-1;for(r=new Array(n);++f<n;)r[f]=((f+1)*t-(f-n)*e)/(n+1);return o}return o.domain=function(f){return arguments.length?([e,t]=f,e=+e,t=+t,c()):[e,t]},o.range=function(f){return arguments.length?(n=(a=Array.from(f)).length-1,c()):a.slice()},o.invertExtent=function(f){var d=a.indexOf(f);return d<0?[NaN,NaN]:d<1?[e,r[0]]:d>=n?[r[n-1],t]:[r[d-1],r[d]]},o.unknown=function(f){return arguments.length&&(u=f),o},o.thresholds=function(){return r.slice()},o.copy=function(){return HM().domain([e,t]).range(a).unknown(u)},vr.apply(ya(o),arguments)}function $M(){var e=[.5],t=[0,1],n,r=1;function a(u){return u!=null&&u<=u?t[_s(e,u,0,r)]:n}return a.domain=function(u){return arguments.length?(e=Array.from(u),r=Math.min(e.length,t.length-1),a):e.slice()},a.range=function(u){return arguments.length?(t=Array.from(u),r=Math.min(e.length,t.length-1),a):t.slice()},a.invertExtent=function(u){var o=t.indexOf(u);return[e[o-1],e[o]]},a.unknown=function(u){return arguments.length?(n=u,a):n},a.copy=function(){return $M().domain(e).range(t).unknown(n)},vr.apply(a,arguments)}const _y=new Date,ky=new Date;function Nt(e,t,n,r){function a(u){return e(u=arguments.length===0?new Date:new Date(+u)),u}return a.floor=u=>(e(u=new Date(+u)),u),a.ceil=u=>(e(u=new Date(u-1)),t(u,1),e(u),u),a.round=u=>{const o=a(u),c=a.ceil(u);return u-o<c-u?o:c},a.offset=(u,o)=>(t(u=new Date(+u),o==null?1:Math.floor(o)),u),a.range=(u,o,c)=>{const f=[];if(u=a.ceil(u),c=c==null?1:Math.floor(c),!(u<o)||!(c>0))return f;let d;do f.push(d=new Date(+u)),t(u,c),e(u);while(d<u&&u<o);return f},a.filter=u=>Nt(o=>{if(o>=o)for(;e(o),!u(o);)o.setTime(o-1)},(o,c)=>{if(o>=o)if(c<0)for(;++c<=0;)for(;t(o,-1),!u(o););else for(;--c>=0;)for(;t(o,1),!u(o););}),n&&(a.count=(u,o)=>(_y.setTime(+u),ky.setTime(+o),e(_y),e(ky),Math.floor(n(_y,ky))),a.every=u=>(u=Math.floor(u),!isFinite(u)||!(u>0)?null:u>1?a.filter(r?o=>r(o)%u===0:o=>a.count(0,o)%u===0):a)),a}const md=Nt(()=>{},(e,t)=>{e.setTime(+e+t)},(e,t)=>t-e);md.every=e=>(e=Math.floor(e),!isFinite(e)||!(e>0)?null:e>1?Nt(t=>{t.setTime(Math.floor(t/e)*e)},(t,n)=>{t.setTime(+t+n*e)},(t,n)=>(n-t)/e):md);md.range;const pi=1e3,dr=pi*60,vi=dr*60,Si=vi*24,pb=Si*7,E_=Si*30,Cy=Si*365,Va=Nt(e=>{e.setTime(e-e.getMilliseconds())},(e,t)=>{e.setTime(+e+t*pi)},(e,t)=>(t-e)/pi,e=>e.getUTCSeconds());Va.range;const vb=Nt(e=>{e.setTime(e-e.getMilliseconds()-e.getSeconds()*pi)},(e,t)=>{e.setTime(+e+t*dr)},(e,t)=>(t-e)/dr,e=>e.getMinutes());vb.range;const yb=Nt(e=>{e.setUTCSeconds(0,0)},(e,t)=>{e.setTime(+e+t*dr)},(e,t)=>(t-e)/dr,e=>e.getUTCMinutes());yb.range;const gb=Nt(e=>{e.setTime(e-e.getMilliseconds()-e.getSeconds()*pi-e.getMinutes()*dr)},(e,t)=>{e.setTime(+e+t*vi)},(e,t)=>(t-e)/vi,e=>e.getHours());gb.range;const bb=Nt(e=>{e.setUTCMinutes(0,0,0)},(e,t)=>{e.setTime(+e+t*vi)},(e,t)=>(t-e)/vi,e=>e.getUTCHours());bb.range;const Ts=Nt(e=>e.setHours(0,0,0,0),(e,t)=>e.setDate(e.getDate()+t),(e,t)=>(t-e-(t.getTimezoneOffset()-e.getTimezoneOffset())*dr)/Si,e=>e.getDate()-1);Ts.range;const ah=Nt(e=>{e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCDate(e.getUTCDate()+t)},(e,t)=>(t-e)/Si,e=>e.getUTCDate()-1);ah.range;const FM=Nt(e=>{e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCDate(e.getUTCDate()+t)},(e,t)=>(t-e)/Si,e=>Math.floor(e/Si));FM.range;function al(e){return Nt(t=>{t.setDate(t.getDate()-(t.getDay()+7-e)%7),t.setHours(0,0,0,0)},(t,n)=>{t.setDate(t.getDate()+n*7)},(t,n)=>(n-t-(n.getTimezoneOffset()-t.getTimezoneOffset())*dr)/pb)}const lh=al(0),pd=al(1),uV=al(2),oV=al(3),yu=al(4),sV=al(5),cV=al(6);lh.range;pd.range;uV.range;oV.range;yu.range;sV.range;cV.range;function ll(e){return Nt(t=>{t.setUTCDate(t.getUTCDate()-(t.getUTCDay()+7-e)%7),t.setUTCHours(0,0,0,0)},(t,n)=>{t.setUTCDate(t.getUTCDate()+n*7)},(t,n)=>(n-t)/pb)}const uh=ll(0),vd=ll(1),fV=ll(2),dV=ll(3),gu=ll(4),hV=ll(5),mV=ll(6);uh.range;vd.range;fV.range;dV.range;gu.range;hV.range;mV.range;const xb=Nt(e=>{e.setDate(1),e.setHours(0,0,0,0)},(e,t)=>{e.setMonth(e.getMonth()+t)},(e,t)=>t.getMonth()-e.getMonth()+(t.getFullYear()-e.getFullYear())*12,e=>e.getMonth());xb.range;const wb=Nt(e=>{e.setUTCDate(1),e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCMonth(e.getUTCMonth()+t)},(e,t)=>t.getUTCMonth()-e.getUTCMonth()+(t.getUTCFullYear()-e.getUTCFullYear())*12,e=>e.getUTCMonth());wb.range;const Oi=Nt(e=>{e.setMonth(0,1),e.setHours(0,0,0,0)},(e,t)=>{e.setFullYear(e.getFullYear()+t)},(e,t)=>t.getFullYear()-e.getFullYear(),e=>e.getFullYear());Oi.every=e=>!isFinite(e=Math.floor(e))||!(e>0)?null:Nt(t=>{t.setFullYear(Math.floor(t.getFullYear()/e)*e),t.setMonth(0,1),t.setHours(0,0,0,0)},(t,n)=>{t.setFullYear(t.getFullYear()+n*e)});Oi.range;const Ei=Nt(e=>{e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCFullYear(e.getUTCFullYear()+t)},(e,t)=>t.getUTCFullYear()-e.getUTCFullYear(),e=>e.getUTCFullYear());Ei.every=e=>!isFinite(e=Math.floor(e))||!(e>0)?null:Nt(t=>{t.setUTCFullYear(Math.floor(t.getUTCFullYear()/e)*e),t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)},(t,n)=>{t.setUTCFullYear(t.getUTCFullYear()+n*e)});Ei.range;function VM(e,t,n,r,a,u){const o=[[Va,1,pi],[Va,5,5*pi],[Va,15,15*pi],[Va,30,30*pi],[u,1,dr],[u,5,5*dr],[u,15,15*dr],[u,30,30*dr],[a,1,vi],[a,3,3*vi],[a,6,6*vi],[a,12,12*vi],[r,1,Si],[r,2,2*Si],[n,1,pb],[t,1,E_],[t,3,3*E_],[e,1,Cy]];function c(d,m,p){const y=m<d;y&&([d,m]=[m,d]);const g=p&&typeof p.range=="function"?p:f(d,m,p),x=g?g.range(d,+m+1):[];return y?x.reverse():x}function f(d,m,p){const y=Math.abs(m-d)/p,g=rb(([,,S])=>S).right(o,y);if(g===o.length)return e.every(Ug(d/Cy,m/Cy,p));if(g===0)return md.every(Math.max(Ug(d,m,p),1));const[x,w]=o[y/o[g-1][2]<o[g][2]/y?g-1:g];return x.every(w)}return[c,f]}const[pV,vV]=VM(Ei,wb,uh,FM,bb,yb),[yV,gV]=VM(Oi,xb,lh,Ts,gb,vb);function Ty(e){if(0<=e.y&&e.y<100){var t=new Date(-1,e.m,e.d,e.H,e.M,e.S,e.L);return t.setFullYear(e.y),t}return new Date(e.y,e.m,e.d,e.H,e.M,e.S,e.L)}function jy(e){if(0<=e.y&&e.y<100){var t=new Date(Date.UTC(-1,e.m,e.d,e.H,e.M,e.S,e.L));return t.setUTCFullYear(e.y),t}return new Date(Date.UTC(e.y,e.m,e.d,e.H,e.M,e.S,e.L))}function Ho(e,t,n){return{y:e,m:t,d:n,H:0,M:0,S:0,L:0}}function bV(e){var t=e.dateTime,n=e.date,r=e.time,a=e.periods,u=e.days,o=e.shortDays,c=e.months,f=e.shortMonths,d=$o(a),m=Fo(a),p=$o(u),y=Fo(u),g=$o(o),x=Fo(o),w=$o(c),S=Fo(c),O=$o(f),_=Fo(f),k={a:Q,A:ue,b:de,B:R,c:null,d:j_,e:j_,f:HV,g:WV,G:eY,H:BV,I:UV,j:qV,L:YM,m:$V,M:FV,p:L,q:J,Q:D_,s:N_,S:VV,u:YV,U:KV,V:GV,w:XV,W:ZV,x:null,X:null,y:QV,Y:JV,Z:tY,"%":z_},M={a:D,A:oe,b:ye,B:ve,c:null,d:M_,e:M_,f:aY,g:pY,G:yY,H:nY,I:rY,j:iY,L:GM,m:lY,M:uY,p:Se,q:ge,Q:D_,s:N_,S:oY,u:sY,U:cY,V:fY,w:dY,W:hY,x:null,X:null,y:mY,Y:vY,Z:gY,"%":z_},N={a:P,A:F,b:I,B:ee,c:Z,d:C_,e:C_,f:PV,g:k_,G:__,H:T_,I:T_,j:MV,L:NV,m:jV,M:zV,p:H,q:TV,Q:IV,s:LV,S:DV,u:EV,U:AV,V:_V,w:OV,W:kV,x:Y,X:U,y:k_,Y:__,Z:CV,"%":RV};k.x=C(n,k),k.X=C(r,k),k.c=C(t,k),M.x=C(n,M),M.X=C(r,M),M.c=C(t,M);function C(K,he){return function(be){var se=[],jt=-1,Ie=0,St=K.length,Ot,Gn,ba;for(be instanceof Date||(be=new Date(+be));++jt<St;)K.charCodeAt(jt)===37&&(se.push(K.slice(Ie,jt)),(Gn=A_[Ot=K.charAt(++jt)])!=null?Ot=K.charAt(++jt):Gn=Ot==="e"?" ":"0",(ba=he[Ot])&&(Ot=ba(be,Gn)),se.push(Ot),Ie=jt+1);return se.push(K.slice(Ie,jt)),se.join("")}}function z(K,he){return function(be){var se=Ho(1900,void 0,1),jt=$(se,K,be+="",0),Ie,St;if(jt!=be.length)return null;if("Q"in se)return new Date(se.Q);if("s"in se)return new Date(se.s*1e3+("L"in se?se.L:0));if(he&&!("Z"in se)&&(se.Z=0),"p"in se&&(se.H=se.H%12+se.p*12),se.m===void 0&&(se.m="q"in se?se.q:0),"V"in se){if(se.V<1||se.V>53)return null;"w"in se||(se.w=1),"Z"in se?(Ie=jy(Ho(se.y,0,1)),St=Ie.getUTCDay(),Ie=St>4||St===0?vd.ceil(Ie):vd(Ie),Ie=ah.offset(Ie,(se.V-1)*7),se.y=Ie.getUTCFullYear(),se.m=Ie.getUTCMonth(),se.d=Ie.getUTCDate()+(se.w+6)%7):(Ie=Ty(Ho(se.y,0,1)),St=Ie.getDay(),Ie=St>4||St===0?pd.ceil(Ie):pd(Ie),Ie=Ts.offset(Ie,(se.V-1)*7),se.y=Ie.getFullYear(),se.m=Ie.getMonth(),se.d=Ie.getDate()+(se.w+6)%7)}else("W"in se||"U"in se)&&("w"in se||(se.w="u"in se?se.u%7:"W"in se?1:0),St="Z"in se?jy(Ho(se.y,0,1)).getUTCDay():Ty(Ho(se.y,0,1)).getDay(),se.m=0,se.d="W"in se?(se.w+6)%7+se.W*7-(St+5)%7:se.w+se.U*7-(St+6)%7);return"Z"in se?(se.H+=se.Z/100|0,se.M+=se.Z%100,jy(se)):Ty(se)}}function $(K,he,be,se){for(var jt=0,Ie=he.length,St=be.length,Ot,Gn;jt<Ie;){if(se>=St)return-1;if(Ot=he.charCodeAt(jt++),Ot===37){if(Ot=he.charAt(jt++),Gn=N[Ot in A_?he.charAt(jt++):Ot],!Gn||(se=Gn(K,be,se))<0)return-1}else if(Ot!=be.charCodeAt(se++))return-1}return se}function H(K,he,be){var se=d.exec(he.slice(be));return se?(K.p=m.get(se[0].toLowerCase()),be+se[0].length):-1}function P(K,he,be){var se=g.exec(he.slice(be));return se?(K.w=x.get(se[0].toLowerCase()),be+se[0].length):-1}function F(K,he,be){var se=p.exec(he.slice(be));return se?(K.w=y.get(se[0].toLowerCase()),be+se[0].length):-1}function I(K,he,be){var se=O.exec(he.slice(be));return se?(K.m=_.get(se[0].toLowerCase()),be+se[0].length):-1}function ee(K,he,be){var se=w.exec(he.slice(be));return se?(K.m=S.get(se[0].toLowerCase()),be+se[0].length):-1}function Z(K,he,be){return $(K,t,he,be)}function Y(K,he,be){return $(K,n,he,be)}function U(K,he,be){return $(K,r,he,be)}function Q(K){return o[K.getDay()]}function ue(K){return u[K.getDay()]}function de(K){return f[K.getMonth()]}function R(K){return c[K.getMonth()]}function L(K){return a[+(K.getHours()>=12)]}function J(K){return 1+~~(K.getMonth()/3)}function D(K){return o[K.getUTCDay()]}function oe(K){return u[K.getUTCDay()]}function ye(K){return f[K.getUTCMonth()]}function ve(K){return c[K.getUTCMonth()]}function Se(K){return a[+(K.getUTCHours()>=12)]}function ge(K){return 1+~~(K.getUTCMonth()/3)}return{format:function(K){var he=C(K+="",k);return he.toString=function(){return K},he},parse:function(K){var he=z(K+="",!1);return he.toString=function(){return K},he},utcFormat:function(K){var he=C(K+="",M);return he.toString=function(){return K},he},utcParse:function(K){var he=z(K+="",!0);return he.toString=function(){return K},he}}}var A_={"-":"",_:" ",0:"0"},$t=/^\s*\d+/,xV=/^%/,wV=/[\\^$*+?|[\]().{}]/g;function Ve(e,t,n){var r=e<0?"-":"",a=(r?-e:e)+"",u=a.length;return r+(u<n?new Array(n-u+1).join(t)+a:a)}function SV(e){return e.replace(wV,"\\$&")}function $o(e){return new RegExp("^(?:"+e.map(SV).join("|")+")","i")}function Fo(e){return new Map(e.map((t,n)=>[t.toLowerCase(),n]))}function OV(e,t,n){var r=$t.exec(t.slice(n,n+1));return r?(e.w=+r[0],n+r[0].length):-1}function EV(e,t,n){var r=$t.exec(t.slice(n,n+1));return r?(e.u=+r[0],n+r[0].length):-1}function AV(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.U=+r[0],n+r[0].length):-1}function _V(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.V=+r[0],n+r[0].length):-1}function kV(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.W=+r[0],n+r[0].length):-1}function __(e,t,n){var r=$t.exec(t.slice(n,n+4));return r?(e.y=+r[0],n+r[0].length):-1}function k_(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.y=+r[0]+(+r[0]>68?1900:2e3),n+r[0].length):-1}function CV(e,t,n){var r=/^(Z)|([+-]\d\d)(?::?(\d\d))?/.exec(t.slice(n,n+6));return r?(e.Z=r[1]?0:-(r[2]+(r[3]||"00")),n+r[0].length):-1}function TV(e,t,n){var r=$t.exec(t.slice(n,n+1));return r?(e.q=r[0]*3-3,n+r[0].length):-1}function jV(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.m=r[0]-1,n+r[0].length):-1}function C_(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.d=+r[0],n+r[0].length):-1}function MV(e,t,n){var r=$t.exec(t.slice(n,n+3));return r?(e.m=0,e.d=+r[0],n+r[0].length):-1}function T_(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.H=+r[0],n+r[0].length):-1}function zV(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.M=+r[0],n+r[0].length):-1}function DV(e,t,n){var r=$t.exec(t.slice(n,n+2));return r?(e.S=+r[0],n+r[0].length):-1}function NV(e,t,n){var r=$t.exec(t.slice(n,n+3));return r?(e.L=+r[0],n+r[0].length):-1}function PV(e,t,n){var r=$t.exec(t.slice(n,n+6));return r?(e.L=Math.floor(r[0]/1e3),n+r[0].length):-1}function RV(e,t,n){var r=xV.exec(t.slice(n,n+1));return r?n+r[0].length:-1}function IV(e,t,n){var r=$t.exec(t.slice(n));return r?(e.Q=+r[0],n+r[0].length):-1}function LV(e,t,n){var r=$t.exec(t.slice(n));return r?(e.s=+r[0],n+r[0].length):-1}function j_(e,t){return Ve(e.getDate(),t,2)}function BV(e,t){return Ve(e.getHours(),t,2)}function UV(e,t){return Ve(e.getHours()%12||12,t,2)}function qV(e,t){return Ve(1+Ts.count(Oi(e),e),t,3)}function YM(e,t){return Ve(e.getMilliseconds(),t,3)}function HV(e,t){return YM(e,t)+"000"}function $V(e,t){return Ve(e.getMonth()+1,t,2)}function FV(e,t){return Ve(e.getMinutes(),t,2)}function VV(e,t){return Ve(e.getSeconds(),t,2)}function YV(e){var t=e.getDay();return t===0?7:t}function KV(e,t){return Ve(lh.count(Oi(e)-1,e),t,2)}function KM(e){var t=e.getDay();return t>=4||t===0?yu(e):yu.ceil(e)}function GV(e,t){return e=KM(e),Ve(yu.count(Oi(e),e)+(Oi(e).getDay()===4),t,2)}function XV(e){return e.getDay()}function ZV(e,t){return Ve(pd.count(Oi(e)-1,e),t,2)}function QV(e,t){return Ve(e.getFullYear()%100,t,2)}function WV(e,t){return e=KM(e),Ve(e.getFullYear()%100,t,2)}function JV(e,t){return Ve(e.getFullYear()%1e4,t,4)}function eY(e,t){var n=e.getDay();return e=n>=4||n===0?yu(e):yu.ceil(e),Ve(e.getFullYear()%1e4,t,4)}function tY(e){var t=e.getTimezoneOffset();return(t>0?"-":(t*=-1,"+"))+Ve(t/60|0,"0",2)+Ve(t%60,"0",2)}function M_(e,t){return Ve(e.getUTCDate(),t,2)}function nY(e,t){return Ve(e.getUTCHours(),t,2)}function rY(e,t){return Ve(e.getUTCHours()%12||12,t,2)}function iY(e,t){return Ve(1+ah.count(Ei(e),e),t,3)}function GM(e,t){return Ve(e.getUTCMilliseconds(),t,3)}function aY(e,t){return GM(e,t)+"000"}function lY(e,t){return Ve(e.getUTCMonth()+1,t,2)}function uY(e,t){return Ve(e.getUTCMinutes(),t,2)}function oY(e,t){return Ve(e.getUTCSeconds(),t,2)}function sY(e){var t=e.getUTCDay();return t===0?7:t}function cY(e,t){return Ve(uh.count(Ei(e)-1,e),t,2)}function XM(e){var t=e.getUTCDay();return t>=4||t===0?gu(e):gu.ceil(e)}function fY(e,t){return e=XM(e),Ve(gu.count(Ei(e),e)+(Ei(e).getUTCDay()===4),t,2)}function dY(e){return e.getUTCDay()}function hY(e,t){return Ve(vd.count(Ei(e)-1,e),t,2)}function mY(e,t){return Ve(e.getUTCFullYear()%100,t,2)}function pY(e,t){return e=XM(e),Ve(e.getUTCFullYear()%100,t,2)}function vY(e,t){return Ve(e.getUTCFullYear()%1e4,t,4)}function yY(e,t){var n=e.getUTCDay();return e=n>=4||n===0?gu(e):gu.ceil(e),Ve(e.getUTCFullYear()%1e4,t,4)}function gY(){return"+0000"}function z_(){return"%"}function D_(e){return+e}function N_(e){return Math.floor(+e/1e3)}var Jl,ZM,QM;bY({dateTime:"%x, %X",date:"%-m/%-d/%Y",time:"%-I:%M:%S %p",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});function bY(e){return Jl=bV(e),ZM=Jl.format,Jl.parse,QM=Jl.utcFormat,Jl.utcParse,Jl}function xY(e){return new Date(e)}function wY(e){return e instanceof Date?+e:+new Date(+e)}function Sb(e,t,n,r,a,u,o,c,f,d){var m=ob(),p=m.invert,y=m.domain,g=d(".%L"),x=d(":%S"),w=d("%I:%M"),S=d("%I %p"),O=d("%a %d"),_=d("%b %d"),k=d("%B"),M=d("%Y");function N(C){return(f(C)<C?g:c(C)<C?x:o(C)<C?w:u(C)<C?S:r(C)<C?a(C)<C?O:_:n(C)<C?k:M)(C)}return m.invert=function(C){return new Date(p(C))},m.domain=function(C){return arguments.length?y(Array.from(C,wY)):y().map(xY)},m.ticks=function(C){var z=y();return e(z[0],z[z.length-1],C??10)},m.tickFormat=function(C,z){return z==null?N:d(z)},m.nice=function(C){var z=y();return(!C||typeof C.range!="function")&&(C=t(z[0],z[z.length-1],C??10)),C?y(IM(z,C)):m},m.copy=function(){return Cs(m,Sb(e,t,n,r,a,u,o,c,f,d))},m}function SY(){return vr.apply(Sb(yV,gV,Oi,xb,lh,Ts,gb,vb,Va,ZM).domain([new Date(2e3,0,1),new Date(2e3,0,2)]),arguments)}function OY(){return vr.apply(Sb(pV,vV,Ei,wb,uh,ah,bb,yb,Va,QM).domain([Date.UTC(2e3,0,1),Date.UTC(2e3,0,2)]),arguments)}function oh(){var e=0,t=1,n,r,a,u,o=hn,c=!1,f;function d(p){return p==null||isNaN(p=+p)?f:o(a===0?.5:(p=(u(p)-n)*a,c?Math.max(0,Math.min(1,p)):p))}d.domain=function(p){return arguments.length?([e,t]=p,n=u(e=+e),r=u(t=+t),a=n===r?0:1/(r-n),d):[e,t]},d.clamp=function(p){return arguments.length?(c=!!p,d):c},d.interpolator=function(p){return arguments.length?(o=p,d):o};function m(p){return function(y){var g,x;return arguments.length?([g,x]=y,o=p(g,x),d):[o(0),o(1)]}}return d.range=m(ku),d.rangeRound=m(ub),d.unknown=function(p){return arguments.length?(f=p,d):f},function(p){return u=p,n=p(e),r=p(t),a=n===r?0:1/(r-n),d}}function ga(e,t){return t.domain(e.domain()).interpolator(e.interpolator()).clamp(e.clamp()).unknown(e.unknown())}function WM(){var e=ya(oh()(hn));return e.copy=function(){return ga(e,WM())},Mi.apply(e,arguments)}function JM(){var e=fb(oh()).domain([1,10]);return e.copy=function(){return ga(e,JM()).base(e.base())},Mi.apply(e,arguments)}function ez(){var e=db(oh());return e.copy=function(){return ga(e,ez()).constant(e.constant())},Mi.apply(e,arguments)}function Ob(){var e=hb(oh());return e.copy=function(){return ga(e,Ob()).exponent(e.exponent())},Mi.apply(e,arguments)}function EY(){return Ob.apply(null,arguments).exponent(.5)}function tz(){var e=[],t=hn;function n(r){if(r!=null&&!isNaN(r=+r))return t((_s(e,r,1)-1)/(e.length-1))}return n.domain=function(r){if(!arguments.length)return e.slice();e=[];for(let a of r)a!=null&&!isNaN(a=+a)&&e.push(a);return e.sort(ha),n},n.interpolator=function(r){return arguments.length?(t=r,n):t},n.range=function(){return e.map((r,a)=>t(a/(e.length-1)))},n.quantiles=function(r){return Array.from({length:r+1},(a,u)=>cF(e,u/r))},n.copy=function(){return tz(t).domain(e)},Mi.apply(n,arguments)}function sh(){var e=0,t=.5,n=1,r=1,a,u,o,c,f,d=hn,m,p=!1,y;function g(w){return isNaN(w=+w)?y:(w=.5+((w=+m(w))-u)*(r*w<r*u?c:f),d(p?Math.max(0,Math.min(1,w)):w))}g.domain=function(w){return arguments.length?([e,t,n]=w,a=m(e=+e),u=m(t=+t),o=m(n=+n),c=a===u?0:.5/(u-a),f=u===o?0:.5/(o-u),r=u<a?-1:1,g):[e,t,n]},g.clamp=function(w){return arguments.length?(p=!!w,g):p},g.interpolator=function(w){return arguments.length?(d=w,g):d};function x(w){return function(S){var O,_,k;return arguments.length?([O,_,k]=S,d=RF(w,[O,_,k]),g):[d(0),d(.5),d(1)]}}return g.range=x(ku),g.rangeRound=x(ub),g.unknown=function(w){return arguments.length?(y=w,g):y},function(w){return m=w,a=w(e),u=w(t),o=w(n),c=a===u?0:.5/(u-a),f=u===o?0:.5/(o-u),r=u<a?-1:1,g}}function nz(){var e=ya(sh()(hn));return e.copy=function(){return ga(e,nz())},Mi.apply(e,arguments)}function rz(){var e=fb(sh()).domain([.1,1,10]);return e.copy=function(){return ga(e,rz()).base(e.base())},Mi.apply(e,arguments)}function iz(){var e=db(sh());return e.copy=function(){return ga(e,iz()).constant(e.constant())},Mi.apply(e,arguments)}function Eb(){var e=hb(sh());return e.copy=function(){return ga(e,Eb()).exponent(e.exponent())},Mi.apply(e,arguments)}function AY(){return Eb.apply(null,arguments).exponent(.5)}const Ko=Object.freeze(Object.defineProperty({__proto__:null,scaleBand:ab,scaleDiverging:nz,scaleDivergingLog:rz,scaleDivergingPow:Eb,scaleDivergingSqrt:AY,scaleDivergingSymlog:iz,scaleIdentity:RM,scaleImplicit:qg,scaleLinear:PM,scaleLog:LM,scaleOrdinal:ib,scalePoint:hF,scalePow:mb,scaleQuantile:qM,scaleQuantize:HM,scaleRadial:UM,scaleSequential:WM,scaleSequentialLog:JM,scaleSequentialPow:Ob,scaleSequentialQuantile:tz,scaleSequentialSqrt:EY,scaleSequentialSymlog:ez,scaleSqrt:aV,scaleSymlog:BM,scaleThreshold:$M,scaleTime:SY,scaleUtc:OY,tickFormat:NM},Symbol.toStringTag,{value:"Module"}));var zi=e=>e.chartData,az=te([zi],e=>{var t=e.chartData!=null?e.chartData.length-1:0;return{chartData:e.chartData,computedData:e.computedData,dataEndIndex:t,dataStartIndex:0}}),lz=(e,t,n,r)=>r?az(e):zi(e),_Y=(e,t,n)=>n?az(e):zi(e);function Ai(e){if(Array.isArray(e)&&e.length===2){var[t,n]=e;if(qe(t)&&qe(n))return!0}return!1}function P_(e,t,n){return n?e:[Math.min(e[0],t[0]),Math.max(e[1],t[1])]}function uz(e,t){if(t&&typeof e!="function"&&Array.isArray(e)&&e.length===2){var[n,r]=e,a,u;if(qe(n))a=n;else if(typeof n=="function")return;if(qe(r))u=r;else if(typeof r=="function")return;var o=[a,u];if(Ai(o))return o}}function kY(e,t,n){if(!(!n&&t==null)){if(typeof e=="function"&&t!=null)try{var r=e(t,n);if(Ai(r))return P_(r,t,n)}catch{}if(Array.isArray(e)&&e.length===2){var[a,u]=e,o,c;if(a==="auto")t!=null&&(o=Math.min(...t));else if(we(a))o=a;else if(typeof a=="function")try{t!=null&&(o=a(t==null?void 0:t[0]))}catch{}else if(typeof a=="string"&&KA.test(a)){var f=KA.exec(a);if(f==null||f[1]==null||t==null)o=void 0;else{var d=+f[1];o=t[0]-d}}else o=t==null?void 0:t[0];if(u==="auto")t!=null&&(c=Math.max(...t));else if(we(u))c=u;else if(typeof u=="function")try{t!=null&&(c=u(t==null?void 0:t[1]))}catch{}else if(typeof u=="string"&&GA.test(u)){var m=GA.exec(u);if(m==null||m[1]==null||t==null)c=void 0;else{var p=+m[1];c=t[1]+p}}else c=t==null?void 0:t[1];var y=[o,c];if(Ai(y))return t==null?y:P_(y,t,n)}}}var Cu=1e9,CY={precision:20,rounding:4,toExpNeg:-7,toExpPos:21,LN10:"2.302585092994045684017991454684364207601101488628772976033327900967572609677352480235997205089598298341967784042286"},_b,mt=!0,pr="[DecimalError] ",Xa=pr+"Invalid argument: ",Ab=pr+"Exponent out of range: ",Tu=Math.floor,Ha=Math.pow,TY=/^(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i,Hn,Ut=1e7,ct=7,oz=9007199254740991,yd=Tu(oz/ct),me={};me.absoluteValue=me.abs=function(){var e=new this.constructor(this);return e.s&&(e.s=1),e};me.comparedTo=me.cmp=function(e){var t,n,r,a,u=this;if(e=new u.constructor(e),u.s!==e.s)return u.s||-e.s;if(u.e!==e.e)return u.e>e.e^u.s<0?1:-1;for(r=u.d.length,a=e.d.length,t=0,n=r<a?r:a;t<n;++t)if(u.d[t]!==e.d[t])return u.d[t]>e.d[t]^u.s<0?1:-1;return r===a?0:r>a^u.s<0?1:-1};me.decimalPlaces=me.dp=function(){var e=this,t=e.d.length-1,n=(t-e.e)*ct;if(t=e.d[t],t)for(;t%10==0;t/=10)n--;return n<0?0:n};me.dividedBy=me.div=function(e){return yi(this,new this.constructor(e))};me.dividedToIntegerBy=me.idiv=function(e){var t=this,n=t.constructor;return rt(yi(t,new n(e),0,1),n.precision)};me.equals=me.eq=function(e){return!this.cmp(e)};me.exponent=function(){return Tt(this)};me.greaterThan=me.gt=function(e){return this.cmp(e)>0};me.greaterThanOrEqualTo=me.gte=function(e){return this.cmp(e)>=0};me.isInteger=me.isint=function(){return this.e>this.d.length-2};me.isNegative=me.isneg=function(){return this.s<0};me.isPositive=me.ispos=function(){return this.s>0};me.isZero=function(){return this.s===0};me.lessThan=me.lt=function(e){return this.cmp(e)<0};me.lessThanOrEqualTo=me.lte=function(e){return this.cmp(e)<1};me.logarithm=me.log=function(e){var t,n=this,r=n.constructor,a=r.precision,u=a+5;if(e===void 0)e=new r(10);else if(e=new r(e),e.s<1||e.eq(Hn))throw Error(pr+"NaN");if(n.s<1)throw Error(pr+(n.s?"NaN":"-Infinity"));return n.eq(Hn)?new r(0):(mt=!1,t=yi(hs(n,u),hs(e,u),u),mt=!0,rt(t,a))};me.minus=me.sub=function(e){var t=this;return e=new t.constructor(e),t.s==e.s?fz(t,e):sz(t,(e.s=-e.s,e))};me.modulo=me.mod=function(e){var t,n=this,r=n.constructor,a=r.precision;if(e=new r(e),!e.s)throw Error(pr+"NaN");return n.s?(mt=!1,t=yi(n,e,0,1).times(e),mt=!0,n.minus(t)):rt(new r(n),a)};me.naturalExponential=me.exp=function(){return cz(this)};me.naturalLogarithm=me.ln=function(){return hs(this)};me.negated=me.neg=function(){var e=new this.constructor(this);return e.s=-e.s||0,e};me.plus=me.add=function(e){var t=this;return e=new t.constructor(e),t.s==e.s?sz(t,e):fz(t,(e.s=-e.s,e))};me.precision=me.sd=function(e){var t,n,r,a=this;if(e!==void 0&&e!==!!e&&e!==1&&e!==0)throw Error(Xa+e);if(t=Tt(a)+1,r=a.d.length-1,n=r*ct+1,r=a.d[r],r){for(;r%10==0;r/=10)n--;for(r=a.d[0];r>=10;r/=10)n++}return e&&t>n?t:n};me.squareRoot=me.sqrt=function(){var e,t,n,r,a,u,o,c=this,f=c.constructor;if(c.s<1){if(!c.s)return new f(0);throw Error(pr+"NaN")}for(e=Tt(c),mt=!1,a=Math.sqrt(+c),a==0||a==1/0?(t=qr(c.d),(t.length+e)%2==0&&(t+="0"),a=Math.sqrt(t),e=Tu((e+1)/2)-(e<0||e%2),a==1/0?t="5e"+e:(t=a.toExponential(),t=t.slice(0,t.indexOf("e")+1)+e),r=new f(t)):r=new f(a.toString()),n=f.precision,a=o=n+3;;)if(u=r,r=u.plus(yi(c,u,o+2)).times(.5),qr(u.d).slice(0,o)===(t=qr(r.d)).slice(0,o)){if(t=t.slice(o-3,o+1),a==o&&t=="4999"){if(rt(u,n+1,0),u.times(u).eq(c)){r=u;break}}else if(t!="9999")break;o+=4}return mt=!0,rt(r,n)};me.times=me.mul=function(e){var t,n,r,a,u,o,c,f,d,m=this,p=m.constructor,y=m.d,g=(e=new p(e)).d;if(!m.s||!e.s)return new p(0);for(e.s*=m.s,n=m.e+e.e,f=y.length,d=g.length,f<d&&(u=y,y=g,g=u,o=f,f=d,d=o),u=[],o=f+d,r=o;r--;)u.push(0);for(r=d;--r>=0;){for(t=0,a=f+r;a>r;)c=u[a]+g[r]*y[a-r-1]+t,u[a--]=c%Ut|0,t=c/Ut|0;u[a]=(u[a]+t)%Ut|0}for(;!u[--o];)u.pop();return t?++n:u.shift(),e.d=u,e.e=n,mt?rt(e,p.precision):e};me.toDecimalPlaces=me.todp=function(e,t){var n=this,r=n.constructor;return n=new r(n),e===void 0?n:(Yr(e,0,Cu),t===void 0?t=r.rounding:Yr(t,0,8),rt(n,e+Tt(n)+1,t))};me.toExponential=function(e,t){var n,r=this,a=r.constructor;return e===void 0?n=nl(r,!0):(Yr(e,0,Cu),t===void 0?t=a.rounding:Yr(t,0,8),r=rt(new a(r),e+1,t),n=nl(r,!0,e+1)),n};me.toFixed=function(e,t){var n,r,a=this,u=a.constructor;return e===void 0?nl(a):(Yr(e,0,Cu),t===void 0?t=u.rounding:Yr(t,0,8),r=rt(new u(a),e+Tt(a)+1,t),n=nl(r.abs(),!1,e+Tt(r)+1),a.isneg()&&!a.isZero()?"-"+n:n)};me.toInteger=me.toint=function(){var e=this,t=e.constructor;return rt(new t(e),Tt(e)+1,t.rounding)};me.toNumber=function(){return+this};me.toPower=me.pow=function(e){var t,n,r,a,u,o,c=this,f=c.constructor,d=12,m=+(e=new f(e));if(!e.s)return new f(Hn);if(c=new f(c),!c.s){if(e.s<1)throw Error(pr+"Infinity");return c}if(c.eq(Hn))return c;if(r=f.precision,e.eq(Hn))return rt(c,r);if(t=e.e,n=e.d.length-1,o=t>=n,u=c.s,o){if((n=m<0?-m:m)<=oz){for(a=new f(Hn),t=Math.ceil(r/ct+4),mt=!1;n%2&&(a=a.times(c),I_(a.d,t)),n=Tu(n/2),n!==0;)c=c.times(c),I_(c.d,t);return mt=!0,e.s<0?new f(Hn).div(a):rt(a,r)}}else if(u<0)throw Error(pr+"NaN");return u=u<0&&e.d[Math.max(t,n)]&1?-1:1,c.s=1,mt=!1,a=e.times(hs(c,r+d)),mt=!0,a=cz(a),a.s=u,a};me.toPrecision=function(e,t){var n,r,a=this,u=a.constructor;return e===void 0?(n=Tt(a),r=nl(a,n<=u.toExpNeg||n>=u.toExpPos)):(Yr(e,1,Cu),t===void 0?t=u.rounding:Yr(t,0,8),a=rt(new u(a),e,t),n=Tt(a),r=nl(a,e<=n||n<=u.toExpNeg,e)),r};me.toSignificantDigits=me.tosd=function(e,t){var n=this,r=n.constructor;return e===void 0?(e=r.precision,t=r.rounding):(Yr(e,1,Cu),t===void 0?t=r.rounding:Yr(t,0,8)),rt(new r(n),e,t)};me.toString=me.valueOf=me.val=me.toJSON=me[Symbol.for("nodejs.util.inspect.custom")]=function(){var e=this,t=Tt(e),n=e.constructor;return nl(e,t<=n.toExpNeg||t>=n.toExpPos)};function sz(e,t){var n,r,a,u,o,c,f,d,m=e.constructor,p=m.precision;if(!e.s||!t.s)return t.s||(t=new m(e)),mt?rt(t,p):t;if(f=e.d,d=t.d,o=e.e,a=t.e,f=f.slice(),u=o-a,u){for(u<0?(r=f,u=-u,c=d.length):(r=d,a=o,c=f.length),o=Math.ceil(p/ct),c=o>c?o+1:c+1,u>c&&(u=c,r.length=1),r.reverse();u--;)r.push(0);r.reverse()}for(c=f.length,u=d.length,c-u<0&&(u=c,r=d,d=f,f=r),n=0;u;)n=(f[--u]=f[u]+d[u]+n)/Ut|0,f[u]%=Ut;for(n&&(f.unshift(n),++a),c=f.length;f[--c]==0;)f.pop();return t.d=f,t.e=a,mt?rt(t,p):t}function Yr(e,t,n){if(e!==~~e||e<t||e>n)throw Error(Xa+e)}function qr(e){var t,n,r,a=e.length-1,u="",o=e[0];if(a>0){for(u+=o,t=1;t<a;t++)r=e[t]+"",n=ct-r.length,n&&(u+=sa(n)),u+=r;o=e[t],r=o+"",n=ct-r.length,n&&(u+=sa(n))}else if(o===0)return"0";for(;o%10===0;)o/=10;return u+o}var yi=(function(){function e(r,a){var u,o=0,c=r.length;for(r=r.slice();c--;)u=r[c]*a+o,r[c]=u%Ut|0,o=u/Ut|0;return o&&r.unshift(o),r}function t(r,a,u,o){var c,f;if(u!=o)f=u>o?1:-1;else for(c=f=0;c<u;c++)if(r[c]!=a[c]){f=r[c]>a[c]?1:-1;break}return f}function n(r,a,u){for(var o=0;u--;)r[u]-=o,o=r[u]<a[u]?1:0,r[u]=o*Ut+r[u]-a[u];for(;!r[0]&&r.length>1;)r.shift()}return function(r,a,u,o){var c,f,d,m,p,y,g,x,w,S,O,_,k,M,N,C,z,$,H=r.constructor,P=r.s==a.s?1:-1,F=r.d,I=a.d;if(!r.s)return new H(r);if(!a.s)throw Error(pr+"Division by zero");for(f=r.e-a.e,z=I.length,N=F.length,g=new H(P),x=g.d=[],d=0;I[d]==(F[d]||0);)++d;if(I[d]>(F[d]||0)&&--f,u==null?_=u=H.precision:o?_=u+(Tt(r)-Tt(a))+1:_=u,_<0)return new H(0);if(_=_/ct+2|0,d=0,z==1)for(m=0,I=I[0],_++;(d<N||m)&&_--;d++)k=m*Ut+(F[d]||0),x[d]=k/I|0,m=k%I|0;else{for(m=Ut/(I[0]+1)|0,m>1&&(I=e(I,m),F=e(F,m),z=I.length,N=F.length),M=z,w=F.slice(0,z),S=w.length;S<z;)w[S++]=0;$=I.slice(),$.unshift(0),C=I[0],I[1]>=Ut/2&&++C;do m=0,c=t(I,w,z,S),c<0?(O=w[0],z!=S&&(O=O*Ut+(w[1]||0)),m=O/C|0,m>1?(m>=Ut&&(m=Ut-1),p=e(I,m),y=p.length,S=w.length,c=t(p,w,y,S),c==1&&(m--,n(p,z<y?$:I,y))):(m==0&&(c=m=1),p=I.slice()),y=p.length,y<S&&p.unshift(0),n(w,p,S),c==-1&&(S=w.length,c=t(I,w,z,S),c<1&&(m++,n(w,z<S?$:I,S))),S=w.length):c===0&&(m++,w=[0]),x[d++]=m,c&&w[0]?w[S++]=F[M]||0:(w=[F[M]],S=1);while((M++<N||w[0]!==void 0)&&_--)}return x[0]||x.shift(),g.e=f,rt(g,o?u+Tt(g)+1:u)}})();function cz(e,t){var n,r,a,u,o,c,f=0,d=0,m=e.constructor,p=m.precision;if(Tt(e)>16)throw Error(Ab+Tt(e));if(!e.s)return new m(Hn);for(mt=!1,c=p,o=new m(.03125);e.abs().gte(.1);)e=e.times(o),d+=5;for(r=Math.log(Ha(2,d))/Math.LN10*2+5|0,c+=r,n=a=u=new m(Hn),m.precision=c;;){if(a=rt(a.times(e),c),n=n.times(++f),o=u.plus(yi(a,n,c)),qr(o.d).slice(0,c)===qr(u.d).slice(0,c)){for(;d--;)u=rt(u.times(u),c);return m.precision=p,t==null?(mt=!0,rt(u,p)):u}u=o}}function Tt(e){for(var t=e.e*ct,n=e.d[0];n>=10;n/=10)t++;return t}function My(e,t,n){if(t>e.LN10.sd())throw mt=!0,n&&(e.precision=n),Error(pr+"LN10 precision limit exceeded");return rt(new e(e.LN10),t)}function sa(e){for(var t="";e--;)t+="0";return t}function hs(e,t){var n,r,a,u,o,c,f,d,m,p=1,y=10,g=e,x=g.d,w=g.constructor,S=w.precision;if(g.s<1)throw Error(pr+(g.s?"NaN":"-Infinity"));if(g.eq(Hn))return new w(0);if(t==null?(mt=!1,d=S):d=t,g.eq(10))return t==null&&(mt=!0),My(w,d);if(d+=y,w.precision=d,n=qr(x),r=n.charAt(0),u=Tt(g),Math.abs(u)<15e14){for(;r<7&&r!=1||r==1&&n.charAt(1)>3;)g=g.times(e),n=qr(g.d),r=n.charAt(0),p++;u=Tt(g),r>1?(g=new w("0."+n),u++):g=new w(r+"."+n.slice(1))}else return f=My(w,d+2,S).times(u+""),g=hs(new w(r+"."+n.slice(1)),d-y).plus(f),w.precision=S,t==null?(mt=!0,rt(g,S)):g;for(c=o=g=yi(g.minus(Hn),g.plus(Hn),d),m=rt(g.times(g),d),a=3;;){if(o=rt(o.times(m),d),f=c.plus(yi(o,new w(a),d)),qr(f.d).slice(0,d)===qr(c.d).slice(0,d))return c=c.times(2),u!==0&&(c=c.plus(My(w,d+2,S).times(u+""))),c=yi(c,new w(p),d),w.precision=S,t==null?(mt=!0,rt(c,S)):c;c=f,a+=2}}function R_(e,t){var n,r,a;for((n=t.indexOf("."))>-1&&(t=t.replace(".","")),(r=t.search(/e/i))>0?(n<0&&(n=r),n+=+t.slice(r+1),t=t.substring(0,r)):n<0&&(n=t.length),r=0;t.charCodeAt(r)===48;)++r;for(a=t.length;t.charCodeAt(a-1)===48;)--a;if(t=t.slice(r,a),t){if(a-=r,n=n-r-1,e.e=Tu(n/ct),e.d=[],r=(n+1)%ct,n<0&&(r+=ct),r<a){for(r&&e.d.push(+t.slice(0,r)),a-=ct;r<a;)e.d.push(+t.slice(r,r+=ct));t=t.slice(r),r=ct-t.length}else r-=a;for(;r--;)t+="0";if(e.d.push(+t),mt&&(e.e>yd||e.e<-yd))throw Error(Ab+n)}else e.s=0,e.e=0,e.d=[0];return e}function rt(e,t,n){var r,a,u,o,c,f,d,m,p=e.d;for(o=1,u=p[0];u>=10;u/=10)o++;if(r=t-o,r<0)r+=ct,a=t,d=p[m=0];else{if(m=Math.ceil((r+1)/ct),u=p.length,m>=u)return e;for(d=u=p[m],o=1;u>=10;u/=10)o++;r%=ct,a=r-ct+o}if(n!==void 0&&(u=Ha(10,o-a-1),c=d/u%10|0,f=t<0||p[m+1]!==void 0||d%u,f=n<4?(c||f)&&(n==0||n==(e.s<0?3:2)):c>5||c==5&&(n==4||f||n==6&&(r>0?a>0?d/Ha(10,o-a):0:p[m-1])%10&1||n==(e.s<0?8:7))),t<1||!p[0])return f?(u=Tt(e),p.length=1,t=t-u-1,p[0]=Ha(10,(ct-t%ct)%ct),e.e=Tu(-t/ct)||0):(p.length=1,p[0]=e.e=e.s=0),e;if(r==0?(p.length=m,u=1,m--):(p.length=m+1,u=Ha(10,ct-r),p[m]=a>0?(d/Ha(10,o-a)%Ha(10,a)|0)*u:0),f)for(;;)if(m==0){(p[0]+=u)==Ut&&(p[0]=1,++e.e);break}else{if(p[m]+=u,p[m]!=Ut)break;p[m--]=0,u=1}for(r=p.length;p[--r]===0;)p.pop();if(mt&&(e.e>yd||e.e<-yd))throw Error(Ab+Tt(e));return e}function fz(e,t){var n,r,a,u,o,c,f,d,m,p,y=e.constructor,g=y.precision;if(!e.s||!t.s)return t.s?t.s=-t.s:t=new y(e),mt?rt(t,g):t;if(f=e.d,p=t.d,r=t.e,d=e.e,f=f.slice(),o=d-r,o){for(m=o<0,m?(n=f,o=-o,c=p.length):(n=p,r=d,c=f.length),a=Math.max(Math.ceil(g/ct),c)+2,o>a&&(o=a,n.length=1),n.reverse(),a=o;a--;)n.push(0);n.reverse()}else{for(a=f.length,c=p.length,m=a<c,m&&(c=a),a=0;a<c;a++)if(f[a]!=p[a]){m=f[a]<p[a];break}o=0}for(m&&(n=f,f=p,p=n,t.s=-t.s),c=f.length,a=p.length-c;a>0;--a)f[c++]=0;for(a=p.length;a>o;){if(f[--a]<p[a]){for(u=a;u&&f[--u]===0;)f[u]=Ut-1;--f[u],f[a]+=Ut}f[a]-=p[a]}for(;f[--c]===0;)f.pop();for(;f[0]===0;f.shift())--r;return f[0]?(t.d=f,t.e=r,mt?rt(t,g):t):new y(0)}function nl(e,t,n){var r,a=Tt(e),u=qr(e.d),o=u.length;return t?(n&&(r=n-o)>0?u=u.charAt(0)+"."+u.slice(1)+sa(r):o>1&&(u=u.charAt(0)+"."+u.slice(1)),u=u+(a<0?"e":"e+")+a):a<0?(u="0."+sa(-a-1)+u,n&&(r=n-o)>0&&(u+=sa(r))):a>=o?(u+=sa(a+1-o),n&&(r=n-a-1)>0&&(u=u+"."+sa(r))):((r=a+1)<o&&(u=u.slice(0,r)+"."+u.slice(r)),n&&(r=n-o)>0&&(a+1===o&&(u+="."),u+=sa(r))),e.s<0?"-"+u:u}function I_(e,t){if(e.length>t)return e.length=t,!0}function dz(e){var t,n,r;function a(u){var o=this;if(!(o instanceof a))return new a(u);if(o.constructor=a,u instanceof a){o.s=u.s,o.e=u.e,o.d=(u=u.d)?u.slice():u;return}if(typeof u=="number"){if(u*0!==0)throw Error(Xa+u);if(u>0)o.s=1;else if(u<0)u=-u,o.s=-1;else{o.s=0,o.e=0,o.d=[0];return}if(u===~~u&&u<1e7){o.e=0,o.d=[u];return}return R_(o,u.toString())}else if(typeof u!="string")throw Error(Xa+u);if(u.charCodeAt(0)===45?(u=u.slice(1),o.s=-1):o.s=1,TY.test(u))R_(o,u);else throw Error(Xa+u)}if(a.prototype=me,a.ROUND_UP=0,a.ROUND_DOWN=1,a.ROUND_CEIL=2,a.ROUND_FLOOR=3,a.ROUND_HALF_UP=4,a.ROUND_HALF_DOWN=5,a.ROUND_HALF_EVEN=6,a.ROUND_HALF_CEIL=7,a.ROUND_HALF_FLOOR=8,a.clone=dz,a.config=a.set=jY,e===void 0&&(e={}),e)for(r=["precision","rounding","toExpNeg","toExpPos","LN10"],t=0;t<r.length;)e.hasOwnProperty(n=r[t++])||(e[n]=this[n]);return a.config(e),a}function jY(e){if(!e||typeof e!="object")throw Error(pr+"Object expected");var t,n,r,a=["precision",1,Cu,"rounding",0,8,"toExpNeg",-1/0,0,"toExpPos",0,1/0];for(t=0;t<a.length;t+=3)if((r=e[n=a[t]])!==void 0)if(Tu(r)===r&&r>=a[t+1]&&r<=a[t+2])this[n]=r;else throw Error(Xa+n+": "+r);if((r=e[n="LN10"])!==void 0)if(r==Math.LN10)this[n]=new this(r);else throw Error(Xa+n+": "+r);return this}var _b=dz(CY);Hn=new _b(1);const Ze=_b;function hz(e){var t;return e===0?t=1:t=Math.floor(new Ze(e).abs().log(10).toNumber())+1,t}function mz(e,t,n){for(var r=new Ze(e),a=0,u=[];r.lt(t)&&a<1e5;)u.push(r.toNumber()),r=r.add(n),a++;return u}var pz=e=>{var[t,n]=e,[r,a]=[t,n];return t>n&&([r,a]=[n,t]),[r,a]},vz=(e,t,n)=>{if(e.lte(0))return new Ze(0);var r=hz(e.toNumber()),a=new Ze(10).pow(r),u=e.div(a),o=r!==1?.05:.1,c=new Ze(Math.ceil(u.div(o).toNumber())).add(n).mul(o),f=c.mul(a);return t?new Ze(f.toNumber()):new Ze(Math.ceil(f.toNumber()))},MY=(e,t,n)=>{var r=new Ze(1),a=new Ze(e);if(!a.isint()&&n){var u=Math.abs(e);u<1?(r=new Ze(10).pow(hz(e)-1),a=new Ze(Math.floor(a.div(r).toNumber())).mul(r)):u>1&&(a=new Ze(Math.floor(e)))}else e===0?a=new Ze(Math.floor((t-1)/2)):n||(a=new Ze(Math.floor(e)));for(var o=Math.floor((t-1)/2),c=[],f=0;f<t;f++)c.push(a.add(new Ze(f-o).mul(r)).toNumber());return c},yz=function(t,n,r,a){var u=arguments.length>4&&arguments[4]!==void 0?arguments[4]:0;if(!Number.isFinite((n-t)/(r-1)))return{step:new Ze(0),tickMin:new Ze(0),tickMax:new Ze(0)};var o=vz(new Ze(n).sub(t).div(r-1),a,u),c;t<=0&&n>=0?c=new Ze(0):(c=new Ze(t).add(n).div(2),c=c.sub(new Ze(c).mod(o)));var f=Math.ceil(c.sub(t).div(o).toNumber()),d=Math.ceil(new Ze(n).sub(c).div(o).toNumber()),m=f+d+1;return m>r?yz(t,n,r,a,u+1):(m<r&&(d=n>0?d+(r-m):d,f=n>0?f:f+(r-m)),{step:o,tickMin:c.sub(new Ze(f).mul(o)),tickMax:c.add(new Ze(d).mul(o))})},zY=function(t){var[n,r]=t,a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:6,u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!0,o=Math.max(a,2),[c,f]=pz([n,r]);if(c===-1/0||f===1/0){var d=f===1/0?[c,...Array(a-1).fill(1/0)]:[...Array(a-1).fill(-1/0),f];return n>r?d.reverse():d}if(c===f)return MY(c,a,u);var{step:m,tickMin:p,tickMax:y}=yz(c,f,o,u,0),g=mz(p,y.add(new Ze(.1).mul(m)),m);return n>r?g.reverse():g},DY=function(t,n){var[r,a]=t,u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!0,[o,c]=pz([r,a]);if(o===-1/0||c===1/0)return[r,a];if(o===c)return[o];var f=Math.max(n,2),d=vz(new Ze(c).sub(o).div(f-1),u,0),m=[...mz(new Ze(o),new Ze(c),d),c];return u===!1&&(m=m.map(p=>Math.round(p))),r>a?m.reverse():m},gz=e=>e.rootProps.maxBarSize,NY=e=>e.rootProps.barGap,bz=e=>e.rootProps.barCategoryGap,PY=e=>e.rootProps.barSize,ch=e=>e.rootProps.stackOffset,xz=e=>e.rootProps.reverseStackOrder,kb=e=>e.options.chartName,Cb=e=>e.rootProps.syncId,wz=e=>e.rootProps.syncMethod,Tb=e=>e.options.eventEmitter,mn={grid:-100,barBackground:-50,area:100,cursorRectangle:200,bar:300,line:400,axis:500,scatter:600,activeBar:1e3,cursorLine:1100,activeDot:1200,label:2e3},Ba={allowDecimals:!1,allowDataOverflow:!1,angleAxisId:0,reversed:!1,scale:"auto",tick:!0,type:"auto"},Rr={allowDataOverflow:!1,allowDecimals:!1,allowDuplicatedCategory:!0,includeHidden:!1,radiusAxisId:0,reversed:!1,scale:"auto",tick:!0,tickCount:5,type:"auto"},fh=(e,t)=>{if(!(!e||!t))return e!=null&&e.reversed?[t[1],t[0]]:t};function dh(e,t,n){if(n!=="auto")return n;if(e!=null)return va(e,t)?"category":"number"}function L_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function gd(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?L_(Object(n),!0).forEach(function(r){RY(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):L_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function RY(e,t,n){return(t=IY(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function IY(e){var t=LY(e,"string");return typeof t=="symbol"?t:t+""}function LY(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var B_={allowDataOverflow:Ba.allowDataOverflow,allowDecimals:Ba.allowDecimals,allowDuplicatedCategory:!1,dataKey:void 0,domain:void 0,id:Ba.angleAxisId,includeHidden:!1,name:void 0,reversed:Ba.reversed,scale:Ba.scale,tick:Ba.tick,tickCount:void 0,ticks:void 0,type:Ba.type,unit:void 0},U_={allowDataOverflow:Rr.allowDataOverflow,allowDecimals:Rr.allowDecimals,allowDuplicatedCategory:Rr.allowDuplicatedCategory,dataKey:void 0,domain:void 0,id:Rr.radiusAxisId,includeHidden:Rr.includeHidden,name:void 0,reversed:Rr.reversed,scale:Rr.scale,tick:Rr.tick,tickCount:Rr.tickCount,ticks:void 0,type:Rr.type,unit:void 0},BY=(e,t)=>{if(t!=null)return e.polarAxis.angleAxis[t]},jb=te([BY,lM],(e,t)=>{var n;if(e!=null)return e;var r=(n=dh(t,"angleAxis",B_.type))!==null&&n!==void 0?n:"category";return gd(gd({},B_),{},{type:r})}),UY=(e,t)=>e.polarAxis.radiusAxis[t],Mb=te([UY,lM],(e,t)=>{var n;if(e!=null)return e;var r=(n=dh(t,"radiusAxis",U_.type))!==null&&n!==void 0?n:"category";return gd(gd({},U_),{},{type:r})}),hh=e=>e.polarOptions,zb=te([Ti,ji,Ht],L$),Sz=te([hh,zb],(e,t)=>{if(e!=null)return kr(e.innerRadius,t,0)}),Oz=te([hh,zb],(e,t)=>{if(e!=null)return kr(e.outerRadius,t,t*.8)}),qY=e=>{if(e==null)return[0,0];var{startAngle:t,endAngle:n}=e;return[t,n]},Ez=te([hh],qY);te([jb,Ez],fh);var Az=te([zb,Sz,Oz],(e,t,n)=>{if(!(e==null||t==null||n==null))return[t,n]});te([Mb,Az],fh);var _z=te([at,hh,Sz,Oz,Ti,ji],(e,t,n,r,a,u)=>{if(!(e!=="centric"&&e!=="radial"||t==null||n==null||r==null)){var{cx:o,cy:c,startAngle:f,endAngle:d}=t;return{cx:kr(o,a,a/2),cy:kr(c,u,u/2),innerRadius:n,outerRadius:r,startAngle:f,endAngle:d,clockWise:!1}}}),Ft=(e,t)=>t,mh=(e,t,n)=>n;function Db(e){return e==null?void 0:e.id}function kz(e,t,n){var{chartData:r=[]}=t,{allowDuplicatedCategory:a,dataKey:u}=n,o=new Map;return e.forEach(c=>{var f,d=(f=c.data)!==null&&f!==void 0?f:r;if(!(d==null||d.length===0)){var m=Db(c);d.forEach((p,y)=>{var g=u==null||a?y:String(tn(p,u,null)),x=tn(p,c.dataKey,0),w;o.has(g)?w=o.get(g):w={},Object.assign(w,{[m]:x}),o.set(g,w)})}}),Array.from(o.values())}function ph(e){return"stackId"in e&&e.stackId!=null&&e.dataKey!=null}var vh=(e,t)=>e===t?!0:e==null||t==null?!1:e[0]===t[0]&&e[1]===t[1];function yh(e,t){return Array.isArray(e)&&Array.isArray(t)&&e.length===0&&t.length===0?!0:e===t}function HY(e,t){if(e.length===t.length){for(var n=0;n<e.length;n++)if(e[n]!==t[n])return!1;return!0}return!1}var Vt=e=>{var t=at(e);return t==="horizontal"?"xAxis":t==="vertical"?"yAxis":t==="centric"?"angleAxis":"radiusAxis"},ju=e=>e.tooltip.settings.axisId;function $Y(e){if(e in Ko)return Ko[e]();var t="scale".concat(xs(e));if(t in Ko)return Ko[t]()}function q_(e){var t=e.ticks,n=e.bandwidth,r=e.range(),a=[Math.min(...r),Math.max(...r)];return{domain:()=>e.domain(),range:(function(u){function o(){return u.apply(this,arguments)}return o.toString=function(){return u.toString()},o})(()=>a),rangeMin:()=>a[0],rangeMax:()=>a[1],isInRange(u){var o=a[0],c=a[1];return o<=c?u>=o&&u<=c:u>=c&&u<=o},bandwidth:n?()=>n.call(e):void 0,ticks:t?u=>t.call(e,u):void 0,map:(u,o)=>{var c=e(u);if(c!=null){if(e.bandwidth&&o!==null&&o!==void 0&&o.position){var f=e.bandwidth();switch(o.position){case"middle":c+=f/2;break;case"end":c+=f;break}}return c}}}}function H_(e,t,n){if(typeof e=="function")return q_(e.copy().domain(t).range(n));if(e!=null){var r=$Y(e);if(r!=null)return r.domain(t).range(n),q_(r)}}var FY=(e,t)=>{if(t!=null)switch(e){case"linear":{if(!Ai(t)){for(var n,r,a=0;a<t.length;a++){var u=t[a];qe(u)&&((n===void 0||u<n)&&(n=u),(r===void 0||u>r)&&(r=u))}return n!==void 0&&r!==void 0?[n,r]:void 0}return t}default:return t}};function $_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function bd(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?$_(Object(n),!0).forEach(function(r){VY(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):$_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function VY(e,t,n){return(t=YY(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function YY(e){var t=KY(e,"string");return typeof t=="symbol"?t:t+""}function KY(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var Vg=[0,"auto"],Lt={allowDataOverflow:!1,allowDecimals:!0,allowDuplicatedCategory:!0,angle:0,dataKey:void 0,domain:void 0,height:30,hide:!0,id:0,includeHidden:!1,interval:"preserveEnd",minTickGap:5,mirror:!1,name:void 0,orientation:"bottom",padding:{left:0,right:0},reversed:!1,scale:"auto",tick:!0,tickCount:5,tickFormatter:void 0,ticks:void 0,type:"category",unit:void 0},Cz=(e,t)=>e.cartesianAxis.xAxis[t],Di=(e,t)=>{var n=Cz(e,t);return n??Lt},Bt={allowDataOverflow:!1,allowDecimals:!0,allowDuplicatedCategory:!0,angle:0,dataKey:void 0,domain:Vg,hide:!0,id:0,includeHidden:!1,interval:"preserveEnd",minTickGap:5,mirror:!1,name:void 0,orientation:"left",padding:{top:0,bottom:0},reversed:!1,scale:"auto",tick:!0,tickCount:5,tickFormatter:void 0,ticks:void 0,type:"number",unit:void 0,width:Os},Tz=(e,t)=>e.cartesianAxis.yAxis[t],Ni=(e,t)=>{var n=Tz(e,t);return n??Bt},GY={domain:[0,"auto"],includeHidden:!1,reversed:!1,allowDataOverflow:!1,allowDuplicatedCategory:!1,dataKey:void 0,id:0,name:"",range:[64,64],scale:"auto",type:"number",unit:""},Nb=(e,t)=>{var n=e.cartesianAxis.zAxis[t];return n??GY},vn=(e,t,n)=>{switch(t){case"xAxis":return Di(e,n);case"yAxis":return Ni(e,n);case"zAxis":return Nb(e,n);case"angleAxis":return jb(e,n);case"radiusAxis":return Mb(e,n);default:throw new Error("Unexpected axis type: ".concat(t))}},XY=(e,t,n)=>{switch(t){case"xAxis":return Di(e,n);case"yAxis":return Ni(e,n);default:throw new Error("Unexpected axis type: ".concat(t))}},js=(e,t,n)=>{switch(t){case"xAxis":return Di(e,n);case"yAxis":return Ni(e,n);case"angleAxis":return jb(e,n);case"radiusAxis":return Mb(e,n);default:throw new Error("Unexpected axis type: ".concat(t))}},jz=e=>e.graphicalItems.cartesianItems.some(t=>t.type==="bar")||e.graphicalItems.polarItems.some(t=>t.type==="radialBar");function Mz(e,t){return n=>{switch(e){case"xAxis":return"xAxisId"in n&&n.xAxisId===t;case"yAxis":return"yAxisId"in n&&n.yAxisId===t;case"zAxis":return"zAxisId"in n&&n.zAxisId===t;case"angleAxis":return"angleAxisId"in n&&n.angleAxisId===t;case"radiusAxis":return"radiusAxisId"in n&&n.radiusAxisId===t;default:return!1}}}var Pb=e=>e.graphicalItems.cartesianItems,ZY=te([Ft,mh],Mz),zz=(e,t,n)=>e.filter(n).filter(r=>(t==null?void 0:t.includeHidden)===!0?!0:!r.hide),Ms=te([Pb,vn,ZY],zz,{memoizeOptions:{resultEqualityCheck:yh}}),Dz=te([Ms],e=>e.filter(t=>t.type==="area"||t.type==="bar").filter(ph)),Nz=e=>e.filter(t=>!("stackId"in t)||t.stackId===void 0),QY=te([Ms],Nz),Pz=e=>e.map(t=>t.data).filter(Boolean).flat(1),WY=te([Ms],Pz,{memoizeOptions:{resultEqualityCheck:yh}}),Rz=(e,t)=>{var{chartData:n=[],dataStartIndex:r,dataEndIndex:a}=t;return e.length>0?e:n.slice(r,a+1)},Rb=te([WY,lz],Rz),Iz=(e,t,n)=>(t==null?void 0:t.dataKey)!=null?e.map(r=>({value:tn(r,t.dataKey)})):n.length>0?n.map(r=>r.dataKey).flatMap(r=>e.map(a=>({value:tn(a,r)}))):e.map(r=>({value:r})),gh=te([Rb,vn,Ms],Iz);function Lz(e,t){switch(e){case"xAxis":return t.direction==="x";case"yAxis":return t.direction==="y";default:return!1}}function Tf(e){if(Fr(e)||e instanceof Date){var t=Number(e);if(qe(t))return t}}function F_(e){if(Array.isArray(e)){var t=[Tf(e[0]),Tf(e[1])];return Ai(t)?t:void 0}var n=Tf(e);if(n!=null)return[n,n]}function _i(e){return e.map(Tf).filter(kn)}function JY(e,t,n){return!n||typeof t!="number"||$r(t)?[]:n.length?_i(n.flatMap(r=>{var a=tn(e,r.dataKey),u,o;if(Array.isArray(a)?[u,o]=a:u=o=a,!(!qe(u)||!qe(o)))return[t-u,t+o]})):[]}var Pt=e=>{var t=Vt(e),n=ju(e);return js(e,t,n)},zs=te([Pt],e=>e==null?void 0:e.dataKey),eK=te([Dz,lz,Pt],kz),Bz=(e,t,n,r)=>{var a={},u=t.reduce((o,c)=>{if(c.stackId==null)return o;var f=o[c.stackId];return f==null&&(f=[]),f.push(c),o[c.stackId]=f,o},a);return Object.fromEntries(Object.entries(u).map(o=>{var[c,f]=o,d=r?[...f].reverse():f,m=d.map(Db);return[c,{stackedData:CH(e,m,n),graphicalItems:d}]}))},Yg=te([eK,Dz,ch,xz],Bz),Uz=(e,t,n,r)=>{var{dataStartIndex:a,dataEndIndex:u}=t;if(r==null&&n!=="zAxis"){var o=DH(e,a,u);if(!(o!=null&&o[0]===0&&o[1]===0))return o}},tK=te([vn],e=>e.allowDataOverflow),Ib=e=>{var t;if(e==null||!("domain"in e))return Vg;if(e.domain!=null)return e.domain;if("ticks"in e&&e.ticks!=null){if(e.type==="number"){var n=_i(e.ticks);return[Math.min(...n),Math.max(...n)]}if(e.type==="category")return e.ticks.map(String)}return(t=e==null?void 0:e.domain)!==null&&t!==void 0?t:Vg},qz=te([vn],Ib),Hz=te([qz,tK],uz),nK=te([Yg,zi,Ft,Hz],Uz,{memoizeOptions:{resultEqualityCheck:vh}}),Lb=e=>e.errorBars,rK=(e,t,n)=>e.flatMap(r=>t[r.id]).filter(Boolean).filter(r=>Lz(n,r)),xd=function(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];var a=n.filter(Boolean);if(a.length!==0){var u=a.flat(),o=Math.min(...u),c=Math.max(...u);return[o,c]}},$z=(e,t,n,r,a)=>{var u,o;if(n.length>0&&e.forEach(c=>{n.forEach(f=>{var d,m,p=(d=r[f.id])===null||d===void 0?void 0:d.filter(O=>Lz(a,O)),y=tn(c,(m=t.dataKey)!==null&&m!==void 0?m:f.dataKey),g=JY(c,y,p);if(g.length>=2){var x=Math.min(...g),w=Math.max(...g);(u==null||x<u)&&(u=x),(o==null||w>o)&&(o=w)}var S=F_(y);S!=null&&(u=u==null?S[0]:Math.min(u,S[0]),o=o==null?S[1]:Math.max(o,S[1]))})}),(t==null?void 0:t.dataKey)!=null&&e.forEach(c=>{var f=F_(tn(c,t.dataKey));f!=null&&(u=u==null?f[0]:Math.min(u,f[0]),o=o==null?f[1]:Math.max(o,f[1]))}),qe(u)&&qe(o))return[u,o]},iK=te([Rb,vn,QY,Lb,Ft],$z,{memoizeOptions:{resultEqualityCheck:vh}});function aK(e){var{value:t}=e;if(Fr(t)||t instanceof Date)return t}var lK=(e,t,n)=>{var r=e.map(aK).filter(a=>a!=null);return n&&(t.dataKey==null||t.allowDuplicatedCategory&&rj(r))?EM(0,e.length):t.allowDuplicatedCategory?r:Array.from(new Set(r))},Fz=e=>e.referenceElements.dots,Mu=(e,t,n)=>e.filter(r=>r.ifOverflow==="extendDomain").filter(r=>t==="xAxis"?r.xAxisId===n:r.yAxisId===n),uK=te([Fz,Ft,mh],Mu),Vz=e=>e.referenceElements.areas,oK=te([Vz,Ft,mh],Mu),Yz=e=>e.referenceElements.lines,sK=te([Yz,Ft,mh],Mu),Kz=(e,t)=>{if(e!=null){var n=_i(e.map(r=>t==="xAxis"?r.x:r.y));if(n.length!==0)return[Math.min(...n),Math.max(...n)]}},cK=te(uK,Ft,Kz),Gz=(e,t)=>{if(e!=null){var n=_i(e.flatMap(r=>[t==="xAxis"?r.x1:r.y1,t==="xAxis"?r.x2:r.y2]));if(n.length!==0)return[Math.min(...n),Math.max(...n)]}},fK=te([oK,Ft],Gz);function dK(e){var t;if(e.x!=null)return _i([e.x]);var n=(t=e.segment)===null||t===void 0?void 0:t.map(r=>r.x);return n==null||n.length===0?[]:_i(n)}function hK(e){var t;if(e.y!=null)return _i([e.y]);var n=(t=e.segment)===null||t===void 0?void 0:t.map(r=>r.y);return n==null||n.length===0?[]:_i(n)}var Xz=(e,t)=>{if(e!=null){var n=e.flatMap(r=>t==="xAxis"?dK(r):hK(r));if(n.length!==0)return[Math.min(...n),Math.max(...n)]}},mK=te([sK,Ft],Xz),pK=te(cK,mK,fK,(e,t,n)=>xd(e,n,t)),Zz=(e,t,n,r,a,u,o,c)=>{if(n!=null)return n;var f=o==="vertical"&&c==="xAxis"||o==="horizontal"&&c==="yAxis",d=f?xd(r,u,a):xd(u,a);return kY(t,d,e.allowDataOverflow)},vK=te([vn,qz,Hz,nK,iK,pK,at,Ft],Zz,{memoizeOptions:{resultEqualityCheck:vh}}),yK=[0,1],Qz=(e,t,n,r,a,u,o)=>{if(!((e==null||n==null||n.length===0)&&o===void 0)){var{dataKey:c,type:f}=e,d=va(t,u);if(d&&c==null){var m;return EM(0,(m=n==null?void 0:n.length)!==null&&m!==void 0?m:0)}return f==="category"?lK(r,e,d):a==="expand"?yK:o}},Bb=te([vn,at,Rb,gh,ch,Ft,vK],Qz);function gK(e){return e in Ko}var Wz=(e,t,n)=>{if(e!=null){var{scale:r,type:a}=e;if(r==="auto")return a==="category"&&n&&(n.indexOf("LineChart")>=0||n.indexOf("AreaChart")>=0||n.indexOf("ComposedChart")>=0&&!t)?"point":a==="category"?"band":"linear";if(typeof r=="string"){var u="scale".concat(xs(r));return gK(u)?u:"point"}}},zu=te([vn,jz,kb],Wz);function Ub(e,t,n,r){if(!(n==null||r==null))return typeof e.scale=="function"?H_(e.scale,n,r):H_(t,n,r)}var Jz=(e,t,n)=>{var r=Ib(t);if(!(n!=="auto"&&n!=="linear")){if(t!=null&&t.tickCount&&Array.isArray(r)&&(r[0]==="auto"||r[1]==="auto")&&Ai(e))return zY(e,t.tickCount,t.allowDecimals);if(t!=null&&t.tickCount&&t.type==="number"&&Ai(e))return DY(e,t.tickCount,t.allowDecimals)}},qb=te([Bb,js,zu],Jz),eD=(e,t,n,r)=>{if(r!=="angleAxis"&&(e==null?void 0:e.type)==="number"&&Ai(t)&&Array.isArray(n)&&n.length>0){var a,u,o=t[0],c=(a=n[0])!==null&&a!==void 0?a:0,f=t[1],d=(u=n[n.length-1])!==null&&u!==void 0?u:0;return[Math.min(o,c),Math.max(f,d)]}return t},bK=te([vn,Bb,qb,Ft],eD),xK=te(gh,vn,(e,t)=>{if(!(!t||t.type!=="number")){var n=1/0,r=Array.from(_i(e.map(p=>p.value))).sort((p,y)=>p-y),a=r[0],u=r[r.length-1];if(a==null||u==null)return 1/0;var o=u-a;if(o===0)return 1/0;for(var c=0;c<r.length-1;c++){var f=r[c],d=r[c+1];if(!(f==null||d==null)){var m=d-f;n=Math.min(n,m)}}return n/o}}),tD=te(xK,at,bz,Ht,(e,t,n,r,a)=>a,(e,t,n,r,a)=>{if(!qe(e))return 0;var u=t==="vertical"?r.height:r.width;if(a==="gap")return e*u/2;if(a==="no-gap"){var o=kr(n,e*u),c=e*u/2;return c-o-(c-o)/u*o}return 0}),wK=(e,t,n)=>{var r=Di(e,t);return r==null||typeof r.padding!="string"?0:tD(e,"xAxis",t,n,r.padding)},SK=(e,t,n)=>{var r=Ni(e,t);return r==null||typeof r.padding!="string"?0:tD(e,"yAxis",t,n,r.padding)},OK=te(Di,wK,(e,t)=>{var n,r;if(e==null)return{left:0,right:0};var{padding:a}=e;return typeof a=="string"?{left:t,right:t}:{left:((n=a.left)!==null&&n!==void 0?n:0)+t,right:((r=a.right)!==null&&r!==void 0?r:0)+t}}),EK=te(Ni,SK,(e,t)=>{var n,r;if(e==null)return{top:0,bottom:0};var{padding:a}=e;return typeof a=="string"?{top:t,bottom:t}:{top:((n=a.top)!==null&&n!==void 0?n:0)+t,bottom:((r=a.bottom)!==null&&r!==void 0?r:0)+t}}),AK=te([Ht,OK,Qd,Zd,(e,t,n)=>n],(e,t,n,r,a)=>{var{padding:u}=r;return a?[u.left,n.width-u.right]:[e.left+t.left,e.left+e.width-t.right]}),_K=te([Ht,at,EK,Qd,Zd,(e,t,n)=>n],(e,t,n,r,a,u)=>{var{padding:o}=a;return u?[r.height-o.bottom,o.top]:t==="horizontal"?[e.top+e.height-n.bottom,e.top+n.top]:[e.top+n.top,e.top+e.height-n.bottom]}),Ds=(e,t,n,r)=>{var a;switch(t){case"xAxis":return AK(e,n,r);case"yAxis":return _K(e,n,r);case"zAxis":return(a=Nb(e,n))===null||a===void 0?void 0:a.range;case"angleAxis":return Ez(e);case"radiusAxis":return Az(e,n);default:return}},nD=te([vn,Ds],fh),kK=te([zu,bK],FY),bh=te([vn,zu,kK,nD],Ub);te([Ms,Lb,Ft],rK);function rD(e,t){return e.id<t.id?-1:e.id>t.id?1:0}var xh=(e,t)=>t,wh=(e,t,n)=>n,CK=te(Gd,xh,wh,(e,t,n)=>e.filter(r=>r.orientation===t).filter(r=>r.mirror===n).sort(rD)),TK=te(Xd,xh,wh,(e,t,n)=>e.filter(r=>r.orientation===t).filter(r=>r.mirror===n).sort(rD)),iD=(e,t)=>({width:e.width,height:t.height}),jK=(e,t)=>{var n=typeof t.width=="number"?t.width:Os;return{width:n,height:e.height}},aD=te(Ht,Di,iD),MK=(e,t,n)=>{switch(t){case"top":return e.top;case"bottom":return n-e.bottom;default:return 0}},zK=(e,t,n)=>{switch(t){case"left":return e.left;case"right":return n-e.right;default:return 0}},DK=te(ji,Ht,CK,xh,wh,(e,t,n,r,a)=>{var u={},o;return n.forEach(c=>{var f=iD(t,c);o==null&&(o=MK(t,r,e));var d=r==="top"&&!a||r==="bottom"&&a;u[c.id]=o-Number(d)*f.height,o+=(d?-1:1)*f.height}),u}),NK=te(Ti,Ht,TK,xh,wh,(e,t,n,r,a)=>{var u={},o;return n.forEach(c=>{var f=jK(t,c);o==null&&(o=zK(t,r,e));var d=r==="left"&&!a||r==="right"&&a;u[c.id]=o-Number(d)*f.width,o+=(d?-1:1)*f.width}),u}),PK=(e,t)=>{var n=Di(e,t);if(n!=null)return DK(e,n.orientation,n.mirror)},RK=te([Ht,Di,PK,(e,t)=>t],(e,t,n,r)=>{if(t!=null){var a=n==null?void 0:n[r];return a==null?{x:e.left,y:0}:{x:e.left,y:a}}}),IK=(e,t)=>{var n=Ni(e,t);if(n!=null)return NK(e,n.orientation,n.mirror)},LK=te([Ht,Ni,IK,(e,t)=>t],(e,t,n,r)=>{if(t!=null){var a=n==null?void 0:n[r];return a==null?{x:0,y:e.top}:{x:a,y:e.top}}}),lD=te(Ht,Ni,(e,t)=>{var n=typeof t.width=="number"?t.width:Os;return{width:n,height:e.height}}),V_=(e,t,n)=>{switch(t){case"xAxis":return aD(e,n).width;case"yAxis":return lD(e,n).height;default:return}},uD=(e,t,n,r)=>{if(n!=null){var{allowDuplicatedCategory:a,type:u,dataKey:o}=n,c=va(e,r),f=t.map(d=>d.value);if(o&&c&&u==="category"&&a&&rj(f))return f}},Hb=te([at,gh,vn,Ft],uD),oD=(e,t,n,r)=>{if(!(n==null||n.dataKey==null)){var{type:a,scale:u}=n,o=va(e,r);if(o&&(a==="number"||u!=="auto"))return t.map(c=>c.value)}},$b=te([at,gh,js,Ft],oD),Y_=te([at,XY,zu,bh,Hb,$b,Ds,qb,Ft],(e,t,n,r,a,u,o,c,f)=>{if(t!=null){var d=va(e,f);return{angle:t.angle,interval:t.interval,minTickGap:t.minTickGap,orientation:t.orientation,tick:t.tick,tickCount:t.tickCount,tickFormatter:t.tickFormatter,ticks:t.ticks,type:t.type,unit:t.unit,axisType:f,categoricalDomain:u,duplicateDomain:a,isCategorical:d,niceTicks:c,range:o,realScaleType:n,scale:r}}}),BK=(e,t,n,r,a,u,o,c,f)=>{if(!(t==null||r==null)){var d=va(e,f),{type:m,ticks:p,tickCount:y}=t,g=n==="scaleBand"&&typeof r.bandwidth=="function"?r.bandwidth()/2:2,x=m==="category"&&r.bandwidth?r.bandwidth()/g:0;x=f==="angleAxis"&&u!=null&&u.length>=2?_n(u[0]-u[1])*2*x:x;var w=p||a;return w?w.map((S,O)=>{var _=o?o.indexOf(S):S,k=r.map(_);return qe(k)?{index:O,coordinate:k+x,value:S,offset:x}:null}).filter(kn):d&&c?c.map((S,O)=>{var _=r.map(S);return qe(_)?{coordinate:_+x,value:S,index:O,offset:x}:null}).filter(kn):r.ticks?r.ticks(y).map((S,O)=>{var _=r.map(S);return qe(_)?{coordinate:_+x,value:S,index:O,offset:x}:null}).filter(kn):r.domain().map((S,O)=>{var _=r.map(S);return qe(_)?{coordinate:_+x,value:o?o[S]:S,index:O,offset:x}:null}).filter(kn)}},sD=te([at,js,zu,bh,qb,Ds,Hb,$b,Ft],BK),UK=(e,t,n,r,a,u,o)=>{if(!(t==null||n==null||r==null||r[0]===r[1])){var c=va(e,o),{tickCount:f}=t,d=0;return d=o==="angleAxis"&&(r==null?void 0:r.length)>=2?_n(r[0]-r[1])*2*d:d,c&&u?u.map((m,p)=>{var y=n.map(m);return qe(y)?{coordinate:y+d,value:m,index:p,offset:d}:null}).filter(kn):n.ticks?n.ticks(f).map((m,p)=>{var y=n.map(m);return qe(y)?{coordinate:y+d,value:m,index:p,offset:d}:null}).filter(kn):n.domain().map((m,p)=>{var y=n.map(m);return qe(y)?{coordinate:y+d,value:a?a[m]:m,index:p,offset:d}:null}).filter(kn)}},bu=te([at,js,bh,Ds,Hb,$b,Ft],UK),xu=te(vn,bh,(e,t)=>{if(!(e==null||t==null))return bd(bd({},e),{},{scale:t})}),qK=te([vn,zu,Bb,nD],Ub);te((e,t,n)=>Nb(e,n),qK,(e,t)=>{if(!(e==null||t==null))return bd(bd({},e),{},{scale:t})});var HK=te([at,Gd,Xd],(e,t,n)=>{switch(e){case"horizontal":return t.some(r=>r.reversed)?"right-to-left":"left-to-right";case"vertical":return n.some(r=>r.reversed)?"bottom-to-top":"top-to-bottom";case"centric":case"radial":return"left-to-right";default:return}}),cD=e=>e.options.defaultTooltipEventType,fD=e=>e.options.validateTooltipEventTypes;function dD(e,t,n){if(e==null)return t;var r=e?"axis":"item";return n==null?t:n.includes(r)?r:t}function Fb(e,t){var n=cD(e),r=fD(e);return dD(t,n,r)}function $K(e){return Ee(t=>Fb(t,e))}var hD=(e,t)=>{var n,r=Number(t);if(!($r(r)||t==null))return r>=0?e==null||(n=e[r])===null||n===void 0?void 0:n.value:void 0},FK=e=>e.tooltip.settings,fa={active:!1,index:null,dataKey:void 0,graphicalItemId:void 0,coordinate:void 0},VK={itemInteraction:{click:fa,hover:fa},axisInteraction:{click:fa,hover:fa},keyboardInteraction:fa,syncInteraction:{active:!1,index:null,dataKey:void 0,label:void 0,coordinate:void 0,sourceViewBox:void 0,graphicalItemId:void 0},tooltipItemPayloads:[],settings:{shared:void 0,trigger:"hover",axisId:0,active:!1,defaultIndex:void 0}},mD=jn({name:"tooltip",initialState:VK,reducers:{addTooltipEntrySettings:{reducer(e,t){e.tooltipItemPayloads.push(t.payload)},prepare:ht()},replaceTooltipEntrySettings:{reducer(e,t){var{prev:n,next:r}=t.payload,a=_r(e).tooltipItemPayloads.indexOf(n);a>-1&&(e.tooltipItemPayloads[a]=r)},prepare:ht()},removeTooltipEntrySettings:{reducer(e,t){var n=_r(e).tooltipItemPayloads.indexOf(t.payload);n>-1&&e.tooltipItemPayloads.splice(n,1)},prepare:ht()},setTooltipSettingsState(e,t){e.settings=t.payload},setActiveMouseOverItemIndex(e,t){e.syncInteraction.active=!1,e.keyboardInteraction.active=!1,e.itemInteraction.hover.active=!0,e.itemInteraction.hover.index=t.payload.activeIndex,e.itemInteraction.hover.dataKey=t.payload.activeDataKey,e.itemInteraction.hover.graphicalItemId=t.payload.activeGraphicalItemId,e.itemInteraction.hover.coordinate=t.payload.activeCoordinate},mouseLeaveChart(e){e.itemInteraction.hover.active=!1,e.axisInteraction.hover.active=!1},mouseLeaveItem(e){e.itemInteraction.hover.active=!1},setActiveClickItemIndex(e,t){e.syncInteraction.active=!1,e.itemInteraction.click.active=!0,e.keyboardInteraction.active=!1,e.itemInteraction.click.index=t.payload.activeIndex,e.itemInteraction.click.dataKey=t.payload.activeDataKey,e.itemInteraction.click.graphicalItemId=t.payload.activeGraphicalItemId,e.itemInteraction.click.coordinate=t.payload.activeCoordinate},setMouseOverAxisIndex(e,t){e.syncInteraction.active=!1,e.axisInteraction.hover.active=!0,e.keyboardInteraction.active=!1,e.axisInteraction.hover.index=t.payload.activeIndex,e.axisInteraction.hover.dataKey=t.payload.activeDataKey,e.axisInteraction.hover.coordinate=t.payload.activeCoordinate},setMouseClickAxisIndex(e,t){e.syncInteraction.active=!1,e.keyboardInteraction.active=!1,e.axisInteraction.click.active=!0,e.axisInteraction.click.index=t.payload.activeIndex,e.axisInteraction.click.dataKey=t.payload.activeDataKey,e.axisInteraction.click.coordinate=t.payload.activeCoordinate},setSyncInteraction(e,t){e.syncInteraction=t.payload},setKeyboardInteraction(e,t){e.keyboardInteraction.active=t.payload.active,e.keyboardInteraction.index=t.payload.activeIndex,e.keyboardInteraction.coordinate=t.payload.activeCoordinate}}}),{addTooltipEntrySettings:YK,replaceTooltipEntrySettings:KK,removeTooltipEntrySettings:GK,setTooltipSettingsState:XK,setActiveMouseOverItemIndex:pD,mouseLeaveItem:ZK,mouseLeaveChart:vD,setActiveClickItemIndex:QK,setMouseOverAxisIndex:yD,setMouseClickAxisIndex:WK,setSyncInteraction:Kg,setKeyboardInteraction:Gg}=mD.actions,JK=mD.reducer;function K_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function wf(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?K_(Object(n),!0).forEach(function(r){eG(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):K_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function eG(e,t,n){return(t=tG(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function tG(e){var t=nG(e,"string");return typeof t=="symbol"?t:t+""}function nG(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function rG(e,t,n){return t==="axis"?n==="click"?e.axisInteraction.click:e.axisInteraction.hover:n==="click"?e.itemInteraction.click:e.itemInteraction.hover}function iG(e){return e.index!=null}var gD=(e,t,n,r)=>{if(t==null)return fa;var a=rG(e,t,n);if(a==null)return fa;if(a.active)return a;if(e.keyboardInteraction.active)return e.keyboardInteraction;if(e.syncInteraction.active&&e.syncInteraction.index!=null)return e.syncInteraction;var u=e.settings.active===!0;if(iG(a)){if(u)return wf(wf({},a),{},{active:!0})}else if(r!=null)return{active:!0,coordinate:void 0,dataKey:void 0,index:r,graphicalItemId:void 0};return wf(wf({},fa),{},{coordinate:a.coordinate})};function aG(e){if(typeof e=="number")return Number.isFinite(e)?e:void 0;if(e instanceof Date){var t=e.valueOf();return Number.isFinite(t)?t:void 0}var n=Number(e);return Number.isFinite(n)?n:void 0}function lG(e,t){var n=aG(e),r=t[0],a=t[1];if(n===void 0)return!1;var u=Math.min(r,a),o=Math.max(r,a);return n>=u&&n<=o}function uG(e,t,n){if(n==null||t==null)return!0;var r=tn(e,t);return r==null||!Ai(n)?!0:lG(r,n)}var Vb=(e,t,n,r)=>{var a=e==null?void 0:e.index;if(a==null)return null;var u=Number(a);if(!qe(u))return a;var o=0,c=1/0;t.length>0&&(c=t.length-1);var f=Math.max(o,Math.min(u,c)),d=t[f];return d==null||uG(d,n,r)?String(f):null},bD=(e,t,n,r,a,u,o)=>{if(u!=null){var c=o[0],f=c==null?void 0:c.getPosition(u);if(f!=null)return f;var d=a==null?void 0:a[Number(u)];if(d)switch(n){case"horizontal":return{x:d.coordinate,y:(r.top+t)/2};default:return{x:(r.left+e)/2,y:d.coordinate}}}},xD=(e,t,n,r)=>{if(t==="axis")return e.tooltipItemPayloads;if(e.tooltipItemPayloads.length===0)return[];var a;if(n==="hover"?a=e.itemInteraction.hover.graphicalItemId:a=e.itemInteraction.click.graphicalItemId,a==null&&r!=null){var u=e.tooltipItemPayloads[0];return u!=null?[u]:[]}return e.tooltipItemPayloads.filter(o=>{var c;return((c=o.settings)===null||c===void 0?void 0:c.graphicalItemId)===a})},wD=e=>e.options.tooltipPayloadSearcher,Du=e=>e.tooltip;function G_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function X_(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?G_(Object(n),!0).forEach(function(r){oG(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):G_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function oG(e,t,n){return(t=sG(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function sG(e){var t=cG(e,"string");return typeof t=="symbol"?t:t+""}function cG(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function fG(e,t){return e??t}var SD=(e,t,n,r,a,u,o)=>{if(!(t==null||u==null)){var{chartData:c,computedData:f,dataStartIndex:d,dataEndIndex:m}=n,p=[];return e.reduce((y,g)=>{var x,{dataDefinedOnItem:w,settings:S}=g,O=fG(w,c),_=Array.isArray(O)?Gj(O,d,m):O,k=(x=S==null?void 0:S.dataKey)!==null&&x!==void 0?x:r,M=S==null?void 0:S.nameKey,N;if(r&&Array.isArray(_)&&!Array.isArray(_[0])&&o==="axis"?N=oU(_,r,a):N=u(_,t,f,M),Array.isArray(N))N.forEach(z=>{var $=X_(X_({},S),{},{name:z.name,unit:z.unit,color:void 0,fill:void 0});y.push(XA({tooltipEntrySettings:$,dataKey:z.dataKey,payload:z.payload,value:tn(z.payload,z.dataKey),name:z.name}))});else{var C;y.push(XA({tooltipEntrySettings:S,dataKey:k,payload:N,value:tn(N,k),name:(C=tn(N,M))!==null&&C!==void 0?C:S==null?void 0:S.name}))}return y},p)}},Yb=te([Pt,jz,kb],Wz),dG=te([e=>e.graphicalItems.cartesianItems,e=>e.graphicalItems.polarItems],(e,t)=>[...e,...t]),hG=te([Vt,ju],Mz),Nu=te([dG,Pt,hG],zz,{memoizeOptions:{resultEqualityCheck:yh}}),mG=te([Nu],e=>e.filter(ph)),pG=te([Nu],Pz,{memoizeOptions:{resultEqualityCheck:yh}}),Pu=te([pG,zi],Rz),vG=te([mG,zi,Pt],kz),Kb=te([Pu,Pt,Nu],Iz),OD=te([Pt],Ib),yG=te([Pt],e=>e.allowDataOverflow),ED=te([OD,yG],uz),gG=te([Nu],e=>e.filter(ph)),bG=te([vG,gG,ch,xz],Bz),xG=te([bG,zi,Vt,ED],Uz),wG=te([Nu],Nz),SG=te([Pu,Pt,wG,Lb,Vt],$z,{memoizeOptions:{resultEqualityCheck:vh}}),OG=te([Fz,Vt,ju],Mu),EG=te([OG,Vt],Kz),AG=te([Vz,Vt,ju],Mu),_G=te([AG,Vt],Gz),kG=te([Yz,Vt,ju],Mu),CG=te([kG,Vt],Xz),TG=te([EG,CG,_G],xd),jG=te([Pt,OD,ED,xG,SG,TG,at,Vt],Zz),Ns=te([Pt,at,Pu,Kb,ch,Vt,jG],Qz),MG=te([Ns,Pt,Yb],Jz),zG=te([Pt,Ns,MG,Vt],eD),AD=e=>{var t=Vt(e),n=ju(e),r=!1;return Ds(e,t,n,r)},_D=te([Pt,AD],fh),kD=te([Pt,Yb,zG,_D],Ub),DG=te([at,Kb,Pt,Vt],uD),NG=te([at,Kb,Pt,Vt],oD),PG=(e,t,n,r,a,u,o,c)=>{if(t){var{type:f}=t,d=va(e,c);if(r){var m=n==="scaleBand"&&r.bandwidth?r.bandwidth()/2:2,p=f==="category"&&r.bandwidth?r.bandwidth()/m:0;return p=c==="angleAxis"&&a!=null&&(a==null?void 0:a.length)>=2?_n(a[0]-a[1])*2*p:p,d&&o?o.map((y,g)=>{var x=r.map(y);return qe(x)?{coordinate:x+p,value:y,index:g,offset:p}:null}).filter(kn):r.domain().map((y,g)=>{var x=r.map(y);return qe(x)?{coordinate:x+p,value:u?u[y]:y,index:g,offset:p}:null}).filter(kn)}}},Pi=te([at,Pt,Yb,kD,AD,DG,NG,Vt],PG),Gb=te([cD,fD,FK],(e,t,n)=>dD(n.shared,e,t)),CD=e=>e.tooltip.settings.trigger,Xb=e=>e.tooltip.settings.defaultIndex,Ps=te([Du,Gb,CD,Xb],gD),wu=te([Ps,Pu,zs,Ns],Vb),TD=te([Pi,wu],hD),jD=te([Ps],e=>{if(e)return e.dataKey});te([Ps],e=>{if(e)return e.graphicalItemId});var MD=te([Du,Gb,CD,Xb],xD),RG=te([Ti,ji,at,Ht,Pi,Xb,MD],bD),IG=te([Ps,RG],(e,t)=>e!=null&&e.coordinate?e.coordinate:t),LG=te([Ps],e=>{var t;return(t=e==null?void 0:e.active)!==null&&t!==void 0?t:!1}),BG=te([MD,wu,zi,zs,TD,wD,Gb],SD);te([BG],e=>{if(e!=null){var t=e.map(n=>n.payload).filter(n=>n!=null);return Array.from(new Set(t))}});function Z_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Q_(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Z_(Object(n),!0).forEach(function(r){UG(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Z_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function UG(e,t,n){return(t=qG(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function qG(e){var t=HG(e,"string");return typeof t=="symbol"?t:t+""}function HG(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var $G=()=>Ee(Pt),FG=()=>{var e=$G(),t=Ee(Pi),n=Ee(kD);return Qf(!e||!n?void 0:Q_(Q_({},e),{},{scale:n}),t)};function W_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function eu(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?W_(Object(n),!0).forEach(function(r){VG(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):W_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function VG(e,t,n){return(t=YG(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function YG(e){var t=KG(e,"string");return typeof t=="symbol"?t:t+""}function KG(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var GG=(e,t,n,r)=>{var a=t.find(u=>u&&u.index===n);if(a){if(e==="horizontal")return{x:a.coordinate,y:r.chartY};if(e==="vertical")return{x:r.chartX,y:a.coordinate}}return{x:0,y:0}},XG=(e,t,n,r)=>{var a=t.find(d=>d&&d.index===n);if(a){if(e==="centric"){var u=a.coordinate,{radius:o}=r;return eu(eu(eu({},r),en(r.cx,r.cy,o,u)),{},{angle:u,radius:o})}var c=a.coordinate,{angle:f}=r;return eu(eu(eu({},r),en(r.cx,r.cy,c,f)),{},{angle:f,radius:c})}return{angle:0,clockWise:!1,cx:0,cy:0,endAngle:0,innerRadius:0,outerRadius:0,radius:0,startAngle:0,x:0,y:0}};function ZG(e,t){var{chartX:n,chartY:r}=e;return n>=t.left&&n<=t.left+t.width&&r>=t.top&&r<=t.top+t.height}var zD=(e,t,n,r,a)=>{var u,o=(u=t==null?void 0:t.length)!==null&&u!==void 0?u:0;if(o<=1||e==null)return 0;if(r==="angleAxis"&&a!=null&&Math.abs(Math.abs(a[1]-a[0])-360)<=1e-6)for(var c=0;c<o;c++){var f,d,m,p,y,g=c>0?(f=n[c-1])===null||f===void 0?void 0:f.coordinate:(d=n[o-1])===null||d===void 0?void 0:d.coordinate,x=(m=n[c])===null||m===void 0?void 0:m.coordinate,w=c>=o-1?(p=n[0])===null||p===void 0?void 0:p.coordinate:(y=n[c+1])===null||y===void 0?void 0:y.coordinate,S=void 0;if(!(g==null||x==null||w==null))if(_n(x-g)!==_n(w-x)){var O=[];if(_n(w-x)===_n(a[1]-a[0])){S=w;var _=x+a[1]-a[0];O[0]=Math.min(_,(_+g)/2),O[1]=Math.max(_,(_+g)/2)}else{S=g;var k=w+a[1]-a[0];O[0]=Math.min(x,(k+x)/2),O[1]=Math.max(x,(k+x)/2)}var M=[Math.min(x,(S+x)/2),Math.max(x,(S+x)/2)];if(e>M[0]&&e<=M[1]||e>=O[0]&&e<=O[1]){var N;return(N=n[c])===null||N===void 0?void 0:N.index}}else{var C=Math.min(g,w),z=Math.max(g,w);if(e>(C+x)/2&&e<=(z+x)/2){var $;return($=n[c])===null||$===void 0?void 0:$.index}}}else if(t)for(var H=0;H<o;H++){var P=t[H];if(P!=null){var F=t[H+1],I=t[H-1];if(H===0&&F!=null&&e<=(P.coordinate+F.coordinate)/2||H===o-1&&I!=null&&e>(P.coordinate+I.coordinate)/2||H>0&&H<o-1&&I!=null&&F!=null&&e>(P.coordinate+I.coordinate)/2&&e<=(P.coordinate+F.coordinate)/2)return P.index}}return-1},QG=()=>Ee(kb),Zb=(e,t)=>t,DD=(e,t,n)=>n,Qb=(e,t,n,r)=>r,WG=te(Pi,e=>Ld(e,t=>t.coordinate)),Wb=te([Du,Zb,DD,Qb],gD),Jb=te([Wb,Pu,zs,Ns],Vb),JG=(e,t,n)=>{if(t!=null){var r=Du(e);return t==="axis"?n==="hover"?r.axisInteraction.hover.dataKey:r.axisInteraction.click.dataKey:n==="hover"?r.itemInteraction.hover.dataKey:r.itemInteraction.click.dataKey}},ND=te([Du,Zb,DD,Qb],xD),wd=te([Ti,ji,at,Ht,Pi,Qb,ND],bD),eX=te([Wb,wd],(e,t)=>{var n;return(n=e.coordinate)!==null&&n!==void 0?n:t}),PD=te([Pi,Jb],hD),tX=te([ND,Jb,zi,zs,PD,wD,Zb],SD),nX=te([Wb,Jb],(e,t)=>({isActive:e.active&&t!=null,activeIndex:t})),rX=(e,t,n,r,a,u,o)=>{if(!(!e||!n||!r||!a)&&ZG(e,o)){var c=NH(e,t),f=zD(c,u,a,n,r),d=GG(t,a,f,e);return{activeIndex:String(f),activeCoordinate:d}}},iX=(e,t,n,r,a,u,o)=>{if(!(!e||!r||!a||!u||!n)){var c=$$(e,n);if(c){var f=PH(c,t),d=zD(f,o,u,r,a),m=XG(t,u,d,c);return{activeIndex:String(d),activeCoordinate:m}}}},aX=(e,t,n,r,a,u,o,c)=>{if(!(!e||!t||!r||!a||!u))return t==="horizontal"||t==="vertical"?rX(e,t,r,a,u,o,c):iX(e,t,n,r,a,u,o)},lX=te(e=>e.zIndex.zIndexMap,(e,t)=>t,(e,t,n)=>n,(e,t,n)=>{if(t!=null){var r=e[t];if(r!=null)return n?r.panoramaElement:r.element}}),uX=te(e=>e.zIndex.zIndexMap,e=>{var t=Object.keys(e).map(r=>parseInt(r,10)).concat(Object.values(mn)),n=Array.from(new Set(t));return n.sort((r,a)=>r-a)},{memoizeOptions:{resultEqualityCheck:HY}});function J_(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function ek(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?J_(Object(n),!0).forEach(function(r){oX(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):J_(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function oX(e,t,n){return(t=sX(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function sX(e){var t=cX(e,"string");return typeof t=="symbol"?t:t+""}function cX(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var fX={},dX={zIndexMap:Object.values(mn).reduce((e,t)=>ek(ek({},e),{},{[t]:{element:void 0,panoramaElement:void 0,consumers:0}}),fX)},hX=new Set(Object.values(mn));function mX(e){return hX.has(e)}var RD=jn({name:"zIndex",initialState:dX,reducers:{registerZIndexPortal:{reducer:(e,t)=>{var{zIndex:n}=t.payload;e.zIndexMap[n]?e.zIndexMap[n].consumers+=1:e.zIndexMap[n]={consumers:1,element:void 0,panoramaElement:void 0}},prepare:ht()},unregisterZIndexPortal:{reducer:(e,t)=>{var{zIndex:n}=t.payload;e.zIndexMap[n]&&(e.zIndexMap[n].consumers-=1,e.zIndexMap[n].consumers<=0&&!mX(n)&&delete e.zIndexMap[n])},prepare:ht()},registerZIndexPortalElement:{reducer:(e,t)=>{var{zIndex:n,element:r,isPanorama:a}=t.payload;e.zIndexMap[n]?a?e.zIndexMap[n].panoramaElement=r:e.zIndexMap[n].element=r:e.zIndexMap[n]={consumers:0,element:a?void 0:r,panoramaElement:a?r:void 0}},prepare:ht()},unregisterZIndexPortalElement:{reducer:(e,t)=>{var{zIndex:n}=t.payload;e.zIndexMap[n]&&(t.payload.isPanorama?e.zIndexMap[n].panoramaElement=void 0:e.zIndexMap[n].element=void 0)},prepare:ht()}}}),{registerZIndexPortal:pX,unregisterZIndexPortal:vX,registerZIndexPortalElement:yX,unregisterZIndexPortalElement:gX}=RD.actions,bX=RD.reducer;function Ri(e){var{zIndex:t,children:n}=e,r=m7(),a=r&&t!==void 0&&t!==0,u=Mn(),o=wt();E.useLayoutEffect(()=>a?(o(pX({zIndex:t})),()=>{o(vX({zIndex:t}))}):Au,[o,t,a]);var c=Ee(f=>lX(f,t,u));return a?c?BT.createPortal(n,c):null:n}function Xg(){return Xg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Xg.apply(null,arguments)}function tk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Sf(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?tk(Object(n),!0).forEach(function(r){xX(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):tk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function xX(e,t,n){return(t=wX(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function wX(e){var t=SX(e,"string");return typeof t=="symbol"?t:t+""}function SX(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function OX(e){var{cursor:t,cursorComp:n,cursorProps:r}=e;return E.isValidElement(t)?E.cloneElement(t,r):E.createElement(n,r)}function EX(e){var t,{coordinate:n,payload:r,index:a,offset:u,tooltipAxisBandSize:o,layout:c,cursor:f,tooltipEventType:d,chartName:m}=e,p=n,y=r,g=a;if(!f||!p||m!=="ScatterChart"&&d!=="axis")return null;var x,w,S;if(m==="ScatterChart")x=p,w=n$,S=mn.cursorLine;else if(m==="BarChart")x=r$(c,p,u,o),w=xM,S=mn.cursorRectangle;else if(c==="radial"&&lj(p)){var{cx:O,cy:_,radius:k,startAngle:M,endAngle:N}=wM(p);x={cx:O,cy:_,startAngle:M,endAngle:N,innerRadius:k,outerRadius:k},w=OM,S=mn.cursorLine}else x={points:K$(c,p,u)},w=pM,S=mn.cursorLine;var C=typeof f=="object"&&"className"in f?f.className:void 0,z=Sf(Sf(Sf(Sf({stroke:"#ccc",pointerEvents:"none"},u),x),D0(f)),{},{payload:y,payloadIndex:g,className:ft("recharts-tooltip-cursor",C)});return E.createElement(Ri,{zIndex:(t=e.zIndex)!==null&&t!==void 0?t:S},E.createElement(OX,{cursor:f,cursorComp:w,cursorProps:z}))}function AX(e){var t=FG(),n=nM(),r=_u(),a=QG();return t==null||n==null||r==null||a==null?null:E.createElement(EX,Xg({},e,{offset:n,layout:r,tooltipAxisBandSize:t,chartName:a}))}var ID=E.createContext(null),_X=()=>E.useContext(ID),zy={exports:{}},nk;function kX(){return nk||(nk=1,(function(e){var t=Object.prototype.hasOwnProperty,n="~";function r(){}Object.create&&(r.prototype=Object.create(null),new r().__proto__||(n=!1));function a(f,d,m){this.fn=f,this.context=d,this.once=m||!1}function u(f,d,m,p,y){if(typeof m!="function")throw new TypeError("The listener must be a function");var g=new a(m,p||f,y),x=n?n+d:d;return f._events[x]?f._events[x].fn?f._events[x]=[f._events[x],g]:f._events[x].push(g):(f._events[x]=g,f._eventsCount++),f}function o(f,d){--f._eventsCount===0?f._events=new r:delete f._events[d]}function c(){this._events=new r,this._eventsCount=0}c.prototype.eventNames=function(){var d=[],m,p;if(this._eventsCount===0)return d;for(p in m=this._events)t.call(m,p)&&d.push(n?p.slice(1):p);return Object.getOwnPropertySymbols?d.concat(Object.getOwnPropertySymbols(m)):d},c.prototype.listeners=function(d){var m=n?n+d:d,p=this._events[m];if(!p)return[];if(p.fn)return[p.fn];for(var y=0,g=p.length,x=new Array(g);y<g;y++)x[y]=p[y].fn;return x},c.prototype.listenerCount=function(d){var m=n?n+d:d,p=this._events[m];return p?p.fn?1:p.length:0},c.prototype.emit=function(d,m,p,y,g,x){var w=n?n+d:d;if(!this._events[w])return!1;var S=this._events[w],O=arguments.length,_,k;if(S.fn){switch(S.once&&this.removeListener(d,S.fn,void 0,!0),O){case 1:return S.fn.call(S.context),!0;case 2:return S.fn.call(S.context,m),!0;case 3:return S.fn.call(S.context,m,p),!0;case 4:return S.fn.call(S.context,m,p,y),!0;case 5:return S.fn.call(S.context,m,p,y,g),!0;case 6:return S.fn.call(S.context,m,p,y,g,x),!0}for(k=1,_=new Array(O-1);k<O;k++)_[k-1]=arguments[k];S.fn.apply(S.context,_)}else{var M=S.length,N;for(k=0;k<M;k++)switch(S[k].once&&this.removeListener(d,S[k].fn,void 0,!0),O){case 1:S[k].fn.call(S[k].context);break;case 2:S[k].fn.call(S[k].context,m);break;case 3:S[k].fn.call(S[k].context,m,p);break;case 4:S[k].fn.call(S[k].context,m,p,y);break;default:if(!_)for(N=1,_=new Array(O-1);N<O;N++)_[N-1]=arguments[N];S[k].fn.apply(S[k].context,_)}}return!0},c.prototype.on=function(d,m,p){return u(this,d,m,p,!1)},c.prototype.once=function(d,m,p){return u(this,d,m,p,!0)},c.prototype.removeListener=function(d,m,p,y){var g=n?n+d:d;if(!this._events[g])return this;if(!m)return o(this,g),this;var x=this._events[g];if(x.fn)x.fn===m&&(!y||x.once)&&(!p||x.context===p)&&o(this,g);else{for(var w=0,S=[],O=x.length;w<O;w++)(x[w].fn!==m||y&&!x[w].once||p&&x[w].context!==p)&&S.push(x[w]);S.length?this._events[g]=S.length===1?S[0]:S:o(this,g)}return this},c.prototype.removeAllListeners=function(d){var m;return d?(m=n?n+d:d,this._events[m]&&o(this,m)):(this._events=new r,this._eventsCount=0),this},c.prototype.off=c.prototype.removeListener,c.prototype.addListener=c.prototype.on,c.prefixed=n,c.EventEmitter=c,e.exports=c})(zy)),zy.exports}var CX=kX();const TX=Tr(CX);var ms=new TX,Zg="recharts.syncEvent.tooltip",rk="recharts.syncEvent.brush",jX=(e,t)=>{if(t&&Array.isArray(e)){var n=Number.parseInt(t,10);if(!$r(n))return e[n]}},MX={chartName:"",tooltipPayloadSearcher:()=>{},eventEmitter:void 0,defaultTooltipEventType:"axis"},LD=jn({name:"options",initialState:MX,reducers:{createEventEmitter:e=>{e.eventEmitter==null&&(e.eventEmitter=Symbol("rechartsEventEmitter"))}}}),zX=LD.reducer,{createEventEmitter:DX}=LD.actions;function NX(e){return e.tooltip.syncInteraction}var PX={chartData:void 0,computedData:void 0,dataStartIndex:0,dataEndIndex:0},BD=jn({name:"chartData",initialState:PX,reducers:{setChartData(e,t){if(e.chartData=t.payload,t.payload==null){e.dataStartIndex=0,e.dataEndIndex=0;return}t.payload.length>0&&e.dataEndIndex!==t.payload.length-1&&(e.dataEndIndex=t.payload.length-1)},setComputedData(e,t){e.computedData=t.payload},setDataStartEndIndexes(e,t){var{startIndex:n,endIndex:r}=t.payload;n!=null&&(e.dataStartIndex=n),r!=null&&(e.dataEndIndex=r)}}}),{setChartData:ik,setDataStartEndIndexes:RX,setComputedData:yne}=BD.actions,IX=BD.reducer,LX=["x","y"];function ak(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function tu(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?ak(Object(n),!0).forEach(function(r){BX(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):ak(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function BX(e,t,n){return(t=UX(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function UX(e){var t=qX(e,"string");return typeof t=="symbol"?t:t+""}function qX(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function HX(e,t){if(e==null)return{};var n,r,a=$X(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function $X(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function FX(){var e=Ee(Cb),t=Ee(Tb),n=wt(),r=Ee(wz),a=Ee(Pi),u=_u(),o=Wd(),c=Ee(f=>f.rootProps.className);E.useEffect(()=>{if(e==null)return Au;var f=(d,m,p)=>{if(t!==p&&e===d){if(r==="index"){var y;if(o&&m!==null&&m!==void 0&&(y=m.payload)!==null&&y!==void 0&&y.coordinate&&m.payload.sourceViewBox){var g=m.payload.coordinate,{x,y:w}=g,S=HX(g,LX),{x:O,y:_,width:k,height:M}=m.payload.sourceViewBox,N=tu(tu({},S),{},{x:o.x+(k?(x-O)/k:0)*o.width,y:o.y+(M?(w-_)/M:0)*o.height});n(tu(tu({},m),{},{payload:tu(tu({},m.payload),{},{coordinate:N})}))}else n(m);return}if(a!=null){var C;if(typeof r=="function"){var z={activeTooltipIndex:m.payload.index==null?void 0:Number(m.payload.index),isTooltipActive:m.payload.active,activeIndex:m.payload.index==null?void 0:Number(m.payload.index),activeLabel:m.payload.label,activeDataKey:m.payload.dataKey,activeCoordinate:m.payload.coordinate},$=r(a,z);C=a[$]}else r==="value"&&(C=a.find(U=>String(U.value)===m.payload.label));var{coordinate:H}=m.payload;if(C==null||m.payload.active===!1||H==null||o==null){n(Kg({active:!1,coordinate:void 0,dataKey:void 0,index:null,label:void 0,sourceViewBox:void 0,graphicalItemId:void 0}));return}var{x:P,y:F}=H,I=Math.min(P,o.x+o.width),ee=Math.min(F,o.y+o.height),Z={x:u==="horizontal"?C.coordinate:I,y:u==="horizontal"?ee:C.coordinate},Y=Kg({active:m.payload.active,coordinate:Z,dataKey:m.payload.dataKey,index:String(C.index),label:m.payload.label,sourceViewBox:m.payload.sourceViewBox,graphicalItemId:m.payload.graphicalItemId});n(Y)}}};return ms.on(Zg,f),()=>{ms.off(Zg,f)}},[c,n,t,e,r,a,u,o])}function VX(){var e=Ee(Cb),t=Ee(Tb),n=wt();E.useEffect(()=>{if(e==null)return Au;var r=(a,u,o)=>{t!==o&&e===a&&n(RX(u))};return ms.on(rk,r),()=>{ms.off(rk,r)}},[n,t,e])}function YX(){var e=wt();E.useEffect(()=>{e(DX())},[e]),FX(),VX()}function KX(e,t,n,r,a,u){var o=Ee(g=>JG(g,e,t)),c=Ee(Tb),f=Ee(Cb),d=Ee(wz),m=Ee(NX),p=m==null?void 0:m.active,y=Wd();E.useEffect(()=>{if(!p&&f!=null&&c!=null){var g=Kg({active:u,coordinate:n,dataKey:o,index:a,label:typeof r=="number"?String(r):r,sourceViewBox:y,graphicalItemId:void 0});ms.emit(Zg,f,g,c)}},[p,n,o,a,r,c,f,d,u,y])}function lk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function uk(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?lk(Object(n),!0).forEach(function(r){GX(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):lk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function GX(e,t,n){return(t=XX(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function XX(e){var t=ZX(e,"string");return typeof t=="symbol"?t:t+""}function ZX(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function QX(e){return e.dataKey}function WX(e,t){return E.isValidElement(e)?E.cloneElement(e,t):typeof e=="function"?E.createElement(e,t):E.createElement(P7,t)}var ok=[],JX={allowEscapeViewBox:{x:!1,y:!1},animationDuration:400,animationEasing:"ease",axisId:0,contentStyle:{},cursor:!0,filterNull:!0,includeHidden:!1,isAnimationActive:"auto",itemSorter:"name",itemStyle:{},labelStyle:{},offset:10,reverseDirection:{x:!1,y:!1},separator:" : ",trigger:"hover",useTranslate3d:!1,wrapperStyle:{}};function eZ(e){var t,n,r=Kn(e,JX),{active:a,allowEscapeViewBox:u,animationDuration:o,animationEasing:c,content:f,filterNull:d,isAnimationActive:m,offset:p,payloadUniqBy:y,position:g,reverseDirection:x,useTranslate3d:w,wrapperStyle:S,cursor:O,shared:_,trigger:k,defaultIndex:M,portal:N,axisId:C}=r,z=wt(),$=typeof M=="number"?String(M):M;E.useEffect(()=>{z(XK({shared:_,trigger:k,axisId:C,active:a,defaultIndex:$}))},[z,_,k,C,a,$]);var H=Wd(),P=mM(),F=$K(_),{activeIndex:I,isActive:ee}=(t=Ee(Se=>nX(Se,F,k,$)))!==null&&t!==void 0?t:{},Z=Ee(Se=>tX(Se,F,k,$)),Y=Ee(Se=>PD(Se,F,k,$)),U=Ee(Se=>eX(Se,F,k,$)),Q=Z,ue=_X(),de=(n=a??ee)!==null&&n!==void 0?n:!1,[R,L]=bq([Q,de]),J=F==="axis"?Y:void 0;KX(F,k,U,J,I,de);var D=N??ue;if(D==null||H==null||F==null)return null;var oe=Q??ok;de||(oe=ok),d&&oe.length&&(oe=VU(oe.filter(Se=>Se.value!=null&&(Se.hide!==!0||r.includeHidden)),y,QX));var ye=oe.length>0,ve=E.createElement(H7,{allowEscapeViewBox:u,animationDuration:o,animationEasing:c,isAnimationActive:m,active:de,coordinate:U,hasPayload:ye,offset:p,position:g,reverseDirection:x,useTranslate3d:w,viewBox:H,wrapperStyle:S,lastBoundingBox:R,innerRef:L,hasPortalFromProps:!!N},WX(f,uk(uk({},r),{},{payload:oe,label:J,active:de,activeIndex:I,coordinate:U,accessibilityLayer:P})));return E.createElement(E.Fragment,null,BT.createPortal(ve,D),de&&E.createElement(AX,{cursor:O,tooltipEventType:F,coordinate:U,payload:oe,index:I}))}var UD=e=>null;UD.displayName="Cell";function tZ(e,t,n){return(t=nZ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function nZ(e){var t=rZ(e,"string");return typeof t=="symbol"?t:t+""}function rZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}class iZ{constructor(t){tZ(this,"cache",new Map),this.maxSize=t}get(t){var n=this.cache.get(t);return n!==void 0&&(this.cache.delete(t),this.cache.set(t,n)),n}set(t,n){if(this.cache.has(t))this.cache.delete(t);else if(this.cache.size>=this.maxSize){var r=this.cache.keys().next().value;r!=null&&this.cache.delete(r)}this.cache.set(t,n)}clear(){this.cache.clear()}size(){return this.cache.size}}function sk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function aZ(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?sk(Object(n),!0).forEach(function(r){lZ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):sk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function lZ(e,t,n){return(t=uZ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function uZ(e){var t=oZ(e,"string");return typeof t=="symbol"?t:t+""}function oZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var sZ={cacheSize:2e3,enableCache:!0},qD=aZ({},sZ),ck=new iZ(qD.cacheSize),cZ={position:"absolute",top:"-20000px",left:0,padding:0,margin:0,border:"none",whiteSpace:"pre"},fk="recharts_measurement_span";function fZ(e,t){var n=t.fontSize||"",r=t.fontFamily||"",a=t.fontWeight||"",u=t.fontStyle||"",o=t.letterSpacing||"",c=t.textTransform||"";return"".concat(e,"|").concat(n,"|").concat(r,"|").concat(a,"|").concat(u,"|").concat(o,"|").concat(c)}var dk=(e,t)=>{try{var n=document.getElementById(fk);n||(n=document.createElement("span"),n.setAttribute("id",fk),n.setAttribute("aria-hidden","true"),document.body.appendChild(n)),Object.assign(n.style,cZ,t),n.textContent="".concat(e);var r=n.getBoundingClientRect();return{width:r.width,height:r.height}}catch{return{width:0,height:0}}},Wo=function(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};if(t==null||nh.isSsr)return{width:0,height:0};if(!qD.enableCache)return dk(t,n);var r=fZ(t,n),a=ck.get(r);if(a)return a;var u=dk(t,n);return ck.set(r,u),u},HD;function dZ(e,t,n){return(t=hZ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function hZ(e){var t=mZ(e,"string");return typeof t=="symbol"?t:t+""}function mZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var hk=/(-?\d+(?:\.\d+)?[a-zA-Z%]*)([*/])(-?\d+(?:\.\d+)?[a-zA-Z%]*)/,mk=/(-?\d+(?:\.\d+)?[a-zA-Z%]*)([+-])(-?\d+(?:\.\d+)?[a-zA-Z%]*)/,pZ=/^px|cm|vh|vw|em|rem|%|mm|in|pt|pc|ex|ch|vmin|vmax|Q$/,vZ=/(-?\d+(?:\.\d+)?)([a-zA-Z%]+)?/,yZ={cm:96/2.54,mm:96/25.4,pt:96/72,pc:96/6,in:96,Q:96/(2.54*40),px:1},gZ=["cm","mm","pt","pc","in","Q","px"];function bZ(e){return gZ.includes(e)}var lu="NaN";function xZ(e,t){return e*yZ[t]}class Wt{static parse(t){var n,[,r,a]=(n=vZ.exec(t))!==null&&n!==void 0?n:[];return r==null?Wt.NaN:new Wt(parseFloat(r),a??"")}constructor(t,n){this.num=t,this.unit=n,this.num=t,this.unit=n,$r(t)&&(this.unit=""),n!==""&&!pZ.test(n)&&(this.num=NaN,this.unit=""),bZ(n)&&(this.num=xZ(t,n),this.unit="px")}add(t){return this.unit!==t.unit?new Wt(NaN,""):new Wt(this.num+t.num,this.unit)}subtract(t){return this.unit!==t.unit?new Wt(NaN,""):new Wt(this.num-t.num,this.unit)}multiply(t){return this.unit!==""&&t.unit!==""&&this.unit!==t.unit?new Wt(NaN,""):new Wt(this.num*t.num,this.unit||t.unit)}divide(t){return this.unit!==""&&t.unit!==""&&this.unit!==t.unit?new Wt(NaN,""):new Wt(this.num/t.num,this.unit||t.unit)}toString(){return"".concat(this.num).concat(this.unit)}isNaN(){return $r(this.num)}}HD=Wt;dZ(Wt,"NaN",new HD(NaN,""));function $D(e){if(e==null||e.includes(lu))return lu;for(var t=e;t.includes("*")||t.includes("/");){var n,[,r,a,u]=(n=hk.exec(t))!==null&&n!==void 0?n:[],o=Wt.parse(r??""),c=Wt.parse(u??""),f=a==="*"?o.multiply(c):o.divide(c);if(f.isNaN())return lu;t=t.replace(hk,f.toString())}for(;t.includes("+")||/.-\d+(?:\.\d+)?/.test(t);){var d,[,m,p,y]=(d=mk.exec(t))!==null&&d!==void 0?d:[],g=Wt.parse(m??""),x=Wt.parse(y??""),w=p==="+"?g.add(x):g.subtract(x);if(w.isNaN())return lu;t=t.replace(mk,w.toString())}return t}var pk=/\(([^()]*)\)/;function wZ(e){for(var t=e,n;(n=pk.exec(t))!=null;){var[,r]=n;t=t.replace(pk,$D(r))}return t}function SZ(e){var t=e.replace(/\s+/g,"");return t=wZ(t),t=$D(t),t}function OZ(e){try{return SZ(e)}catch{return lu}}function Dy(e){var t=OZ(e.slice(5,-1));return t===lu?"":t}var EZ=["x","y","lineHeight","capHeight","fill","scaleToFit","textAnchor","verticalAnchor"],AZ=["dx","dy","angle","className","breakAll"];function Qg(){return Qg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Qg.apply(null,arguments)}function vk(e,t){if(e==null)return{};var n,r,a=_Z(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function _Z(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var FD=/[ \f\n\r\t\v\u2028\u2029]+/,VD=e=>{var{children:t,breakAll:n,style:r}=e;try{var a=[];qt(t)||(n?a=t.toString().split(""):a=t.toString().split(FD));var u=a.map(c=>({word:c,width:Wo(c,r).width})),o=n?0:Wo(" ",r).width;return{wordsWithComputedWidth:u,spaceWidth:o}}catch{return null}};function kZ(e){return e==="start"||e==="middle"||e==="end"||e==="inherit"}var YD=(e,t,n,r)=>e.reduce((a,u)=>{var{word:o,width:c}=u,f=a[a.length-1];if(f&&c!=null&&(t==null||r||f.width+c+n<Number(t)))f.words.push(o),f.width+=c+n;else{var d={words:[o],width:c};a.push(d)}return a},[]),KD=e=>e.reduce((t,n)=>t.width>n.width?t:n),CZ="…",yk=(e,t,n,r,a,u,o,c)=>{var f=e.slice(0,t),d=VD({breakAll:n,style:r,children:f+CZ});if(!d)return[!1,[]];var m=YD(d.wordsWithComputedWidth,u,o,c),p=m.length>a||KD(m).width>Number(u);return[p,m]},TZ=(e,t,n,r,a)=>{var{maxLines:u,children:o,style:c,breakAll:f}=e,d=we(u),m=String(o),p=YD(t,r,n,a);if(!d||a)return p;var y=p.length>u||KD(p).width>Number(r);if(!y)return p;for(var g=0,x=m.length-1,w=0,S;g<=x&&w<=m.length-1;){var O=Math.floor((g+x)/2),_=O-1,[k,M]=yk(m,_,f,c,u,r,n,a),[N]=yk(m,O,f,c,u,r,n,a);if(!k&&!N&&(g=O+1),k&&N&&(x=O-1),!k&&N){S=M;break}w++}return S||p},gk=e=>{var t=qt(e)?[]:e.toString().split(FD);return[{words:t,width:void 0}]},jZ=e=>{var{width:t,scaleToFit:n,children:r,style:a,breakAll:u,maxLines:o}=e;if((t||n)&&!nh.isSsr){var c,f,d=VD({breakAll:u,children:r,style:a});if(d){var{wordsWithComputedWidth:m,spaceWidth:p}=d;c=m,f=p}else return gk(r);return TZ({breakAll:u,children:r,maxLines:o,style:a},c,f,t,!!n)}return gk(r)},GD="#808080",MZ={angle:0,breakAll:!1,capHeight:"0.71em",fill:GD,lineHeight:"1em",scaleToFit:!1,textAnchor:"start",verticalAnchor:"end",x:0,y:0},ex=E.forwardRef((e,t)=>{var n=Kn(e,MZ),{x:r,y:a,lineHeight:u,capHeight:o,fill:c,scaleToFit:f,textAnchor:d,verticalAnchor:m}=n,p=vk(n,EZ),y=E.useMemo(()=>jZ({breakAll:p.breakAll,children:p.children,maxLines:p.maxLines,scaleToFit:f,style:p.style,width:p.width}),[p.breakAll,p.children,p.maxLines,f,p.style,p.width]),{dx:g,dy:x,angle:w,className:S,breakAll:O}=p,_=vk(p,AZ);if(!Fr(r)||!Fr(a)||y.length===0)return null;var k=Number(r)+(we(g)?g:0),M=Number(a)+(we(x)?x:0);if(!qe(k)||!qe(M))return null;var N;switch(m){case"start":N=Dy("calc(".concat(o,")"));break;case"middle":N=Dy("calc(".concat((y.length-1)/2," * -").concat(u," + (").concat(o," / 2))"));break;default:N=Dy("calc(".concat(y.length-1," * -").concat(u,")"));break}var C=[],z=y[0];if(f&&z!=null){var $=z.width,{width:H}=p;C.push("scale(".concat(we(H)&&we($)?H/$:1,")"))}return w&&C.push("rotate(".concat(w,", ").concat(k,", ").concat(M,")")),C.length&&(_.transform=C.join(" ")),E.createElement("text",Qg({},hr(_),{ref:t,x:k,y:M,className:ft("recharts-text",S),textAnchor:d,fill:c.includes("url")?GD:c}),y.map((P,F)=>{var I=P.words.join(O?"":" ");return E.createElement("tspan",{x:k,dy:F===0?N:u,key:"".concat(I,"-").concat(F)},I)}))});ex.displayName="Text";function bk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ir(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?bk(Object(n),!0).forEach(function(r){zZ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):bk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function zZ(e,t,n){return(t=DZ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function DZ(e){var t=NZ(e,"string");return typeof t=="symbol"?t:t+""}function NZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var PZ=e=>{var{viewBox:t,position:n,offset:r=0,parentViewBox:a}=e,{x:u,y:o,height:c,upperWidth:f,lowerWidth:d}=W0(t),m=u,p=u+(f-d)/2,y=(m+p)/2,g=(f+d)/2,x=m+f/2,w=c>=0?1:-1,S=w*r,O=w>0?"end":"start",_=w>0?"start":"end",k=f>=0?1:-1,M=k*r,N=k>0?"end":"start",C=k>0?"start":"end",z=a;if(n==="top"){var $={x:m+f/2,y:o-S,horizontalAnchor:"middle",verticalAnchor:O};return z&&($.height=Math.max(o-z.y,0),$.width=f),$}if(n==="bottom"){var H={x:p+d/2,y:o+c+S,horizontalAnchor:"middle",verticalAnchor:_};return z&&(H.height=Math.max(z.y+z.height-(o+c),0),H.width=d),H}if(n==="left"){var P={x:y-M,y:o+c/2,horizontalAnchor:N,verticalAnchor:"middle"};return z&&(P.width=Math.max(P.x-z.x,0),P.height=c),P}if(n==="right"){var F={x:y+g+M,y:o+c/2,horizontalAnchor:C,verticalAnchor:"middle"};return z&&(F.width=Math.max(z.x+z.width-F.x,0),F.height=c),F}var I=z?{width:g,height:c}:{};return n==="insideLeft"?Ir({x:y+M,y:o+c/2,horizontalAnchor:C,verticalAnchor:"middle"},I):n==="insideRight"?Ir({x:y+g-M,y:o+c/2,horizontalAnchor:N,verticalAnchor:"middle"},I):n==="insideTop"?Ir({x:m+f/2,y:o+S,horizontalAnchor:"middle",verticalAnchor:_},I):n==="insideBottom"?Ir({x:p+d/2,y:o+c-S,horizontalAnchor:"middle",verticalAnchor:O},I):n==="insideTopLeft"?Ir({x:m+M,y:o+S,horizontalAnchor:C,verticalAnchor:_},I):n==="insideTopRight"?Ir({x:m+f-M,y:o+S,horizontalAnchor:N,verticalAnchor:_},I):n==="insideBottomLeft"?Ir({x:p+M,y:o+c-S,horizontalAnchor:C,verticalAnchor:O},I):n==="insideBottomRight"?Ir({x:p+d-M,y:o+c-S,horizontalAnchor:N,verticalAnchor:O},I):n&&typeof n=="object"&&(we(n.x)||Wa(n.x))&&(we(n.y)||Wa(n.y))?Ir({x:u+kr(n.x,g),y:o+kr(n.y,c),horizontalAnchor:"end",verticalAnchor:"end"},I):Ir({x,y:o+c/2,horizontalAnchor:"middle",verticalAnchor:"middle"},I)},RZ=["labelRef"],IZ=["content"];function xk(e,t){if(e==null)return{};var n,r,a=LZ(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function LZ(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function wk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Go(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?wk(Object(n),!0).forEach(function(r){BZ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):wk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function BZ(e,t,n){return(t=UZ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function UZ(e){var t=qZ(e,"string");return typeof t=="symbol"?t:t+""}function qZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function mi(){return mi=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},mi.apply(null,arguments)}var XD=E.createContext(null),HZ=e=>{var{x:t,y:n,upperWidth:r,lowerWidth:a,width:u,height:o,children:c}=e,f=E.useMemo(()=>({x:t,y:n,upperWidth:r,lowerWidth:a,width:u,height:o}),[t,n,r,a,u,o]);return E.createElement(XD.Provider,{value:f},c)},ZD=()=>{var e=E.useContext(XD),t=Wd();return e||(t?W0(t):void 0)},$Z=E.createContext(null),FZ=()=>{var e=E.useContext($Z),t=Ee(_z);return e||t},VZ=e=>{var{value:t,formatter:n}=e,r=qt(e.children)?t:e.children;return typeof n=="function"?n(r):r},tx=e=>e!=null&&typeof e=="function",YZ=(e,t)=>{var n=_n(t-e),r=Math.min(Math.abs(t-e),360);return n*r},KZ=(e,t,n,r,a)=>{var{offset:u,className:o}=e,{cx:c,cy:f,innerRadius:d,outerRadius:m,startAngle:p,endAngle:y,clockWise:g}=a,x=(d+m)/2,w=YZ(p,y),S=w>=0?1:-1,O,_;switch(t){case"insideStart":O=p+S*u,_=g;break;case"insideEnd":O=y-S*u,_=!g;break;case"end":O=y+S*u,_=g;break;default:throw new Error("Unsupported position ".concat(t))}_=w<=0?_:!_;var k=en(c,f,x,O),M=en(c,f,x,O+(_?1:-1)*359),N="M".concat(k.x,",").concat(k.y,`
    A`).concat(x,",").concat(x,",0,1,").concat(_?0:1,`,
    `).concat(M.x,",").concat(M.y),C=qt(e.id)?ts("recharts-radial-line-"):e.id;return E.createElement("text",mi({},r,{dominantBaseline:"central",className:ft("recharts-radial-bar-label",o)}),E.createElement("defs",null,E.createElement("path",{id:C,d:N})),E.createElement("textPath",{xlinkHref:"#".concat(C)},n))},GZ=(e,t,n)=>{var{cx:r,cy:a,innerRadius:u,outerRadius:o,startAngle:c,endAngle:f}=e,d=(c+f)/2;if(n==="outside"){var{x:m,y:p}=en(r,a,o+t,d);return{x:m,y:p,textAnchor:m>=r?"start":"end",verticalAnchor:"middle"}}if(n==="center")return{x:r,y:a,textAnchor:"middle",verticalAnchor:"middle"};if(n==="centerTop")return{x:r,y:a,textAnchor:"middle",verticalAnchor:"start"};if(n==="centerBottom")return{x:r,y:a,textAnchor:"middle",verticalAnchor:"end"};var y=(u+o)/2,{x:g,y:x}=en(r,a,y,d);return{x:g,y:x,textAnchor:"middle",verticalAnchor:"middle"}},jf=e=>e!=null&&"cx"in e&&we(e.cx),XZ={angle:0,offset:5,zIndex:mn.label,position:"middle",textBreakAll:!1};function ZZ(e){if(!jf(e))return e;var{cx:t,cy:n,outerRadius:r}=e,a=r*2;return{x:t-r,y:n-r,width:a,upperWidth:a,lowerWidth:a,height:a}}function ca(e){var t=Kn(e,XZ),{viewBox:n,parentViewBox:r,position:a,value:u,children:o,content:c,className:f="",textBreakAll:d,labelRef:m}=t,p=FZ(),y=ZD(),g=a==="center"?y:p??y,x,w,S;n==null?x=g:jf(n)?x=n:x=W0(n);var O=ZZ(x);if(!x||qt(u)&&qt(o)&&!E.isValidElement(c)&&typeof c!="function")return null;var _=Go(Go({},t),{},{viewBox:x});if(E.isValidElement(c)){var{labelRef:k}=_,M=xk(_,RZ);return E.cloneElement(c,M)}if(typeof c=="function"){var{content:N}=_,C=xk(_,IZ);if(w=E.createElement(c,C),E.isValidElement(w))return w}else w=VZ(t);var z=hr(t);if(jf(x)){if(a==="insideStart"||a==="insideEnd"||a==="end")return KZ(t,a,w,z,x);S=GZ(x,t.offset,t.position)}else{if(!O)return null;var $=PZ({viewBox:O,position:a,offset:t.offset,parentViewBox:jf(r)?void 0:r});S=Go(Go({x:$.x,y:$.y,textAnchor:$.horizontalAnchor,verticalAnchor:$.verticalAnchor},$.width!==void 0?{width:$.width}:{}),$.height!==void 0?{height:$.height}:{})}return E.createElement(Ri,{zIndex:t.zIndex},E.createElement(ex,mi({ref:m,className:ft("recharts-label",f)},z,S,{textAnchor:kZ(z.textAnchor)?z.textAnchor:S.textAnchor,breakAll:d}),w))}ca.displayName="Label";var QZ=(e,t,n)=>{if(!e)return null;var r={viewBox:t,labelRef:n};return e===!0?E.createElement(ca,mi({key:"label-implicit"},r)):Fr(e)?E.createElement(ca,mi({key:"label-implicit",value:e},r)):E.isValidElement(e)?e.type===ca?E.cloneElement(e,Go({key:"label-implicit"},r)):E.createElement(ca,mi({key:"label-implicit",content:e},r)):tx(e)?E.createElement(ca,mi({key:"label-implicit",content:e},r)):e&&typeof e=="object"?E.createElement(ca,mi({},e,{key:"label-implicit"},r)):null};function WZ(e){var{label:t,labelRef:n}=e,r=ZD();return QZ(t,r,n)||null}var Ny={},Py={},Sk;function JZ(){return Sk||(Sk=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n[n.length-1]}e.last=t})(Py)),Py}var Ry={},Ok;function eQ(){return Ok||(Ok=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return Array.isArray(n)?n:Array.from(n)}e.toArray=t})(Ry)),Ry}var Ek;function tQ(){return Ek||(Ek=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=JZ(),n=eQ(),r=q0();function a(u){if(r.isArrayLike(u))return t.last(n.toArray(u))}e.last=a})(Ny)),Ny}var Iy,Ak;function nQ(){return Ak||(Ak=1,Iy=tQ().last),Iy}var rQ=nQ();const iQ=Tr(rQ);var aQ=["valueAccessor"],lQ=["dataKey","clockWise","id","textBreakAll","zIndex"];function Sd(){return Sd=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Sd.apply(null,arguments)}function _k(e,t){if(e==null)return{};var n,r,a=uQ(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function uQ(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var oQ=e=>Array.isArray(e.value)?iQ(e.value):e.value,QD=E.createContext(void 0),sQ=QD.Provider,WD=E.createContext(void 0);WD.Provider;function cQ(){return E.useContext(QD)}function fQ(){return E.useContext(WD)}function Mf(e){var{valueAccessor:t=oQ}=e,n=_k(e,aQ),{dataKey:r,clockWise:a,id:u,textBreakAll:o,zIndex:c}=n,f=_k(n,lQ),d=cQ(),m=fQ(),p=d||m;return!p||!p.length?null:E.createElement(Ri,{zIndex:c??mn.label},E.createElement(xi,{className:"recharts-label-list"},p.map((y,g)=>{var x,w=qt(r)?t(y,g):tn(y.payload,r),S=qt(u)?{}:{id:"".concat(u,"-").concat(g)};return E.createElement(ca,Sd({key:"label-".concat(g)},hr(y),f,S,{fill:(x=n.fill)!==null&&x!==void 0?x:y.fill,parentViewBox:y.parentViewBox,value:w,textBreakAll:o,viewBox:y.viewBox,index:g,zIndex:0}))})))}Mf.displayName="LabelList";function dQ(e){var{label:t}=e;return t?t===!0?E.createElement(Mf,{key:"labelList-implicit"}):E.isValidElement(t)||tx(t)?E.createElement(Mf,{key:"labelList-implicit",content:t}):typeof t=="object"?E.createElement(Mf,Sd({key:"labelList-implicit"},t,{type:String(t.type)})):null:null}var hQ={radiusAxis:{},angleAxis:{}},JD=jn({name:"polarAxis",initialState:hQ,reducers:{addRadiusAxis(e,t){e.radiusAxis[t.payload.id]=t.payload},removeRadiusAxis(e,t){delete e.radiusAxis[t.payload.id]},addAngleAxis(e,t){e.angleAxis[t.payload.id]=t.payload},removeAngleAxis(e,t){delete e.angleAxis[t.payload.id]}}}),{addRadiusAxis:gne,removeRadiusAxis:bne,addAngleAxis:xne,removeAngleAxis:wne}=JD.actions,mQ=JD.reducer;function pQ(e){return e&&typeof e=="object"&&"className"in e&&typeof e.className=="string"?e.className:""}var Ly={exports:{}},et={};/**
 * @license React
 * react-is.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var kk;function vQ(){if(kk)return et;kk=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),a=Symbol.for("react.profiler"),u=Symbol.for("react.consumer"),o=Symbol.for("react.context"),c=Symbol.for("react.forward_ref"),f=Symbol.for("react.suspense"),d=Symbol.for("react.suspense_list"),m=Symbol.for("react.memo"),p=Symbol.for("react.lazy"),y=Symbol.for("react.view_transition"),g=Symbol.for("react.client.reference");function x(w){if(typeof w=="object"&&w!==null){var S=w.$$typeof;switch(S){case e:switch(w=w.type,w){case n:case a:case r:case f:case d:case y:return w;default:switch(w=w&&w.$$typeof,w){case o:case c:case p:case m:return w;case u:return w;default:return S}}case t:return S}}}return et.ContextConsumer=u,et.ContextProvider=o,et.Element=e,et.ForwardRef=c,et.Fragment=n,et.Lazy=p,et.Memo=m,et.Portal=t,et.Profiler=a,et.StrictMode=r,et.Suspense=f,et.SuspenseList=d,et.isContextConsumer=function(w){return x(w)===u},et.isContextProvider=function(w){return x(w)===o},et.isElement=function(w){return typeof w=="object"&&w!==null&&w.$$typeof===e},et.isForwardRef=function(w){return x(w)===c},et.isFragment=function(w){return x(w)===n},et.isLazy=function(w){return x(w)===p},et.isMemo=function(w){return x(w)===m},et.isPortal=function(w){return x(w)===t},et.isProfiler=function(w){return x(w)===a},et.isStrictMode=function(w){return x(w)===r},et.isSuspense=function(w){return x(w)===f},et.isSuspenseList=function(w){return x(w)===d},et.isValidElementType=function(w){return typeof w=="string"||typeof w=="function"||w===n||w===a||w===r||w===f||w===d||typeof w=="object"&&w!==null&&(w.$$typeof===p||w.$$typeof===m||w.$$typeof===o||w.$$typeof===u||w.$$typeof===c||w.$$typeof===g||w.getModuleId!==void 0)},et.typeOf=x,et}var Ck;function yQ(){return Ck||(Ck=1,Ly.exports=vQ()),Ly.exports}var gQ=yQ(),Tk=e=>typeof e=="string"?e:e?e.displayName||e.name||"Component":"",jk=null,By=null,eN=e=>{if(e===jk&&Array.isArray(By))return By;var t=[];return E.Children.forEach(e,n=>{qt(n)||(gQ.isFragment(n)?t=t.concat(eN(n.props.children)):t.push(n))}),By=t,jk=e,t};function bQ(e,t){var n=[],r=[];return Array.isArray(t)?r=t.map(a=>Tk(a)):r=[Tk(t)],eN(e).forEach(a=>{var u=hu(a,"type.displayName")||hu(a,"type.name");u&&r.indexOf(u)!==-1&&n.push(a)}),n}var Uy={},Mk;function xQ(){return Mk||(Mk=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){var a;if(typeof n!="object"||n==null)return!1;if(Object.getPrototypeOf(n)===null)return!0;if(Object.prototype.toString.call(n)!=="[object Object]"){const u=n[Symbol.toStringTag];return u==null||!((a=Object.getOwnPropertyDescriptor(n,Symbol.toStringTag))!=null&&a.writable)?!1:n.toString()===`[object ${u}]`}let r=n;for(;Object.getPrototypeOf(r)!==null;)r=Object.getPrototypeOf(r);return Object.getPrototypeOf(n)===r}e.isPlainObject=t})(Uy)),Uy}var qy,zk;function wQ(){return zk||(zk=1,qy=xQ().isPlainObject),qy}var SQ=wQ();const OQ=Tr(SQ);var Dk,Nk,Pk,Rk,Ik;function Lk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Bk(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Lk(Object(n),!0).forEach(function(r){EQ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Lk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function EQ(e,t,n){return(t=AQ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function AQ(e){var t=_Q(e,"string");return typeof t=="symbol"?t:t+""}function _Q(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function Od(){return Od=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Od.apply(null,arguments)}function Vo(e,t){return t||(t=e.slice(0)),Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(t)}}))}var Uk=(e,t,n,r,a)=>{var u=n-r,o;return o=gt(Dk||(Dk=Vo(["M ",",",""])),e,t),o+=gt(Nk||(Nk=Vo(["L ",",",""])),e+n,t),o+=gt(Pk||(Pk=Vo(["L ",",",""])),e+n-u/2,t+a),o+=gt(Rk||(Rk=Vo(["L ",",",""])),e+n-u/2-r,t+a),o+=gt(Ik||(Ik=Vo(["L ",","," Z"])),e,t),o},kQ={x:0,y:0,upperWidth:0,lowerWidth:0,height:0,isUpdateAnimationActive:!1,animationBegin:0,animationDuration:1500,animationEasing:"ease"},CQ=e=>{var t=Kn(e,kQ),{x:n,y:r,upperWidth:a,lowerWidth:u,height:o,className:c}=t,{animationEasing:f,animationDuration:d,animationBegin:m,isUpdateAnimationActive:p}=t,y=E.useRef(null),[g,x]=E.useState(-1),w=E.useRef(a),S=E.useRef(u),O=E.useRef(o),_=E.useRef(n),k=E.useRef(r),M=nb(e,"trapezoid-");if(E.useEffect(()=>{if(y.current&&y.current.getTotalLength)try{var Z=y.current.getTotalLength();Z&&x(Z)}catch{}},[]),n!==+n||r!==+r||a!==+a||u!==+u||o!==+o||a===0&&u===0||o===0)return null;var N=ft("recharts-trapezoid",c);if(!p)return E.createElement("g",null,E.createElement("path",Od({},hr(t),{className:N,d:Uk(n,r,a,u,o)})));var C=w.current,z=S.current,$=O.current,H=_.current,P=k.current,F="0px ".concat(g===-1?1:g,"px"),I="".concat(g,"px 0px"),ee=vM(["strokeDasharray"],d,f);return E.createElement(tb,{animationId:M,key:M,canBegin:g>0,duration:d,easing:f,isActive:p,begin:m},Z=>{var Y=Jt(C,a,Z),U=Jt(z,u,Z),Q=Jt($,o,Z),ue=Jt(H,n,Z),de=Jt(P,r,Z);y.current&&(w.current=Y,S.current=U,O.current=Q,_.current=ue,k.current=de);var R=Z>0?{transition:ee,strokeDasharray:I}:{strokeDasharray:F};return E.createElement("path",Od({},hr(t),{className:N,d:Uk(ue,de,Y,U,Q),ref:y,style:Bk(Bk({},R),t.style)}))})},TQ=["option","shapeType","activeClassName"];function jQ(e,t){if(e==null)return{};var n,r,a=MQ(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function MQ(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function qk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ed(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?qk(Object(n),!0).forEach(function(r){zQ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):qk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function zQ(e,t,n){return(t=DQ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function DQ(e){var t=NQ(e,"string");return typeof t=="symbol"?t:t+""}function NQ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function PQ(e,t){return Ed(Ed({},t),e)}function RQ(e,t){return e==="symbols"}function Hk(e){var{shapeType:t,elementProps:n}=e;switch(t){case"rectangle":return E.createElement(xM,n);case"trapezoid":return E.createElement(CQ,n);case"sector":return E.createElement(OM,n);case"symbols":if(RQ(t))return E.createElement(aj,n);break;case"curve":return E.createElement(pM,n);default:return null}}function IQ(e){return E.isValidElement(e)?e.props:e}function LQ(e){var{option:t,shapeType:n,activeClassName:r="recharts-active-shape"}=e,a=jQ(e,TQ),u;if(E.isValidElement(t))u=E.cloneElement(t,Ed(Ed({},a),IQ(t)));else if(typeof t=="function")u=t(a,a.index);else if(OQ(t)&&typeof t!="boolean"){var o=PQ(t,a);u=E.createElement(Hk,{shapeType:n,elementProps:o})}else{var c=a;u=E.createElement(Hk,{shapeType:n,elementProps:c})}return a.isActive?E.createElement(xi,{className:r},u):u}var tN=(e,t,n)=>{var r=wt();return(a,u)=>o=>{e==null||e(a,u,o),r(pD({activeIndex:String(u),activeDataKey:t,activeCoordinate:a.tooltipPosition,activeGraphicalItemId:n}))}},nN=e=>{var t=wt();return(n,r)=>a=>{e==null||e(n,r,a),t(ZK())}},rN=(e,t,n)=>{var r=wt();return(a,u)=>o=>{e==null||e(a,u,o),r(QK({activeIndex:String(u),activeDataKey:t,activeCoordinate:a.tooltipPosition,activeGraphicalItemId:n}))}};function BQ(e){var{tooltipEntrySettings:t}=e,n=wt(),r=Mn(),a=E.useRef(null);return E.useLayoutEffect(()=>{r||(a.current===null?n(YK(t)):a.current!==t&&n(KK({prev:a.current,next:t})),a.current=t)},[t,n,r]),E.useLayoutEffect(()=>()=>{a.current&&(n(GK(a.current)),a.current=null)},[n]),null}function UQ(e){var{legendPayload:t}=e,n=wt(),r=Mn(),a=E.useRef(null);return E.useLayoutEffect(()=>{r||(a.current===null?n(k7(t)):a.current!==t&&n(C7({prev:a.current,next:t})),a.current=t)},[n,r,t]),E.useLayoutEffect(()=>()=>{a.current&&(n(T7(a.current)),a.current=null)},[n]),null}var Hy,qQ=()=>{var[e]=E.useState(()=>ts("uid-"));return e},HQ=(Hy=WR.useId)!==null&&Hy!==void 0?Hy:qQ;function $Q(e,t){var n=HQ();return t||(e?"".concat(e,"-").concat(n):n)}var FQ=E.createContext(void 0),VQ=e=>{var{id:t,type:n,children:r}=e,a=$Q("recharts-".concat(n),t);return E.createElement(FQ.Provider,{value:a},r(a))},YQ={cartesianItems:[],polarItems:[]},iN=jn({name:"graphicalItems",initialState:YQ,reducers:{addCartesianGraphicalItem:{reducer(e,t){e.cartesianItems.push(t.payload)},prepare:ht()},replaceCartesianGraphicalItem:{reducer(e,t){var{prev:n,next:r}=t.payload,a=_r(e).cartesianItems.indexOf(n);a>-1&&(e.cartesianItems[a]=r)},prepare:ht()},removeCartesianGraphicalItem:{reducer(e,t){var n=_r(e).cartesianItems.indexOf(t.payload);n>-1&&e.cartesianItems.splice(n,1)},prepare:ht()},addPolarGraphicalItem:{reducer(e,t){e.polarItems.push(t.payload)},prepare:ht()},removePolarGraphicalItem:{reducer(e,t){var n=_r(e).polarItems.indexOf(t.payload);n>-1&&e.polarItems.splice(n,1)},prepare:ht()}}}),{addCartesianGraphicalItem:KQ,replaceCartesianGraphicalItem:GQ,removeCartesianGraphicalItem:XQ,addPolarGraphicalItem:Sne,removePolarGraphicalItem:One}=iN.actions,ZQ=iN.reducer,QQ=e=>{var t=wt(),n=E.useRef(null);return E.useLayoutEffect(()=>{n.current===null?t(KQ(e)):n.current!==e&&t(GQ({prev:n.current,next:e})),n.current=e},[t,e]),E.useLayoutEffect(()=>()=>{n.current&&(t(XQ(n.current)),n.current=null)},[t]),null},WQ=E.memo(QQ);function $k(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Fk(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?$k(Object(n),!0).forEach(function(r){JQ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):$k(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function JQ(e,t,n){return(t=eW(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function eW(e){var t=tW(e,"string");return typeof t=="symbol"?t:t+""}function tW(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var aN=0,nW={xAxis:{},yAxis:{},zAxis:{}},lN=jn({name:"cartesianAxis",initialState:nW,reducers:{addXAxis:{reducer(e,t){e.xAxis[t.payload.id]=t.payload},prepare:ht()},replaceXAxis:{reducer(e,t){var{prev:n,next:r}=t.payload;e.xAxis[n.id]!==void 0&&(n.id!==r.id&&delete e.xAxis[n.id],e.xAxis[r.id]=r)},prepare:ht()},removeXAxis:{reducer(e,t){delete e.xAxis[t.payload.id]},prepare:ht()},addYAxis:{reducer(e,t){e.yAxis[t.payload.id]=t.payload},prepare:ht()},replaceYAxis:{reducer(e,t){var{prev:n,next:r}=t.payload;e.yAxis[n.id]!==void 0&&(n.id!==r.id&&delete e.yAxis[n.id],e.yAxis[r.id]=r)},prepare:ht()},removeYAxis:{reducer(e,t){delete e.yAxis[t.payload.id]},prepare:ht()},addZAxis:{reducer(e,t){e.zAxis[t.payload.id]=t.payload},prepare:ht()},replaceZAxis:{reducer(e,t){var{prev:n,next:r}=t.payload;e.zAxis[n.id]!==void 0&&(n.id!==r.id&&delete e.zAxis[n.id],e.zAxis[r.id]=r)},prepare:ht()},removeZAxis:{reducer(e,t){delete e.zAxis[t.payload.id]},prepare:ht()},updateYAxisWidth(e,t){var{id:n,width:r}=t.payload,a=e.yAxis[n];if(a){var u,o=a.widthHistory||[];if(o.length===3&&o[0]===o[2]&&r===o[1]&&r!==a.width&&Math.abs(r-((u=o[0])!==null&&u!==void 0?u:0))<=1)return;var c=[...o,r].slice(-3);e.yAxis[n]=Fk(Fk({},a),{},{width:r,widthHistory:c})}}}}),{addXAxis:rW,replaceXAxis:iW,removeXAxis:aW,addYAxis:lW,replaceYAxis:uW,removeYAxis:oW,addZAxis:Ene,replaceZAxis:Ane,removeZAxis:_ne,updateYAxisWidth:sW}=lN.actions,cW=lN.reducer,fW=te([Ht],e=>({top:e.top,bottom:e.bottom,left:e.left,right:e.right})),dW=te([fW,Ti,ji],(e,t,n)=>{if(!(!e||t==null||n==null))return{x:e.left,y:e.top,width:Math.max(0,t-e.left-e.right),height:Math.max(0,n-e.top-e.bottom)}}),uN=()=>Ee(dW),Vk=(e,t,n)=>{var r=n??e;if(!qt(r))return kr(r,t,0)},hW=(e,t,n)=>{var r={},a=e.filter(ph),u=e.filter(d=>d.stackId==null),o=a.reduce((d,m)=>{var p=d[m.stackId];return p==null&&(p=[]),p.push(m),d[m.stackId]=p,d},r),c=Object.entries(o).map(d=>{var m,[p,y]=d,g=y.map(w=>w.dataKey),x=Vk(t,n,(m=y[0])===null||m===void 0?void 0:m.barSize);return{stackId:p,dataKeys:g,barSize:x}}),f=u.map(d=>{var m=[d.dataKey].filter(y=>y!=null),p=Vk(t,n,d.barSize);return{stackId:void 0,dataKeys:m,barSize:p}});return[...c,...f]};function Yk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Of(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Yk(Object(n),!0).forEach(function(r){mW(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Yk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function mW(e,t,n){return(t=pW(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function pW(e){var t=vW(e,"string");return typeof t=="symbol"?t:t+""}function vW(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function yW(e,t,n,r,a){var u,o=r.length;if(!(o<1)){var c=kr(e,n,0,!0),f,d=[];if(qe((u=r[0])===null||u===void 0?void 0:u.barSize)){var m=!1,p=n/o,y=r.reduce((_,k)=>_+(k.barSize||0),0);y+=(o-1)*c,y>=n&&(y-=(o-1)*c,c=0),y>=n&&p>0&&(m=!0,p*=.9,y=o*p);var g=(n-y)/2>>0,x={offset:g-c,size:0};f=r.reduce((_,k)=>{var M,N={stackId:k.stackId,dataKeys:k.dataKeys,position:{offset:x.offset+x.size+c,size:m?p:(M=k.barSize)!==null&&M!==void 0?M:0}},C=[..._,N];return x=N.position,C},d)}else{var w=kr(t,n,0,!0);n-2*w-(o-1)*c<=0&&(c=0);var S=(n-2*w-(o-1)*c)/o;S>1&&(S>>=0);var O=qe(a)?Math.min(S,a):S;f=r.reduce((_,k,M)=>[..._,{stackId:k.stackId,dataKeys:k.dataKeys,position:{offset:w+(S+c)*M+(S-O)/2,size:O}}],d)}return f}}var gW=(e,t,n,r,a,u,o)=>{var c=qt(o)?t:o,f=yW(n,r,a!==u?a:u,e,c);return a!==u&&f!=null&&(f=f.map(d=>Of(Of({},d),{},{position:Of(Of({},d.position),{},{offset:d.position.offset-a/2})}))),f},bW=(e,t)=>{var n=Db(t);if(!(!e||n==null||t==null)){var{stackId:r}=t;if(r!=null){var a=e[r];if(a){var{stackedData:u}=a;if(u)return u.find(o=>o.key===n)}}}},xW=(e,t)=>{if(!(e==null||t==null)){var n=e.find(r=>r.stackId===t.stackId&&t.dataKey!=null&&r.dataKeys.includes(t.dataKey));if(n!=null)return n.position}};function wW(e,t){return e&&typeof e=="object"&&"zIndex"in e&&typeof e.zIndex=="number"&&qe(e.zIndex)?e.zIndex:t}var SW=e=>{var{chartData:t}=e,n=wt(),r=Mn();return E.useEffect(()=>r?()=>{}:(n(ik(t)),()=>{n(ik(void 0))}),[t,n,r]),null},Kk={x:0,y:0,width:0,height:0,padding:{top:0,right:0,bottom:0,left:0}},oN=jn({name:"brush",initialState:Kk,reducers:{setBrushSettings(e,t){return t.payload==null?Kk:t.payload}}}),{setBrushSettings:kne}=oN.actions,OW=oN.reducer;function EW(e){return(e%180+180)%180}var AW=function(t){var{width:n,height:r}=t,a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0,u=EW(a),o=u*Math.PI/180,c=Math.atan(r/n),f=o>c&&o<Math.PI-c?r/Math.sin(o):n/Math.cos(o);return Math.abs(f)},_W={dots:[],areas:[],lines:[]},sN=jn({name:"referenceElements",initialState:_W,reducers:{addDot:(e,t)=>{e.dots.push(t.payload)},removeDot:(e,t)=>{var n=_r(e).dots.findIndex(r=>r===t.payload);n!==-1&&e.dots.splice(n,1)},addArea:(e,t)=>{e.areas.push(t.payload)},removeArea:(e,t)=>{var n=_r(e).areas.findIndex(r=>r===t.payload);n!==-1&&e.areas.splice(n,1)},addLine:(e,t)=>{e.lines.push(t.payload)},removeLine:(e,t)=>{var n=_r(e).lines.findIndex(r=>r===t.payload);n!==-1&&e.lines.splice(n,1)}}}),{addDot:Cne,removeDot:Tne,addArea:jne,removeArea:Mne,addLine:zne,removeLine:Dne}=sN.actions,kW=sN.reducer,CW=E.createContext(void 0),TW=e=>{var{children:t}=e,[n]=E.useState("".concat(ts("recharts"),"-clip")),r=uN();if(r==null)return null;var{x:a,y:u,width:o,height:c}=r;return E.createElement(CW.Provider,{value:n},E.createElement("defs",null,E.createElement("clipPath",{id:n},E.createElement("rect",{x:a,y:u,height:c,width:o}))),t)};function cN(e,t){if(t<1)return[];if(t===1)return e;for(var n=[],r=0;r<e.length;r+=t){var a=e[r];a!==void 0&&n.push(a)}return n}function jW(e,t,n){var r={width:e.width+t.width,height:e.height+t.height};return AW(r,n)}function MW(e,t,n){var r=n==="width",{x:a,y:u,width:o,height:c}=e;return t===1?{start:r?a:u,end:r?a+o:u+c}:{start:r?a+o:u+c,end:r?a:u}}function ps(e,t,n,r,a){if(e*t<e*r||e*t>e*a)return!1;var u=n();return e*(t-e*u/2-r)>=0&&e*(t+e*u/2-a)<=0}function zW(e,t){return cN(e,t+1)}function DW(e,t,n,r,a){for(var u=(r||[]).slice(),{start:o,end:c}=t,f=0,d=1,m=o,p=function(){var x=r==null?void 0:r[f];if(x===void 0)return{v:cN(r,d)};var w=f,S,O=()=>(S===void 0&&(S=n(x,w)),S),_=x.coordinate,k=f===0||ps(e,_,O,m,c);k||(f=0,m=o,d+=1),k&&(m=_+e*(O()/2+a),f+=d)},y;d<=u.length;)if(y=p(),y)return y.v;return[]}function NW(e,t,n,r,a){var u=(r||[]).slice(),o=u.length;if(o===0)return[];for(var{start:c,end:f}=t,d=1;d<=o;d++){for(var m=(o-1)%d,p=c,y=!0,g=function(){var M=r[w];if(M==null)return 0;var N=w,C,z=()=>(C===void 0&&(C=n(M,N)),C),$=M.coordinate,H=w===m||ps(e,$,z,p,f);if(!H)return y=!1,1;H&&(p=$+e*(z()/2+a))},x,w=m;w<o&&(x=g(),!(x!==0&&x===1));w+=d);if(y){for(var S=[],O=m;O<o;O+=d){var _=r[O];_!=null&&S.push(_)}return S}}return[]}function Gk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function rn(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Gk(Object(n),!0).forEach(function(r){PW(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Gk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function PW(e,t,n){return(t=RW(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function RW(e){var t=IW(e,"string");return typeof t=="symbol"?t:t+""}function IW(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function LW(e,t,n,r,a){for(var u=(r||[]).slice(),o=u.length,{start:c}=t,{end:f}=t,d=function(y){var g=u[y];if(g==null)return 1;var x=g,w,S=()=>(w===void 0&&(w=n(g,y)),w);if(y===o-1){var O=e*(x.coordinate+e*S()/2-f);u[y]=x=rn(rn({},x),{},{tickCoord:O>0?x.coordinate-O*e:x.coordinate})}else u[y]=x=rn(rn({},x),{},{tickCoord:x.coordinate});if(x.tickCoord!=null){var _=ps(e,x.tickCoord,S,c,f);_&&(f=x.tickCoord-e*(S()/2+a),u[y]=rn(rn({},x),{},{isShow:!0}))}},m=o-1;m>=0;m--)d(m);return u}function BW(e,t,n,r,a,u){var o=(r||[]).slice(),c=o.length,{start:f,end:d}=t;if(u){var m=r[c-1];if(m!=null){var p=n(m,c-1),y=e*(m.coordinate+e*p/2-d);if(o[c-1]=m=rn(rn({},m),{},{tickCoord:y>0?m.coordinate-y*e:m.coordinate}),m.tickCoord!=null){var g=ps(e,m.tickCoord,()=>p,f,d);g&&(d=m.tickCoord-e*(p/2+a),o[c-1]=rn(rn({},m),{},{isShow:!0}))}}}for(var x=u?c-1:c,w=function(_){var k=o[_];if(k==null)return 1;var M=k,N,C=()=>(N===void 0&&(N=n(k,_)),N);if(_===0){var z=e*(M.coordinate-e*C()/2-f);o[_]=M=rn(rn({},M),{},{tickCoord:z<0?M.coordinate-z*e:M.coordinate})}else o[_]=M=rn(rn({},M),{},{tickCoord:M.coordinate});if(M.tickCoord!=null){var $=ps(e,M.tickCoord,C,f,d);$&&(f=M.tickCoord+e*(C()/2+a),o[_]=rn(rn({},M),{},{isShow:!0}))}},S=0;S<x;S++)w(S);return o}function nx(e,t,n){var{tick:r,ticks:a,viewBox:u,minTickGap:o,orientation:c,interval:f,tickFormatter:d,unit:m,angle:p}=e;if(!a||!a.length||!r)return[];if(we(f)||nh.isSsr){var y;return(y=zW(a,we(f)?f:0))!==null&&y!==void 0?y:[]}var g=[],x=c==="top"||c==="bottom"?"width":"height",w=m&&x==="width"?Wo(m,{fontSize:t,letterSpacing:n}):{width:0,height:0},S=(N,C)=>{var z=typeof d=="function"?d(N.value,C):N.value;return x==="width"?jW(Wo(z,{fontSize:t,letterSpacing:n}),w,p):Wo(z,{fontSize:t,letterSpacing:n})[x]},O=a[0],_=a[1],k=a.length>=2&&O!=null&&_!=null?_n(_.coordinate-O.coordinate):1,M=MW(u,k,x);return f==="equidistantPreserveStart"?DW(k,M,S,a,o):f==="equidistantPreserveEnd"?NW(k,M,S,a,o):(f==="preserveStart"||f==="preserveStartEnd"?g=BW(k,M,S,a,o,f==="preserveStartEnd"):g=LW(k,M,S,a,o),g.filter(N=>N.isShow))}var UW=e=>{var{ticks:t,label:n,labelGapWithTick:r=5,tickSize:a=0,tickMargin:u=0}=e,o=0;if(t){Array.from(t).forEach(m=>{if(m){var p=m.getBoundingClientRect();p.width>o&&(o=p.width)}});var c=n?n.getBoundingClientRect().width:0,f=a+u,d=o+f+c+(n?r:0);return Math.round(d)}return 0},qW=["axisLine","width","height","className","hide","ticks","axisType"];function HW(e,t){if(e==null)return{};var n,r,a=$W(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function $W(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function rl(){return rl=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},rl.apply(null,arguments)}function Xk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function yt(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Xk(Object(n),!0).forEach(function(r){FW(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Xk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function FW(e,t,n){return(t=VW(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function VW(e){var t=YW(e,"string");return typeof t=="symbol"?t:t+""}function YW(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}var gi={x:0,y:0,width:0,height:0,viewBox:{x:0,y:0,width:0,height:0},orientation:"bottom",ticks:[],stroke:"#666",tickLine:!0,axisLine:!0,tick:!0,mirror:!1,minTickGap:5,tickSize:6,tickMargin:2,interval:"preserveEnd",zIndex:mn.axis};function KW(e){var{x:t,y:n,width:r,height:a,orientation:u,mirror:o,axisLine:c,otherSvgProps:f}=e;if(!c)return null;var d=yt(yt(yt({},f),bi(c)),{},{fill:"none"});if(u==="top"||u==="bottom"){var m=+(u==="top"&&!o||u==="bottom"&&o);d=yt(yt({},d),{},{x1:t,y1:n+m*a,x2:t+r,y2:n+m*a})}else{var p=+(u==="left"&&!o||u==="right"&&o);d=yt(yt({},d),{},{x1:t+p*r,y1:n,x2:t+p*r,y2:n+a})}return E.createElement("line",rl({},d,{className:ft("recharts-cartesian-axis-line",hu(c,"className"))}))}function GW(e,t,n,r,a,u,o,c,f){var d,m,p,y,g,x,w=c?-1:1,S=e.tickSize||o,O=we(e.tickCoord)?e.tickCoord:e.coordinate;switch(u){case"top":d=m=e.coordinate,y=n+ +!c*a,p=y-w*S,x=p-w*f,g=O;break;case"left":p=y=e.coordinate,m=t+ +!c*r,d=m-w*S,g=d-w*f,x=O;break;case"right":p=y=e.coordinate,m=t+ +c*r,d=m+w*S,g=d+w*f,x=O;break;default:d=m=e.coordinate,y=n+ +c*a,p=y+w*S,x=p+w*f,g=O;break}return{line:{x1:d,y1:p,x2:m,y2:y},tick:{x:g,y:x}}}function XW(e,t){switch(e){case"left":return t?"start":"end";case"right":return t?"end":"start";default:return"middle"}}function ZW(e,t){switch(e){case"left":case"right":return"middle";case"top":return t?"start":"end";default:return t?"end":"start"}}function QW(e){var{option:t,tickProps:n,value:r}=e,a,u=ft(n.className,"recharts-cartesian-axis-tick-value");if(E.isValidElement(t))a=E.cloneElement(t,yt(yt({},n),{},{className:u}));else if(typeof t=="function")a=t(yt(yt({},n),{},{className:u}));else{var o="recharts-cartesian-axis-tick-value";typeof t!="boolean"&&(o=ft(o,pQ(t))),a=E.createElement(ex,rl({},n,{className:o}),r)}return a}var WW=E.forwardRef((e,t)=>{var{ticks:n=[],tick:r,tickLine:a,stroke:u,tickFormatter:o,unit:c,padding:f,tickTextProps:d,orientation:m,mirror:p,x:y,y:g,width:x,height:w,tickSize:S,tickMargin:O,fontSize:_,letterSpacing:k,getTicksConfig:M,events:N,axisType:C}=e,z=nx(yt(yt({},M),{},{ticks:n}),_,k),$=XW(m,p),H=ZW(m,p),P=bi(M),F=D0(r),I={};typeof a=="object"&&(I=a);var ee=yt(yt({},P),{},{fill:"none"},I),Z=z.map(Q=>yt({entry:Q},GW(Q,y,g,x,w,m,S,p,O))),Y=Z.map(Q=>{var{entry:ue,line:de}=Q;return E.createElement(xi,{className:"recharts-cartesian-axis-tick",key:"tick-".concat(ue.value,"-").concat(ue.coordinate,"-").concat(ue.tickCoord)},a&&E.createElement("line",rl({},ee,de,{className:ft("recharts-cartesian-axis-tick-line",hu(a,"className"))})))}),U=Z.map((Q,ue)=>{var de,R,{entry:L,tick:J}=Q,D=yt(yt(yt(yt({verticalAnchor:H},P),{},{textAnchor:$,stroke:"none",fill:u},J),{},{index:ue,payload:L,visibleTicksCount:z.length,tickFormatter:o,padding:f},d),{},{angle:(de=(R=d==null?void 0:d.angle)!==null&&R!==void 0?R:P.angle)!==null&&de!==void 0?de:0}),oe=yt(yt({},D),F);return E.createElement(xi,rl({className:"recharts-cartesian-axis-tick-label",key:"tick-label-".concat(L.value,"-").concat(L.coordinate,"-").concat(L.tickCoord)},U0(N,L,ue)),r&&E.createElement(QW,{option:r,tickProps:oe,value:"".concat(typeof o=="function"?o(L.value,ue):L.value).concat(c||"")}))});return E.createElement("g",{className:"recharts-cartesian-axis-ticks recharts-".concat(C,"-ticks")},U.length>0&&E.createElement(Ri,{zIndex:mn.label},E.createElement("g",{className:"recharts-cartesian-axis-tick-labels recharts-".concat(C,"-tick-labels"),ref:t},U)),Y.length>0&&E.createElement("g",{className:"recharts-cartesian-axis-tick-lines recharts-".concat(C,"-tick-lines")},Y))}),JW=E.forwardRef((e,t)=>{var{axisLine:n,width:r,height:a,className:u,hide:o,ticks:c,axisType:f}=e,d=HW(e,qW),[m,p]=E.useState(""),[y,g]=E.useState(""),x=E.useRef(null);E.useImperativeHandle(t,()=>({getCalculatedWidth:()=>{var S;return UW({ticks:x.current,label:(S=e.labelRef)===null||S===void 0?void 0:S.current,labelGapWithTick:5,tickSize:e.tickSize,tickMargin:e.tickMargin})}}));var w=E.useCallback(S=>{if(S){var O=S.getElementsByClassName("recharts-cartesian-axis-tick-value");x.current=O;var _=O[0];if(_){var k=window.getComputedStyle(_),M=k.fontSize,N=k.letterSpacing;(M!==m||N!==y)&&(p(M),g(N))}}},[m,y]);return o||r!=null&&r<=0||a!=null&&a<=0?null:E.createElement(Ri,{zIndex:e.zIndex},E.createElement(xi,{className:ft("recharts-cartesian-axis",u)},E.createElement(KW,{x:e.x,y:e.y,width:r,height:a,orientation:e.orientation,mirror:e.mirror,axisLine:n,otherSvgProps:bi(e)}),E.createElement(WW,{ref:w,axisType:f,events:d,fontSize:m,getTicksConfig:e,height:e.height,letterSpacing:y,mirror:e.mirror,orientation:e.orientation,padding:e.padding,stroke:e.stroke,tick:e.tick,tickFormatter:e.tickFormatter,tickLine:e.tickLine,tickMargin:e.tickMargin,tickSize:e.tickSize,tickTextProps:e.tickTextProps,ticks:c,unit:e.unit,width:e.width,x:e.x,y:e.y}),E.createElement(HZ,{x:e.x,y:e.y,width:e.width,height:e.height,lowerWidth:e.width,upperWidth:e.width},E.createElement(WZ,{label:e.label,labelRef:e.labelRef}),e.children)))}),rx=E.forwardRef((e,t)=>{var n=Kn(e,gi);return E.createElement(JW,rl({},n,{ref:t}))});rx.displayName="CartesianAxis";var eJ=["x1","y1","x2","y2","key"],tJ=["offset"],nJ=["xAxisId","yAxisId"],rJ=["xAxisId","yAxisId"];function Zk(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function an(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Zk(Object(n),!0).forEach(function(r){iJ(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Zk(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function iJ(e,t,n){return(t=aJ(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function aJ(e){var t=lJ(e,"string");return typeof t=="symbol"?t:t+""}function lJ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function Ya(){return Ya=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ya.apply(null,arguments)}function Ad(e,t){if(e==null)return{};var n,r,a=uJ(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function uJ(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var oJ=e=>{var{fill:t}=e;if(!t||t==="none")return null;var{fillOpacity:n,x:r,y:a,width:u,height:o,ry:c}=e;return E.createElement("rect",{x:r,y:a,ry:c,width:u,height:o,stroke:"none",fill:t,fillOpacity:n,className:"recharts-cartesian-grid-bg"})};function fN(e){var{option:t,lineItemProps:n}=e,r;if(E.isValidElement(t))r=E.cloneElement(t,n);else if(typeof t=="function")r=t(n);else{var a,{x1:u,y1:o,x2:c,y2:f,key:d}=n,m=Ad(n,eJ),p=(a=bi(m))!==null&&a!==void 0?a:{},{offset:y}=p,g=Ad(p,tJ);r=E.createElement("line",Ya({},g,{x1:u,y1:o,x2:c,y2:f,fill:"none",key:d}))}return r}function sJ(e){var{x:t,width:n,horizontal:r=!0,horizontalPoints:a}=e;if(!r||!a||!a.length)return null;var{xAxisId:u,yAxisId:o}=e,c=Ad(e,nJ),f=a.map((d,m)=>{var p=an(an({},c),{},{x1:t,y1:d,x2:t+n,y2:d,key:"line-".concat(m),index:m});return E.createElement(fN,{key:"line-".concat(m),option:r,lineItemProps:p})});return E.createElement("g",{className:"recharts-cartesian-grid-horizontal"},f)}function cJ(e){var{y:t,height:n,vertical:r=!0,verticalPoints:a}=e;if(!r||!a||!a.length)return null;var{xAxisId:u,yAxisId:o}=e,c=Ad(e,rJ),f=a.map((d,m)=>{var p=an(an({},c),{},{x1:d,y1:t,x2:d,y2:t+n,key:"line-".concat(m),index:m});return E.createElement(fN,{option:r,lineItemProps:p,key:"line-".concat(m)})});return E.createElement("g",{className:"recharts-cartesian-grid-vertical"},f)}function fJ(e){var{horizontalFill:t,fillOpacity:n,x:r,y:a,width:u,height:o,horizontalPoints:c,horizontal:f=!0}=e;if(!f||!t||!t.length||c==null)return null;var d=c.map(p=>Math.round(p+a-a)).sort((p,y)=>p-y);a!==d[0]&&d.unshift(0);var m=d.map((p,y)=>{var g=d[y+1],x=g==null,w=x?a+o-p:g-p;if(w<=0)return null;var S=y%t.length;return E.createElement("rect",{key:"react-".concat(y),y:p,x:r,height:w,width:u,stroke:"none",fill:t[S],fillOpacity:n,className:"recharts-cartesian-grid-bg"})});return E.createElement("g",{className:"recharts-cartesian-gridstripes-horizontal"},m)}function dJ(e){var{vertical:t=!0,verticalFill:n,fillOpacity:r,x:a,y:u,width:o,height:c,verticalPoints:f}=e;if(!t||!n||!n.length)return null;var d=f.map(p=>Math.round(p+a-a)).sort((p,y)=>p-y);a!==d[0]&&d.unshift(0);var m=d.map((p,y)=>{var g=d[y+1],x=g==null,w=x?a+o-p:g-p;if(w<=0)return null;var S=y%n.length;return E.createElement("rect",{key:"react-".concat(y),x:p,y:u,width:w,height:c,stroke:"none",fill:n[S],fillOpacity:r,className:"recharts-cartesian-grid-bg"})});return E.createElement("g",{className:"recharts-cartesian-gridstripes-vertical"},m)}var hJ=(e,t)=>{var{xAxis:n,width:r,height:a,offset:u}=e;return Xj(nx(an(an(an({},gi),n),{},{ticks:Zj(n),viewBox:{x:0,y:0,width:r,height:a}})),u.left,u.left+u.width,t)},mJ=(e,t)=>{var{yAxis:n,width:r,height:a,offset:u}=e;return Xj(nx(an(an(an({},gi),n),{},{ticks:Zj(n),viewBox:{x:0,y:0,width:r,height:a}})),u.top,u.top+u.height,t)},pJ={horizontal:!0,vertical:!0,horizontalPoints:[],verticalPoints:[],stroke:"#ccc",fill:"none",verticalFill:[],horizontalFill:[],xAxisId:0,yAxisId:0,syncWithTicks:!1,zIndex:mn.grid};function dN(e){var t=rM(),n=iM(),r=nM(),a=an(an({},Kn(e,pJ)),{},{x:we(e.x)?e.x:r.left,y:we(e.y)?e.y:r.top,width:we(e.width)?e.width:r.width,height:we(e.height)?e.height:r.height}),{xAxisId:u,yAxisId:o,x:c,y:f,width:d,height:m,syncWithTicks:p,horizontalValues:y,verticalValues:g}=a,x=Mn(),w=Ee(H=>Y_(H,"xAxis",u,x)),S=Ee(H=>Y_(H,"yAxis",o,x));if(!Vr(d)||!Vr(m)||!we(c)||!we(f))return null;var O=a.verticalCoordinatesGenerator||hJ,_=a.horizontalCoordinatesGenerator||mJ,{horizontalPoints:k,verticalPoints:M}=a;if((!k||!k.length)&&typeof _=="function"){var N=y&&y.length,C=_({yAxis:S?an(an({},S),{},{ticks:N?y:S.ticks}):void 0,width:t??d,height:n??m,offset:r},N?!0:p);Wf(Array.isArray(C),"horizontalCoordinatesGenerator should return Array but instead it returned [".concat(typeof C,"]")),Array.isArray(C)&&(k=C)}if((!M||!M.length)&&typeof O=="function"){var z=g&&g.length,$=O({xAxis:w?an(an({},w),{},{ticks:z?g:w.ticks}):void 0,width:t??d,height:n??m,offset:r},z?!0:p);Wf(Array.isArray($),"verticalCoordinatesGenerator should return Array but instead it returned [".concat(typeof $,"]")),Array.isArray($)&&(M=$)}return E.createElement(Ri,{zIndex:a.zIndex},E.createElement("g",{className:"recharts-cartesian-grid"},E.createElement(oJ,{fill:a.fill,fillOpacity:a.fillOpacity,x:a.x,y:a.y,width:a.width,height:a.height,ry:a.ry}),E.createElement(fJ,Ya({},a,{horizontalPoints:k})),E.createElement(dJ,Ya({},a,{verticalPoints:M})),E.createElement(sJ,Ya({},a,{offset:r,horizontalPoints:k,xAxis:w,yAxis:S})),E.createElement(cJ,Ya({},a,{offset:r,verticalPoints:M,xAxis:w,yAxis:S}))))}dN.displayName="CartesianGrid";var vJ={},hN=jn({name:"errorBars",initialState:vJ,reducers:{addErrorBar:(e,t)=>{var{itemId:n,errorBar:r}=t.payload;e[n]||(e[n]=[]),e[n].push(r)},replaceErrorBar:(e,t)=>{var{itemId:n,prev:r,next:a}=t.payload;e[n]&&(e[n]=e[n].map(u=>u.dataKey===r.dataKey&&u.direction===r.direction?a:u))},removeErrorBar:(e,t)=>{var{itemId:n,errorBar:r}=t.payload;e[n]&&(e[n]=e[n].filter(a=>a.dataKey!==r.dataKey||a.direction!==r.direction))}}}),{addErrorBar:Nne,replaceErrorBar:Pne,removeErrorBar:Rne}=hN.actions,yJ=hN.reducer,gJ=["children"];function bJ(e,t){if(e==null)return{};var n,r,a=xJ(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function xJ(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var wJ={data:[],xAxisId:"xAxis-0",yAxisId:"yAxis-0",dataPointFormatter:()=>({x:0,y:0,value:0}),errorBarOffset:0},SJ=E.createContext(wJ);function OJ(e){var{children:t}=e,n=bJ(e,gJ);return E.createElement(SJ.Provider,{value:n},t)}function mN(e,t){var n,r,a=Ee(d=>Di(d,e)),u=Ee(d=>Ni(d,t)),o=(n=a==null?void 0:a.allowDataOverflow)!==null&&n!==void 0?n:Lt.allowDataOverflow,c=(r=u==null?void 0:u.allowDataOverflow)!==null&&r!==void 0?r:Bt.allowDataOverflow,f=o||c;return{needClip:f,needClipX:o,needClipY:c}}function EJ(e){var{xAxisId:t,yAxisId:n,clipPathId:r}=e,a=uN(),{needClipX:u,needClipY:o,needClip:c}=mN(t,n);if(!c||!a)return null;var{x:f,y:d,width:m,height:p}=a;return E.createElement("clipPath",{id:"clipPath-".concat(r)},E.createElement("rect",{x:u?f:f-m/2,y:o?d:d-p/2,width:u?m:m*2,height:o?p:p*2}))}var $y={exports:{}},Fy={};/**
 * @license React
 * use-sync-external-store-with-selector.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Qk;function AJ(){if(Qk)return Fy;Qk=1;var e=Su();function t(f,d){return f===d&&(f!==0||1/f===1/d)||f!==f&&d!==d}var n=typeof Object.is=="function"?Object.is:t,r=e.useSyncExternalStore,a=e.useRef,u=e.useEffect,o=e.useMemo,c=e.useDebugValue;return Fy.useSyncExternalStoreWithSelector=function(f,d,m,p,y){var g=a(null);if(g.current===null){var x={hasValue:!1,value:null};g.current=x}else x=g.current;g=o(function(){function S(N){if(!O){if(O=!0,_=N,N=p(N),y!==void 0&&x.hasValue){var C=x.value;if(y(C,N))return k=C}return k=N}if(C=k,n(_,N))return C;var z=p(N);return y!==void 0&&y(C,z)?(_=N,C):(_=N,k=z)}var O=!1,_,k,M=m===void 0?null:m;return[function(){return S(d())},M===null?void 0:function(){return S(M())}]},[d,m,p,y]);var w=r(f,g[0],g[1]);return u(function(){x.hasValue=!0,x.value=w},[w]),c(w),w},Fy}var Wk;function _J(){return Wk||(Wk=1,$y.exports=AJ()),$y.exports}_J();function kJ(e){e()}function CJ(){let e=null,t=null;return{clear(){e=null,t=null},notify(){kJ(()=>{let n=e;for(;n;)n.callback(),n=n.next})},get(){const n=[];let r=e;for(;r;)n.push(r),r=r.next;return n},subscribe(n){let r=!0;const a=t={callback:n,next:null,prev:t};return a.prev?a.prev.next=a:e=a,function(){!r||e===null||(r=!1,a.next?a.next.prev=a.prev:t=a.prev,a.prev?a.prev.next=a.next:e=a.next)}}}}var Jk={notify(){},get:()=>[]};function TJ(e,t){let n,r=Jk,a=0,u=!1;function o(w){m();const S=r.subscribe(w);let O=!1;return()=>{O||(O=!0,S(),p())}}function c(){r.notify()}function f(){x.onStateChange&&x.onStateChange()}function d(){return u}function m(){a++,n||(n=e.subscribe(f),r=CJ())}function p(){a--,n&&a===0&&(n(),n=void 0,r.clear(),r=Jk)}function y(){u||(u=!0,m())}function g(){u&&(u=!1,p())}const x={addNestedSub:o,notifyNestedSubs:c,handleChangeWrapper:f,isSubscribed:d,trySubscribe:y,tryUnsubscribe:g,getListeners:()=>r};return x}var jJ=()=>typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u",MJ=jJ(),zJ=()=>typeof navigator<"u"&&navigator.product==="ReactNative",DJ=zJ(),NJ=()=>MJ||DJ?E.useLayoutEffect:E.useEffect,PJ=NJ();function eC(e,t){return e===t?e!==0||t!==0||1/e===1/t:e!==e&&t!==t}function RJ(e,t){if(eC(e,t))return!0;if(typeof e!="object"||e===null||typeof t!="object"||t===null)return!1;const n=Object.keys(e),r=Object.keys(t);if(n.length!==r.length)return!1;for(let a=0;a<n.length;a++)if(!Object.prototype.hasOwnProperty.call(t,n[a])||!eC(e[n[a]],t[n[a]]))return!1;return!0}var Vy=Symbol.for("react-redux-context"),Yy=typeof globalThis<"u"?globalThis:{};function IJ(){if(!E.createContext)return{};const e=Yy[Vy]??(Yy[Vy]=new Map);let t=e.get(E.createContext);return t||(t=E.createContext(null),e.set(E.createContext,t)),t}var LJ=IJ();function BJ(e){const{children:t,context:n,serverState:r,store:a}=e,u=E.useMemo(()=>{const f=TJ(a);return{store:a,subscription:f,getServerState:r?()=>r:void 0}},[a,r]),o=E.useMemo(()=>a.getState(),[a]);PJ(()=>{const{subscription:f}=u;return f.onStateChange=f.notifyNestedSubs,f.trySubscribe(),o!==a.getState()&&f.notifyNestedSubs(),()=>{f.tryUnsubscribe(),f.onStateChange=void 0}},[u,o]);const c=n||LJ;return E.createElement(c.Provider,{value:u},t)}var UJ=BJ,qJ=new Set(["axisLine","tickLine","activeBar","activeDot","activeLabel","activeShape","allowEscapeViewBox","background","cursor","dot","label","line","margin","padding","position","shape","style","tick","wrapperStyle","radius"]);function HJ(e,t){return e==null&&t==null?!0:typeof e=="number"&&typeof t=="number"?e===t||e!==e&&t!==t:e===t}function ix(e,t){var n=new Set([...Object.keys(e),...Object.keys(t)]);for(var r of n)if(qJ.has(r)){if(e[r]==null&&t[r]==null)continue;if(!RJ(e[r],t[r]))return!1}else if(!HJ(e[r],t[r]))return!1;return!0}function ul(e,t){var n,r;return(n=(r=e.graphicalItems.cartesianItems.find(a=>a.id===t))===null||r===void 0?void 0:r.xAxisId)!==null&&n!==void 0?n:aN}function ol(e,t){var n,r;return(n=(r=e.graphicalItems.cartesianItems.find(a=>a.id===t))===null||r===void 0?void 0:r.yAxisId)!==null&&n!==void 0?n:aN}var $J="Invariant failed";function FJ(e,t){throw new Error($J)}function Wg(){return Wg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Wg.apply(null,arguments)}function _d(e){return E.createElement(LQ,Wg({shapeType:"rectangle",activeClassName:"recharts-active-bar"},e))}var VJ=function(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0;return(r,a)=>{if(we(t))return t;var u=we(r)||qt(r);return u?t(r,a):(u||FJ(),n)}},YJ=(e,t,n)=>n,KJ=(e,t)=>t,Rs=te([Pb,KJ],(e,t)=>e.filter(n=>n.type==="bar").find(n=>n.id===t)),GJ=te([Rs],e=>e==null?void 0:e.maxBarSize),XJ=(e,t,n,r)=>r,ZJ=te([at,Pb,ul,ol,YJ],(e,t,n,r,a)=>t.filter(u=>e==="horizontal"?u.xAxisId===n:u.yAxisId===r).filter(u=>u.isPanorama===a).filter(u=>u.hide===!1).filter(u=>u.type==="bar")),QJ=(e,t,n)=>{var r=at(e),a=ul(e,t),u=ol(e,t);if(!(a==null||u==null))return r==="horizontal"?Yg(e,"yAxis",u,n):Yg(e,"xAxis",a,n)},WJ=(e,t)=>{var n=at(e),r=ul(e,t),a=ol(e,t);if(!(r==null||a==null))return n==="horizontal"?V_(e,"xAxis",r):V_(e,"yAxis",a)},JJ=te([ZJ,PY,WJ],hW),eee=(e,t,n)=>{var r,a,u=Rs(e,t);if(u==null)return 0;var o=ul(e,t),c=ol(e,t);if(o==null||c==null)return 0;var f=at(e),d=gz(e),{maxBarSize:m}=u,p=qt(m)?d:m,y,g;return f==="horizontal"?(y=xu(e,"xAxis",o,n),g=bu(e,"xAxis",o,n)):(y=xu(e,"yAxis",c,n),g=bu(e,"yAxis",c,n)),(r=(a=Qf(y,g,!0))!==null&&a!==void 0?a:p)!==null&&r!==void 0?r:0},pN=(e,t,n)=>{var r=at(e),a=ul(e,t),u=ol(e,t);if(!(a==null||u==null)){var o,c;return r==="horizontal"?(o=xu(e,"xAxis",a,n),c=bu(e,"xAxis",a,n)):(o=xu(e,"yAxis",u,n),c=bu(e,"yAxis",u,n)),Qf(o,c)}},tee=te([JJ,gz,NY,bz,eee,pN,GJ],gW),nee=(e,t,n)=>{var r=ul(e,t);if(r!=null)return xu(e,"xAxis",r,n)},ree=(e,t,n)=>{var r=ol(e,t);if(r!=null)return xu(e,"yAxis",r,n)},iee=(e,t,n)=>{var r=ul(e,t);if(r!=null)return bu(e,"xAxis",r,n)},aee=(e,t,n)=>{var r=ol(e,t);if(r!=null)return bu(e,"yAxis",r,n)},lee=te([tee,Rs],xW),uee=te([QJ,Rs],bW),oee=te([Ht,Z0,nee,ree,iee,aee,lee,at,_Y,pN,uee,Rs,XJ],(e,t,n,r,a,u,o,c,f,d,m,p,y)=>{var{chartData:g,dataStartIndex:x,dataEndIndex:w}=f;if(!(p==null||o==null||t==null||c!=="horizontal"&&c!=="vertical"||n==null||r==null||a==null||u==null||d==null)){var{data:S}=p,O;if(S!=null&&S.length>0?O=S:O=g==null?void 0:g.slice(x,w+1),O!=null)return Ree({layout:c,barSettings:p,pos:o,parentViewBox:t,bandSize:d,xAxis:n,yAxis:r,xAxisTicks:a,yAxisTicks:u,stackedData:m,displayedData:O,offset:e,cells:y,dataStartIndex:x})}}),see=["index"];function Jg(){return Jg=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Jg.apply(null,arguments)}function cee(e,t){if(e==null)return{};var n,r,a=fee(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function fee(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var vN=E.createContext(void 0),dee=e=>{var t=E.useContext(vN);if(t!=null)return t.stackId;if(e!=null)return TH(e)},hee=(e,t)=>"recharts-bar-stack-clip-path-".concat(e,"-").concat(t),mee=e=>{var t=E.useContext(vN);if(t!=null){var{stackId:n}=t;return"url(#".concat(hee(n,e),")")}},yN=e=>{var{index:t}=e,n=cee(e,see),r=mee(t);return E.createElement(xi,Jg({className:"recharts-bar-stack-layer",clipPath:r},n))},pee=["onMouseEnter","onMouseLeave","onClick"],vee=["value","background","tooltipPosition"],yee=["id"],gee=["onMouseEnter","onClick","onMouseLeave"];function ki(){return ki=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},ki.apply(null,arguments)}function tC(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function fn(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?tC(Object(n),!0).forEach(function(r){bee(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):tC(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function bee(e,t,n){return(t=xee(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function xee(e){var t=wee(e,"string");return typeof t=="symbol"?t:t+""}function wee(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function kd(e,t){if(e==null)return{};var n,r,a=See(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function See(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var Oee=e=>{var{dataKey:t,name:n,fill:r,legendType:a,hide:u}=e;return[{inactive:u,dataKey:t,type:a,color:r,value:Qj(n,t),payload:e}]},Eee=E.memo(e=>{var{dataKey:t,stroke:n,strokeWidth:r,fill:a,name:u,hide:o,unit:c,tooltipType:f,id:d}=e,m={dataDefinedOnItem:void 0,getPosition:Au,settings:{stroke:n,strokeWidth:r,fill:a,dataKey:t,nameKey:void 0,name:Qj(u,t),hide:o,type:f,color:a,unit:c,graphicalItemId:d}};return E.createElement(BQ,{tooltipEntrySettings:m})});function Aee(e){var t=Ee(wu),{data:n,dataKey:r,background:a,allOtherBarProps:u}=e,{onMouseEnter:o,onMouseLeave:c,onClick:f}=u,d=kd(u,pee),m=tN(o,r,u.id),p=nN(c),y=rN(f,r,u.id);if(!a||n==null)return null;var g=D0(a);return E.createElement(Ri,{zIndex:wW(a,mn.barBackground)},n.map((x,w)=>{var{value:S,background:O,tooltipPosition:_}=x,k=kd(x,vee);if(!O)return null;var M=m(x,w),N=p(x,w),C=y(x,w),z=fn(fn(fn(fn(fn({option:a,isActive:String(w)===t},k),{},{fill:"#eee"},O),g),U0(d,x,w)),{},{onMouseEnter:M,onMouseLeave:N,onClick:C,dataKey:r,index:w,className:"recharts-bar-background-rectangle"});return E.createElement(_d,ki({key:"background-bar-".concat(w)},z))}))}function _ee(e){var{showLabels:t,children:n,rects:r}=e,a=r==null?void 0:r.map(u=>{var o={x:u.x,y:u.y,width:u.width,lowerWidth:u.width,upperWidth:u.width,height:u.height};return fn(fn({},o),{},{value:u.value,payload:u.payload,parentViewBox:u.parentViewBox,viewBox:o,fill:u.fill})});return E.createElement(sQ,{value:t?a:void 0},n)}function kee(e){var{shape:t,activeBar:n,baseProps:r,entry:a,index:u,dataKey:o}=e,c=Ee(wu),f=Ee(jD),d=n&&String(u)===c&&(f==null||o===f),m=d?n:t;return d?E.createElement(Ri,{zIndex:mn.activeBar},E.createElement(yN,{index:u},E.createElement(_d,ki({},r,{name:String(r.name)},a,{isActive:d,option:m,index:u,dataKey:o})))):E.createElement(_d,ki({},r,{name:String(r.name)},a,{isActive:d,option:m,index:u,dataKey:o}))}function Cee(e){var{shape:t,baseProps:n,entry:r,index:a,dataKey:u}=e;return E.createElement(_d,ki({},n,{name:String(n.name)},r,{isActive:!1,option:t,index:a,dataKey:u}))}function Tee(e){var t,{data:n,props:r}=e,a=(t=bi(r))!==null&&t!==void 0?t:{},{id:u}=a,o=kd(a,yee),{shape:c,dataKey:f,activeBar:d}=r,{onMouseEnter:m,onClick:p,onMouseLeave:y}=r,g=kd(r,gee),x=tN(m,f,u),w=nN(y),S=rN(p,f,u);return n?E.createElement(E.Fragment,null,n.map((O,_)=>E.createElement(yN,ki({index:_,key:"rectangle-".concat(O==null?void 0:O.x,"-").concat(O==null?void 0:O.y,"-").concat(O==null?void 0:O.value,"-").concat(_),className:"recharts-bar-rectangle"},U0(g,O,_),{onMouseEnter:x(O,_),onMouseLeave:w(O,_),onClick:S(O,_)}),d?E.createElement(kee,{shape:c,activeBar:d,baseProps:o,entry:O,index:_,dataKey:f}):E.createElement(Cee,{shape:c,baseProps:o,entry:O,index:_,dataKey:f})))):null}function jee(e){var{props:t,previousRectanglesRef:n}=e,{data:r,layout:a,isAnimationActive:u,animationBegin:o,animationDuration:c,animationEasing:f,onAnimationEnd:d,onAnimationStart:m}=t,p=n.current,y=nb(t,"recharts-bar-"),[g,x]=E.useState(!1),w=!g,S=E.useCallback(()=>{typeof d=="function"&&d(),x(!1)},[d]),O=E.useCallback(()=>{typeof m=="function"&&m(),x(!0)},[m]);return E.createElement(_ee,{showLabels:w,rects:r},E.createElement(tb,{animationId:y,begin:o,duration:c,isActive:u,easing:f,onAnimationEnd:S,onAnimationStart:O,key:y},_=>{var k=_===1?r:r==null?void 0:r.map((M,N)=>{var C=p&&p[N];if(C)return fn(fn({},M),{},{x:Jt(C.x,M.x,_),y:Jt(C.y,M.y,_),width:Jt(C.width,M.width,_),height:Jt(C.height,M.height,_)});if(a==="horizontal"){var z=Jt(0,M.height,_),$=Jt(M.stackedBarStart,M.y,_);return fn(fn({},M),{},{y:$,height:z})}var H=Jt(0,M.width,_),P=Jt(M.stackedBarStart,M.x,_);return fn(fn({},M),{},{width:H,x:P})});return _>0&&(n.current=k??null),k==null?null:E.createElement(xi,null,E.createElement(Tee,{props:t,data:k}))}),E.createElement(dQ,{label:t.label}),t.children)}function Mee(e){var t=E.useRef(null);return E.createElement(jee,{previousRectanglesRef:t,props:e})}var gN=0,zee=(e,t)=>{var n=Array.isArray(e.value)?e.value[1]:e.value;return{x:e.x,y:e.y,value:n,errorVal:tn(e,t)}};class Dee extends E.PureComponent{render(){var{hide:t,data:n,dataKey:r,className:a,xAxisId:u,yAxisId:o,needClip:c,background:f,id:d}=this.props;if(t||n==null)return null;var m=ft("recharts-bar",a),p=d;return E.createElement(xi,{className:m,id:d},c&&E.createElement("defs",null,E.createElement(EJ,{clipPathId:p,xAxisId:u,yAxisId:o})),E.createElement(xi,{className:"recharts-bar-rectangles",clipPath:c?"url(#clipPath-".concat(p,")"):void 0},E.createElement(Aee,{data:n,dataKey:r,background:f,allOtherBarProps:this.props}),E.createElement(Mee,this.props)))}}var Nee={activeBar:!1,animationBegin:0,animationDuration:400,animationEasing:"ease",background:!1,hide:!1,isAnimationActive:"auto",label:!1,legendType:"rect",minPointSize:gN,xAxisId:0,yAxisId:0,zIndex:mn.bar};function Pee(e){var{xAxisId:t,yAxisId:n,hide:r,legendType:a,minPointSize:u,activeBar:o,animationBegin:c,animationDuration:f,animationEasing:d,isAnimationActive:m}=e,{needClip:p}=mN(t,n),y=_u(),g=Mn(),x=bQ(e.children,UD),w=Ee(_=>oee(_,e.id,g,x));if(y!=="vertical"&&y!=="horizontal")return null;var S,O=w==null?void 0:w[0];return O==null||O.height==null||O.width==null?S=0:S=y==="vertical"?O.height/2:O.width/2,E.createElement(OJ,{xAxisId:t,yAxisId:n,data:w,dataPointFormatter:zee,errorBarOffset:S},E.createElement(Dee,ki({},e,{layout:y,needClip:p,data:w,xAxisId:t,yAxisId:n,hide:r,legendType:a,minPointSize:u,activeBar:o,animationBegin:c,animationDuration:f,animationEasing:d,isAnimationActive:m})))}function Ree(e){var{layout:t,barSettings:{dataKey:n,minPointSize:r},pos:a,bandSize:u,xAxis:o,yAxis:c,xAxisTicks:f,yAxisTicks:d,stackedData:m,displayedData:p,offset:y,cells:g,parentViewBox:x,dataStartIndex:w}=e,S=t==="horizontal"?c:o,O=m?S.scale.domain():null,_=jH({numericAxis:S}),k=S.scale.map(_);return p.map((M,N)=>{var C,z,$,H,P,F;if(m){var I=m[N+w];if(I==null)return null;C=EH(I,O)}else C=tn(M,n),Array.isArray(C)||(C=[_,C]);var ee=VJ(r,gN)(C[1],N);if(t==="horizontal"){var Z,Y=c.scale.map(C[0]),U=c.scale.map(C[1]);if(Y==null||U==null)return null;z=YA({axis:o,ticks:f,bandSize:u,offset:a.offset,entry:M,index:N}),$=(Z=U??Y)!==null&&Z!==void 0?Z:void 0,H=a.size;var Q=Y-U;if(P=$r(Q)?0:Q,F={x:z,y:y.top,width:H,height:y.height},Math.abs(ee)>0&&Math.abs(P)<Math.abs(ee)){var ue=_n(P||ee)*(Math.abs(ee)-Math.abs(P));$-=ue,P+=ue}}else{var de=o.scale.map(C[0]),R=o.scale.map(C[1]);if(de==null||R==null)return null;if(z=de,$=YA({axis:c,ticks:d,bandSize:u,offset:a.offset,entry:M,index:N}),H=R-de,P=a.size,F={x:y.left,y:$,width:y.width,height:P},Math.abs(ee)>0&&Math.abs(H)<Math.abs(ee)){var L=_n(H||ee)*(Math.abs(ee)-Math.abs(H));H+=L}}if(z==null||$==null||H==null||P==null)return null;var J=fn(fn({},M),{},{stackedBarStart:k,x:z,y:$,width:H,height:P,value:m?C:C[1],payload:M,background:F,tooltipPosition:{x:z+H/2,y:$+P/2},parentViewBox:x},g&&g[N]&&g[N].props);return J}).filter(Boolean)}function Iee(e){var t=Kn(e,Nee),n=dee(t.stackId),r=Mn();return E.createElement(VQ,{id:t.id,type:"bar"},a=>E.createElement(E.Fragment,null,E.createElement(UQ,{legendPayload:Oee(t)}),E.createElement(Eee,{dataKey:t.dataKey,stroke:t.stroke,strokeWidth:t.strokeWidth,fill:t.fill,name:t.name,hide:t.hide,unit:t.unit,tooltipType:t.tooltipType,id:a}),E.createElement(WQ,{type:"bar",id:a,data:void 0,xAxisId:t.xAxisId,yAxisId:t.yAxisId,zAxisId:0,dataKey:t.dataKey,stackId:n,hide:t.hide,barSize:t.barSize,minPointSize:t.minPointSize,maxBarSize:t.maxBarSize,isPanorama:r}),E.createElement(Ri,{zIndex:t.zIndex},E.createElement(Pee,ki({},t,{id:a})))))}var e0=E.memo(Iee,ix);e0.displayName="Bar";var Lee=["domain","range"],Bee=["domain","range"];function nC(e,t){if(e==null)return{};var n,r,a=Uee(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function Uee(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function rC(e,t){return e===t?!0:Array.isArray(e)&&e.length===2&&Array.isArray(t)&&t.length===2?e[0]===t[0]&&e[1]===t[1]:!1}function bN(e,t){if(e===t)return!0;var{domain:n,range:r}=e,a=nC(e,Lee),{domain:u,range:o}=t,c=nC(t,Bee);return!rC(n,u)||!rC(r,o)?!1:ix(a,c)}var qee=["type"],Hee=["dangerouslySetInnerHTML","ticks","scale"],$ee=["id","scale"];function t0(){return t0=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},t0.apply(null,arguments)}function iC(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function aC(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?iC(Object(n),!0).forEach(function(r){Fee(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):iC(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function Fee(e,t,n){return(t=Vee(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Vee(e){var t=Yee(e,"string");return typeof t=="symbol"?t:t+""}function Yee(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function n0(e,t){if(e==null)return{};var n,r,a=Kee(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function Kee(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function Gee(e){var t=wt(),n=E.useRef(null),r=aM(),{type:a}=e,u=n0(e,qee),o=dh(r,"xAxis",a),c=E.useMemo(()=>{if(o!=null)return aC(aC({},u),{},{type:o})},[u,o]);return E.useLayoutEffect(()=>{c!=null&&(n.current===null?t(rW(c)):n.current!==c&&t(iW({prev:n.current,next:c})),n.current=c)},[c,t]),E.useLayoutEffect(()=>()=>{n.current&&(t(aW(n.current)),n.current=null)},[t]),null}var Xee=e=>{var{xAxisId:t,className:n}=e,r=Ee(Z0),a=Mn(),u="xAxis",o=Ee(O=>sD(O,u,t,a)),c=Ee(O=>aD(O,t)),f=Ee(O=>RK(O,t)),d=Ee(O=>Cz(O,t));if(c==null||f==null||d==null)return null;var{dangerouslySetInnerHTML:m,ticks:p,scale:y}=e,g=n0(e,Hee),{id:x,scale:w}=d,S=n0(d,$ee);return E.createElement(rx,t0({},g,S,{x:f.x,y:f.y,width:c.width,height:c.height,className:ft("recharts-".concat(u," ").concat(u),n),viewBox:r,ticks:o,axisType:u}))},Zee={allowDataOverflow:Lt.allowDataOverflow,allowDecimals:Lt.allowDecimals,allowDuplicatedCategory:Lt.allowDuplicatedCategory,angle:Lt.angle,axisLine:gi.axisLine,height:Lt.height,hide:!1,includeHidden:Lt.includeHidden,interval:Lt.interval,label:!1,minTickGap:Lt.minTickGap,mirror:Lt.mirror,orientation:Lt.orientation,padding:Lt.padding,reversed:Lt.reversed,scale:Lt.scale,tick:Lt.tick,tickCount:Lt.tickCount,tickLine:gi.tickLine,tickSize:gi.tickSize,type:Lt.type,xAxisId:0},Qee=e=>{var t=Kn(e,Zee);return E.createElement(E.Fragment,null,E.createElement(Gee,{allowDataOverflow:t.allowDataOverflow,allowDecimals:t.allowDecimals,allowDuplicatedCategory:t.allowDuplicatedCategory,angle:t.angle,dataKey:t.dataKey,domain:t.domain,height:t.height,hide:t.hide,id:t.xAxisId,includeHidden:t.includeHidden,interval:t.interval,minTickGap:t.minTickGap,mirror:t.mirror,name:t.name,orientation:t.orientation,padding:t.padding,reversed:t.reversed,scale:t.scale,tick:t.tick,tickCount:t.tickCount,tickFormatter:t.tickFormatter,ticks:t.ticks,type:t.type,unit:t.unit}),E.createElement(Xee,t))},xN=E.memo(Qee,bN);xN.displayName="XAxis";var Wee=["type"],Jee=["dangerouslySetInnerHTML","ticks","scale"],ete=["id","scale"];function r0(){return r0=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},r0.apply(null,arguments)}function lC(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function uC(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?lC(Object(n),!0).forEach(function(r){tte(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):lC(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function tte(e,t,n){return(t=nte(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function nte(e){var t=rte(e,"string");return typeof t=="symbol"?t:t+""}function rte(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function i0(e,t){if(e==null)return{};var n,r,a=ite(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function ite(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function ate(e){var t=wt(),n=E.useRef(null),r=aM(),{type:a}=e,u=i0(e,Wee),o=dh(r,"yAxis",a),c=E.useMemo(()=>{if(o!=null)return uC(uC({},u),{},{type:o})},[o,u]);return E.useLayoutEffect(()=>{c!=null&&(n.current===null?t(lW(c)):n.current!==c&&t(uW({prev:n.current,next:c})),n.current=c)},[c,t]),E.useLayoutEffect(()=>()=>{n.current&&(t(oW(n.current)),n.current=null)},[t]),null}function lte(e){var{yAxisId:t,className:n,width:r,label:a}=e,u=E.useRef(null),o=E.useRef(null),c=Ee(Z0),f=Mn(),d=wt(),m="yAxis",p=Ee(C=>lD(C,t)),y=Ee(C=>LK(C,t)),g=Ee(C=>sD(C,m,t,f)),x=Ee(C=>Tz(C,t));if(E.useLayoutEffect(()=>{if(!(r!=="auto"||!p||tx(a)||E.isValidElement(a)||x==null)){var C=u.current;if(C){var z=C.getCalculatedWidth();Math.round(p.width)!==Math.round(z)&&d(sW({id:t,width:z}))}}},[g,p,d,a,t,r,x]),p==null||y==null||x==null)return null;var{dangerouslySetInnerHTML:w,ticks:S,scale:O}=e,_=i0(e,Jee),{id:k,scale:M}=x,N=i0(x,ete);return E.createElement(rx,r0({},_,N,{ref:u,labelRef:o,x:y.x,y:y.y,tickTextProps:r==="auto"?{width:void 0}:{width:r},width:p.width,height:p.height,className:ft("recharts-".concat(m," ").concat(m),n),viewBox:c,ticks:g,axisType:m}))}var ute={allowDataOverflow:Bt.allowDataOverflow,allowDecimals:Bt.allowDecimals,allowDuplicatedCategory:Bt.allowDuplicatedCategory,angle:Bt.angle,axisLine:gi.axisLine,hide:!1,includeHidden:Bt.includeHidden,interval:Bt.interval,label:!1,minTickGap:Bt.minTickGap,mirror:Bt.mirror,orientation:Bt.orientation,padding:Bt.padding,reversed:Bt.reversed,scale:Bt.scale,tick:Bt.tick,tickCount:Bt.tickCount,tickLine:gi.tickLine,tickSize:gi.tickSize,type:Bt.type,width:Bt.width,yAxisId:0},ote=e=>{var t=Kn(e,ute);return E.createElement(E.Fragment,null,E.createElement(ate,{interval:t.interval,id:t.yAxisId,scale:t.scale,type:t.type,domain:t.domain,allowDataOverflow:t.allowDataOverflow,dataKey:t.dataKey,allowDuplicatedCategory:t.allowDuplicatedCategory,allowDecimals:t.allowDecimals,tickCount:t.tickCount,padding:t.padding,includeHidden:t.includeHidden,reversed:t.reversed,ticks:t.ticks,width:t.width,orientation:t.orientation,mirror:t.mirror,hide:t.hide,unit:t.unit,name:t.name,angle:t.angle,minTickGap:t.minTickGap,tick:t.tick,tickFormatter:t.tickFormatter}),E.createElement(lte,t))},wN=E.memo(ote,bN);wN.displayName="YAxis";var ste=(e,t)=>t,ax=te([ste,at,_z,Vt,_D,Pi,WG,Ht],aX),lx=e=>{var t=e.currentTarget.getBoundingClientRect(),n=t.width/e.currentTarget.offsetWidth,r=t.height/e.currentTarget.offsetHeight;return{chartX:Math.round((e.clientX-t.left)/n),chartY:Math.round((e.clientY-t.top)/r)}},SN=mr("mouseClick"),ON=Ss();ON.startListening({actionCreator:SN,effect:(e,t)=>{var n=e.payload,r=ax(t.getState(),lx(n));(r==null?void 0:r.activeIndex)!=null&&t.dispatch(WK({activeIndex:r.activeIndex,activeDataKey:void 0,activeCoordinate:r.activeCoordinate}))}});var a0=mr("mouseMove"),EN=Ss(),Ef=null;EN.startListening({actionCreator:a0,effect:(e,t)=>{var n=e.payload;Ef!==null&&cancelAnimationFrame(Ef);var r=lx(n);Ef=requestAnimationFrame(()=>{var a=t.getState(),u=Fb(a,a.tooltip.settings.shared);if(u==="axis"){var o=ax(a,r);(o==null?void 0:o.activeIndex)!=null?t.dispatch(yD({activeIndex:o.activeIndex,activeDataKey:void 0,activeCoordinate:o.activeCoordinate})):t.dispatch(vD())}Ef=null})}});function cte(e,t){return t instanceof HTMLElement?"HTMLElement <".concat(t.tagName,' class="').concat(t.className,'">'):t===window?"global.window":e==="children"&&typeof t=="object"&&t!==null?"<<CHILDREN>>":t}var oC={accessibilityLayer:!0,barCategoryGap:"10%",barGap:4,barSize:void 0,className:void 0,maxBarSize:void 0,stackOffset:"none",syncId:void 0,syncMethod:"index",baseValue:void 0,reverseStackOrder:!1},AN=jn({name:"rootProps",initialState:oC,reducers:{updateOptions:(e,t)=>{var n;e.accessibilityLayer=t.payload.accessibilityLayer,e.barCategoryGap=t.payload.barCategoryGap,e.barGap=(n=t.payload.barGap)!==null&&n!==void 0?n:oC.barGap,e.barSize=t.payload.barSize,e.maxBarSize=t.payload.maxBarSize,e.stackOffset=t.payload.stackOffset,e.syncId=t.payload.syncId,e.syncMethod=t.payload.syncMethod,e.className=t.payload.className,e.baseValue=t.payload.baseValue,e.reverseStackOrder=t.payload.reverseStackOrder}}}),fte=AN.reducer,{updateOptions:dte}=AN.actions,hte=null,mte={updatePolarOptions:(e,t)=>t.payload},_N=jn({name:"polarOptions",initialState:hte,reducers:mte}),{updatePolarOptions:Ine}=_N.actions,pte=_N.reducer,kN=mr("keyDown"),CN=mr("focus"),ux=Ss();ux.startListening({actionCreator:kN,effect:(e,t)=>{var n=t.getState(),r=n.rootProps.accessibilityLayer!==!1;if(r){var{keyboardInteraction:a}=n.tooltip,u=e.payload;if(!(u!=="ArrowRight"&&u!=="ArrowLeft"&&u!=="Enter")){var o=Vb(a,Pu(n),zs(n),Ns(n)),c=o==null?-1:Number(o);if(!(!Number.isFinite(c)||c<0)){var f=Pi(n);if(u==="Enter"){var d=wd(n,"axis","hover",String(a.index));t.dispatch(Gg({active:!a.active,activeIndex:a.index,activeCoordinate:d}));return}var m=HK(n),p=m==="left-to-right"?1:-1,y=u==="ArrowRight"?1:-1,g=c+y*p;if(!(f==null||g>=f.length||g<0)){var x=wd(n,"axis","hover",String(g));t.dispatch(Gg({active:!0,activeIndex:g.toString(),activeCoordinate:x}))}}}}}});ux.startListening({actionCreator:CN,effect:(e,t)=>{var n=t.getState(),r=n.rootProps.accessibilityLayer!==!1;if(r){var{keyboardInteraction:a}=n.tooltip;if(!a.active&&a.index==null){var u="0",o=wd(n,"axis","hover",String(u));t.dispatch(Gg({active:!0,activeIndex:u,activeCoordinate:o}))}}}});var or=mr("externalEvent"),TN=Ss(),Ky=new Map;TN.startListening({actionCreator:or,effect:(e,t)=>{var{handler:n,reactEvent:r}=e.payload;if(n!=null){r.persist();var a=r.type,u=Ky.get(a);u!==void 0&&cancelAnimationFrame(u);var o=requestAnimationFrame(()=>{try{var c=t.getState(),f={activeCoordinate:IG(c),activeDataKey:jD(c),activeIndex:wu(c),activeLabel:TD(c),activeTooltipIndex:wu(c),isTooltipActive:LG(c)};n(f,r)}finally{Ky.delete(a)}});Ky.set(a,o)}}});var vte=te([Du],e=>e.tooltipItemPayloads),yte=te([vte,(e,t)=>t,(e,t,n)=>n],(e,t,n)=>{if(t!=null){var r=e.find(u=>u.settings.graphicalItemId===n);if(r!=null){var{getPosition:a}=r;if(a!=null)return a(t)}}}),jN=mr("touchMove"),MN=Ss();MN.startListening({actionCreator:jN,effect:(e,t)=>{var n=e.payload;if(!(n.touches==null||n.touches.length===0)){var r=t.getState(),a=Fb(r,r.tooltip.settings.shared);if(a==="axis"){var u=n.touches[0];if(u==null)return;var o=ax(r,lx({clientX:u.clientX,clientY:u.clientY,currentTarget:n.currentTarget}));(o==null?void 0:o.activeIndex)!=null&&t.dispatch(yD({activeIndex:o.activeIndex,activeDataKey:void 0,activeCoordinate:o.activeCoordinate}))}else if(a==="item"){var c,f=n.touches[0];if(document.elementFromPoint==null||f==null)return;var d=document.elementFromPoint(f.clientX,f.clientY);if(!d||!d.getAttribute)return;var m=d.getAttribute(IH),p=(c=d.getAttribute(LH))!==null&&c!==void 0?c:void 0,y=Nu(r).find(w=>w.id===p);if(m==null||y==null||p==null)return;var{dataKey:g}=y,x=yte(r,m,p);t.dispatch(pD({activeDataKey:g,activeIndex:m,activeCoordinate:x,activeGraphicalItemId:p}))}}}});var gte=xj({brush:OW,cartesianAxis:cW,chartData:IX,errorBars:yJ,graphicalItems:ZQ,layout:bH,legend:j7,options:zX,polarAxis:mQ,polarOptions:pte,referenceElements:kW,rootProps:fte,tooltip:JK,zIndex:bX}),bte=function(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"Chart";return Fq({reducer:gte,preloadedState:t,middleware:r=>{var a;return r({serializableCheck:!1,immutableCheck:!["commonjs","es6","production"].includes((a="es6")!==null&&a!==void 0?a:"")}).concat([ON.middleware,EN.middleware,ux.middleware,TN.middleware,MN.middleware])},enhancers:r=>{var a=r;return typeof r=="function"&&(a=r()),a.concat(Pj({type:"raf"}))},devTools:{serialize:{replacer:cte},name:"recharts-".concat(n)}})};function xte(e){var{preloadedState:t,children:n,reduxStoreName:r}=e,a=Mn(),u=E.useRef(null);if(a)return n;u.current==null&&(u.current=bte(t,r));var o=$0;return E.createElement(UJ,{context:o,store:u.current},n)}function wte(e){var{layout:t,margin:n}=e,r=wt(),a=Mn();return E.useEffect(()=>{a||(r(vH(t)),r(pH(n)))},[r,a,t,n]),null}var Ste=E.memo(wte,ix);function Ote(e){var t=wt();return E.useEffect(()=>{t(dte(e))},[t,e]),null}function sC(e){var{zIndex:t,isPanorama:n}=e,r=E.useRef(null),a=wt();return E.useLayoutEffect(()=>(r.current&&a(yX({zIndex:t,element:r.current,isPanorama:n})),()=>{a(gX({zIndex:t,isPanorama:n}))}),[a,t,n]),E.createElement("g",{tabIndex:-1,ref:r})}function cC(e){var{children:t,isPanorama:n}=e,r=Ee(uX);if(!r||r.length===0)return t;var a=r.filter(o=>o<0),u=r.filter(o=>o>0);return E.createElement(E.Fragment,null,a.map(o=>E.createElement(sC,{key:o,zIndex:o,isPanorama:n})),t,u.map(o=>E.createElement(sC,{key:o,zIndex:o,isPanorama:n})))}var Ete=["children"];function Ate(e,t){if(e==null)return{};var n,r,a=_te(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function _te(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function Cd(){return Cd=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Cd.apply(null,arguments)}var kte={width:"100%",height:"100%",display:"block"},Cte=E.forwardRef((e,t)=>{var n=rM(),r=iM(),a=mM();if(!Vr(n)||!Vr(r))return null;var{children:u,otherAttributes:o,title:c,desc:f}=e,d,m;return o!=null&&(typeof o.tabIndex=="number"?d=o.tabIndex:d=a?0:void 0,typeof o.role=="string"?m=o.role:m=a?"application":void 0),E.createElement(LT,Cd({},o,{title:c,desc:f,role:m,tabIndex:d,width:n,height:r,style:kte,ref:t}),u)}),Tte=e=>{var{children:t}=e,n=Ee(Qd);if(!n)return null;var{width:r,height:a,y:u,x:o}=n;return E.createElement(LT,{width:r,height:a,x:o,y:u},t)},fC=E.forwardRef((e,t)=>{var{children:n}=e,r=Ate(e,Ete),a=Mn();return a?E.createElement(Tte,null,E.createElement(cC,{isPanorama:!0},n)):E.createElement(Cte,Cd({ref:t},r),E.createElement(cC,{isPanorama:!1},n))});function jte(){var e=wt(),[t,n]=E.useState(null),r=Ee(RH);return E.useEffect(()=>{if(t!=null){var a=t.getBoundingClientRect(),u=a.width/t.offsetWidth;qe(u)&&u!==r&&e(gH(u))}},[t,e,r]),n}function dC(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Mte(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?dC(Object(n),!0).forEach(function(r){zte(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):dC(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function zte(e,t,n){return(t=Dte(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Dte(e){var t=Nte(e,"string");return typeof t=="symbol"?t:t+""}function Nte(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function ma(){return ma=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},ma.apply(null,arguments)}var Pte=()=>(YX(),null);function Td(e){if(typeof e=="number")return e;if(typeof e=="string"){var t=parseFloat(e);if(!Number.isNaN(t))return t}return 0}var Rte=E.forwardRef((e,t)=>{var n,r,a=E.useRef(null),[u,o]=E.useState({containerWidth:Td((n=e.style)===null||n===void 0?void 0:n.width),containerHeight:Td((r=e.style)===null||r===void 0?void 0:r.height)}),c=E.useCallback((d,m)=>{o(p=>{var y=Math.round(d),g=Math.round(m);return p.containerWidth===y&&p.containerHeight===g?p:{containerWidth:y,containerHeight:g}})},[]),f=E.useCallback(d=>{if(typeof t=="function"&&t(d),d!=null&&typeof ResizeObserver<"u"){var{width:m,height:p}=d.getBoundingClientRect();c(m,p);var y=x=>{var w=x[0];if(w!=null){var{width:S,height:O}=w.contentRect;c(S,O)}},g=new ResizeObserver(y);g.observe(d),a.current=g}},[t,c]);return E.useEffect(()=>()=>{var d=a.current;d!=null&&d.disconnect()},[c]),E.createElement(E.Fragment,null,E.createElement(Es,{width:u.containerWidth,height:u.containerHeight}),E.createElement("div",ma({ref:f},e)))}),Ite=E.forwardRef((e,t)=>{var{width:n,height:r}=e,[a,u]=E.useState({containerWidth:Td(n),containerHeight:Td(r)}),o=E.useCallback((f,d)=>{u(m=>{var p=Math.round(f),y=Math.round(d);return m.containerWidth===p&&m.containerHeight===y?m:{containerWidth:p,containerHeight:y}})},[]),c=E.useCallback(f=>{if(typeof t=="function"&&t(f),f!=null){var{width:d,height:m}=f.getBoundingClientRect();o(d,m)}},[t,o]);return E.createElement(E.Fragment,null,E.createElement(Es,{width:a.containerWidth,height:a.containerHeight}),E.createElement("div",ma({ref:c},e)))}),Lte=E.forwardRef((e,t)=>{var{width:n,height:r}=e;return E.createElement(E.Fragment,null,E.createElement(Es,{width:n,height:r}),E.createElement("div",ma({ref:t},e)))}),Bte=E.forwardRef((e,t)=>{var{width:n,height:r}=e;return typeof n=="string"||typeof r=="string"?E.createElement(Ite,ma({},e,{ref:t})):typeof n=="number"&&typeof r=="number"?E.createElement(Lte,ma({},e,{width:n,height:r,ref:t})):E.createElement(E.Fragment,null,E.createElement(Es,{width:n,height:r}),E.createElement("div",ma({ref:t},e)))});function Ute(e){return e?Rte:Bte}var qte=E.forwardRef((e,t)=>{var{children:n,className:r,height:a,onClick:u,onContextMenu:o,onDoubleClick:c,onMouseDown:f,onMouseEnter:d,onMouseLeave:m,onMouseMove:p,onMouseUp:y,onTouchEnd:g,onTouchMove:x,onTouchStart:w,style:S,width:O,responsive:_,dispatchTouchEvents:k=!0}=e,M=E.useRef(null),N=wt(),[C,z]=E.useState(null),[$,H]=E.useState(null),P=jte(),F=Q0(),I=(F==null?void 0:F.width)>0?F.width:O,ee=(F==null?void 0:F.height)>0?F.height:a,Z=E.useCallback(K=>{P(K),typeof t=="function"&&t(K),z(K),H(K),K!=null&&(M.current=K)},[P,t,z,H]),Y=E.useCallback(K=>{N(SN(K)),N(or({handler:u,reactEvent:K}))},[N,u]),U=E.useCallback(K=>{N(a0(K)),N(or({handler:d,reactEvent:K}))},[N,d]),Q=E.useCallback(K=>{N(vD()),N(or({handler:m,reactEvent:K}))},[N,m]),ue=E.useCallback(K=>{N(a0(K)),N(or({handler:p,reactEvent:K}))},[N,p]),de=E.useCallback(()=>{N(CN())},[N]),R=E.useCallback(K=>{N(kN(K.key))},[N]),L=E.useCallback(K=>{N(or({handler:o,reactEvent:K}))},[N,o]),J=E.useCallback(K=>{N(or({handler:c,reactEvent:K}))},[N,c]),D=E.useCallback(K=>{N(or({handler:f,reactEvent:K}))},[N,f]),oe=E.useCallback(K=>{N(or({handler:y,reactEvent:K}))},[N,y]),ye=E.useCallback(K=>{N(or({handler:w,reactEvent:K}))},[N,w]),ve=E.useCallback(K=>{k&&N(jN(K)),N(or({handler:x,reactEvent:K}))},[N,k,x]),Se=E.useCallback(K=>{N(or({handler:g,reactEvent:K}))},[N,g]),ge=Ute(_);return E.createElement(ID.Provider,{value:C},E.createElement(S9.Provider,{value:$},E.createElement(ge,{width:I??(S==null?void 0:S.width),height:ee??(S==null?void 0:S.height),className:ft("recharts-wrapper",r),style:Mte({position:"relative",cursor:"default",width:I,height:ee},S),onClick:Y,onContextMenu:L,onDoubleClick:J,onFocus:de,onKeyDown:R,onMouseDown:D,onMouseEnter:U,onMouseLeave:Q,onMouseMove:ue,onMouseUp:oe,onTouchEnd:Se,onTouchMove:ve,onTouchStart:ye,ref:Z},E.createElement(Pte,null),n)))}),Hte=["width","height","responsive","children","className","style","compact","title","desc"];function $te(e,t){if(e==null)return{};var n,r,a=Fte(e,t);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)n=u[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function Fte(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var Vte=E.forwardRef((e,t)=>{var{width:n,height:r,responsive:a,children:u,className:o,style:c,compact:f,title:d,desc:m}=e,p=$te(e,Hte),y=bi(p);return f?E.createElement(E.Fragment,null,E.createElement(Es,{width:n,height:r}),E.createElement(fC,{otherAttributes:y,title:d,desc:m},u)):E.createElement(qte,{className:o,style:c,width:n,height:r,responsive:a??!1,onClick:e.onClick,onMouseLeave:e.onMouseLeave,onMouseEnter:e.onMouseEnter,onMouseMove:e.onMouseMove,onMouseDown:e.onMouseDown,onMouseUp:e.onMouseUp,onContextMenu:e.onContextMenu,onDoubleClick:e.onDoubleClick,onTouchStart:e.onTouchStart,onTouchMove:e.onTouchMove,onTouchEnd:e.onTouchEnd},E.createElement(fC,{otherAttributes:y,title:d,desc:m,ref:t},E.createElement(TW,null,u)))});function l0(){return l0=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},l0.apply(null,arguments)}var Yte={top:5,right:5,bottom:5,left:5},Kte={accessibilityLayer:!0,barCategoryGap:"10%",barGap:4,layout:"horizontal",margin:Yte,responsive:!1,reverseStackOrder:!1,stackOffset:"none",syncMethod:"index"},Gte=E.forwardRef(function(t,n){var r,a=Kn(t.categoricalChartProps,Kte),{chartName:u,defaultTooltipEventType:o,validateTooltipEventTypes:c,tooltipPayloadSearcher:f,categoricalChartProps:d}=t,m={chartName:u,defaultTooltipEventType:o,validateTooltipEventTypes:c,tooltipPayloadSearcher:f,eventEmitter:void 0};return E.createElement(xte,{preloadedState:{options:m},reduxStoreName:(r=d.id)!==null&&r!==void 0?r:u},E.createElement(SW,{chartData:d.data}),E.createElement(Ste,{layout:a.layout,margin:a.margin}),E.createElement(Ote,{baseValue:a.baseValue,accessibilityLayer:a.accessibilityLayer,barCategoryGap:a.barCategoryGap,maxBarSize:a.maxBarSize,stackOffset:a.stackOffset,barGap:a.barGap,barSize:a.barSize,syncId:a.syncId,syncMethod:a.syncMethod,className:a.className,reverseStackOrder:a.reverseStackOrder}),E.createElement(Vte,l0({},a,{ref:n})))}),Xte=["axis","item"],Zte=E.forwardRef((e,t)=>E.createElement(Gte,{chartName:"BarChart",defaultTooltipEventType:"axis",validateTooltipEventTypes:Xte,tooltipPayloadSearcher:jX,categoricalChartProps:e,ref:t}));function Qte(e){return e>=1e6?`${(e/1e6).toFixed(1)}M`:e>=1e3?`${(e/1e3).toFixed(1)}k`:String(e)}function Wte({active:e,payload:t}){if(!e||!(t!=null&&t.length))return null;const n=t[0].payload;return T.jsxs("div",{className:"px-3 py-2 rounded shadow-lg border text-xs",style:{backgroundColor:"var(--color-surface-2)",borderColor:"var(--color-border)",color:"var(--color-text)"},children:[T.jsxs("p",{className:"font-medium mb-1",children:["Turn ",n.turn]}),T.jsxs("p",{style:{color:"#3b82f6"},children:["Input: ",n.input.toLocaleString()]}),T.jsxs("p",{style:{color:"#14b8a6"},children:["Output: ",n.output.toLocaleString()]}),T.jsxs("p",{className:"mt-1 font-medium",style:{color:"var(--color-text)"},children:["Total: ",n.total.toLocaleString()]})]})}function Jte({data:e,tokenUsage:t}){return e.length===0?T.jsx("div",{className:"flex items-center justify-center h-[200px] text-xs text-[var(--color-text-muted)]",children:"No usage data yet"}):T.jsxs("div",{children:[T.jsx(d7,{width:"100%",height:200,children:T.jsxs(Zte,{data:e,margin:{top:8,right:8,left:-8,bottom:0},children:[T.jsx(dN,{strokeDasharray:"3 3",stroke:"var(--color-border)",opacity:.3}),T.jsx(xN,{dataKey:"turn",stroke:"var(--color-text-muted)",tick:{fill:"var(--color-text-muted)",fontSize:11},tickLine:!1}),T.jsx(wN,{stroke:"var(--color-text-muted)",tick:{fill:"var(--color-text-muted)",fontSize:11},tickFormatter:Qte,tickLine:!1,width:42}),T.jsx(eZ,{content:T.jsx(Wte,{}),cursor:{fill:"var(--color-surface)",opacity:.5}}),T.jsx(e0,{dataKey:"input",stackId:"tokens",fill:"#3b82f6",radius:[0,0,2,2],name:"Input"}),T.jsx(e0,{dataKey:"output",stackId:"tokens",fill:"#14b8a6",radius:[2,2,0,0],name:"Output"})]})}),T.jsxs("div",{className:"grid grid-cols-3 gap-3 mt-3 pt-3 border-t border-[var(--color-border)] text-xs",children:[T.jsxs("div",{children:[T.jsx("div",{className:"text-[var(--color-text-muted)] mb-0.5",children:"Input"}),T.jsx("div",{className:"font-medium text-[var(--color-text)]",children:t.input.toLocaleString()})]}),T.jsxs("div",{children:[T.jsx("div",{className:"text-[var(--color-text-muted)] mb-0.5",children:"Output"}),T.jsx("div",{className:"font-medium text-[var(--color-text)]",children:t.output.toLocaleString()})]}),T.jsxs("div",{children:[T.jsx("div",{className:"text-[var(--color-text-muted)] mb-0.5",children:"Total"}),T.jsx("div",{className:"font-medium text-[var(--color-text)]",children:t.total.toLocaleString()})]})]}),T.jsxs("div",{className:"flex items-center gap-3 mt-2 text-[10px] text-[var(--color-text-muted)]",children:[T.jsxs("span",{className:"flex items-center gap-1",children:[T.jsx("span",{className:"w-2 h-2 rounded-sm",style:{backgroundColor:"#3b82f6"}}),"Input"]}),T.jsxs("span",{className:"flex items-center gap-1",children:[T.jsx("span",{className:"w-2 h-2 rounded-sm",style:{backgroundColor:"#14b8a6"}}),"Output"]})]})]})}function ene(e){return e>=1e6?`${(e/1e6).toFixed(1)}M`:e>=1e3?`${(e/1e3).toFixed(1)}k`:String(e)}function tne({connectionStatus:e,isStreaming:t,tokenUsage:n,usageHistory:r}){const[a,u]=E.useState(!1),o=E.useRef(null);return E.useEffect(()=>{if(!a)return;const c=d=>{o.current&&!o.current.contains(d.target)&&u(!1)},f=d=>{d.key==="Escape"&&u(!1)};return document.addEventListener("mousedown",c),document.addEventListener("keydown",f),()=>{document.removeEventListener("mousedown",c),document.removeEventListener("keydown",f)}},[a]),T.jsxs("div",{className:"flex items-center gap-2.5 text-[11px]",children:[t&&T.jsxs("span",{className:"flex items-center gap-1 text-[var(--color-text-secondary)]",children:[T.jsx(c0,{size:10,className:"animate-spin"}),"Working"]}),n.total>0&&T.jsxs("div",{className:"relative",ref:o,children:[T.jsxs("button",{onClick:()=>u(c=>!c),className:"flex items-center gap-1 text-[var(--color-text-muted)] hover:text-[var(--color-text-secondary)] transition-colors cursor-pointer",title:"View token usage breakdown",children:[T.jsx(o3,{size:10}),ene(n.total)," tokens"]}),a&&T.jsxs("div",{className:"absolute right-0 top-full mt-2 w-[340px] p-4 rounded-lg shadow-lg border border-[var(--color-border)] bg-[var(--color-surface-2)] z-50",children:[T.jsx("div",{className:"text-xs font-medium text-[var(--color-text)] mb-3",children:"Token Usage by Turn"}),T.jsx(Jte,{data:r,tokenUsage:n})]})]}),T.jsxs("span",{className:"flex items-center gap-1.5",children:[T.jsx("span",{className:`w-1.5 h-1.5 rounded-full ${e==="connected"?"bg-[var(--color-success)]":e==="error"?"bg-[var(--color-error)]":"bg-[var(--color-text-muted)]"}`}),T.jsx("span",{className:"text-[var(--color-text-muted)]",children:e==="connected"?"Connected":e==="connecting"?"Connecting":e==="error"?"Error":"Disconnected"})]})]})}function nne(e){const[t,n]=E.useState("tasks"),[r,a]=E.useState(!0);return T.jsxs("div",{className:"h-full flex flex-col bg-[var(--color-surface)]",children:[T.jsxs("header",{className:"flex items-center justify-between px-5 h-11 border-b border-[var(--color-border)] bg-[var(--color-surface)]",children:[T.jsxs("div",{className:"flex items-center gap-2.5",children:[e.config.icon_url?T.jsx("img",{src:e.config.icon_url,alt:"",className:"w-6 h-6 rounded-md object-cover"}):T.jsx("div",{className:"w-6 h-6 rounded-md bg-gradient-to-br from-[var(--color-primary)] to-[var(--color-primary-dark)] flex items-center justify-center",children:T.jsx(kC,{size:13,className:"text-white"})}),T.jsx("h1",{className:"text-sm font-semibold tracking-tight text-[var(--color-text)]",children:e.config.title}),e.config.subtitle&&T.jsx("span",{className:"text-[11px] text-[var(--color-text-muted)] hidden sm:inline border-l border-[var(--color-border)] pl-2.5",children:e.config.subtitle})]}),T.jsxs("div",{className:"flex items-center gap-2",children:[T.jsx(tne,{connectionStatus:e.connectionStatus,isStreaming:e.isStreaming,tokenUsage:e.tokenUsage,usageHistory:e.usageHistory}),T.jsx("div",{className:"w-px h-4 bg-[var(--color-border)]"}),T.jsx(d9,{initialTheme:e.config.theme}),T.jsx("button",{onClick:()=>a(u=>!u),className:"p-1 rounded hover:bg-[var(--color-surface-3)] transition-colors",title:r?"Hide sidebar":"Show sidebar",children:r?T.jsx(e3,{size:15,className:"text-[var(--color-text-secondary)]"}):T.jsx(t3,{size:15,className:"text-[var(--color-text-secondary)]"})})]})]}),T.jsx("div",{className:"flex-1 overflow-hidden",children:T.jsxs(Xp,{defaultSizes:[60,40],children:[T.jsx(Xp.Pane,{minSize:300,children:T.jsx($8,{messages:e.messages,isStreaming:e.isStreaming,welcomeMessage:e.config.welcome_message,agentName:e.config.agent_name,iconUrl:e.config.icon_url,onSend:e.onSend,onCancel:e.onCancel})}),T.jsx(Xp.Pane,{minSize:250,visible:r,children:T.jsxs("div",{className:"flex flex-col h-full bg-[var(--color-surface)]",children:[T.jsxs("div",{className:"flex items-center h-10 border-b border-[var(--color-border)]",children:[T.jsxs("button",{onClick:()=>n("tasks"),className:`flex items-center gap-1.5 px-4 h-full text-xs font-medium tracking-wide uppercase transition-colors border-b-2 ${t==="tasks"?"border-[var(--color-text)] text-[var(--color-text)]":"border-transparent text-[var(--color-text-muted)] hover:text-[var(--color-text-secondary)]"}`,children:[T.jsx(_C,{size:13}),"Tasks",e.todos.length>0&&T.jsx("span",{className:"ml-1 min-w-[16px] h-4 px-1 rounded-full bg-[var(--color-surface-3)] text-[10px] tabular-nums text-[var(--color-text-muted)] inline-flex items-center justify-center",children:e.todos.length})]}),T.jsxs("button",{onClick:()=>n("canvas"),className:`flex items-center gap-1.5 px-4 h-full text-xs font-medium tracking-wide uppercase transition-colors border-b-2 ${t==="canvas"?"border-[var(--color-text)] text-[var(--color-text)]":"border-transparent text-[var(--color-text-muted)] hover:text-[var(--color-text-secondary)]"}`,children:[T.jsx(JI,{size:13}),"Canvas",e.canvasItems.length>0&&T.jsx("span",{className:"ml-1 min-w-[16px] h-4 px-1 rounded-full bg-[var(--color-surface-3)] text-[10px] tabular-nums text-[var(--color-text-muted)] inline-flex items-center justify-center",children:e.canvasItems.length})]}),T.jsxs("button",{onClick:()=>n("files"),className:`flex items-center gap-1.5 px-4 h-full text-xs font-medium tracking-wide uppercase transition-colors border-b-2 ${t==="files"?"border-[var(--color-text)] text-[var(--color-text)]":"border-transparent text-[var(--color-text-muted)] hover:text-[var(--color-text-secondary)]"}`,children:[T.jsx(VI,{size:13}),"Files"]})]}),T.jsxs("div",{className:"flex-1 overflow-hidden",children:[t==="tasks"&&T.jsx(c9,{todos:e.todos}),t==="canvas"&&T.jsx(s9,{items:e.canvasItems,onDelete:e.onDeleteCanvasItem,onClearAll:e.onClearCanvas,onExport:e.onExportCanvas}),t==="files"&&(e.selectedFile?T.jsx(X8,{file:e.selectedFile,onClose:e.onCloseFile}):T.jsx(K8,{entries:e.fileEntries,expandedDirs:e.expandedDirs,loading:e.fileLoading,workspacePath:e.workspacePath,onToggleDir:e.onToggleDir,onOpenFile:e.onOpenFile,onEnterDir:e.onEnterDir,onUpload:e.onUpload,onCreateFolder:e.onCreateFolder,onDelete:e.onDeletePath}))]})]})})]})}),e.interrupt&&T.jsx(f9,{interrupt:e.interrupt,onRespond:e.onRespondInterrupt})]})}const rne={title:"Cowork Dash",subtitle:"AI-Powered Workspace",welcome_message:"",theme:"auto",workspace_name:"",agent_name:"Agent",icon_url:""};function ine(){const[e,t]=E.useState(rne),[n,r]=E.useState(!1);E.useEffect(()=>{fetch("/api/config").then(Y=>Y.json()).then(Y=>{t(Y),r(!0)}).catch(()=>{r(!0)})},[]);const{messages:a,isStreaming:u,interrupt:o,todos:c,tokenUsage:f,usageHistory:d,connectionStatus:m,fileChanges:p,sendMessage:y,respondToInterrupt:g,cancelStream:x}=lI(),{tree:w,selectedFile:S,expandedDirs:O,workspacePath:_,toggleDir:k,openFile:M,enterDir:N,uploadFile:C,createFolder:z,deletePath:$,setSelectedFile:H}=uI(p),{items:P,deleteItem:F,clearAll:I,exportMarkdown:ee}=oI(p),Z=E.useCallback(Y=>y(Y,{cwd:_}),[y,_]);return E.useEffect(()=>{document.title=e.title},[e.title]),n?T.jsx(nne,{config:e,messages:a,todos:c,isStreaming:u,interrupt:o,connectionStatus:m,tokenUsage:f,usageHistory:d,onSend:Z,onCancel:x,onRespondInterrupt:g,fileEntries:w.entries,fileLoading:w.loading,expandedDirs:O,selectedFile:S,workspacePath:_,onToggleDir:k,onOpenFile:M,onCloseFile:()=>H(null),onEnterDir:N,onUpload:C,onCreateFolder:z,onDeletePath:$,canvasItems:P,onDeleteCanvasItem:F,onClearCanvas:I,onExportCanvas:ee}):T.jsx("div",{className:"h-full flex items-center justify-center bg-[var(--color-surface)]",children:T.jsx("div",{className:"text-[var(--color-text-muted)]",children:"Loading..."})})}iI.createRoot(document.getElementById("root")).render(T.jsx(E.StrictMode,{children:T.jsx(ine,{})}));export{PF as $,vne as A,SY as B,ks as C,t_ as D,e_ as E,ZM as F,xb as G,lh as H,cV as I,sV as J,yu as K,oV as L,uV as M,pd as N,Ts as O,gb as P,vb as Q,Cn as R,Va as S,md as T,cb as U,XT as V,Lf as W,cd as X,fs as Y,c_ as Z,e9 as _,VT as a,G9 as a0,X9 as a1,K9 as a2,Y9 as a3,V9 as a4,F9 as a5,$9 as a6,Rd as a7,k9 as a8,_9 as a9,H9 as aa,q9 as ab,ab as b,U9 as c,UT as d,ut as e,cne as f,jr as g,AE as h,lne as i,une as j,one as k,PM as l,sne as m,dne as n,fne as o,du as p,P0 as q,ib as r,If as s,Pd as t,Tr as u,OF as v,N0 as w,lb as x,TM as y,zM as z};
